@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: AccrualBalanceFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3562 $
+ * $Id: AccrualBalanceFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -46,6 +46,64 @@ class AccrualBalanceFactory extends Factory {
 	protected $table = 'accrual_balance';
 	protected $pk_sequence_name = 'accrual_balance_id_seq'; //PK Sequence name
 
+	function _getFactoryOptions( $name ) {
+		$retval = NULL;
+		switch( $name ) {
+			case 'columns':
+				$retval = array(
+
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+
+										'-1030-accrual_policy' => TTi18n::gettext('Accrual Policy'),
+										'-1040-accrual_policy_type' => TTi18n::gettext('Accrual Policy Type'),
+										'-1050-balance' => TTi18n::gettext('Balance'),
+
+										'-1090-title' => TTi18n::gettext('Title'),
+										'-1099-group' => TTi18n::gettext('Group'),
+										'-1100-default_branch' => TTi18n::gettext('Branch'),
+										'-1110-default_department' => TTi18n::gettext('Department'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'accrual_policy',
+								'accrual_policy_type',
+								'balance'
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'user_id' => 'User',
+											'first_name' => FALSE,
+											'last_name' => FALSE,
+											'accrual_policy_id' => 'AccrualPolicyID',
+											'accrual_policy' => FALSE,
+											'accrual_policy_type_id' => FALSE,
+											'accrual_policy_type' => FALSE,
+											'default_branch' => FALSE,
+											'default_department' => FALSE,
+											'group' => FALSE,
+											'title' => FALSE,
+											'balance' => 'Balance',
+											);
+			return $variable_function_map;
+	}
+
 	function getUser() {
 		if ( isset($this->data['user_id']) ) {
 			return $this->data['user_id'];
@@ -204,5 +262,44 @@ class AccrualBalanceFactory extends Factory {
 		return TRUE;
 	}
 
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			$apf = new AccrualPolicyFactory();
+
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'accrual_policy':
+						case 'accrual_policy_type_id':
+						case 'first_name':
+						case 'last_name':
+						case 'title':
+						case 'group':
+						case 'default_branch':
+						case 'default_department':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'accrual_policy_type':
+							$data[$variable] = Option::getByKey( $this->getColumn( 'accrual_policy_type_id' ), $apf->getOptions( 'type' ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			//Accrual Balances are only created/modified by the system.
+			//$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 }
 ?>
