@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: AccrualFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: AccrualFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -49,7 +49,6 @@ class AccrualFactory extends Factory {
 
 
 	function _getFactoryOptions( $name ) {
-
 		$retval = NULL;
 		switch( $name ) {
 			case 'type':
@@ -66,12 +65,67 @@ class AccrualFactory extends Factory {
 										80 => TTi18n::gettext('Other')
 									);
 				break;
+			case 'columns':
+				$retval = array(
+
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+
+										'-1030-accrual_policy' => TTi18n::gettext('Accrual Policy'),
+										'-1040-type' => TTi18n::gettext('Type'),
+										'-1050-amount' => TTi18n::gettext('Amount'),
+										'-1060-time_stamp' => TTi18n::gettext('Date'),
+
+										'-1090-title' => TTi18n::gettext('Title'),
+										'-1099-group' => TTi18n::gettext('Group'),
+										'-1100-default_branch' => TTi18n::gettext('Branch'),
+										'-1110-default_department' => TTi18n::gettext('Department'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'accrual_policy',
+								'type',
+								'amount',
+								'time_stamp'
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_id' => 'User',
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'default_branch' => FALSE,
+										'default_department' => FALSE,
+										'group' => FALSE,
+										'title' => FALSE,
+										'accrual_policy_id' => 'AccrualPolicyID',
+										'accrual_policy' => FALSE,
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'user_date_total_id' => 'UserDateTotalID',
+										'time_stamp' => 'TimeStamp',
+										'amount' => 'Amount',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getUser() {
 		if ( isset($this->data['user_id']) ) {
@@ -344,6 +398,79 @@ class AccrualFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'time_stamp':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'accrual_policy':
+						case 'first_name':
+						case 'last_name':
+						case 'title':
+						case 'group':
+						case 'default_branch':
+						case 'default_department':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'time_stamp':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Accrual'), NULL, $this->getTable() );
 	}
