@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: CompanyFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3628 $
+ * $Id: CompanyFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 
 /**
@@ -480,7 +480,7 @@ class CompanyFactory extends Factory {
 														'LG' => TTi18n::gettext('La Guajira'),
 														'MA' => TTi18n::gettext('Magdalena'),
 														'ME' => TTi18n::gettext('Meta'),
-														'NA' => TTi18n::gettext('Nariño'),
+														'NA' => TTi18n::gettext('Narino'),
 														'NS' => TTi18n::gettext('Norte de Santander'),
 														'PU' => TTi18n::gettext('Putumayo'),
 														'QD' => TTi18n::gettext('Quindio'),
@@ -521,7 +521,7 @@ class CompanyFactory extends Factory {
 										'SV' => array(
 														'00' => '--',
 														'AH' => TTi18n::gettext('Ahuachapan'),
-														'CA' => TTi18n::gettext('Cabañas'),
+														'CA' => TTi18n::gettext('Cabanas'),
 														'CH' => TTi18n::gettext('Chalatenango'),
 														'CU' => TTi18n::gettext('Cuscatlan'),
 														'LI' => TTi18n::gettext('La Libertad'),
@@ -817,7 +817,90 @@ class CompanyFactory extends Factory {
 										'PG' => array( '00' => '--'),
 										'PY' => array( '00' => '--'),
 										'PE' => array( '00' => '--'),
-										'PH' => array( '00' => '--'),
+										'PH' => array(
+														'00' => '--',
+														'AB' => TTi18n::gettext('Abra'),
+														'AN' => TTi18n::gettext('Agusan del Norte'),
+														'AS' => TTi18n::gettext('Agusan del Sur'),
+														'AK' => TTi18n::gettext('Aklan'),
+														'AL' => TTi18n::gettext('Albay'),
+														'AQ' => TTi18n::gettext('Antique'),
+														'AP' => TTi18n::gettext('Apayao'),
+														'AU' => TTi18n::gettext('Aurora'),
+														'BS' => TTi18n::gettext('Basilan'),
+														'BA' => TTi18n::gettext('Bataan'),
+														'BN' => TTi18n::gettext('Batanes'),
+														'BT' => TTi18n::gettext('Batangas'),
+														'BG' => TTi18n::gettext('Benguet'),
+														'BI' => TTi18n::gettext('Biliran'),
+														'BO' => TTi18n::gettext('Bohol'),
+														'BK' => TTi18n::gettext('Bukidnon'),
+														'BU' => TTi18n::gettext('Bulacan'),
+														'CG' => TTi18n::gettext('Cagayan'),
+														'CN' => TTi18n::gettext('Camarines Norte'),
+														'CS' => TTi18n::gettext('Camarines Sur'),
+														'CM' => TTi18n::gettext('Camiguin'),
+														'CP' => TTi18n::gettext('Capiz'),
+														'CT' => TTi18n::gettext('Catanduanes'),
+														'CV' => TTi18n::gettext('Cavite'),
+														'CB' => TTi18n::gettext('Cebu'),
+														'CL' => TTi18n::gettext('Compostela Valley'),
+														'NC' => TTi18n::gettext('Cotabato'),
+														'DV' => TTi18n::gettext('Davao del Norte'),
+														'DS' => TTi18n::gettext('Davao del Sur'),
+														'DO' => TTi18n::gettext('Davao Oriental'),
+														'DI' => TTi18n::gettext('Dinagat Islands'),
+														'ES' => TTi18n::gettext('Eastern Samar'),
+														'GU' => TTi18n::gettext('Guimaras'),
+														'IF' => TTi18n::gettext('Ifugao'),
+														'IN' => TTi18n::gettext('Ilocos Norte'),
+														'IS' => TTi18n::gettext('Ilocos Sur'),
+														'II' => TTi18n::gettext('Iloilo'),
+														'IB' => TTi18n::gettext('Isabela'),
+														'KA' => TTi18n::gettext('Kalinga'),
+														'LG' => TTi18n::gettext('Laguna'),
+														'LN' => TTi18n::gettext('Lanao del Norte'),
+														'LS' => TTi18n::gettext('Lanao del Sur'),
+														'LU' => TTi18n::gettext('La Union'),
+														'LE' => TTi18n::gettext('Leyte'),
+														'MG' => TTi18n::gettext('Maguindanao'),
+														'MQ' => TTi18n::gettext('Marinduque'),
+														'MB' => TTi18n::gettext('Masbate'),
+														'MM' => TTi18n::gettext('Metropolitan Manila'),
+														'MD' => TTi18n::gettext('Misamis Occidental'),
+														'MN' => TTi18n::gettext('Misamis Oriental'),
+														'MT' => TTi18n::gettext('Mountain'),
+														'ND' => TTi18n::gettext('Negros Occidental'),
+														'NR' => TTi18n::gettext('Negros Oriental'),
+														'NS' => TTi18n::gettext('Northern Samar'),
+														'NE' => TTi18n::gettext('Nueva Ecija'),
+														'NV' => TTi18n::gettext('Nueva Vizcaya'),
+														'MC' => TTi18n::gettext('Occidental Mindoro'),
+														'MR' => TTi18n::gettext('Oriental Mindoro'),
+														'PL' => TTi18n::gettext('Palawan'),
+														'PM' => TTi18n::gettext('Pampanga'),
+														'PN' => TTi18n::gettext('Pangasinan'),
+														'QZ' => TTi18n::gettext('Quezon'),
+														'QR' => TTi18n::gettext('Quirino'),
+														'RI' => TTi18n::gettext('Rizal'),
+														'RO' => TTi18n::gettext('Romblon'),
+														'SM' => TTi18n::gettext('Samar'),
+														'SG' => TTi18n::gettext('Sarangani'),
+														'SQ' => TTi18n::gettext('Siquijor'),
+														'SR' => TTi18n::gettext('Sorsogon'),
+														'SC' => TTi18n::gettext('South Cotabato'),
+														'SL' => TTi18n::gettext('Southern Leyte'),
+														'SK' => TTi18n::gettext('Sultan Kudarat'),
+														'SU' => TTi18n::gettext('Sulu'),
+														'ST' => TTi18n::gettext('Surigao del Norte'),
+														'SS' => TTi18n::gettext('Surigao del Sur'),
+														'TR' => TTi18n::gettext('Tarlac'),
+														'TT' => TTi18n::gettext('Tawi-Tawi'),
+														'ZM' => TTi18n::gettext('Zambales'),
+														'ZN' => TTi18n::gettext('Zamboanga del Norte'),
+														'ZS' => TTi18n::gettext('Zamboanga del Sur'),
+														'ZY' => TTi18n::gettext('Zamboanga-Sibugay'),
+														),
 										'PN' => array( '00' => '--'),
 										'PL' => array( '00' => '--'),
 										'PT' => array( '00' => '--'),
@@ -960,12 +1043,95 @@ class CompanyFactory extends Factory {
 													),
 										);
 				break;
+			case 'ldap_authentication_type':
+				$retval = array(
+										0 => TTi18n::gettext('Disabled'),
+										1 => TTi18n::gettext('Enabled - w/Local Fallback'),
+										2 => TTi18n::gettext('Enabled - LDAP Only')
+									);
+				break;
+			case 'columns':
+				$retval = array(
+										'-1010-status' => TTi18n::gettext('Status'),
+										'-1030-name' => TTi18n::gettext('Name'),
+										'-1040-short_name' => TTi18n::gettext('Short Name'),
+										'-1050-business_number' => TTi18n::gettext('Business Number'),
 
+										'-1140-address1' => TTi18n::gettext('Address 1'),
+										'-1150-address2' => TTi18n::gettext('Address 2'),
+										'-1160-city' => TTi18n::gettext('City'),
+										'-1170-province' => TTi18n::gettext('Province/State'),
+										'-1180-country' => TTi18n::gettext('Country'),
+										'-1190-postal_code' => TTi18n::gettext('Postal Code'),
+										'-1200-work_phone' => TTi18n::gettext('Work Phone'),
+										'-1210-fax_phone' => TTi18n::gettext('Fax Phone'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'name',
+								'city',
+								'province',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								'country',
+								'province',
+								'postal_code'
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'parent_id' => 'Parent',
+											'status_id' => 'Status',
+											'product_edition_id' => 'ProductEdition',
+											'name' => 'Name',
+											'business_number' => 'BusinessNumber',
+											'originator_id' => 'OriginatorID',
+											'data_center_id' => 'DataCenterID',
+											'short_name' => 'ShortName',
+											'address1' => 'Address1',
+											'address2' => 'Address2',
+											'city' => 'City',
+											'country' => 'Country',
+											'province' => 'Province',
+											'postal_code' => 'PostalCode',
+											'work_phone' => 'WorkPhone',
+											'fax_phone' => 'FaxPhone',
+											'admin_contact' => 'AdminContact',
+											'billing_contact' => 'BillingContact',
+											'support_contact' => 'SupportContact',
+											'enable_second_last_name' => 'EnableSecondLastName',
+											'ldap_authentication_type_id' => 'LDAPAuthenticationType',
+											'ldap_host' => 'LDAPHost',
+											'ldap_port' => 'LDAPPort',
+											'ldap_bind_user_name' => 'LDAPBindUserName',
+											'ldap_bind_password' => 'LDAPBindPassword',
+											'ldap_base_dn' => 'LDAPBaseDN',
+											'ldap_bind_attribute' => 'LDAPBindAttribute',
+											'ldap_user_filter' => 'LDAPUserFilter',
+											'ldap_login_attribute' => 'LDAPLoginAttribute',
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
 
 	function getParent() {
 		return $this->data['parent_id'];
@@ -1656,6 +1822,232 @@ class CompanyFactory extends Factory {
 		return FALSE;
 	}
 
+
+	/*
+		LDAP Authentication functions
+	*/
+	function getLDAPAuthenticationType() {
+		if ( isset($this->data['ldap_authentication_type_id']) ) {
+			return $this->data['ldap_authentication_type_id'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPAuthenticationType($type) {
+		$type = trim($type);
+
+		if ( $this->Validator->inArrayKey(	'ldap_authentication_type_id',
+											$type,
+											TTi18n::gettext('Incorrect LDAP authentication type'),
+											$this->getOptions('ldap_authentication_type')) ) {
+
+			$this->data['ldap_authentication_type_id'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPHost() {
+		if ( isset($this->data['ldap_host']) ) {
+			return $this->data['ldap_host'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPHost($value) {
+		$value = trim($value);
+
+		if 	(	$value == ''
+				OR
+				$this->Validator->isLength(		'ldap_host',
+												$value,
+												TTi18n::gettext('LDAP server host name is too short or too long'),
+												2,
+												100) ) {
+
+			$this->data['ldap_host'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPPort() {
+		if ( isset($this->data['ldap_port']) ) {
+			return $this->data['ldap_port'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPPort($value) {
+		$value = $this->Validator->stripNonNumeric( trim($value) );
+
+		//Allow setting a blank employee number, so we can use Validate() to check employee number against the status_id
+		//To allow terminated employees to have a blank employee number, but active ones always have a number.
+		if (
+				$value == ''
+				OR (
+					$this->Validator->isNumeric(	'ldap_port',
+													$value,
+													TTi18n::gettext('LDAP port must only be digits'))
+					)
+												) {
+			$this->data['ldap_port'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPBindUserName() {
+		if ( isset($this->data['ldap_bind_user_name']) ) {
+			return $this->data['ldap_bind_user_name'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPBindUserName($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_bind_user_name',
+												$value,
+												TTi18n::gettext('LDAP bind user name is too long'),
+												0,
+												100) ) {
+
+			$this->data['ldap_bind_user_name'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPBindPassword() {
+		if ( isset($this->data['ldap_bind_password']) ) {
+			return $this->data['ldap_bind_password'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPBindPassword($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_bind_password',
+												$value,
+												TTi18n::gettext('LDAP bind password is too long'),
+												0,
+												100) ) {
+
+			$this->data['ldap_bind_password'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPBaseDN() {
+		if ( isset($this->data['ldap_base_dn']) ) {
+			return $this->data['ldap_base_dn'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPBaseDN($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_base_dn',
+												$value,
+												TTi18n::gettext('LDAP base DN is too long'),
+												0,
+												250) ) {
+
+			$this->data['ldap_base_dn'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPBindAttribute() {
+		if ( isset($this->data['ldap_bind_attribute']) ) {
+			return $this->data['ldap_bind_attribute'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPBindAttribute($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_bind_attribute',
+												$value,
+												TTi18n::gettext('LDAP bind attribute is too long'),
+												0,
+												100) ) {
+
+			$this->data['ldap_bind_attribute'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPUserFilter() {
+		if ( isset($this->data['ldap_user_filter']) ) {
+			return $this->data['ldap_user_filter'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPUserFilter($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_user_filter',
+												$value,
+												TTi18n::gettext('LDAP user filter is too long'),
+												0,
+												250) ) {
+
+			$this->data['ldap_user_filter'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getLDAPLoginAttribute() {
+		if ( isset($this->data['ldap_login_attribute']) ) {
+			return $this->data['ldap_login_attribute'];
+		}
+
+		return FALSE;
+	}
+	function setLDAPLoginAttribute($value) {
+		$value = trim($value);
+
+		if 	(	$this->Validator->isLength(		'ldap_login_attribute',
+												$value,
+												TTi18n::gettext('LDAP login attribute is too long'),
+												0,
+												100) ) {
+
+			$this->data['ldap_login_attribute'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+
 	function Validate() {
 																																				$obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); }
 		return TRUE;
@@ -1799,6 +2191,61 @@ class CompanyFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			//Disable this for now, as if a master administrator is editing other companies it will cause an error.
+			//$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Company Information'), NULL, $this->getTable() );
 	}
