@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: CurrencyFactory.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2740 $
+ * $Id: CurrencyFactory.class.php 2740 2009-08-19 20:21:50Z ipso $
+ * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
  */
 
 /**
@@ -289,12 +302,71 @@ class CurrencyFactory extends Factory {
 										'ZW' => 'ZWD',
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1000-status' => TTi18n::gettext('Status'),
+										'-1010-name' => TTi18n::gettext('Name'),
+										'-1020-iso_code' => TTi18n::gettext('ISO Code'),
+										'-1030-conversion_rate' => TTi18n::gettext('Conversion Rate'),
+										'-1040-auto_update' => TTi18n::gettext('Auto Update'),
+										'-1050-actual_rate' => TTi18n::gettext('Actual Rate'),
+										'-1060-actual_rate_updated_date' => TTi18n::gettext('Last Downloaded Date'),
+										'-1070-rate_modify_percent' => TTi18n::gettext('Rate Modify Percent'),
+										'-1080-is_default' => TTi18n::gettext('Default Currency'),
+										'-1090-is_base' => TTi18n::gettext('Base Currency'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'name',
+								'iso_code',
+								'conversion_rate',
+								'is_default',
+								'is_base',
+								'created_by',
+								'created_date',
+								'updated_by',
+								'updated_date',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'name',
+								'is_default',
+								'is_base',
+								);
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'name' => 'Name',
+										'iso_code' => 'ISOCode',
+										'conversion_rate' => 'ConversionRate',
+										'auto_update' => 'AutoUpdate',
+										'actual_rate' => 'ActualRate',
+										'actual_rate_updated_date' => 'ActualRateUpdatedDate',
+										'rate_modify_percent' => 'RateModifyPercent',
+										'is_default' => 'Default',
+										'is_base' => 'Base',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getISOCodesArray() {
 		return TTi18n::getCurrencyArray();
@@ -481,7 +553,10 @@ class CurrencyFactory extends Factory {
 		//Pull out only digits and periods.
 		$value = $this->Validator->stripNonFloat($value);
 
-		if (	$this->Validator->isFloat(	'actual_rate',
+		//Ignore any boolean values passed in to this function.
+		if (	is_numeric( $value )
+				AND
+				$this->Validator->isFloat(	'actual_rate',
 											$value,
 											TTi18n::gettext('Incorrect Actual Rate')) ) {
 
@@ -575,7 +650,7 @@ class CurrencyFactory extends Factory {
 		if 	(
 				$bool == TRUE
 				AND
-				$this->Validator->isTrue(		'default',
+				$this->Validator->isTrue(		'is_default',
 												$this->isUniqueDefault(),
 												TTi18n::gettext('There is already a default currency set')
 												)
@@ -619,7 +694,7 @@ class CurrencyFactory extends Factory {
 		if 	(
 				$bool == TRUE
 				AND
-				$this->Validator->isTrue(		'base',
+				$this->Validator->isTrue(		'is_base',
 												$this->isUniqueBase(),
 												TTi18n::gettext('There is already a base currency set')
 												)
@@ -638,7 +713,7 @@ class CurrencyFactory extends Factory {
 	function getSymbol(){
 		return TTi18n::getCurrencySymbol( $this->getISOCode() );
 	}
-	
+
 	static function convert( $src_rate, $dst_rate, $amount ) {
 		$base_amount = bcmul( bcdiv(1, $src_rate), $amount );
 		$retval = bcmul( $dst_rate, $base_amount, 2);
@@ -760,6 +835,36 @@ class CurrencyFactory extends Factory {
 		return FALSE;
 	}
 
+	function Validate() {
+
+		if ( $this->getDeleted() == TRUE ){
+			//CHeck to make sure currency isnt in-use by paystubs/employees/wages, if so, don't delete.
+			$invalid = FALSE;
+
+			$pslf = new PayStubListFactory();
+			$pslf->getByCurrencyId( $this->getId() );
+			if ( $pslf->getRecordCount() > 0 ) {
+				$invalid = TRUE;
+			}
+
+			if ( $invalid == FALSE ) {
+				$ulf = new UserListFactory();
+				$ulf->getByCurrencyId( $this->getId() );
+				if ( $ulf->getRecordCount() > 0 ) {
+					$invalid = TRUE;
+				}
+			}
+
+			if ( $invalid == TRUE ) {
+				$this->Validator->isTRUE(	'in_use',
+											FALSE,
+											TTi18n::gettext('This currency is in use'));
+			}
+		}
+
+		return TRUE;
+	}
+
 	function preSave() {
 		if ( $this->getBase() == TRUE ) {
 			$this->setConversionRate( '1.00' );
@@ -776,6 +881,73 @@ class CurrencyFactory extends Factory {
 		return TRUE;
 	}
 
+	//Support setting created_by,updated_by especially for importing data.
+	//Make sure data is set based on the getVariableToFunctionMap order.
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		/*
+		 $include_columns = array(
+								'id' => TRUE,
+								'company_id' => TRUE,
+								...
+								)
+
+		*/
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+						//case 'country_currency':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Currency').': '. $this->getISOCode() .' '.  TTi18n::getText('Rate').': '. $this->getConversionRate(), NULL, $this->getTable() );
 	}
