@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: ExceptionFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: ExceptionFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -71,11 +71,88 @@ class ExceptionFactory extends Factory {
 										70 => TTi18n::gettext('Corrected')
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1000-first_name' => TTi18n::gettext('First Name'),
+										'-1002-last_name' => TTi18n::gettext('Last Name'),
+										//'-1005-user_status' => TTi18n::gettext('Employee Status'),
+										'-1010-title' => TTi18n::gettext('Title'),
+										'-1039-group' => TTi18n::gettext('Group'),
+										'-1040-default_branch' => TTi18n::gettext('Default Branch'),
+										'-1050-default_department' => TTi18n::gettext('Default Department'),
+										'-1160-branch' => TTi18n::gettext('Branch'),
+										'-1170-department' => TTi18n::gettext('Department'),
+
+										'-1040-date_stamp' => TTi18n::gettext('Date'),
+										'-1050-severity' => TTi18n::gettext('Severity'),
+										'-1060-exception_policy_type' => TTi18n::gettext('Exception'),
+										'-1070-exception_policy_type_id' => TTi18n::gettext('Code'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'date_stamp',
+								'severity',
+								'exception_policy_type',
+								'exception_policy_type_id',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'user_date_id' => 'UserDateID',
+											'date_stamp' => FALSE,
+											'exception_policy_id' => 'ExceptionPolicyID',
+											'punch_control_id' => 'PunchControlID',
+											'punch_id' => 'PunchID',
+											'type_id' => 'Type',
+											'type' => FALSE,
+											'severity_id' => FALSE,
+											'severity' => FALSE,
+											'exception_color' => 'Color',
+											'exception_background_color' => 'BackgroundColor',
+											'exception_policy_type_id' => FALSE,
+											'exception_policy_type' => FALSE,
+											//'enable_demerit' => 'EnableDemerits',
+
+											'user_id' => FALSE,
+											'first_name' => FALSE,
+											'last_name' => FALSE,
+											'user_status_id' => FALSE,
+											'user_status' => FALSE,
+											'group_id' => FALSE,
+											'group' => FALSE,
+											'title_id' => FALSE,
+											'title' => FALSE,
+											'default_branch_id' => FALSE,
+											'default_branch' => FALSE,
+											'default_department_id' => FALSE,
+											'default_department' => FALSE,
+
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
 
 	function getUserDateObject() {
 		if ( is_object($this->user_date_obj) ) {
@@ -255,22 +332,46 @@ class ExceptionFactory extends Factory {
 		return TRUE;
 	}
 
-	function getColor() {
-		$retval = FALSE;
-
+	function getBackgroundColor() {
+		//Use HTML color codes so they work in Flex too.
 		if (  $this->getType() == 5 ) {
-			$retval = "gray";
+			$retval = '#666666'; #'gray';
 		} else {
 			if ( $this->getColumn('severity_id') != '' ) {
 				switch ( $this->getColumn('severity_id') ) {
 					case 10:
-						$retval = 'black';
+						$retval = FALSE;
 						break;
 					case 20:
-						$retval = 'blue';
+						$retval = '#FFFF00'; #'yellow';
 						break;
 					case 30:
-						$retval = 'red';
+						$retval = '#FF0000'; #'red';
+						break;
+				}
+			}
+		}
+
+		return $retval;
+	}
+
+	function getColor() {
+		$retval = FALSE;
+
+		//Use HTML color codes so they work in Flex too.
+		if (  $this->getType() == 5 ) {
+			$retval = '#666666'; #'gray';
+		} else {
+			if ( $this->getColumn('severity_id') != '' ) {
+				switch ( $this->getColumn('severity_id') ) {
+					case 10:
+						$retval = '#000000'; #'black';
+						break;
+					case 20:
+						$retval = '#0000FF'; #'blue';
+						break;
+					case 30:
+						$retval = '#FF0000'; #'red';
 						break;
 				}
 			}
@@ -311,26 +412,29 @@ class ExceptionFactory extends Factory {
 
 				//Make sure supervisor email notifcations are enabled
 				if ( $ep_obj->getEmailNotification() == 20 OR $ep_obj->getEmailNotification() == 100 ) {
-					//Find supervisor
+					//Find supervisor(s)
 					$hlf = new HierarchyListFactory();
 					$parent_user_id = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $u_obj->getCompany(), $u_obj->getId(), 80 );
 					if ( $parent_user_id != FALSE ) {
+						//Parent could be multiple supervisors, make sure we email them all.
 						$ulf = new UserListFactory();
-						$ulf->getById( $parent_user_id );
+						$ulf->getByIdAndCompanyId( $parent_user_id, $u_obj->getCompany() );
 						if ( $ulf->getRecordCount() > 0 ) {
-							$parent_user_obj = $ulf->getCurrent();
+							foreach( $ulf as $parent_user_obj ) {
+								//$parent_user_obj = $ulf->getCurrent();
 
-							if ( is_object( $parent_user_obj->getUserPreferenceObject() ) AND $parent_user_obj->getUserPreferenceObject()->getEnableEmailNotificationException() == TRUE ) {
-								Debug::Text(' Emailing exception to supervisor!', __FILE__, __LINE__, __METHOD__,10);
-								if ( $parent_user_obj->getWorkEmail() != '' ) {
-									$retarr[] = $parent_user_obj->getWorkEmail();
-								}
+								if ( is_object( $parent_user_obj->getUserPreferenceObject() ) AND $parent_user_obj->getUserPreferenceObject()->getEnableEmailNotificationException() == TRUE ) {
+									Debug::Text(' Emailing exception to supervisor!', __FILE__, __LINE__, __METHOD__,10);
+									if ( $parent_user_obj->getWorkEmail() != '' ) {
+										$retarr[] = $parent_user_obj->getWorkEmail();
+									}
 
-								if ( $up_obj->getEnableEmailNotificationHome() == TRUE AND $parent_user_obj->getHomeEmail() != '' ) {
-									$retarr[] = $parent_user_obj->getHomeEmail();
+									if ( $up_obj->getEnableEmailNotificationHome() == TRUE AND $parent_user_obj->getHomeEmail() != '' ) {
+										$retarr[] = $parent_user_obj->getHomeEmail();
+									}
+								} else {
+									Debug::Text(' Skipping email to supervisor.', __FILE__, __LINE__, __METHOD__,10);
 								}
-							} else {
-								Debug::Text(' Skipping email to supervisor.', __FILE__, __LINE__, __METHOD__,10);
 							}
 						}
 					} else {
@@ -466,5 +570,88 @@ class ExceptionFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+
+		$epf = new ExceptionPolicyFactory();
+		$exception_policy_type_options = $epf->getOptions('type');
+		$exception_policy_severity_options = $epf->getOptions('severity');
+
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'user_id':
+						case 'first_name':
+						case 'last_name':
+						case 'user_status_id':
+						case 'group_id':
+						case 'group':
+						case 'title_id':
+						case 'title':
+						case 'default_branch_id':
+						case 'default_branch':
+						case 'default_department_id':
+						case 'default_department':
+						case 'severity_id':
+						case 'exception_policy_type_id':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'severity':
+							$data[$variable] = Option::getByKey( $this->getColumn( 'severity_id' ), $exception_policy_severity_options );
+							break;
+						case 'exception_policy_type':
+							$data[$variable] = Option::getByKey( $this->getColumn( 'exception_policy_type_id' ), $exception_policy_type_options );
+							break;
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'date_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::strtotime( $this->getColumn( 'date_stamp' ) ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 }
 ?>
