@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2372 $
- * $Id: ExceptionListFactory.class.php 2372 2009-01-22 08:04:55Z ipso $
- * $Date: 2009-01-22 00:04:55 -0800 (Thu, 22 Jan 2009) $
+ * $Revision: 3562 $
+ * $Id: ExceptionListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -222,7 +222,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 
 		$query = '
 					select 	d.severity_id as severity_id,
-							count(*) as count
+							count(*) as total
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
 					LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
@@ -231,7 +231,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 					where
 						b.user_id = ?
 						AND a.type_id = 50
-						AND b.date_stamp < ?
+						AND b.date_stamp <= ?
 						AND e.status_id = ?
 						AND NOT EXISTS ( select z.id from '. $rf->getTable() .' as z where z.user_date_id = a.user_date_id AND z.status_id = 30 )
 						AND ( a.deleted = 0 AND b.deleted = 0 AND e.deleted=0)
@@ -820,7 +820,219 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 		*/
 
 		$query .= 	'
-						AND ( a.deleted = 0 AND c.deleted = 0 AND h.deleted = 0 )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND h.deleted = 0 )
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('d.name', 'e.name', 'f.name', 'g.name', 'h.status_id','i.severity_id','i.type_id','c.first_name','c.last_name', 'b.date_stamp');
+		if ( $order == NULL ) {
+			//$order = array( 'status_id' => 'asc', 'last_name' => 'asc', 'first_name' => 'asc', 'middle_name' => 'asc');
+			$order = array( 'i.severity_id' => 'desc', 'c.last_name' => 'asc', 'b.date_stamp' => 'asc', 'i.type_id' => 'asc' );
+
+			$strict = FALSE;
+		} else {
+			//Do order by column conversions, because if we include these columns in the SQL
+			//query, they contaminate the data array.
+			if ( isset($order['default_branch']) ) {
+				$order['d.name'] = $order['default_branch'];
+				unset($order['default_branch']);
+			}
+			if ( isset($order['default_department']) ) {
+				$order['e.name'] = $order['default_department'];
+				unset($order['default_department']);
+			}
+			if ( isset($order['user_group']) ) {
+				$order['f.name'] = $order['user_group'];
+				unset($order['user_group']);
+			}
+			if ( isset($order['title']) ) {
+				$order['g.name'] = $order['title'];
+				unset($order['title']);
+			}
+			if ( isset($order['exception_policy_type_id']) ) {
+				$order['i.type_id'] = $order['exception_policy_type_id'];
+				unset($order['exception_policy_type_id']);
+			}
+			if ( isset($order['severity_id']) ) {
+				$order['i.severity_id'] = $order['severity_id'];
+				unset($order['severity_id']);
+			}
+			if ( isset($order['severity']) ) {
+				$order['i.severity_id'] = $order['severity'];
+				unset($order['severity']);
+			}
+			if ( isset($order['exception_policy_type']) ) {
+				$order['i.type_id'] = $order['exception_policy_type'];
+				unset($order['exception_policy_type']);
+			}
+			if ( isset($order['exception_policy_type_id']) ) {
+				$order['i.type_id'] = $order['exception_policy_type_id'];
+				unset($order['exception_policy_type_id']);
+			}
+
+			if ( isset($order['first_name']) ) {
+				$order['c.first_name'] = $order['first_name'];
+				unset($order['first_name']);
+			}
+			if ( isset($order['last_name']) ) {
+				$order['c.last_name'] = $order['last_name'];
+				unset($order['last_name']);
+			}
+			if ( isset($order['date_stamp']) ) {
+				$order['b.date_stamp'] = $order['date_stamp'];
+				unset($order['date_stamp']);
+			}
+
+			//Always sort by last name,first name after other columns
+			if ( !isset($order['c.last_name']) ) {
+				$order['c.last_name'] = 'asc';
+			}
+			if ( !isset($order['c.first_name']) ) {
+				$order['c.first_name'] = 'asc';
+			}
+			if ( !isset($order['b.date_stamp']) ) {
+				$order['b.date_stamp'] = 'asc';
+			}
+			if ( !isset($order['i.severity_id']) ) {
+				$order['i.severity_id'] = 'desc';
+			}
+
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$udf = new UserDateFactory();
+		$uf = new UserFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$ppf = new PayPeriodFactory();
+		$epf = new ExceptionPolicyFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							b.date_stamp as date_stamp,
+							i.severity_id as severity_id,
+							i.type_id as exception_policy_type_id,
+							b.user_id as user_id,
+
+							c.first_name as first_name,
+							c.last_name as last_name,
+							c.status_id as user_status_id,
+							c.group_id as group_id,
+							f.name as group,
+							c.title_id as title_id,
+							g.name as title,
+							c.default_branch_id as default_branch_id,
+							d.name as default_branch,
+							c.default_department_id as default_department_id,
+							e.name as default_department,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+						LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
+						LEFT JOIN '. $bf->getTable() .' as d ON c.default_branch_id = d.id
+						LEFT JOIN '. $df->getTable() .' as e ON c.default_department_id = e.id
+						LEFT JOIN '. $ugf->getTable() .' as f ON c.group_id = f.id
+						LEFT JOIN '. $utf->getTable() .' as g ON c.title_id = g.id
+						LEFT JOIN '. $ppf->getTable() .' as h ON b.pay_period_id = h.id
+						LEFT JOIN '. $epf->getTable() .' as i ON a.exception_policy_id = i.id
+
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	c.company_id = ?
+					';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND c.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND c.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND c.id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND c.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['severity_id']) AND isset($filter_data['severity_id'][0]) AND !in_array(-1, (array)$filter_data['severity_id']) ) {
+			$query  .=	' AND i.severity_id in ('. $this->getListSQL($filter_data['severity_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exception_policy_type_id']) AND isset($filter_data['exception_policy_type_id'][0]) AND !in_array(-1, (array)$filter_data['exception_policy_type_id']) ) {
+			$query  .=	' AND i.type_id in ('. $this->getListSQL($filter_data['exception_policy_type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query  .=	' AND b.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_status_id']) AND isset($filter_data['pay_period_status_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_status_id']) ) {
+			$query  .=	' AND h.status_id in ('. $this->getListSQL($filter_data['pay_period_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND c.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND c.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND c.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND c.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['start_date']);
+			$query  .=	' AND b.date_stamp >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['end_date']);
+			$query  .=	' AND b.date_stamp <= ?';
+		}
+
+
+		$query .= 	'
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND h.deleted = 0 )
 					';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
