@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: Factory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3562 $
+ * $Id: Factory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -443,7 +443,7 @@ abstract class Factory {
 		if ( isset($data['created_by_id']) AND is_numeric($data['created_by_id']) AND $data['created_by_id'] > 0 ) {
 			$this->setCreatedBy( $data['created_by_id'] );
 		}
-		if ( isset($data['created_date']) AND $data['created_date'] != FALSE ) {
+		if ( isset($data['created_date']) AND $data['created_date'] != FALSE AND $data['created_date'] != '' ) {
 			$this->setCreatedDate( TTDate::parseDateTime( $data['created_date'] ) );
 		}
 
@@ -453,7 +453,7 @@ abstract class Factory {
 		if ( isset($data['updated_by_id']) AND is_numeric($data['updated_by_id']) AND $data['updated_by_id'] > 0 ) {
 			$this->setUpdatedBy( $data['updated_by_id'] );
 		}
-		if ( isset($data['updated_date']) AND $data['created_date'] != FALSE ) {
+		if ( isset($data['updated_date']) AND $data['updated_date'] != FALSE AND $data['updated_date'] != '' ) {
 			$this->setUpdatedDate( TTDate::parseDateTime( $data['updated_date'] ) );
 		}
 
@@ -879,6 +879,9 @@ abstract class Factory {
 			$id = -1;
 		}
 
+		//Possible errors can happen if $this->data[<invalid_column>] is passed, like what happens with APIPunch when attempting to delete a punch.
+		//Why are we not using '*' for all empty record set queries? Will using * cause more fields to be updated then necessary?
+		//Yes, it will, as well the updated_by/updated_date fields aren't controllable by getColumnList() then either.
 		$column_list = $this->getColumnList();
 		if ( is_array($column_list) ) {
 			//Implode columns.
@@ -888,25 +891,6 @@ abstract class Factory {
 		}
 
 		try {
-/*
-			//Cache_Lite fails when caching this query.
-			$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
-			//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
-			if ( $id == -1 ) {
-				$cache_id = md5($this->getTable().$column_str.$id);
-
-				$rs = $this->getCache($cache_id);
-				if ( $rs === FALSE ) {
-					$rs = $this->db->Execute($query);
-
-					$this->saveCache($rs, $cache_id);
-				}
-			} else {
-				$rs = $this->db->Execute($query);
-			}
-			Debug::Arr($rs, 'getEmptyRecordSet() RS:' , __FILE__, __LINE__, __METHOD__,9);
-*/
 			$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
 			//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
 
@@ -1065,8 +1049,13 @@ abstract class Factory {
 			//Insert
 			$time = TTDate::getTime();
 
-			$this->setCreatedDate($time);
-			$this->setCreatedBy();
+			if ( $this->getCreatedDate() == '' ) {
+				Debug::text('Current Created Date: '. $this->getCreatedDate() .' Setting new one...' , __FILE__, __LINE__, __METHOD__,10);
+				$this->setCreatedDate($time);
+			}
+			if ( $this->getCreatedBy() == '' ) {
+				$this->setCreatedBy();
+			}
 
 			//Set updated date at the same time, so we can easily select last
 			//updated, or last created records.
