@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: FastTree.class.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 3562 $
+ * $Id: FastTree.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /*
@@ -355,7 +355,7 @@ class FastTree {
 		return $child_id;
 	}
 
-	function getAllChildren( $object_id = NULL, $recurse = FALSE ) {
+	function getAllChildren( $object_id = NULL, $recurse = FALSE, $data_format = 0 ) {
 		$original_object_id = $object_id;
 		//Debug::Text(' Object ID: '. $object_id .' Recurse: '. $recurse , __FILE__, __LINE__, __METHOD__,10);
 
@@ -382,9 +382,6 @@ class FastTree {
 				FROM		'. $this->table .' a
 				LEFT JOIN '. $this->table .' b ON a.tree_id = b.tree_id AND a.left_id BETWEEN b.left_id AND b.right_id
 				';
-//				LEFT JOIN 	'. $this->table .' b ON b.left_id < a.left_id AND b.right_id > a.right_id
-//				LEFT JOIN '. $this->table .' b ON a.left_id BETWEEN b.left_id AND b.right_id
-//				LEFT JOIN '. $this->table .' b ON a.left_id BETWEEN b.left_id AND b.right_id
 		switch (strtoupper($recurse)) {
 			case 'RECURSE':
 				$ph = array(
@@ -401,10 +398,7 @@ class FastTree {
 					AND 	b.left_id > ?
 					AND		b.right_id <= ?';
 
-				//Why is this here?
-				//To exclude the parent?
-				//SHould we ever do that?
-				//Yes, but only when the passed object is forsure NULL!
+				//Exclude the parnet, but only when the passed object is forsure NULL!
 				if ( $original_object_id === NULL OR $original_object_id === FALSE ) {
 					$ph['object_id'] = $object_id;
 
@@ -432,7 +426,11 @@ class FastTree {
 		$rs = $this->db->Execute($query, $ph);
 
 		while ( $row = $rs->FetchRow() ) {
-			$retarr[$row['object_id']] = $row['level'];
+			if ( $data_format == 1 ) {
+				$retarr[$row['object_id']] = $row;
+			} else {
+				$retarr[$row['object_id']] = $row['level'];
+			}
 		}
 
 		if ( isset($retarr) ) {
@@ -746,12 +744,12 @@ class FastTree {
 	function move( $object_id, $parent_id ) {
 		Debug::Text(' Object ID: '. $object_id .' Parent ID: '. $parent_id , __FILE__, __LINE__, __METHOD__,10);
 
-		if ( $object_id == '') {
+		if ( $object_id === '' ) {
 			Debug::Text(' aReturning False...' , __FILE__, __LINE__, __METHOD__,10);
 			return FALSE;
 		}
 
-		if ( $parent_id == '') {
+		if ( $parent_id === '' ) {
 			Debug::Text(' bReturning False...' , __FILE__, __LINE__, __METHOD__,10);
 			return FALSE;
 		}
@@ -842,6 +840,62 @@ class FastTree {
 
 	}
 
+	//Flex requires that all index keys start at 0, even in the children section,
+	//So we need to handle that as well so Flex doesn't need any post processing.
+	static function FormatFlexArray( $nodes, $include_root = TRUE ) {
+		Debug::Text(' Formatting Flex Array...' , __FILE__, __LINE__, __METHOD__,10);
+		$nested = array();
+		$depths = array();
+
+		if ( is_array($nodes) ) {
+			foreach( $nodes as $key => $node ) {
+				if( $node['level'] == 1 ) {
+
+					//Using sequential keys
+					$nested[] = $node; //Each new branch of the tree the key should start at 0 and be a sequence without holes.
+					end($nested);
+					$depths[$node['level'] + 1] = key($nested);
+
+					/*
+					//Using non-sequential keys:
+					$nested[$key] = $node;
+					$depths[$node['level'] + 1] = $key;
+					*/
+				} else {
+					$parent =& $nested;
+					for( $i = 2; $i <= $node['level']; $i++ ) {
+						if ( $i == 2 ) {
+							$parent =& $parent[$depths[$i]];
+						} else {
+							$parent =& $parent['children'][$depths[$i]];
+						}
+					}
+
+					//Using sequential keys.
+					$parent['children'][] = $node; //Each new branch of the tree the key should start at 0 and be a sequence without holes.
+					end($parent['children']);
+					$depths[$node['level'] + 1] = key($parent['children']);
+
+					/*
+					//Using non-sequential keys:
+					$parent['children'][$key] = $node;
+					$depths[$node['level'] + 1] = $key;
+					*/
+				}
+			}
+		}
+
+		if ( $include_root == TRUE ) {
+			return array( 0 => array( 	'id' => 0,
+										'name' => TTi18n::getText('Root'),
+										'level' => 0,
+										'children' => $nested )
+										);
+		} else {
+			return $nested;
+		}
+	}
+
 	static function FormatArray($nodes, $type = 'HTML', $include_root = FALSE) {
 		$type = strtolower($type);
 
