@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: Misc.class.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: Misc.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -401,7 +401,7 @@ class Misc {
 	static function getBeforeDecimal($float) {
 		$float = Misc::MoneyFormat( $float, FALSE );
 
-		$float_array = split('\.', $float);
+		$float_array = preg_split('/\./', $float);
 
 		if ( isset($float_array[0]) ) {
 			return $float_array[0];
@@ -415,7 +415,7 @@ class Misc {
 			$float = Misc::MoneyFormat( $float, FALSE );
 		}
 
-		$float_array = split('\.', $float);
+		$float_array = preg_split('/\./', $float);
 
 		if ( isset($float_array[1]) ) {
 			return str_pad($float_array[1],2,'0');
