@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2816 $
- * $Id: PermissionFactory.class.php 2816 2009-09-14 23:03:18Z ipso $
- * $Date: 2009-09-14 16:03:18 -0700 (Mon, 14 Sep 2009) $
+ * $Revision: 3562 $
+ * $Id: PermissionFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -747,6 +747,7 @@ class PermissionFactory extends Factory {
 																//'view_shift_amendment_summary' => TTi18n::gettext('Shift Amendment Summary'),
 																'view_timesheet_summary' => TTi18n::gettext('Timesheet Summary'),
 																'view_accrual_balance_summary' => TTi18n::gettext('Accrual Balance Summary'),
+																'view_schedule_summary' => TTi18n::gettext('Schedule Summary'),
 																'view_punch_summary' => TTi18n::gettext('Punch Summary'),
 																'view_remittance_summary' => TTi18n::gettext('Remittance Summary'),
 																//'view_branch_summary' => TTi18n::gettext('Branch Summary'),
@@ -1541,6 +1542,7 @@ class PermissionFactory extends Factory {
 																'view_user_information' => TRUE,
 																'view_user_detail' => TRUE,
 																'view_timesheet_summary' => TRUE,
+																'view_schedule_summary' => TRUE,
 																'view_punch_summary' => TRUE,
 																'view_accrual_balance_summary' => TRUE,
 																'view_user_barcode' => TRUE,
