@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2570 $
- * $Id: StationFactory.class.php 2570 2009-05-28 21:29:33Z ipso $
- * $Date: 2009-05-28 14:29:33 -0700 (Thu, 28 May 2009) $
+ * $Revision: 3060 $
+ * $Id: StationFactory.class.php 3060 2009-11-13 16:08:37Z ipso $
+ * $Date: 2009-11-13 08:08:37 -0800 (Fri, 13 Nov 2009) $
  */
 include_once('Net/IPv4.php');
 
@@ -59,9 +72,9 @@ class StationFactory extends Factory {
 					$retval[40]	= TTi18n::gettext('Barcode');
 					$retval[50]	= TTi18n::gettext('FingerPrint');
 					$retval[100] = TTi18n::gettext('TimeClock: TT-A8');
-					$retval[110] = TTi18n::gettext('TimeClock: TT-F4');
+					//$retval[110] = TTi18n::gettext('TimeClock: TT-F4');
 					$retval[120] = TTi18n::gettext('TimeClock: TT-S300');
-					$retval[200] = TTi18n::gettext('TimeClock: ACTAtek');
+					//$retval[200] = TTi18n::gettext('TimeClock: ACTAtek');
 				}
 				break;
 			case 'station_reserved_word':
@@ -110,6 +123,7 @@ class StationFactory extends Factory {
 										604800 => TTi18n::gettext('1 Week'),
 									);
 				break;
+			case 'partial_push_frequency':
 			case 'push_frequency':
 				$retval = array(
 										60 => TTi18n::gettext('1 Minute'),
@@ -147,14 +161,113 @@ class StationFactory extends Factory {
 				$retval = array(
 										1 =>  TTi18n::gettext('-- Default --'),
 										2 =>  TTi18n::gettext('Must Select In/Out Status'),
-										4 =>  TTi18n::gettext('Enable Work Code (Mode 1)'),
-										8 =>  TTi18n::gettext('Enable Work Code (Mode 2)'),
+										//4 =>  TTi18n::gettext('Enable Work Code (Mode 1)'),
+										//8 =>  TTi18n::gettext('Enable Work Code (Mode 2)'),
+										4 =>  TTi18n::gettext('Disable Out Status'),
+										8 =>  TTi18n::gettext('Enable Breaks'),
+										16 =>  TTi18n::gettext('Enable Lunches'),
+										32  => TTi18n::gettext('Enable: Branch'),
+										64  => TTi18n::gettext('Enable: Department'),
 									);
+				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+					$retval[128]  = TTi18n::gettext('Enable: Job');
+					$retval[256] = TTi18n::gettext('Enable: Task');
+					$retval[512] = TTi18n::gettext('Enable: Quantity');
+					$retval[1024] = TTi18n::gettext('Enable: Bad Quantity');
+				}
+
+				break;
+
+			case 'columns':
+				$retval = array(
+										'-1010-status' => TTi18n::gettext('Status'),
+										'-1020-type' => TTi18n::gettext('Type'),
+										'-1030-source' => TTi18n::gettext('Source'),
+
+										'-1140-station_id' => TTi18n::gettext('Station'),
+										'-1150-description' => TTi18n::gettext('Description'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'type',
+								'source',
+								'station_id',
+								'description',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'station_id',
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array();
+				break;
+
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'station_id' => 'Station',
+										'source' => 'Source',
+										'description' => 'Description',
+										'branch_id' => 'DefaultBranch',
+										'department_id' => 'DefaultDepartment',
+										'time_zone' => 'TimeZone',
+										'user_group_selection_type_id' => 'GroupSelectionType',
+										'group_selection_type' => FALSE,
+										'group' => FALSE,
+										'branch_selection_type_id' => 'BranchSelectionType',
+										'branch_selection_type' => FALSE,
+										'branch' => FALSE,
+										'department_selection_type_id' => 'DepartmentSelectionType',
+										'department_selection_type' => FALSE,
+										'department' => FALSE,
+										'include_user' => FALSE,
+										'exclude_user' => FALSE,
+										'port' => 'Port',
+										'user_name' => 'UserName',
+										'password' => 'Password',
+										'poll_frequency' => 'PollFrequency',
+										'push_frequency' => 'PushFrequency',
+										'partial_push_frequency' => 'PartialPushFrequency',
+										'enable_auto_punch_status' => 'EnableAutoPunchStatus',
+										'mode_flag' => 'ModeFlag',
+										'work_code_definition' => 'WorkCodeDefinition',
+										'last_punch_time_stamp' => 'LastPunchTimeStamp',
+										'last_poll_date' => 'LastPollDate',
+										'last_poll_status_message' => 'LastPollStatusMessage',
+										'last_push_date' => 'LastPushDate',
+										'last_push_status_message' => 'LastPushStatusMessage',
+										'last_partial_push_date' => 'LastPartialPushDate',
+										'last_partial_push_status_message' => 'LastPartialPushStatusMessage',
+										'user_value_1' => 'UserValue1',
+										'user_value_2' => 'UserValue2',
+										'user_value_3' => 'UserValue3',
+										'user_value_4' => 'UserValue4',
+										'user_value_5' => 'UserValue5',
+										'allowed_date' => 'AllowedDate',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	 }
+
 	function getCompanyObject() {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
@@ -369,9 +482,9 @@ class StationFactory extends Factory {
 		if (
 				$id == 0
 				OR
-				$this->Validator->isResultSetWithRows(	'default_branch',
+				$this->Validator->isResultSetWithRows(	'branch_id',
 														$blf->getByID($id),
-														TTi18n::gettext('Invalid Default Branch')
+														TTi18n::gettext('Invalid Branch')
 													) ) {
 
 			$this->data['branch_id'] = $id;
@@ -398,9 +511,9 @@ class StationFactory extends Factory {
 		if (
 				$id == 0
 				OR
-				$this->Validator->isResultSetWithRows(	'default_department',
+				$this->Validator->isResultSetWithRows(	'department_id',
 														$dlf->getByID($id),
-														TTi18n::gettext('Invalid Default Department')
+														TTi18n::gettext('Invalid Department')
 													) ) {
 
 			$this->data['department_id'] = $id;
@@ -411,6 +524,76 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 
+	function getDefaultJob() {
+		if ( isset($this->data['job_id']) ) {
+			return (int)$this->data['job_id'];
+		}
+
+		return FALSE;
+	}
+	function setDefaultJob($id) {
+		$id = trim($id);
+
+		if ( $id == FALSE OR $id == 0 OR $id == '' ) {
+			$id = 0;
+		}
+
+		Debug::Text('Job ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jlf = new JobListFactory();
+		}
+
+		if (
+				$id == 0
+				OR
+				$this->Validator->isResultSetWithRows(	'job_id',
+														$jlf->getByID($id),
+														TTi18n::gettext('Invalid Job')
+													) ) {
+
+			$this->data['job_id'] = $id;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getDefaultJobItem() {
+		if ( isset($this->data['job_item_id']) ) {
+			return (int)$this->data['job_item_id'];
+		}
+
+		return FALSE;
+	}
+	function setDefaultJobItem($id) {
+		$id = trim($id);
+
+		if ( $id == FALSE OR $id == 0 OR $id == '' ) {
+			$id = 0;
+		}
+
+		Debug::Text('Job Item ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jilf = new JobItemListFactory();
+		}
+
+		if (
+				$id == 0
+				OR
+				$this->Validator->isResultSetWithRows(	'job_item_id',
+														$jilf->getByID($id),
+														TTi18n::gettext('Invalid Task')
+													) ) {
+
+			$this->data['job_item_id'] = $id;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getTimeZone() {
 		if ( isset($this->data['time_zone']) ) {
 			return $this->data['time_zone'];
@@ -482,12 +665,13 @@ class StationFactory extends Factory {
 	function setGroup($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new StationUserGroupListFactory();
 				$lf_a->getByStationId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getGroup();
 					Debug::text('Group ID: '. $obj->getGroup() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -569,13 +753,15 @@ class StationFactory extends Factory {
 	}
 	function setBranch($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
+		Debug::Arr($ids, 'IDs: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new StationBranchListFactory();
 				$lf_a->getByStationId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getBranch();
 					Debug::text('Branch ID: '. $obj->getBranch() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -658,12 +844,13 @@ class StationFactory extends Factory {
 	function setDepartment($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new StationDepartmentListFactory();
 				$lf_a->getByStationId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getDepartment();
 					Debug::text('Department ID: '. $obj->getDepartment() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -723,12 +910,13 @@ class StationFactory extends Factory {
 	function setIncludeUser($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new StationIncludeUserListFactory();
 				$lf_a->getByStationId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getIncludeUser();
 					Debug::text('IncludeUser ID: '. $obj->getIncludeUser() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -787,12 +975,13 @@ class StationFactory extends Factory {
 	function setExcludeUser($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new StationExcludeUserListFactory();
 				$lf_a->getByStationId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getExcludeUser();
 					Debug::text('ExcludeUser ID: '. $obj->getExcludeUser() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -924,7 +1113,9 @@ class StationFactory extends Factory {
 	function setPollFrequency($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'poll_frequency',
+		if (	$value == 0
+				OR
+				$this->Validator->inArrayKey(	'poll_frequency',
 											$value,
 											TTi18n::gettext('Incorrect Download Frequency'),
 											$this->getOptions('poll_frequency')) ) {
@@ -948,10 +1139,12 @@ class StationFactory extends Factory {
 	function setPushFrequency($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'push_frequency',
-											$value,
-											TTi18n::gettext('Incorrect Upload Frequency'),
-											$this->getOptions('push_frequency')) ) {
+		if ( 	$value == 0
+				OR
+				$this->Validator->inArrayKey(	'push_frequency',
+												$value,
+												TTi18n::gettext('Incorrect Upload Frequency'),
+												$this->getOptions('push_frequency')) ) {
 
 			$this->data['push_frequency'] = $value;
 
@@ -971,7 +1164,9 @@ class StationFactory extends Factory {
 	function setPartialPushFrequency($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'partial_push_frequency',
+		if ( $value == 0
+			OR
+			$this->Validator->inArrayKey(	'partial_push_frequency',
 											$value,
 											TTi18n::gettext('Incorrect Partial Upload Frequency'),
 											$this->getOptions('push_frequency')) ) {
@@ -1047,7 +1242,7 @@ class StationFactory extends Factory {
 
 		return $retarr;
 	}
-
+/*
 	function getWorkCodeDefinition() {
 		if ( isset($this->data['work_code_definition']) ) {
 			return unserialize( $this->data['work_code_definition'] );
@@ -1056,6 +1251,10 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setWorkCodeDefinition($arr) {
+		if ( $arr == FALSE ) {
+			return TRUE;
+		}
+
 		$arr = Misc::preSetArrayValues( $arr, array('branch', 'department', 'job', 'job_item'), 0);
 
 		if ( is_array( $arr )
@@ -1071,7 +1270,7 @@ class StationFactory extends Factory {
 
 		return FALSE;
 	}
-
+*/
 	function getLastPunchTimeStamp( $raw = FALSE) {
 		if ( isset($this->data['last_punch_time_stamp']) ) {
 			if ( $raw === TRUE ) {
@@ -1569,22 +1768,22 @@ class StationFactory extends Factory {
 			global $current_user;
 			$user_id = $current_user->getId();
 		}
-		Debug::text('User ID: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('User ID: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 
 		if ($current_station_id == NULL OR $current_station_id == ''){
 			global $current_station;
 			$current_station_id = $current_station->getStation();
 		}
-		Debug::text('Station ID: '. $current_station_id, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Station ID: '. $current_station_id, __FILE__, __LINE__, __METHOD__, 10);
 
-		Debug::text('Status: '. $this->getStatus(), __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Status: '. $this->getStatus(), __FILE__, __LINE__, __METHOD__, 10);
 		if ( $this->getStatus() != 20 ) { //Enabled
 			return FALSE;
 		}
 
 		$retval = FALSE;
 
-		Debug::text('Current Station: '. $this->getStation() , __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('User ID: '. $user_id .' Station ID: '. $current_station_id .' Status: '. $this->getStatus() .' Current Station: '. $this->getStation() , __FILE__, __LINE__, __METHOD__, 10);
 
 		//Handle IP Addresses/Hostnames
 		if ( $this->getType() == 10
@@ -1613,7 +1812,7 @@ class StationFactory extends Factory {
 			$retval = $this->checkSource( $source, $current_station_id );
 		}
 
-		Debug::text('Retval: '. (int)$retval, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Retval: '. (int)$retval, __FILE__, __LINE__, __METHOD__, 10);
 		//Debug::text('Current Station ID: '. $current_station_id .' Station ID: '. $this->getStation(), __FILE__, __LINE__, __METHOD__, 10);
 
 		if ( $retval === TRUE ) {
@@ -1660,10 +1859,10 @@ class StationFactory extends Factory {
 				return FALSE;
 			}
 		}
-		Debug::text('Station ID: '. $station_id, __FILE__, __LINE__, __METHOD__, 10);
 
 		$slf = new StationListFactory();
 		$slf->getByUserIdAndStatusAndType($user_id, 'ENABLED', $type);
+		Debug::text('Station ID: '. $station_id .' Type: '. $type .' Found Stations: '. $slf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		foreach($slf as $station) {
 			Debug::text('Checking Station ID: '. $station->getId(), __FILE__, __LINE__, __METHOD__, 10);
 
@@ -1704,6 +1903,100 @@ class StationFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'group':
+							$this->setGroup( $data[$key] );
+							break;
+						case 'branch':
+							$this->setBranch( $data[$key] );
+							break;
+						case 'department':
+							$this->setDepartment( $data[$key] );
+							break;
+						case 'include_user':
+							$this->setIncludeUser( $data[$key] );
+							break;
+						case 'exclude_user':
+							$this->setExcludeUser( $data[$key] );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+						case 'type':
+/*
+						case 'branch_selection_type':
+						case 'department_selection_type':
+						case 'group_selection_type':
+						case 'poll_frequency':
+						case 'push_frequency':
+						case 'time_clock_command':
+						case 'mode_flag':
+*/
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'group':
+							$data[$variable] = $this->getGroup();
+							break;
+						case 'branch':
+							$data[$variable] = $this->getBranch();
+							break;
+						case 'department':
+							$data[$variable] = $this->getDepartment();
+							break;
+						case 'include_user':
+							$data[$variable] = $this->getIncludeUser();
+							break;
+						case 'exclude_user':
+							$data[$variable] = $this->getExcludeUser();
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Station'), NULL, $this->getTable() );
 	}
