@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: TTDate.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: TTDate.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -112,7 +112,7 @@ class TTDate {
 		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		//Default to system local timezone if no timezone is specified.
-		if ( $time_zone == '' ) {
+		if ( $time_zone == '' OR strtolower($time_zone) == 'system/localtime' ) { //System/Localtime is an invalid timezone, so default to GMT instead.
 			if ( isset($config_vars['other']['system_timezone']) ) {
 				$time_zone = $config_vars['other']['system_timezone'];
 			} else {
@@ -478,7 +478,7 @@ class TTDate {
 					$time_result = preg_replace( $date_pattern, '', $str );
 					$formatted_date = $tmp_date .' '. $time_result;
 				} else {
-					Debug::text('  Custom Date Match Failed... Falling back to strtotime', __FILE__, __LINE__, __METHOD__, 10);
+					Debug::text('  Custom Date Match Failed... Falling back to strtotime. Date String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
 				}
 			}
 		}
@@ -689,82 +689,13 @@ class TTDate {
 
 	public static function doesRangeSpanDST( $start_epoch, $end_epoch ) {
 		Debug::text('Start Epoch: '. TTDate::getDate('DATE+TIME', $start_epoch) .'  End Epoch: '. TTDate::getDate('DATE+TIME', $end_epoch), __FILE__, __LINE__, __METHOD__, 10);
-		$dst_epochs = self::getDSTEpoch($start_epoch);
-
-		if ( $dst_epochs !== FALSE ) {
-			if ($start_epoch <= $dst_epochs['start'] AND $end_epoch >= $dst_epochs['start']
-					OR $start_epoch <= $dst_epochs['end'] AND $end_epoch >= $dst_epochs['end'] ) {
-
-				return TRUE;
-			}
+		if ( date('I', $start_epoch) != date('I', $end_epoch) ) {
+			return TRUE;
 		}
 
 		return FALSE;
 	}
 
-	public static function getDSTepoch($epoch = NULL) {
-		if ($epoch == NULL OR $epoch == '') {
-			$epoch = self::getTime();
-		}
-
-		if ( strtolower( self::$time_zone ) == 'gmt' ) {
-			return FALSE;
-		}
-
-		/*
-
-			Daylight Saving Time begins for most of the United States at 2 a.m. on the first Sunday of April.
-            Time reverts to standard time at 2 a.m. on the last Sunday of October. In the U.S.,
-            each time zone switches at a different time.
-
-			In the European Union, Summer Time begins and ends at 1 am Universal Time (Greenwich Mean Time).
-            It starts the last Sunday in March, and ends the last Sunday in October.
-            In the EU, all time zones change at the same moment.
-
-		*/
-
-		$epoch = mktime(0,0,0,4,1,date('Y', $epoch));
-
-        //Lets try to make PHP do as much work as possible. So we know DST always happens between 1am and 2am on specific days.
-		$first_sunday_in_april = strtotime('This Sunday', $epoch ) + 3600;
-		Debug::text('Epoch of first Sunday in April: '. $first_sunday_in_april .' - '. TTDate::getDate('DATE+TIME', $first_sunday_in_april) , __FILE__, __LINE__, __METHOD__, 10);
-
-		if ( date('I', $first_sunday_in_april) == 1) { //1am
-			Debug::text('Found european DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-			$dst_start = $first_sunday_in_april;
-		} elseif (date('I', ($first_sunday_in_april + 3600) ) == 1 ) { //2am
-			Debug::text('Found US DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-			$dst_start = $first_sunday_in_april + 3599;
-		} else {
-			Debug::text('Failed to find DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-			$dst_start = FALSE;
-		}
-		Debug::text('DST Start '. $dst_start .' - '. TTDate::getDate('DATE+TIME', $dst_start) , __FILE__, __LINE__, __METHOD__, 10);
-		unset($first_sunday_in_april);
-
-		$epoch = mktime(0,0,0,4,1,date('Y', $epoch));
-
-		//Find DST end
-		$epoch = mktime(0,0,0,11,1,date('Y', $epoch));
-
-		$last_sunday_in_oct = strtotime('Last Sunday', $epoch );
-		Debug::text('Epoch of last Sunday in Oct: '. $last_sunday_in_oct .' - '. TTDate::getDate('DATE+TIME', $last_sunday_in_oct) , __FILE__, __LINE__, __METHOD__, 10);
-
-		if ( date('I', $last_sunday_in_oct) == 0) { //1am
-			Debug::text('Found european DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-			$dst_end = $last_sunday_in_oct;
-		} elseif (date('I', ($last_sunday_in_oct + 3600) ) == 0 ) { //2am
-			Debug::text('Found US DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-			$dst_end = $last_sunday_in_oct + 3599;
-		} else {
-			Debug::text('Failed to find DST boundary', __FILE__, __LINE__, __METHOD__, 10);
-		}
-		Debug::text('DST End '. $dst_end .' - '. TTDate::getDate('DATE+TIME', $dst_end) , __FILE__, __LINE__, __METHOD__, 10);
-		unset($last_sunday_in_oct);
-
-		return array('start' => $dst_start, 'end' => $dst_end);
-	}
-
 	public static function getTime() {
 		return time();
 	}
@@ -1195,7 +1126,7 @@ class TTDate {
 		return TTDate::getBeginDayEpoch( $retval );
 	}
 
-	public static function getDateOfNextYear( $anchor_epoch ) {
+	public static function getDateOfNextYear( $anchor_epoch, $year_epoch ) {
 		//Anchor Epoch is the anchor date to start searching from.
 		//Day of year epoch is the epoch we use to extract the day of the year from.
 		Debug::text('-------- ', __FILE__, __LINE__, __METHOD__,10);
@@ -1210,7 +1141,7 @@ class TTDate {
 							date('s', $anchor_epoch ),
 							date('m', $anchor_epoch ),
 							date('j', $anchor_epoch ),
-							date('Y', $anchor_epoch )+1
+							date('Y', $year_epoch )
 							);
 
 		Debug::text('Retval: '. TTDate::getDate('DATE+TIME', $retval), __FILE__, __LINE__, __METHOD__,10);
@@ -1258,7 +1189,7 @@ class TTDate {
 
 		$retval = mktime(0,0,0,date("m",$epoch),( date("j", $epoch) - $offset) ,date("Y",$epoch) );
 
-		Debug::text(' Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' Retval: '. TTDate::getDate('DATE+TIME', $retval) .' Start Day of Week: '. $start_day_of_week .' Offset: '. $offset, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::text(' Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' Retval: '. TTDate::getDate('DATE+TIME', $retval) .' Start Day of Week: '. $start_day_of_week .' Offset: '. $offset, __FILE__, __LINE__, __METHOD__,10);
 		return $retval;
 	}
 
@@ -1404,6 +1335,47 @@ class TTDate {
 		return $start_days;
 	}
 
+	function getNearestWeekDay( $epoch, $type = 0, $exclude_epochs = array() ) {
+		Debug::Text('Epoch: '. TTDate::getDate('DATE+TIME', $epoch ) .' Type: '. $type, __FILE__, __LINE__, __METHOD__, 10);
+
+		while( TTDate::isWeekDay($epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $epoch ), $exclude_epochs) ) {
+			Debug::text('<b>FOUND WeekDay/HOLIDAY!</b>', __FILE__, __LINE__, __METHOD__, 10);
+			switch ( $type ) {
+				case 0: //No adjustment
+					break 2;
+				case 1: //Previous day
+					$epoch -= 86400;
+					break;
+				case 2: //Next day
+					$epoch += 86400;
+					break;
+				case 3: //Closest day
+					$forward_epoch = $epoch;
+					$forward_days = 0;
+					while( TTDate::isWeekDay($forward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $forward_epoch ), $exclude_epochs) ) {
+						$forward_epoch += 86400;
+						$forward_days++;
+					}
+
+					$backward_epoch = $epoch;
+					$backward_days = 0;
+					while( TTDate::isWeekDay($backward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $backward_epoch ), $exclude_epochs) ) {
+						$backward_epoch -= 86400;
+						$backward_days++;
+					}
+
+					if ( $backward_days <= $forward_days ) {
+						$epoch = $backward_epoch;
+					} else {
+						$epoch = $forward_epoch;
+					}
+					break;
+			}
+		}
+
+		return $epoch;
+	}
+
 	//Loop from filter start date to end date. Creating an array entry for each day.
 	function getCalendarArray($start_date, $end_date, $start_day_of_week = 0, $force_weeks = TRUE) {
 		if ( $start_date == '' OR $end_date == '' ) {
@@ -1442,9 +1414,7 @@ class TTDate {
 		//Causes infinite loop without it.
 		//Don't add 7200 to Cal End Date because that could cause more then one
 		//week to be displayed.
-
-		//for($i=$cal_start_date; $i <= $cal_end_date; $i+=86400) {
-		//for($i=$cal_start_date; $i <= ($cal_end_date+7200); $i+=93600) {
+		$retarr = array();
 		for($i=$cal_start_date; $i <= ($cal_end_date); $i+=93600) {
 			if ( $x > 200 ) {
 				break;
@@ -1453,7 +1423,6 @@ class TTDate {
 			$i = TTDate::getBeginDayEpoch($i);
 
 			$current_month = date('n', $i);
-			//$current_week = date('W', $i);
 			$current_day_of_week = date('w', $i);
 
 			if ( $current_month != $prev_month AND $i >= $start_date ) {
@@ -1462,7 +1431,6 @@ class TTDate {
 				$isNewMonth = FALSE;
 			}
 
-			//if ( $current_week != $prev_week ) {
 			if ( $current_day_of_week == $start_day_of_week ) {
 				$isNewWeek = TRUE;
 			} else {
@@ -1496,7 +1464,6 @@ class TTDate {
 							);
 
 			$prev_month = $current_month;
-			//$prev_week = $current_week;
 
 			//Debug::text('i: '. $i .' Date: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__,10);
 			$x++;
@@ -1574,6 +1541,7 @@ class TTDate {
 					2.   |-------------------------|
 		3. |-----------------------|
 		4. |------------------------------------------|
+		5.    |-----------------------| (match exactly)
 
 		*/
 		if 	( ($start_date2 >= $start_date1 AND $end_date2 <= $end_date1) ) { //Case #1
@@ -1606,6 +1574,12 @@ class TTDate {
 			return TRUE;
 		}
 
+		if 	( ($start_date2 == $start_date1 AND $end_date2 == $end_date1) ) { //Case #5
+			//Debug::text(' Overlap on Case #5: ', __FILE__, __LINE__, __METHOD__,10);
+
+			return TRUE;
+		}
+
 		return FALSE;
 	}
 
