@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: TTi18n.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3349 $
+ * $Id: TTi18n.class.php 3349 2010-02-10 17:38:41Z ipso $
+ * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
  */
 
 /*
@@ -512,8 +512,8 @@ class TTi18n {
 		//asort($retarr);
 
 		// Return supported languages only.
-		$supported_langs = array( 'en', 'es', 'fr', 'de', 'it', 'pt', 'da' );
-		$beta_langs = array( 'es','fr','de','it','pt', 'da' );
+		$supported_langs = array( 'en', 'es', 'fr', 'de', 'it', 'pt', 'da', 'zh' );
+		$beta_langs = array( 'es','fr','de','it','pt', 'da', 'zh' );
 
 		$retarr2 = array();
 		foreach( $supported_langs as $language ) {
@@ -642,7 +642,8 @@ class TTi18n {
 								'uz' => 'uz_UZ',	// Uzbek	Uzbekistan
 								'vi' => 'vi_VN',	// Vietnamese	Vietnam
 								'wa' => 'wa_BE',	// Walloon	Belgium
-								'we' => 'wen_DE'	// Sorbian	Germany
+								'we' => 'wen_DE',	// Sorbian	Germany
+								'zh' => 'zh_CN',	// Chinese Simplified
 								);
 
 		$lang = trim(substr($locale,0,2));
@@ -939,11 +940,13 @@ class NativeGettextTranslationHandler implements TranslationHandler {
 		//Because apparently LC_ALL doesn't matter on some Unix, it still doesn't set LC_MESSAGES.
 		//So if we didn't explicity set LC_MESSAGES above, do it here.
 		if ( OPERATING_SYSTEM == 'LINUX' ) {
-			$rc = setlocale( LC_MESSAGES, $locale );
+			$rc = setlocale( LC_MESSAGES, $locale.'.UTF-8' );
 
+			/* This often reports failure even if it works.
 			if ( $rc == 0 ) {
 				Debug::text('setLocale failed!: '. (int)$rc .' Locale: '. $locale, __FILE__, __LINE__, __METHOD__,10);
 			}
+			*/
 		}
 
 		// Normally, setting env var(s) would not be necessary, but I18Nv2
