@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: UserDateFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3349 $
+ * $Id: UserDateFactory.class.php 3349 2010-02-10 17:38:41Z ipso $
+ * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
  */
 
 /**
@@ -337,7 +337,7 @@ class UserDateFactory extends Factory {
 	function postSave() {
 		$this->removeCache( $this->getId() );
 
-		Debug::Text('Post Save... Deleted: '. (int)$this->getDeleted(), __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('Post Save... Deleted: '. (int)$this->getDeleted(), __FILE__, __LINE__, __METHOD__,10);
 
 		//Delete punch control/schedules assigned to this.
 		if ( $this->getDeleted() == TRUE ) {
@@ -362,6 +362,16 @@ class UserDateFactory extends Factory {
 				}
 			}
 
+			//Delete exceptions
+			$elf = new ExceptionListFactory();
+			$elf->getByUserDateID( $this->getId() );
+			if ( $elf->getRecordCount() > 0 ) {
+				foreach( $elf as $e_obj ) {
+					$e_obj->setDeleted(TRUE);
+					$e_obj->Save();
+				}
+			}
+
 			//Delete user_date_total rows too
 			$udtlf = new UserDateTotalListFactory();
 			$udtlf->getByUserDateID( $this->getId() );
