@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3091 $
- * $Id: HierarchyListFactory.class.php 3091 2009-11-18 18:00:31Z ipso $
- * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
+ * $Revision: 3562 $
+ * $Id: HierarchyListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -392,7 +392,7 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 								x.user_id,
 								x.level,
 								0 as is_subordinate
-						from	'. $hlf->getTable() .' as x
+						from 	'. $hlf->getTable() .' as x
 						LEFT JOIN '. $hcf->getTable() .' as y ON x.hierarchy_control_id = y.id
 						LEFT JOIN '. $hotf->getTable() .' as y2 ON x.hierarchy_control_id = y2.hierarchy_control_id
 						LEFT JOIN '. $hlf->getTable() .' as z ON x.hierarchy_control_id = z.hierarchy_control_id AND z.user_id = '. (int)$user_id .'
@@ -412,7 +412,7 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 									where z.hierarchy_control_id = n.hierarchy_control_id AND z.deleted = 0
 								) as level,
 								1 as is_subordinate
-						from	'. $huf->getTable() .' as n
+						from 	'. $huf->getTable() .' as n
 						LEFT JOIN '. $hcf->getTable() .' as o ON n.hierarchy_control_id = o.id
 						LEFT JOIN '. $hotf->getTable() .' as p ON n.hierarchy_control_id = p.hierarchy_control_id
 						LEFT JOIN '. $hlf->getTable() .' as z ON n.hierarchy_control_id = z.hierarchy_control_id AND z.user_id = '. (int)$user_id .'
@@ -430,18 +430,17 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 		//Debug::Text(' Rows: '. $rs->RecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $rs->RecordCount() > 0 ) {
-
-			//The first row should belong to the user_id that was passed.
 			$current_level = $level;
 			$i=0;
 			foreach( $rs as $row ) {
 				//Debug::Text(' User ID: '. $row['user_id'] .' Level: '. $row['level'] .' Sub: '. $row['is_subordinate'] .' Current Level: '. $current_level, __FILE__, __LINE__, __METHOD__,10);
 				if (  $row['level'] == $current_level AND $row['is_subordinate'] == 0 ) {
-					//First row.
 					$retarr['current_level'][] = $row['user_id'];
 				} elseif ( $row['level'] < $current_level AND $row['is_subordinate'] == 0 ) {
 					$retarr['parent_level'][] = $row['user_id'];
-				} elseif ( $row['level'] > $current_level ) {
+				} elseif ( $row['level'] > $current_level AND $row['is_subordinate'] == 1 ) {
+					//Only ever show suborindates at child levels, this fixes the bug where the currently logged in user would see their own requests
+					//in the authorization list.
 					$retarr['child_level'][] = $row['user_id'];
 				} else {
 					//Debug::Text(' Skipping row...', __FILE__, __LINE__, __METHOD__,10);
@@ -463,7 +462,117 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 		return FALSE;
 	}
 
-	function getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $company_id, $user_id, $object_type_id = 100, $immediate_parent_only = TRUE, $include_levels = TRUE ) {
+	function getByUserIdAndObjectTypeIDAndLevelAndHierarchyControlIDs( $user_id, $object_type_id, $level = 1, $hierarchy_control_ids, $recursive = TRUE ) {
+		if ( $user_id == '' ) {
+			return FALSE;
+		}
+
+		if ( !is_numeric($level) ) {
+			return FALSE;
+		}
+
+		$min_level = $level-1;
+		if ( $min_level <= 0 ) {
+			$min_level = 0;
+		}
+
+		//This should have two modes, one where it returns just the immediate child level, and one that returns all children "recursively".
+		if ( $recursive == TRUE ) {
+			$max_level = 99;
+		} else {
+			$max_level = $level+1;
+		}
+		Debug::Text(' User ID: '. $user_id .' Object Type ID: '. $object_type_id .' Level: '. $level .' Min Level: '. $min_level .' Max Level: '. $max_level, __FILE__, __LINE__, __METHOD__,10);
+
+		$retarr = array( 'current_level' => array(), 'parent_level' => array(), 'child_level' => array() );
+
+		$hcf = new HierarchyControlFactory();
+		$hlf = new HierarchyLevelFactory();
+		$huf = new HierarchyUserFactory();
+		$hotf = new HierarchyObjectTypeFactory();
+
+		$ph = array();
+
+		//UNION two queries together, the first query gets all superiors, one level above, and all levels below.
+		//The 2nd query gets all subordinates.
+		$query = '
+				select * from  (
+						select 	x.hierarchy_control_id,
+								x.user_id,
+								x.level,
+								0 as is_subordinate
+						from 	'. $hlf->getTable() .' as x
+						LEFT JOIN '. $hcf->getTable() .' as y ON x.hierarchy_control_id = y.id
+						LEFT JOIN '. $hotf->getTable() .' as y2 ON x.hierarchy_control_id = y2.hierarchy_control_id
+						LEFT JOIN '. $hlf->getTable() .' as z ON x.hierarchy_control_id = z.hierarchy_control_id AND z.user_id = '. (int)$user_id .'
+						where
+							y2.object_type_id in ('. $this->getListSQL($object_type_id, $ph) .')
+							AND x.level >= z.level-1
+							AND ( x.deleted = 0 AND y.deleted = 0 AND z.deleted = 0 )
+
+						UNION ALL
+
+						select
+								n.hierarchy_control_id,
+								n.user_id,
+								(
+									select max(level)+1
+									from '. $hlf->getTable() .' as z
+									where z.hierarchy_control_id = n.hierarchy_control_id AND z.deleted = 0
+								) as level,
+								1 as is_subordinate
+						from 	'. $huf->getTable() .' as n
+						LEFT JOIN '. $hcf->getTable() .' as o ON n.hierarchy_control_id = o.id
+						LEFT JOIN '. $hotf->getTable() .' as p ON n.hierarchy_control_id = p.hierarchy_control_id
+						LEFT JOIN '. $hlf->getTable() .' as z ON n.hierarchy_control_id = z.hierarchy_control_id AND z.user_id = '. (int)$user_id .'
+						where
+							p.object_type_id in ('. $this->getListSQL($object_type_id, $ph) .')
+							AND ( o.deleted = 0 AND z.deleted = 0 )
+					) as tmp
+					WHERE
+						hierarchy_control_id in ('. $this->getListSQL($hierarchy_control_ids, $ph) .')
+						AND ( level >= '. (int)$min_level .' AND level <= '. (int)$max_level.' )
+					ORDER BY level ASC, user_id ASC
+				';
+
+		//Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+		$rs = $this->db->Execute($query, $ph);
+		//Debug::Text(' Rows: '. $rs->RecordCount(), __FILE__, __LINE__, __METHOD__,10);
+
+		if ( $rs->RecordCount() > 0 ) {
+			$current_level = $level;
+			$i=0;
+			foreach( $rs as $row ) {
+				Debug::Text(' User ID: '. $row['user_id'] .' Level: '. $row['level'] .' Sub: '. $row['is_subordinate'] .' Current Level: '. $current_level, __FILE__, __LINE__, __METHOD__,10);
+				if (  $row['level'] == $current_level AND $row['is_subordinate'] == 0 ) {
+					$retarr['current_level'][] = $row['user_id'];
+				} elseif ( $row['level'] < $current_level AND $row['is_subordinate'] == 0 ) {
+					$retarr['parent_level'][] = $row['user_id'];
+				} elseif ( $row['level'] > $current_level AND $row['is_subordinate'] == 1 ) {
+					//Only ever show suborindates at child levels, this fixes the bug where the currently logged in user would see their own requests
+					//in the authorization list.
+					$retarr['child_level'][] = $row['user_id'];
+				} else {
+					//Debug::Text(' Skipping row...', __FILE__, __LINE__, __METHOD__,10);
+				}
+
+				$i++;
+			}
+
+			$retarr['current_level'] = array_unique( $retarr['current_level'] );
+			$retarr['parent_level'] = array_unique( $retarr['parent_level'] );
+			$retarr['child_level'] = array_unique( $retarr['child_level'] );
+
+			Debug::Arr($retarr ,' aChildren of User: '. $user_id .' At Level: '. $level, __FILE__, __LINE__, __METHOD__,10);
+
+			return $retarr;
+
+		}
+
+		return FALSE;
+	}
+
+	function getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $company_id, $user_id, $object_type_id = 100, $immediate_parents_only = TRUE, $include_levels = TRUE ) {
 		if ( $company_id == '' ) {
 			return FALSE;
 		}
@@ -505,7 +614,7 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 							x.user_id = ?
 							AND y.object_type_id = ?
 							AND z.company_id = ?
-							AND e.deleted = 0
+							AND ( w.deleted = 0 AND e.deleted = 0 )
 						ORDER BY w.level DESC
 					';
 
@@ -514,10 +623,18 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 		//Debug::Text(' Rows: '. $rs->RecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $rs->RecordCount() > 0 ) {
+			$valid_level = FALSE;
 			foreach( $rs as $row ) {
-				if ( $immediate_parent_only == TRUE ) {
-					$retval = (int)$row['user_id'];
-					break;
+				if ( $immediate_parents_only == TRUE ) {
+					//Even if immediate_parents_only is set, we need to return all parents at the same level.
+					//Prior to v3.1 we just returned a single parent.
+					if ( $valid_level === FALSE OR $valid_level == $row['level'] ) {
+						$retval[] = (int)$row['user_id'];
+
+						if ( $valid_level === FALSE ) {
+							$valid_level = $row['level'];
+						}
+					}
 				} else {
 					if ( $include_levels == TRUE ) {
 						$retval[(int)$row['level']][] = (int)$row['user_id'];
@@ -527,7 +644,7 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 				}
 			}
 
-			if ( $immediate_parent_only == FALSE ) {
+			if ( $immediate_parents_only == FALSE ) {
 				ksort($retval);
 			}
 		}
@@ -633,7 +750,7 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 
 
 
-	//Used by installed to upgrade.
+	//Used by installer to upgrade.
 	function getByCompanyIdAndHierarchyControlId( $company_id, $tree_id ) {
 		if ( $company_id == '' ) {
 			return FALSE;
