@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2707 $
- * $Id: RecurringHolidayFactory.class.php 2707 2009-08-06 22:48:08Z ipso $
- * $Date: 2009-08-06 15:48:08 -0700 (Thu, 06 Aug 2009) $
+ * $Revision: 3298 $
+ * $Id: RecurringHolidayFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 
 /**
@@ -86,6 +86,15 @@ class RecurringHolidayFactory extends Factory {
 										40 => TTi18n::gettext('On or After'),
 									);
 				break;
+			case 'always_week_day':
+				$retval = array(
+											//Adjust holiday to next weekday
+											0 => TTi18n::gettext('No'),
+											1 => TTi18n::gettext('Yes - Previous Week Day'),
+											2 => TTi18n::gettext('Yes - Next Week Day'),
+											3 => TTi18n::gettext('Yes - Closest Week Day'),
+										);
+				break;
 			case 'columns':
 				$retval = array(
 										'-1010-name' => TTi18n::gettext('Name'),
@@ -295,7 +304,7 @@ class RecurringHolidayFactory extends Factory {
 
 		return FALSE;
 	}
-	
+
 	function getWeekInterval() {
 		if ( isset($this->data['week_interval']) ) {
 			return (int)$this->data['week_interval'];
@@ -397,6 +406,28 @@ class RecurringHolidayFactory extends Factory {
 		return FALSE;
 	}
 
+	function getAlwaysOnWeekDay() {
+		if ( isset($this->data['always_week_day_id']) ) {
+			return (int)$this->data['always_week_day_id'];
+		}
+		return FALSE;
+	}
+	function setAlwaysOnWeekDay($int) {
+		$int = (int)$int;
+
+		if ( $this->Validator->inArrayKey(	'always_week_day_id',
+											$int,
+											TTi18n::gettext('Incorrect always on week day adjustment'),
+											$this->getOptions('always_week_day') ) ) {
+
+			$this->data['always_week_day_id'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getNextDate( $epoch = FALSE ) {
 		if ( $epoch == '' ) {
 			$epoch = TTDate::getTime();
@@ -504,6 +535,8 @@ class RecurringHolidayFactory extends Factory {
 			}
 		}
 
+		$holiday_epoch = TTDate::getNearestWeekDay( $holiday_epoch, $this->getAlwaysOnWeekDay() );
+
 		Debug::text('Next Date for: '. $this->getName() .' is: '. TTDate::getDate('DATE+TIME', $holiday_epoch), __FILE__, __LINE__, __METHOD__, 10);
 
 		return $holiday_epoch;
