@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: Install.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3562 $
+ * $Id: Install.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -500,6 +500,7 @@ class Install {
 
 		/*
 			Invalid PHP Versions:
+				v5.3.0+ - Fails due to deprecated functions still in use. This is mostly fixed as of v3.1.0-rc1, leave enabled for now.
 				v5.0.4 - Fails to assign object values by ref. In ViewTimeSheet.php $smarty->assign_by_ref( $pp_obj->getId() ) fails.
 				v5.2.2 - Fails to populate $HTTP_RAW_POST_DATA http://bugs.php.net/bug.php?id=41293
 				 	   - Implemented work around in global.inc.php
@@ -613,8 +614,9 @@ class Install {
 		if ( function_exists('mysqli_real_connect') ) {
 			$retval['mysqli'] = 'MySQLi (v5.0.48+ w/InnoDB)';
 		}
+		//MySQLt driver is no longer supported, as it causes conflicts with ADODB and complex queries.
 		if ( function_exists('mysql_connect') ) {
-			$retval['mysqlt'] = 'MySQL (Legacy Driver w/InnoDB)';
+			$retval['mysqlt'] = 'MySQL (Legacy Driver - NOT SUPPORTED, use MYSQLi instead!)';
 		}
 
 		return $retval;
@@ -631,10 +633,10 @@ class Install {
 
 		if ( function_exists('pg_connect') ) {
 			$retval = 0;
-		} elseif ( function_exists('mysql_connect') ) {
-			$retval = 0;
 		} elseif ( function_exists('mysqli_real_connect') ) {
 			$retval = 0;
+		} elseif ( function_exists('mysql_connect') ) {
+			$retval = 2;
 		}
 
 		return $retval;
@@ -845,6 +847,15 @@ class Install {
 		return 1;
 	}
 
+	//Not currently mandatory, but can be useful to provide better SOAP timeouts.
+	function checkCURL() {
+		if ( function_exists('curl_exec') ) {
+			return 0;
+		}
+
+		return 1;
+	}
+
 	function checkSimpleXML() {
 		if ( class_exists('SimpleXMLElement') ) {
 			return 0;
