@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: MessageFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3359 $
+ * $Id: MessageFactory.class.php 3359 2010-02-23 16:22:05Z ipso $
+ * $Date: 2010-02-23 08:22:05 -0800 (Tue, 23 Feb 2010) $
  */
 
 /**
@@ -492,17 +492,9 @@ class MessageFactory extends Factory {
 							//Get direct parent in hierarchy.
 							$u_obj = $obj->getUserObject();
 
-							//Find proper hierarchy to use for this object
-							$hotlf = new HierarchyObjectTypeListFactory();
-							$control_id = $hotlf->getByCompanyIdAndObjectTypeId( $u_obj->getCompany(), $this->getObjectType() )->getCurrent()->getHierarchyControl();
-							Debug::Text(' Hierarchy Control ID: '. $control_id , __FILE__, __LINE__, __METHOD__,10);
-
 							$hlf = new HierarchyListFactory();
-							$node_data = $hlf->getByHierarchyControlIdAndUserId( $control_id, $u_obj->getId() );
-							if ( $node_data['parent_id'] != 0 ) {
-								$user_ids[] = $node_data['parent_id'];
-							}
-							unset($hotlf,$control_id, $hlf, $node_data);
+							$user_ids[] = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $u_obj->getCompany(), $u_obj->getId(), $this->getObjectType(), TRUE, FALSE );
+							unset($hlf);
 						}
 
 						global $current_user;
@@ -639,8 +631,9 @@ class MessageFactory extends Factory {
 	}
 
 	function postSave() {
+		//Only email message notifications when they are not deleted and UNREAD still. Other it may email when a message is marked as read as well.
 		//Don't email messages when they are being deleted.
-		if ( $this->getDeleted() == FALSE ) {
+		if ( $this->getDeleted() == FALSE AND $this->getStatus() == 10 ) {
 			$this->emailMessage();
 		}
 
