@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: EFT.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3628 $
+ * $Id: EFT.class.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 
 /*
@@ -93,7 +93,7 @@ $eft->save('/tmp/eft01.txt');
  */
 class EFT {
 
-	var $file_format_options = array( '1464','105', 'HSBC' );
+	var $file_format_options = array( '1464','105', 'HSBC', 'BEANSTREAM' );
 	var $file_format = NULL; //File format
 
 	var $header_data = NULL;
@@ -311,6 +311,9 @@ class EFT {
 			case 'HSBC':
 				$file_format_obj = new EFT_File_Format_HSBC($this->data);
 				break;
+			case 'BEANSTREAM':
+				$file_format_obj = new EFT_File_Format_BEANSTREAM($this->data);
+				break;
 			case 'ACH':
 				$file_format_obj = new EFT_File_Format_ACH($this->header_data, $this->data);
 				break;
@@ -475,7 +478,7 @@ class EFT_record extends EFT {
 	}
 
 	function setTransit($value) {
-		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 5 ) {
+		if ( $this->isNumeric( $value ) AND strlen( $value ) <= 9 ) { //EFT Transit <= 5, ACH Transit/Routing <= 9:
 			$this->record_data['transit'] = $value;
 
 			return TRUE;
@@ -493,7 +496,7 @@ class EFT_record extends EFT {
 	}
 
 	function setAccount($value) {
-		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 12 ) {
+		if ( $this->isAlphaNumeric( $value ) AND strlen( $value ) <= 13 ) {
 			$this->record_data['account'] = $value;
 
 			return TRUE;
@@ -629,6 +632,21 @@ class EFT_record extends EFT {
 
 		return FALSE;
 	}
+
+	function getOtherData( $key ) {
+		if ( isset($this->record_data[$key]) ) {
+			return $this->record_data[$key];
+		}
+
+		return FALSE;
+	}
+
+	function setOtherData($key, $value) {
+		$this->record_data[$key] = $value;
+
+		return TRUE;
+	}
+
 }
 
 
@@ -1325,4 +1343,88 @@ class EFT_File_Format_ACH Extends EFT {
 	}
 }
 
+
+/**
+ * @package Module_Other
+ */
+class EFT_File_Format_BEANSTREAM Extends EFT {
+	var $data = NULL;
+
+	function __construct( $data ) {
+		Debug::Text(' EFT_Format_BEANSTREAM Contruct... ', __FILE__, __LINE__, __METHOD__,10);
+
+		$this->data = $data;
+
+		return TRUE;
+	}
+
+	private function compileRecords() {
+		//gets all Detail records.
+
+		if ( count($this->data) == 0 ) {
+			Debug::Text('No data for D Record:', __FILE__, __LINE__, __METHOD__, 10);
+			return FALSE;
+		}
+
+		foreach ( $this->data as $key => $record ) {
+			//Debug::Arr($record, 'Record Object:', __FILE__, __LINE__, __METHOD__, 10);
+
+			//Transaction method, EFT = E, ACH = A
+			if ( $record->getInstitution() == '' ) {
+				//ACH
+				$line[] = 'A';
+			} else {
+				//EFT
+				$line[] = 'E';
+			}
+
+			//Transaction type
+			$line[] = $record->getType(); //C = Credit, D= Debit
+
+			if ( $record->getInstitution() != '' ) {
+				$line[] = $record->getInstitution();
+			}
+			$line[] = $record->getTransit();
+			$line[] = $record->getAccount();
+
+			if ( $record->getInstitution() == '' ) {
+				$line[] = 'CC'; //Corporate Checking Account, for ACH only.
+			}
+
+			$line[] = $this->removeDecimal( $record->getAmount() );
+
+			$line[] = $record->getOriginatorReferenceNumber();
+
+			$line[] = $record->getName();
+
+			$d_record = implode(',', $line);
+			Debug::Text('D Record:'. $d_record .' - Length: '. strlen($d_record), __FILE__, __LINE__, __METHOD__, 10);
+
+			$retval[] = $d_record;
+
+			unset($line);
+			unset($d_record);
+		}
+
+		if ( isset($retval) ) {
+			return $retval;
+		}
+
+		return FALSE;
+	}
+
+	function _compile() {
+		//Processes all the data, padding it.
+		$compiled_data = @implode("\r\n", $this->compileRecords() );
+
+		if ( strlen( $compiled_data ) >= 25 ) {
+			return $compiled_data;
+		}
+
+		Debug::Text('Not enough compiled data!', __FILE__, __LINE__, __METHOD__, 10);
+
+		return FALSE;
+	}
+}
+
 ?>
