@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: ROEFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3415 $
+ * $Id: ROEFactory.class.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 
 /**
@@ -358,7 +358,10 @@ class ROEFactory extends Factory {
 	function setSerial($value) {
 		$value = trim($value);
 
-		if 	(	$this->Validator->isLength(		'serial',
+		//Don't force serial numbers anymore, as online ROEs don't require them.
+		if 	(	$value == ''
+				OR
+				$this->Validator->isLength(		'serial',
 												$value,
 												TTi18n::gettext('Invalid serial'),
 												9,
@@ -469,6 +472,18 @@ class ROEFactory extends Factory {
 		return TRUE;
 	}
 
+	function getEnableReleaseAccruals() {
+		if ( isset($this->release_accruals) ) {
+			return $this->release_accruals;
+		}
+
+		return FALSE;
+	}
+	function setEnableReleaseAccruals($bool) {
+		$this->release_accruals = $bool;
+
+		return TRUE;
+	}
 	function getEnableGeneratePayStub() {
 		if ( isset($this->generate_pay_stub) ) {
 			return $this->generate_pay_stub;
@@ -535,6 +550,9 @@ class ROEFactory extends Factory {
 	}
 
 	function isPayPeriodWithNoEarnings() {
+		//Show earnings per pay period always, as some provinces require it for certain purposes like EI to determine highest weekly earnings.
+		return TRUE;
+		/*
 		$pp_earnings = $this->getInsurableEarningsByPayPeriod();
 		if ( is_array($pp_earnings) ) {
 			foreach( $pp_earnings as $pp_earning ) {
@@ -546,6 +564,7 @@ class ROEFactory extends Factory {
 		}
 
 		return FALSE;
+		*/
 	}
 
 	function getTotalInsurableEarnings() {
@@ -1058,7 +1077,7 @@ class ROEFactory extends Factory {
 
 	function preSave() {
 
-		if ( $this->isNew() ) {
+		if ( $this->isNew() AND $this->getEnableReleaseAccruals() == TRUE ) {
 			//Create PS amendment releasing all accruals
 			UserGenericStatusFactory::queueGenericStatus( $this->getUserObject()->getFullName(TRUE).' - '. TTi18n::gettext('Pay Stub Amendment'), 30, TTi18n::gettext('Releasing all employee accruals'), NULL );
 
