@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: PayStubEntryAccountFactory.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2838 $
+ * $Id: PayStubEntryAccountFactory.class.php 2838 2009-09-18 20:57:41Z ipso $
+ * $Date: 2009-09-18 13:57:41 -0700 (Fri, 18 Sep 2009) $
  */
 
 /**
@@ -66,12 +79,64 @@ class PayStubEntryAccountFactory extends Factory {
 										65 => 20,
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-status' => TTi18n::gettext('Status'),
+										'-1020-type' => TTi18n::gettext('Type'),
+										'-1030-name' => TTi18n::gettext('Name'),
+
+										'-1140-ps_order' => TTi18n::gettext('Order'),
+										'-1150-debit_account' => TTi18n::gettext('Debit Account'),
+										'-1150-credit_account' => TTi18n::gettext('Credit Account'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'type',
+								'name',
+								'ps_order',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'name',
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								'type',
+								'accrual',
+								);
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'company_id' => 'Company',
+											'status_id' => 'Status',
+											'status' => FALSE,
+											'type_id' => 'Type',
+											'type' => FALSE,
+											'name' => 'Name',
+											'ps_order' => 'Order',
+											'debit_account' => 'DebitAccount',
+											'credit_account' => 'CreditAccount',
+											'accrual_pay_stub_entry_account_id' => 'Accrual',
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
 
 	function getCompany() {
 		if ( isset($this->data['company_id']) ) {
@@ -145,12 +210,7 @@ class PayStubEntryAccountFactory extends Factory {
 		return FALSE;
 	}
 	function setType($type) {
-		$type = trim($type);
-
-		$key = Option::getByValue($type, $this->getOptions('type') );
-		if ($key !== FALSE) {
-			$type = $key;
-		}
+		$type = (int)trim($type);
 
 		if ( $this->Validator->inArrayKey(	'type_id',
 											$type,
@@ -232,7 +292,7 @@ class PayStubEntryAccountFactory extends Factory {
 	function setOrder($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->isNumeric(		'order',
+		if ( $this->Validator->isNumeric(		'ps_order',
 												$value,
 												TTi18n::gettext('Invalid Order')
 										) ) {
@@ -333,7 +393,7 @@ class PayStubEntryAccountFactory extends Factory {
 		if (
 				( $id == '' OR $id == 0 )
 				OR
-				$this->Validator->isResultSetWithRows(	'accrual',
+				$this->Validator->isResultSetWithRows(	'accrual_pay_stub_entry_account_id',
 														$psealf,
 														TTi18n::gettext('Accrual account is invalid')
 													) ) {
@@ -948,7 +1008,7 @@ class PayStubEntryAccountFactory extends Factory {
 
 			if ( isset($min_ps_order) AND isset($max_ps_order) AND ( $this->getOrder() <= $min_ps_order OR $this->getOrder() >= $max_ps_order ) ) {
 				Debug::text('PS Order... Min: '. $min_ps_order .' Max: '. $max_ps_order, __FILE__, __LINE__, __METHOD__, 10);
-				$this->Validator->isTrue(				'order',
+				$this->Validator->isTrue(				'ps_order',
 														FALSE,
 														TTi18n::gettext('Order is invalid for this type of account, it must be between'). ' '. ($min_ps_order+1) . ' ' . TTi18n::gettext('and') . ' ' . ($max_ps_order-1) );
 			}
@@ -982,6 +1042,61 @@ class PayStubEntryAccountFactory extends Factory {
 		$this->removeCache( $this->getId() );
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Stub Account'), NULL, $this->getTable() );
 	}
