@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: PayStubAmendmentFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: PayStubAmendmentFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -56,6 +56,17 @@ class PayStubAmendmentFactory extends Factory {
 
 		$retval = NULL;
 		switch( $name ) {
+			case 'filtered_status':
+				//Select box options;
+				$status_options_filter = array(50);
+				if ( $this->getStatus() == 55 ) {
+					$status_options_filter = array(55);
+				} elseif ( $this->getStatus() == 52 ) {
+					$status_options_filter = array(52);
+				}
+
+				$retval = Option::getByArray( $status_options_filter, $this->getOptions('status') );
+				break;
 			case 'status':
 				$retval = array(
 										10 => TTi18n::gettext('NEW'),
@@ -74,12 +85,100 @@ class PayStubAmendmentFactory extends Factory {
 											20 => TTi18n::gettext('Percent')
 										);
 				break;
+			case 'pay_stub_account_type':
+				$retval = array(10,20,30,50,60,65);
+				break;
+			case 'percent_pay_stub_account_type':
+				$retval = array(10,20,30,40,50,60,65);
+				break;
+			case 'columns':
+				$retval = array(
+										'-1000-first_name' => TTi18n::gettext('First Name'),
+										'-1002-last_name' => TTi18n::gettext('Last Name'),
+										'-1005-user_status' => TTi18n::gettext('Employee Status'),
+										'-1010-title' => TTi18n::gettext('Title'),
+										'-1020-group' => TTi18n::gettext('Group'),
+										'-1030-default_branch' => TTi18n::gettext('Default Branch'),
+										'-1040-default_department' => TTi18n::gettext('Default Department'),
 
+										'-1110-status' => TTi18n::gettext('Status'),
+										'-1120-type' => TTi18n::gettext('Type'),
+										'-1130-pay_stub_entry_name' => TTi18n::gettext('Account'),
+										'-1140-effective_date' => TTi18n::gettext('Effective Date'),
+										'-1150-amount' => TTi18n::gettext('Amount'),
+										'-1160-rate' => TTi18n::gettext('Rate'),
+										'-1170-units' => TTi18n::gettext('Units'),
+										'-1180-description' => TTi18n::gettext('Description'),
+										//'-1190-ytd_adjustment' => TTi18n::gettext('YTD'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'status',
+								'pay_stub_entry_name',
+								'effective_date',
+								'amount',
+								'description',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_id' => 'User',
+
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'user_status_id' => FALSE,
+										'user_status' => FALSE,
+										'group_id' => FALSE,
+										'group' => FALSE,
+										'title_id' => FALSE,
+										'title' => FALSE,
+										'default_branch_id' => FALSE,
+										'default_branch' => FALSE,
+										'default_department_id' => FALSE,
+										'default_department' => FALSE,
+
+										'pay_stub_entry_name_id' => 'PayStubEntryNameId',
+										'pay_stub_entry_name' => FALSE,
+										'recurring_ps_amendment_id' => 'RecurringPayStubAmendmentId',
+										'effective_date' => 'EffectiveDate',
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'rate' => 'Rate',
+										'units' => 'Units',
+										'amount' => 'Amount',
+										'percent_amount' => 'PercentAmount',
+										'percent_amount_entry_name_id' => 'PercentAmountEntryNameId',
+										'ytd_adjustment' => 'YTDAdjustment',
+										'description' => 'Description',
+										'authorized' => 'Authorized',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getUserObject() {
 		if ( is_object($this->user_obj) ) {
@@ -169,14 +268,15 @@ class PayStubAmendmentFactory extends Factory {
 
 		//$psenlf = new PayStubEntryNameListFactory();
 		$psealf = new PayStubEntryAccountListFactory();
-		$result = $psealf->getById( $id )->getCurrent();
+		$result = $psealf->getById( $id );
+		Debug::Arr($result, 'Result: ID: '. $id .' Rows: '. $result->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
 		if (  $this->Validator->isResultSetWithRows(	'pay_stub_entry_name_id',
 														$result,
-														TTi18n::gettext('Invalid Type')
+														TTi18n::gettext('Invalid Pay Stub Account')
 														) ) {
 
-			$this->data['pay_stub_entry_name_id'] = $result->getId();
+			$this->data['pay_stub_entry_name_id'] = $id;
 
 			return TRUE;
 		}
@@ -195,7 +295,7 @@ class PayStubAmendmentFactory extends Factory {
 														TTi18n::gettext('Invalid Entry Name')
 														) ) {
 
-			$this->data['pay_stub_entry_name_id'] = $result->getId();
+			$this->data['pay_stub_entry_name_id'] = $result->getCurrent()->getId();
 
 			return TRUE;
 		}
@@ -214,16 +314,18 @@ class PayStubAmendmentFactory extends Factory {
 		$id = trim($id);
 
 		$rpsalf = new RecurringPayStubAmendmentListFactory();
-		$result = $rpsalf->getById( $id )->getCurrent();
+		$rpsalf->getById( $id );
+		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
+		//$result = $rpsalf->getById( $id )->getCurrent();
 
-		if (	$id == NULL
+		if (	( $id == NULL OR $id == 0 )
 				OR
 				$this->Validator->isResultSetWithRows(	'recurring_ps_amendment_id',
-														$result,
+														$rpsalf,
 														TTi18n::gettext('Invalid Recurring Pay Stub Amendment ID')
 														) ) {
 
-			$this->data['recurring_ps_amendment_id'] = $result->getId();
+			$this->data['recurring_ps_amendment_id'] = $id;
 
 			return TRUE;
 		}
@@ -544,15 +646,16 @@ class PayStubAmendmentFactory extends Factory {
 	}
 	function setPercentAmountEntryNameId($id) {
 		$id = trim($id);
-/*
-		$psenlf = new PayStubEntryNameListFactory();
-		$result = $psenlf->getById( $id )->getCurrent();
-*/
-		$psealf = new PayStubEntryAccountListFactory();
-		$result = $psealf->getById( $id )->getCurrent();
 
-		if (  $this->Validator->isResultSetWithRows(	'percent_amount_entry_name',
-														$result,
+		$psealf = new PayStubEntryAccountListFactory();
+		$psealf->getById( $id );
+		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
+		//$result = $psealf->getById( $id )->getCurrent();
+
+		if (	( $id == NULL OR $id == 0 )
+				OR
+				$this->Validator->isResultSetWithRows(	'percent_amount_entry_name',
+														$psealf,
 														TTi18n::gettext('Invalid Percent Of')
 														) ) {
 
@@ -739,8 +842,86 @@ class PayStubAmendmentFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$uf = new UserFactory();
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+						case 'user_status_id':
+						case 'group_id':
+						case 'group':
+						case 'title_id':
+						case 'title':
+						case 'default_branch_id':
+						case 'default_branch':
+						case 'default_department_id':
+						case 'default_department':
+						case 'pay_stub_entry_name':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'user_status':
+							$data[$variable] = Option::getByKey( (int)$this->getColumn( 'user_status_id' ), $uf->getOptions( 'status' ) );
+							break;
+						case 'status':
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'effective_date':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Stub Amendment - User ID').': '. $this->getUser() .' '.  TTi18n::getText('Amount').': '. $this->getAmount(), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Stub Amendment - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) .' '.  TTi18n::getText('Amount').': '. $this->getAmount(), NULL, $this->getTable() );
 	}
 }
 ?>
