@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: RecurringPayStubAmendmentFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3298 $
+ * $Id: RecurringPayStubAmendmentFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 
 /**
@@ -649,7 +649,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 						//it does not already exist.
 						if ( $epoch >= $pay_period_obj->getEndDate()
 								AND $this->checkTimeFrame($epoch) ) {
-							Debug::text('After end of pay period.', __FILE__, __LINE__, __METHOD__,10);
+							Debug::text('After end of pay period. Start Date: '. TTDate::getDate('DATE+TIME', $pay_period_obj->getStartDate() ) .' End Date: '. TTDate::getDate('DATE+TIME', $pay_period_obj->getEndDate() ) , __FILE__, __LINE__, __METHOD__,10);
 
 							$psalf = new PayStubAmendmentListFactory();
 
@@ -730,17 +730,19 @@ class RecurringPayStubAmendmentFactory extends Factory {
 							$end_date = TTDate::getEndMonthEpoch($epoch);
 							break;
 						case 70:
-							$trigger_date = TTDate::getDateOfNextYear( $this->getStartDate() );
+							$trigger_date = TTDate::getDateOfNextYear( $this->getStartDate(), $epoch );
 
-							$start_date = TTDate::getBeginYearEpoch($epoch);
-							$end_date = TTDate::getEndYearEpoch($epoch);
+							//$start_date = TTDate::getBeginYearEpoch($epoch);
+							//$end_date = TTDate::getEndYearEpoch($epoch);
+							$start_date = TTDate::getBeginDayEpoch( ( $epoch-( 86400*365 ) ) );
+							$end_date = TTDate::getEndDayEpoch( $epoch );
 							break;
 					}
 					Debug::text('Trigger Date: '. TTDate::getDate('DATE', $trigger_date), __FILE__, __LINE__, __METHOD__,10);
 
 					if ( $epoch >= $trigger_date
 							AND $this->checkTimeFrame($epoch) ) {
-							Debug::text('After end of pay period.', __FILE__, __LINE__, __METHOD__,10);
+							Debug::text('Within timeframe... Start Date: '. TTDate::getDate('DATE+TIME', $start_date ) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date ) , __FILE__, __LINE__, __METHOD__,10);
 
 						foreach( $user_ids as $user_id ) {
 							//Make sure schedule user is in the PS amendment user list and user is active.
