@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3091 $
- * $Id: PayPeriodFactory.class.php 3091 2009-11-18 18:00:31Z ipso $
- * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
+ * $Revision: 3562 $
+ * $Id: PayPeriodFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -513,6 +513,13 @@ class PayPeriodFactory extends Factory {
 		return FALSE;
 	}
 
+	function getTimeSheetVerifyType() {
+		if ( is_object( $this->getPayPeriodScheduleObject() ) ) {
+			return $this->getPayPeriodScheduleObject()->getTimeSheetVerifyType();
+		}
+
+		return FALSE;
+	}
 	function getTimeSheetVerifyWindowStartDate() {
 		if ( is_object( $this->getPayPeriodScheduleObject() ) ) {
 			return (int)$this->getEndDate()-( (int)$this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeEndDate()*86400);
@@ -560,7 +567,8 @@ class PayPeriodFactory extends Factory {
 		return TRUE;
 	}
 
-	function importData() {
+	//Imports only data not assigned to other pay periods
+	function importOrphanedData() {
 		$pps_obj = $this->getPayPeriodScheduleObject();
 
 		if ( is_object( $pps_obj ) ) {
@@ -585,6 +593,60 @@ class PayPeriodFactory extends Factory {
 		return FALSE;
 	}
 
+	//Imports all data from other pay periods into this one.
+	function importData() {
+		$pps_obj = $this->getPayPeriodScheduleObject();
+
+		$udlf = new UserDateListFactory();
+
+		$udlf->StartTransaction();
+		$udlf->getByUserIdAndStartDateAndEndDate($pps_obj->getUser(), $this->getStartDate(), $this->getEndDate() );
+		Debug::text(' Pay Period ID: '. $this->getId() .' Pay Period User Date Rows: '. $udlf->getRecordCount() .' Start Date: '. TTDate::getDate('DATE+TIME', $this->getStartDate() ) .' End Date: '. TTDate::getDate('DATE+TIME', $this->getEndDate() ), __FILE__, __LINE__, __METHOD__,10);
+		foreach($udlf as $ud_obj) {
+			$new_pay_period_id = $ud_obj->findPayPeriod();
+			Debug::Text('Current Pay Period: '. $ud_obj->getPayPeriod() .' ('.$this->getID() .') New PayPeriod ID: '. $new_pay_period_id , __FILE__, __LINE__, __METHOD__,10);
+
+			//Make sure original pay period isn't already closed
+			if ( $this->getID() == $new_pay_period_id
+					AND $new_pay_period_id != $ud_obj->getPayPeriod()
+					AND $ud_obj->getPayPeriodObject()->getStatus() != 20) {
+				$ud_obj->setPayPeriod( $new_pay_period_id );
+				if ( $ud_obj->isValid() ) {
+					$ud_obj->Save();
+				}
+			} else {
+				Debug::Text('Pay Period is already closed, OR Current Pay Period DOES NOT match New PayPeriod ID OR no changes are needed!!', __FILE__, __LINE__, __METHOD__,10);
+			}
+			unset($new_pay_period_id);
+		}
+		//$udlf->FailTransaction();
+		$udlf->CommitTransaction();
+
+		return TRUE;
+	}
+
+	//Delete all data assigned to this pay period.
+	function deleteData() {
+		Debug::text('Deleting all data from pay period: '. $this->getID(), __FILE__, __LINE__, __METHOD__, 10);
+		//Remove all user_date rows, punch control, punches, and schedules
+		$udlf = new UserDateListFactory();
+		$udlf->getByPayPeriodID( $this->getId() );
+		Debug::text(' Pay Period ID: '. $this->getId() .' Pay Period User Date Rows: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+		if ( $udlf->getRecordCount() > 0 ) {
+				$udlf->StartTransaction();
+				Debug::text('Delete User Date Rows: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
+				foreach($udlf as $ud_obj ) {
+					$ud_obj->setDeleted(TRUE);
+					$ud_obj->Save();
+				}
+				$ud_obj->CommitTransaction();
+		} else {
+				Debug::text('No User Date Rows to Delete', __FILE__, __LINE__, __METHOD__, 10);
+		}
+
+		return TRUE;
+	}
+
 	function Validate() {
 		//Make sure there aren't conflicting pay periods.
 		//Start date checks that...
@@ -695,7 +757,7 @@ class PayPeriodFactory extends Factory {
 			}
 
 			if ( $this->getEnableImportData() == TRUE ) {
-				$this->importData();
+				$this->importOrphanedData();
 			}
 		}
 
