@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: PayPeriodListFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3298 $
+ * $Id: PayPeriodListFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 
 /**
@@ -934,14 +934,16 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 					'id' => $id,
 					);
 
+		$uf = new UserFactory();
 		$psf = new PayStubFactory();
 
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $psf->getTable() .' as b ON a.id = b.pay_period_id
 					where	a.company_id = ?
-						AND EXISTS ( select z.id from '. $psf->getTable() .' as z where z.pay_period_id = a.id AND z.deleted = 0 )
-						AND a.deleted=0';
+						AND b.id IS NOT NULL
+						AND ( a.deleted = 0 AND b.deleted = 0 )';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
