@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: PayPeriodScheduleFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: PayPeriodScheduleFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -55,12 +55,15 @@ class PayPeriodScheduleFactory extends Factory {
 		$retval = NULL;
 		switch( $name ) {
 			case 'type':
+				/*
+				 * Set type to MANUAL to disable PP schedule. Rather then add a status_id field.
+				 */
 				$retval = array(
 											5 => TTi18n::gettext('Manual'),
 											10  => TTi18n::gettext('Weekly'),
 											20  => TTi18n::gettext('Bi-Weekly'),
 											30  => TTi18n::gettext('Semi-Monthly'),
-											//40  => TTi18n::gettext('Monthly + Advance'),
+											//40  => TTi18n::gettext('Monthly + Advance'), //Handled with monthly PP schedule and Tax / Deduction to automatically enter advance each month. Advances are paid manually.
 											50  => TTi18n::gettext('Monthly') //Must have this here, for ROEs
 										);
 				break;
@@ -92,6 +95,14 @@ class PayPeriodScheduleFactory extends Factory {
 											3 => TTi18n::gettext('Yes - Closest Business Day'),
 										);
 				break;
+			case 'timesheet_verify_type':
+				$retval = array(
+											10 => TTi18n::gettext('Disabled'),
+											20 => TTi18n::gettext('Employee Only'),
+											30 => TTi18n::gettext('Superior Only'),
+											40 => TTi18n::gettext('Employee & Superior'),
+										);
+				break;
 			case 'columns':
 				$retval = array(
 										'-1010-type_id' => TTi18n::gettext('Type'),
@@ -705,6 +716,29 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	function getTimeSheetVerifyType() {
+		if ( isset($this->data['timesheet_verify_type_id']) ) {
+			return $this->data['timesheet_verify_type_id'];
+		}
+
+		return TRUE;
+	}
+	function setTimeSheetVerifyType($type) {
+		$type = trim($type);
+
+		if ( $this->Validator->inArrayKey(	'timesheet_verify_type_id',
+											$type,
+											TTi18n::gettext('Incorrect TimeSheet Verification Type'),
+											$this->getOptions('timesheet_verify_type')) ) {
+
+			$this->data['timesheet_verify_type_id'] = $type;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getTimeSheetVerifyBeforeEndDate() {
 		if ( isset($this->data['timesheet_verify_before_end_date']) ) {
 			return (int)$this->data['timesheet_verify_before_end_date'];
@@ -859,78 +893,12 @@ class PayPeriodScheduleFactory extends Factory {
 				//Debug::Arr($holiday_epochs, 'Holiday Epochs: ', __FILE__, __LINE__, __METHOD__, 10);
 			}
 
-			while( TTDate::isWeekDay($epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $epoch ), $holiday_epochs) ) {
-				Debug::text('<b>FOUND WeekDay/HOLIDAY!</b>', __FILE__, __LINE__, __METHOD__, 10);
-				switch ( $this->getTransactionDateBusinessDay() ) {
-					case 0: //No adjustment
-						break 2;
-					case 1: //Previous day
-						$epoch -= 86400;
-						break;
-					case 2: //Next day
-						$epoch += 86400;
-						break;
-					case 3: //Closest day
-						$forward_epoch = $epoch;
-						$forward_days = 0;
-						while( TTDate::isWeekDay($forward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $forward_epoch ), $holiday_epochs) ) {
-							$forward_epoch += 86400;
-							$forward_days++;
-						}
-
-						$backward_epoch = $epoch;
-						$backward_days = 0;
-						while( TTDate::isWeekDay($backward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $backward_epoch ), $holiday_epochs) ) {
-							$backward_epoch -= 86400;
-							$backward_days++;
-						}
-
-						if ( $backward_days <= $forward_days ) {
-							$epoch = $backward_epoch;
-						} else {
-							$epoch = $forward_epoch;
-						}
-						break;
-				}
-
-			}
-
+			$epoch = TTDate::getNearestWeekDay( $epoch, $this->getTransactionDateBusinessDay(), $holiday_epochs );
 		}
 
 		return $epoch;
 	}
 
-/*
-	function getPreviousBusinessDay($epoch) {
-
-		Debug::Text('Epoch: '. TTDate::getDate('DATE+TIME', $epoch ), __FILE__, __LINE__, __METHOD__, 10);
-
-		$holiday_epochs = array();
-
-		$user_ids = $this->getUser();
-
-		if ( count($user_ids) > 0 ) {
-			$hlf = new HolidayListFactory();
-			$hlf->getByPolicyGroupUserIdAndStartDateAndEndDate( $user_ids, $epoch-(86400*14), $epoch+(86400*2) );
-			if ( $hlf->getRecordCount() > 0 ) {
-				foreach( $hlf as $h_obj ) {
-					Debug::Text('Found Holiday Epoch: '. TTDate::getDate('DATE+TIME', $h_obj->getDateStamp() ) .' Name: '. $h_obj->getName() , __FILE__, __LINE__, __METHOD__, 10);
-					$holiday_epochs[] = $h_obj->getDateStamp();
-				}
-
-				//Debug::Arr($holiday_epochs, 'Holiday Epochs: ', __FILE__, __LINE__, __METHOD__, 10);
-			}
-
-			while( TTDate::isWeekDay($epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $epoch ), $holiday_epochs) ) {
-				Debug::text('<b>FOUND WeekDay/HOLIDAY!</b>', __FILE__, __LINE__, __METHOD__, 10);
-				$epoch -= 86400;
-			}
-
-		}
-
-		return $epoch;
-	}
-*/
 	function getNextPayPeriod($end_date = NULL) {
 		if ( !$this->Validator->isValid() ) {
 			return FALSE;
@@ -1470,7 +1438,7 @@ class PayPeriodScheduleFactory extends Factory {
 */
 				if ( $i > 0 AND isset($shift_data[$shift]['last_out'])
 						AND ( $p_obj->getStatus() == 10 OR $p_obj->getStatus() == $prev_punch_arr['status_id'] )) {
-					Debug::text('Checking for new shift...', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('Checking for new shift...', __FILE__, __LINE__, __METHOD__, 10);
 					//Assume that if two punches are assigned to the same punch_control_id are the same shift, even if the time between
 					//them exceeds the new_shift_trigger_time. This helps fix the bug where you could add a In punch then add a Out
 					//punch BEFORE the In punch as long as it was more than the Maximum Shift Time before the In Punch.
