@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2682 $
- * $Id: AbsencePolicyFactory.class.php 2682 2009-07-23 22:31:20Z ipso $
- * $Date: 2009-07-23 15:31:20 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 3562 $
+ * $Id: AbsencePolicyFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -61,6 +61,9 @@ class AbsencePolicyFactory extends Factory {
 										30 => TTi18n::gettext('Dock'),
 									);
 				break;
+			case 'paid_type': //Types that are considered paid.
+				$retval = array(10,12);
+				break;
 			case 'columns':
 				$retval = array(
 										'-1010-type' => TTi18n::gettext('Type'),
@@ -146,6 +149,12 @@ class AbsencePolicyFactory extends Factory {
 		return FALSE;
 	}
 
+	function isPaid() {
+		if ( in_array( $this->getType(), $this->getOptions('paid_type') ) ) {
+			return TRUE;
+		}
+		return FALSE;
+	}
 	function getType() {
 		if ( isset($this->data['type_id']) ) {
 			return $this->data['type_id'];
