@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: AccrualPolicyFactory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 3199 $
+ * $Id: AccrualPolicyFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -55,12 +68,60 @@ class AccrualPolicyFactory extends Factory {
 										40 => TTi18n::gettext('Weekly'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-type' => TTi18n::gettext('Type'),
+										'-1030-name' => TTi18n::gettext('Name'),
 
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'type',
+								'name',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'name',
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'company_id' => 'Company',
+											'type_id' => 'Type',
+											'type' => FALSE,
+											'name' => 'Name',
+											'enable_pay_stub_balance_display' => 'EnablePayStubBalanceDisplay',
+											'minimum_time' => 'MinimumTime',
+											'maximum_time' => 'MaximumTime',
+											'apply_frequency_id' => 'ApplyFrequency',
+											'apply_frequency' => 'ApplyFrequency',
+											'apply_frequency_month' => 'ApplyFrequencyMonth',
+											'apply_frequency_day_of_month' => 'ApplyFrequencyDayOfMonth',
+											'apply_frequency_day_of_week' => 'ApplyFrequencyDayOfWeek',
+											'milestone_rollover_hire_date' => 'MilestoneRolloverHireDate',
+											'milestone_rollover_month' => 'MilestoneRolloverMonth',
+											'milestone_rollover_day_of_month' => 'MilestoneRolloverDayOfMonth',
+											'minimum_employed_days' => 'MinimumEmployedDays',
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
 
 	function getCompanyObject() {
 		if ( is_object($this->company_obj) ) {
@@ -222,15 +283,12 @@ class AccrualPolicyFactory extends Factory {
 	function setApplyFrequency($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, $this->getOptions('apply_frequency') );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'apply_frequency',
-											$value,
-											TTi18n::gettext('Incorrect frequency'),
-											$this->getOptions('apply_frequency')) ) {
+		if ( 	$value == 0
+				OR
+				$this->Validator->inArrayKey(	'apply_frequency_id',
+												$value,
+												TTi18n::gettext('Incorrect frequency'),
+												$this->getOptions('apply_frequency')) ) {
 
 			$this->data['apply_frequency_id'] = $value;
 
@@ -250,12 +308,9 @@ class AccrualPolicyFactory extends Factory {
 	function setApplyFrequencyMonth($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, TTDate::getMonthOfYearArray() );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'apply_frequency_month',
+		if ( $value == 0
+				OR
+				$this->Validator->inArrayKey(	'apply_frequency_month',
 											$value,
 											TTi18n::gettext('Incorrect frequency month'),
 											TTDate::getMonthOfYearArray() ) ) {
@@ -278,12 +333,9 @@ class AccrualPolicyFactory extends Factory {
 	function setApplyFrequencyDayOfMonth($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, TTDate::getDayOfMonthArray() );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'apply_frequency_day_of_month',
+		if ( $value == 0
+				OR
+				$this->Validator->inArrayKey(	'apply_frequency_day_of_month',
 											$value,
 											TTi18n::gettext('Incorrect frequency day of month'),
 											TTDate::getDayOfMonthArray() ) ) {
@@ -306,12 +358,9 @@ class AccrualPolicyFactory extends Factory {
 	function setApplyFrequencyDayOfWeek($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, TTDate::getDayOfWeekArray() );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'apply_frequency_day_of_week',
+		if ( $value == 0
+				OR
+				$this->Validator->inArrayKey(	'apply_frequency_day_of_week',
 											$value,
 											TTi18n::gettext('Incorrect frequency day of week'),
 											TTDate::getDayOfWeekArray() ) ) {
@@ -343,12 +392,9 @@ class AccrualPolicyFactory extends Factory {
 	function setMilestoneRolloverMonth($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, TTDate::getMonthOfYearArray() );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'milestone_rollover_month',
+		if ( $value == 0
+				OR
+				$this->Validator->inArrayKey(	'milestone_rollover_month',
 											$value,
 											TTi18n::gettext('Incorrect milestone rollover month'),
 											TTDate::getMonthOfYearArray() ) ) {
@@ -371,15 +417,12 @@ class AccrualPolicyFactory extends Factory {
 	function setMilestoneRolloverDayOfMonth($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, TTDate::getDayOfMonthArray() );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'milestone_rollover_day_of_month',
-											$value,
-											TTi18n::gettext('Incorrect milestone rollover day of month'),
-											TTDate::getDayOfMonthArray() ) ) {
+		if ( $value == 0
+				OR
+				$this->Validator->inArrayKey(	'milestone_rollover_day_of_month',
+												$value,
+												TTi18n::gettext('Incorrect milestone rollover day of month'),
+												TTDate::getDayOfMonthArray() ) ) {
 
 			$this->data['milestone_rollover_day_of_month'] = $value;
 
@@ -399,7 +442,7 @@ class AccrualPolicyFactory extends Factory {
 	function setMinimumEmployedDays($int) {
 		$int = trim($int);
 
-		if  ( empty($int) ){
+		if  ( empty($int) ) {
 			$int = 0;
 		}
 
@@ -430,6 +473,18 @@ class AccrualPolicyFactory extends Factory {
 		return $retval;
 	}
 
+	function getCurrentMilestoneRolloverDate( $epoch, $user_hire_date = NULL ) {
+		$base_rollover_date = $this->getMilestoneRolloverDate( $user_hire_date );
+		$rollover_date = mktime( 0, 0, 0, TTDate::getMonth( $base_rollover_date ), TTDate::getDayOfMonth( $base_rollover_date ), TTDate::getYear( $epoch ) );
+
+		if ( $rollover_date < $user_hire_date ) {
+			$rollover_date = $user_hire_date;
+		}
+
+		Debug::Text('Current Milestone Rollover Date: '. TTDate::getDate('DATE+TIME', $rollover_date) .' Hire Date: '. TTDate::getDate('DATE+TIME', $user_hire_date), __FILE__, __LINE__, __METHOD__,10);
+		return $rollover_date;
+	}
+
 	function getAccrualRatePerTimeFrequency( $accrual_rate, $annual_pay_periods = NULL ) {
 		$retval = FALSE;
 		switch( $this->getApplyFrequency() ) {
@@ -441,7 +496,6 @@ class AccrualPolicyFactory extends Factory {
 				break;
 			case 20: //Year
 				$retval = $accrual_rate;
-
 				break;
 			case 30: //Month
 				$retval = bcdiv( $accrual_rate, 12,0);
@@ -459,6 +513,20 @@ class AccrualPolicyFactory extends Factory {
 		return $retval;
 	}
 
+	function inRolloverFrequencyWindow( $current_epoch, $offset, $user_hire_date, $pay_period_start_date = NULL ) {
+		//Use current_epoch mainly for Yearly cases where the rollover date is 01-Nov and the hire date is always right after it, 10-Nov in the next year.
+		$rollover_date = $this->getCurrentMilestoneRolloverDate( $current_epoch, $user_hire_date );
+		Debug::Text('Rollover Date: '. TTDate::getDate('DATE+TIME', $rollover_date ) .' Current Epoch: '. TTDate::getDate('DATE+TIME', $current_epoch ), __FILE__, __LINE__, __METHOD__,10);
+
+		if ( $rollover_date >= ($current_epoch-$offset) AND $rollover_date <= $current_epoch ) {
+			Debug::Text('In rollover frequency window...', __FILE__, __LINE__, __METHOD__,10);
+			return TRUE;
+		}
+
+		Debug::Text('NOT in rollover frequency window...', __FILE__, __LINE__, __METHOD__,10);
+		return FALSE;
+	}
+
 	function inApplyFrequencyWindow( $current_epoch, $offset, $pay_period_end_date = NULL ) {
 		$retval = FALSE;
 		switch( $this->getApplyFrequency() ) {
@@ -481,9 +549,16 @@ class AccrualPolicyFactory extends Factory {
 				}
 				break;
 			case 30: //Month
-				$month_epoch = mktime( 0,0,0, TTDate::getMonth( $current_epoch ), $this->getApplyFrequencyDayOfMonth(), TTDate::getYear( $current_epoch ) );
-				Debug::Text('Day of Month: '. $this->getApplyFrequencyDayOfMonth() .' Month EPOCH: '. TTDate::getDate('DATE+TIME', $month_epoch), __FILE__, __LINE__, __METHOD__,10);
+				$apply_frequency_day_of_month = $this->getApplyFrequencyDayOfMonth();
 
+				//Make sure if they specify the day of month to be 31, that is still works for months with 30, or 28-29 days, assuming 31 basically means the last day of the month
+				if ( $apply_frequency_day_of_month > TTDate::getDaysInMonth( $current_epoch ) ) {
+					$apply_frequency_day_of_month = TTDate::getDaysInMonth( $current_epoch );
+					Debug::Text('Apply frequency day of month exceeds days in this month, using last day of the month instead: '. $apply_frequency_day_of_month, __FILE__, __LINE__, __METHOD__,10);
+				}
+
+				$month_epoch = mktime( 0,0,0, TTDate::getMonth( $current_epoch ), $apply_frequency_day_of_month, TTDate::getYear( $current_epoch ) );
+				Debug::Text('Day of Month: '. $this->getApplyFrequencyDayOfMonth() .' Month EPOCH: '. TTDate::getDate('DATE+TIME', $month_epoch) .' Current Month: '. TTDate::getMonth( $current_epoch ), __FILE__, __LINE__, __METHOD__,10);
 				Debug::Text('Month EPOCH: '. TTDate::getDate('DATE+TIME', $month_epoch) .' Greater Than: '. TTDate::getDate('DATE+TIME', ($current_epoch-$offset)) .' Less Than: '.  TTDate::getDate('DATE+TIME', $current_epoch), __FILE__, __LINE__, __METHOD__,10);
 
 				if ( $month_epoch >= ($current_epoch-$offset)
@@ -515,7 +590,7 @@ class AccrualPolicyFactory extends Factory {
 		$udtlf = new UserDateTotalListFactory();
 		$retval = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $user_id, 1, $end_date );
 
-		Debug::Text('Worked Hours: '. (int)$retval .' Before: '. TTDate::getDate('DATE+TIME', $end_date), __FILE__, __LINE__, __METHOD__,10);
+		Debug::Text('Worked Seconds: '. (int)$retval .' Before: '. TTDate::getDate('DATE+TIME', $end_date), __FILE__, __LINE__, __METHOD__,10);
 
 		return $retval;
 	}
@@ -657,6 +732,8 @@ class AccrualPolicyFactory extends Factory {
 
 								$annual_pay_periods = 0;
 								$in_apply_frequency_window = FALSE;
+								$in_apply_rollover_window = FALSE;
+								$pay_period_start_date = NULL;
 								$accrual_balance = 0;
 								$accrual_amount = 0;
 								if ( $this->getType() == 30 ) {
@@ -677,6 +754,8 @@ class AccrualPolicyFactory extends Factory {
 												if ( $this->inApplyFrequencyWindow( $epoch, $offset, $pp_obj->getEndDate() ) == TRUE ) {
 													$in_apply_frequency_window = TRUE;
 													$annual_pay_periods = $pp_obj->getPayPeriodScheduleObject()->getAnnualPayPeriods();
+
+													$pay_period_start_date = $pp_obj->getStartDate(); //Used for inRolloverFrequencyWindow
 													break;
 												} else {
 													Debug::Text('&nbsp;&nbsp;User not in Apply Frequency Window: ', __FILE__, __LINE__, __METHOD__,10);
@@ -694,13 +773,64 @@ class AccrualPolicyFactory extends Factory {
 									}
 								}
 
-								if ( $in_apply_frequency_window == TRUE ) {
-									$milestone_obj = $this->getActiveMilestoneObject( $u_obj, $epoch );
+								if ( $this->inRolloverFrequencyWindow( $epoch, $offset, $u_obj->getHireDate(), $pay_period_start_date ) ) {
+									Debug::Text('&nbsp;&nbsp; In rollover window...', __FILE__, __LINE__, __METHOD__,10);
+									$in_apply_rollover_window = TRUE;
+								}
 
+								if ( $in_apply_frequency_window == TRUE OR $in_apply_rollover_window == TRUE ) {
+									$milestone_obj = $this->getActiveMilestoneObject( $u_obj, $epoch );
+								}
+
+								if ( $in_apply_rollover_window == TRUE AND ( isset($milestone_obj) AND is_object( $milestone_obj ) ) ) {
+									$accrual_balance = $this->getCurrentAccrualBalance( $user_id, $this->getId() );
+
+									//Handle maximum rollover adjustments before continuing.
+									if ( $accrual_balance > $milestone_obj->getRolloverTime() ) {
+										$rollover_accrual_adjustment = bcsub( $milestone_obj->getRolloverTime(), $accrual_balance, 0);
+										Debug::Text('&nbsp;&nbsp; Adding rollover adjustment of: '. $rollover_accrual_adjustment, __FILE__, __LINE__, __METHOD__,10);
+
+										//Check to make sure there isn't an identical entry already made.
+										//Ignore rollover adjustment is another adjustment of any amount has been made on the same day.
+										$alf = new AccrualListFactory();
+										$alf->getByCompanyIdAndUserIdAndAccrualPolicyIDAndTypeIDAndTimeStamp( $u_obj->getCompany(), $user_id, $this->getId(), 60, TTDate::getMiddleDayEpoch( $epoch ) );
+										if ( $alf->getRecordCount() == 0 ) {
+
+											//Get effective date, try to use the current milestone rollover date to make things more clear.
+											$current_milestone_rollover_date = $this->getCurrentMilestoneRolloverDate( $epoch, $u_obj->getHireDate() );
+											//If milestone rollover date comes after the current epoch, back date it by one year.
+											if ( $current_milestone_rollover_date > $epoch ) {
+												$current_milestone_rollover_date = mktime( 0,0,0, TTDate::getMonth($current_milestone_rollover_date), TTDate::getDayOfMonth($current_milestone_rollover_date), (TTDate::getYear($epoch)-1) );
+											}
+
+											//Round to nearest 1min
+											$af = new AccrualFactory();
+											$af->setUser( $user_id );
+											$af->setType( 60 ); //Rollover Adjustment
+											$af->setAccrualPolicyID( $this->getId() );
+											$af->setAmount( $rollover_accrual_adjustment );
+											$af->setTimeStamp( TTDate::getMiddleDayEpoch( $current_milestone_rollover_date ) );
+											$af->setEnableCalcBalance( TRUE );
+
+											if ( $af->isValid() ) {
+												$af->Save();
+											}
+											unset($current_milestone_rollover_date);
+										} else {
+											Debug::Text('&nbsp;&nbsp; Found duplicate rollover accrual entry, skipping...', __FILE__, __LINE__, __METHOD__,10);
+										}
+									} else {
+										Debug::Text('&nbsp;&nbsp; Balance hasnt exceeded rollover adjustment...', __FILE__, __LINE__, __METHOD__,10);
+									}
+									unset($rollover_accrual_adjustment, $alf, $af);
+								}
+
+								if ( $in_apply_frequency_window === TRUE ) {
 									if ( isset($milestone_obj) AND is_object( $milestone_obj ) ) {
 										Debug::Text('&nbsp;&nbsp;Found Matching Milestone, Accrual Rate: (ID: '. $milestone_obj->getId() .') '. $milestone_obj->getAccrualRate() .'/year', __FILE__, __LINE__, __METHOD__,10);
-										$accrual_balance = $this->getCurrentAccrualBalance( $user_id, $this->getId() );
 
+										//Make sure we get updated balance after rollover adjustment was made.
+										$accrual_balance = $this->getCurrentAccrualBalance( $user_id, $this->getId() );
 										if ( $accrual_balance < $milestone_obj->getMaximumTime() ) {
 											$accrual_amount = $this->calcAccrualAmount( $milestone_obj, 0, $annual_pay_periods);
 
@@ -739,7 +869,6 @@ class AccrualPolicyFactory extends Factory {
 											}
 										} else {
 											Debug::Text('&nbsp;&nbsp; Accrual Balance is outside Milestone Range. Skipping...', __FILE__, __LINE__, __METHOD__,10);
-
 										}
 									} else {
 										Debug::Text('&nbsp;&nbsp;DID NOT Find Matching Milestone.', __FILE__, __LINE__, __METHOD__,10);
@@ -786,6 +915,66 @@ class AccrualPolicyFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'apply_frequency':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Accrual Policy'), NULL, $this->getTable() );
 	}
