@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2338 $
- * $Id: PremiumPolicyFactory.class.php 2338 2009-01-14 21:32:59Z ipso $
- * $Date: 2009-01-14 13:32:59 -0800 (Wed, 14 Jan 2009) $
+ * $Revision: 3021 $
+ * $Id: PremiumPolicyFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 
 /**
@@ -52,9 +65,8 @@ class PremiumPolicyFactory extends Factory {
 				//and the premium. So the PS Account could be postitive or negative amount
 				$retval = array(
 										10 => TTi18n::gettext('Pay Multiplied By Factor'),
-										20 => TTi18n::gettext('Pay + Premium'),
-										30 => TTi18n::gettext('Flat Hourly Rate') //Make this (Relative), based on hourly rate.
-										//40 => TTi18n::gettext('Flat Hourly Rate (Absolute)') //Not based on hourly rate
+										20 => TTi18n::gettext('Pay + Premium'), //This is the same a Flat Hourly Rate (Absolute)
+										30 => TTi18n::gettext('Flat Hourly Rate (Relative to Wage)'), //This is a relative rate based on their hourly rate.
 									);
 				break;
 			case 'branch_selection_type':
@@ -99,11 +111,99 @@ class PremiumPolicyFactory extends Factory {
 										30 => TTi18n::gettext('All Except Selected Tasks'),
 									);
 				break;
+
+			case 'columns':
+				$retval = array(
+										'-1010-type' => TTi18n::gettext('Type'),
+										'-1030-name' => TTi18n::gettext('Name'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'name',
+								'type',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'name',
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+
 		}
 
+
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'name' => 'Name',
+										'pay_type_id' => 'PayType',
+										'pay_type' => FALSE,
+										'start_date' => 'StartDate',
+										'end_date' => 'EndDate',
+										'start_time' => 'StartTime',
+										'end_time' => 'EndTime',
+										'daily_trigger_time' => 'DailyTriggerTime',
+										'weekly_trigger_time' => 'WeeklyTriggerTime',
+										'sun' => 'Sun',
+										'mon' => 'Mon',
+										'tue' => 'Tue',
+										'wed' => 'Wed',
+										'thu' => 'Thu',
+										'fri' => 'Fri',
+										'sat' => 'Sat',
+										'include_partial_punch' => 'IncludePartialPunch',
+										'maximum_no_break_time' => 'MaximumNoBreakTime',
+										'minimum_break_time' => 'MinimumBreakTime',
+										'minimum_time' => 'MinimumTime',
+										'maximum_time' => 'MaximumTime',
+										'include_meal_policy' => 'IncludeMealPolicy',
+										'include_break_policy' => 'IncludeBreakPolicy',
+										'wage_group_id' => 'WageGroup',
+										'rate' => 'Rate',
+										'accrual_rate' => 'AccrualRate',
+										'accrual_policy_id' => 'AccrualPolicyID',
+										'pay_stub_entry_account_id' => 'PayStubEntryAccountId',
+										'pay_stub_entry_account' => FALSE,
+										'branch' => 'Branch',
+										'branch_selection_type_id' => 'BranchSelectionType',
+										'branch_selection_type' => FALSE,
+										'exclude_default_branch' => 'ExcludeDefaultBranch',
+										'department' => 'Department',
+										'department_selection_type_id' => 'DepartmentSelectionType',
+										'department_selection_type' => FALSE,
+										'exclude_default_department' => 'ExcludeDefaultDepartment',
+										'job_group' => 'JobGroup',
+										'job_group_selection_type_id' => 'JobGroupSelectionType',
+										'job_group_selection_type' => FALSE,
+										'job' => 'Job',
+										'job_selection_type_id' => 'JobSelectionType',
+										'job_selection_type' => FALSE,
+										'job_item_group' => 'JobItemGroup',
+										'job_item_group_selection_type_id' => 'JobItemGroupSelectionType',
+										'job_item_group_selection_type' => FALSE,
+										'job_item' => 'JobItem',
+										'job_item_selection_type_id' => 'JobItemSelectionType',
+										'job_item_selection_type' => FALSE,
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getCompanyObject() {
 		if ( is_object($this->company_obj) ) {
@@ -208,7 +308,7 @@ class PremiumPolicyFactory extends Factory {
 			$value = $key;
 		}
 
-		if ( $this->Validator->inArrayKey(	'pay_type',
+		if ( $this->Validator->inArrayKey(	'pay_type_id',
 											$value,
 											TTi18n::gettext('Incorrect Pay Type'),
 											$this->getOptions('pay_type')) ) {
@@ -304,7 +404,7 @@ class PremiumPolicyFactory extends Factory {
 
 		if 	(	$epoch == ''
 				OR
-				$this->Validator->isDate(		'start_time'.$this->getLabelID(),
+				$this->Validator->isDate(		'start_time',
 												$epoch,
 												TTi18n::gettext('Incorrect Start time'))
 			) {
@@ -333,7 +433,7 @@ class PremiumPolicyFactory extends Factory {
 
 		if 	(	$epoch == ''
 				OR
-				$this->Validator->isDate(		'end_time'.$this->getLabelID(),
+				$this->Validator->isDate(		'end_time',
 												$epoch,
 												TTi18n::gettext('Incorrect End time'))
 			) {
@@ -510,7 +610,8 @@ class PremiumPolicyFactory extends Factory {
 			$int = 0;
 		}
 
-		if 	(	$this->Validator->isNumeric(		'maximum_no_break_time',
+		if 	( $int == 0
+				OR $this->Validator->isNumeric(		'maximum_no_break_time',
 													$int,
 													TTi18n::gettext('Incorrect Maximum Time Without Break')) ) {
 			$this->data['maximum_no_break_time'] = $int;
@@ -535,7 +636,8 @@ class PremiumPolicyFactory extends Factory {
 			$int = 0;
 		}
 
-		if 	(	$this->Validator->isNumeric(		'minimum_break_time',
+		if 	(	$int == 0
+				OR $this->Validator->isNumeric(		'minimum_break_time',
 													$int,
 													TTi18n::gettext('Incorrect Minimum Break Time')) ) {
 			$this->data['minimum_break_time'] = $int;
@@ -610,6 +712,46 @@ class PremiumPolicyFactory extends Factory {
 		return TRUE;
 	}
 
+	function getIncludeBreakPolicy() {
+		if ( isset($this->data['include_break_policy']) ) {
+			return $this->fromBool( $this->data['include_break_policy'] );
+		}
+
+		return FALSE;
+	}
+	function setIncludeBreakPolicy($bool) {
+		$this->data['include_break_policy'] = $this->toBool($bool);
+
+		return TRUE;
+	}
+
+	function getWageGroup() {
+		if ( isset($this->data['wage_group_id']) ) {
+			return $this->data['wage_group_id'];
+		}
+
+		return FALSE;
+	}
+	function setWageGroup($id) {
+		$id = trim($id);
+
+		$wglf = new WageGroupListFactory();
+
+		if ( $id == 0
+				OR
+				$this->Validator->isResultSetWithRows(	'wage_group',
+													$wglf->getByID($id),
+													TTi18n::gettext('Wage Group is invalid')
+													) ) {
+
+			$this->data['wage_group_id'] = $id;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getRate() {
 		if ( isset($this->data['rate']) ) {
 			return $this->data['rate'];
@@ -753,7 +895,8 @@ class PremiumPolicyFactory extends Factory {
 	function setBranchSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'branch_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'branch_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Branch Selection Type'),
 											$this->getOptions('branch_selection_type')) ) {
@@ -794,13 +937,15 @@ class PremiumPolicyFactory extends Factory {
 	}
 	function setBranch($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
+		Debug::Arr($ids, 'Setting Branch IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyBranchListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getBranch();
 					Debug::text('Branch ID: '. $obj->getBranch() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -822,7 +967,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new BranchListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyBranchFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setBranch( $id );
@@ -854,7 +999,8 @@ class PremiumPolicyFactory extends Factory {
 	function setDepartmentSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'department_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'department_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Department Selection Type'),
 											$this->getOptions('department_selection_type')) ) {
@@ -896,12 +1042,13 @@ class PremiumPolicyFactory extends Factory {
 	function setDepartment($ids) {
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyDepartmentListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getDepartment();
 					Debug::text('Department ID: '. $obj->getDepartment() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -923,7 +1070,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new DepartmentListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyDepartmentFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setDepartment( $id );
@@ -958,7 +1105,8 @@ class PremiumPolicyFactory extends Factory {
 	function setJobGroupSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'job_group_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'job_group_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Job Group Selection Type'),
 											$this->getOptions('job_group_selection_type')) ) {
@@ -995,12 +1143,13 @@ class PremiumPolicyFactory extends Factory {
 
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyJobGroupListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getJobGroup();
 					Debug::text('Job Group ID: '. $obj->getJobGroup() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -1022,7 +1171,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new JobGroupListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyJobGroupFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobGroup( $id );
@@ -1054,7 +1203,8 @@ class PremiumPolicyFactory extends Factory {
 	function setJobSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'job_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'job_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Job Selection Type'),
 											$this->getOptions('job_selection_type')) ) {
@@ -1091,12 +1241,13 @@ class PremiumPolicyFactory extends Factory {
 
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyJobListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getjob();
 					Debug::text('job ID: '. $obj->getJob() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -1118,7 +1269,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new JobListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyJobFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJob( $id );
@@ -1150,7 +1301,8 @@ class PremiumPolicyFactory extends Factory {
 	function setJobItemGroupSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'job_item_group_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'job_item_group_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Task Group Selection Type'),
 											$this->getOptions('job_item_group_selection_type')) ) {
@@ -1187,12 +1339,13 @@ class PremiumPolicyFactory extends Factory {
 
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyJobItemGroupListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getJobItemGroup();
 					Debug::text('Job Item Group ID: '. $obj->getJobItemGroup() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -1214,7 +1367,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new JobItemGroupListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyJobItemGroupFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobItemGroup( $id );
@@ -1246,7 +1399,8 @@ class PremiumPolicyFactory extends Factory {
 	function setJobItemSelectionType($value) {
 		$value = trim($value);
 
-		if ( $this->Validator->inArrayKey(	'job_item_selection_type',
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'job_item_selection_type',
 											$value,
 											TTi18n::gettext('Incorrect Task Selection Type'),
 											$this->getOptions('job_item_selection_type')) ) {
@@ -1283,12 +1437,13 @@ class PremiumPolicyFactory extends Factory {
 
 		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new PremiumPolicyJobItemListFactory();
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
 					$id = $obj->getJobItem();
 					Debug::text('Job Item ID: '. $obj->getJobItem() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -1310,7 +1465,7 @@ class PremiumPolicyFactory extends Factory {
 			$lf_b = new JobItemListFactory();
 
 			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
 					$f = new PremiumPolicyJobItemFactory();
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobItem( $id );
@@ -1332,17 +1487,27 @@ class PremiumPolicyFactory extends Factory {
 		return FALSE;
 	}
 
-	function isActive($epoch) {
-		if ( $this->isActiveDate($epoch) == TRUE
-				AND $this->isActiveDayOfWeek($epoch) == TRUE ) {
-			return TRUE;
+	function isActive( $in_epoch, $out_epoch = NULL ) {
+		if ( $out_epoch == '' ) {
+			$out_epoch = $in_epoch;
 		}
 
+		//Debug::text(' In: '. TTDate::getDate('DATE+TIME', $in_epoch) .' Out: '. TTDate::getDate('DATE+TIME', $out_epoch), __FILE__, __LINE__, __METHOD__, 10);
+		for( $i=$in_epoch; $i <= $out_epoch; $i+=86400 ) {
+			if ( $this->isActiveDate($i) == TRUE AND $this->isActiveDayOfWeek($i) == TRUE ) {
+				//Debug::text('Active Date/DayOfWeek: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__, 10);
+
+				return TRUE;
+			}
+		}
+
+		Debug::text('NOT Active Date/DayOfWeek: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__, 10);
+
 		return FALSE;
 	}
 
 	//Check if this premium policy is restricted by time.
-	//If its not, we can applu it to non-punched hours.
+	//If its not, we can apply it to non-punched hours.
 	function isTimeRestricted() {
 		//If time restrictions account for over 23.5 hours, then we assume
 		//that this policy is not time restricted at all.
@@ -1364,7 +1529,9 @@ class PremiumPolicyFactory extends Factory {
 	function getPartialPunchTotalTime( $in_epoch, $out_epoch, $total_time ) {
 		$retval = $total_time;
 
-		if ( $this->isActiveTime( $in_epoch, $out_epoch ) AND $this->getIncludePartialPunch() == TRUE ) {
+		if ( $this->isActiveTime( $in_epoch, $out_epoch )
+				AND $this->getIncludePartialPunch() == TRUE
+				AND ( $this->getStartTime() > 0 OR $this->getEndTime() > 0 ) ) {
 			Debug::text(' Checking for Active Time with: In: '. TTDate::getDate('DATE+TIME', $in_epoch) .' Out: '. TTDate::getDate('DATE+TIME', $out_epoch), __FILE__, __LINE__, __METHOD__, 10);
 
 			Debug::text(' Raw Start TimeStamp('.$this->getStartTime(TRUE).'): '. TTDate::getDate('DATE+TIME', $this->getStartTime() ) .' Raw End TimeStamp: '. TTDate::getDate('DATE+TIME', $this->getEndTime() )  , __FILE__, __LINE__, __METHOD__, 10);
@@ -1377,13 +1544,18 @@ class PremiumPolicyFactory extends Factory {
 				$end_time_stamp = $end_time_stamp + 86400;
 			}
 
-			$start_time_stamp2 = $start_time_stamp - 86400;
-			$end_time_stamp2 = $end_time_stamp - 86400;
+			$retval = 0;
+			for( $i=($start_time_stamp-86400); $i <= ($end_time_stamp+86400); $i+=86400 ) {
+				$tmp_start_time_stamp = $i;
+				$tmp_end_time_stamp = $tmp_start_time_stamp + ($end_time_stamp - $start_time_stamp);
 
-			Debug::text(' Start TimeStamp: '. TTDate::getDate('DATE+TIME', $start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
-			Debug::text(' Start TimeStamp2: '. TTDate::getDate('DATE+TIME', $start_time_stamp2) .' End TimeStamp2: '. TTDate::getDate('DATE+TIME', $end_time_stamp2)  , __FILE__, __LINE__, __METHOD__, 10);
-
-			$retval = TTDate::getTimeOverLapDifference( $start_time_stamp, $end_time_stamp, $in_epoch, $out_epoch ) + TTDate::getTimeOverLapDifference( $start_time_stamp2, $end_time_stamp2, $in_epoch, $out_epoch );
+				if ( $this->isActiveTime( $tmp_start_time_stamp, $tmp_end_time_stamp ) == TRUE ) {
+					$retval += TTDate::getTimeOverLapDifference( $tmp_start_time_stamp, $tmp_end_time_stamp, $in_epoch, $out_epoch );
+					Debug::text(' Calculating partial time against Start TimeStamp: '. TTDate::getDate('DATE+TIME', $tmp_start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $tmp_end_time_stamp) .' Total: '. $retval  , __FILE__, __LINE__, __METHOD__, 10);
+				} else {
+					Debug::text(' Not Active on this day: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__, 10);
+				}
+			}
 		}
 
 		Debug::text(' Partial Punch Total Time : '. $retval, __FILE__, __LINE__, __METHOD__, 10);
@@ -1404,14 +1576,7 @@ class PremiumPolicyFactory extends Factory {
 			$end_time_stamp = $end_time_stamp + 86400;
 		}
 
-		//If the premium policy start/end time spans midnight, there could be two windows in a single day
-		//where the premium policy applies, make sure we check both windows.
-		$start_time_stamp2 = $start_time_stamp - 86400;
-		$end_time_stamp2 = $end_time_stamp - 86400;
-
 		Debug::text(' Start TimeStamp: '. TTDate::getDate('DATE+TIME', $start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
-		Debug::text(' Start TimeStamp2: '. TTDate::getDate('DATE+TIME', $start_time_stamp2) .' End TimeStamp2: '. TTDate::getDate('DATE+TIME', $end_time_stamp2)  , __FILE__, __LINE__, __METHOD__, 10);
-
 		//Check to see if start/end time stamps are not set or are equal, we always return TRUE if they are.
 		if ( $start_time_stamp == ''
 				OR $end_time_stamp == ''
@@ -1420,17 +1585,25 @@ class PremiumPolicyFactory extends Factory {
 
 			return TRUE;
 		} else {
-			if ( $this->getIncludePartialPunch() == TRUE ) {
-				if ( ( ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp ) OR ( $out_epoch >= $start_time_stamp AND $out_epoch <= $end_time_stamp ) )
-						OR ( ( $in_epoch >= $start_time_stamp2 AND $in_epoch <= $end_time_stamp2 ) OR ( $out_epoch >= $start_time_stamp2 AND $out_epoch <= $end_time_stamp2 ) ) ) {
-					Debug::text(' Partial Punch Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
-					return TRUE;
-				}
-			} else {
-				if ( ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp )
-						OR ( $in_epoch >= $start_time_stamp2 AND $in_epoch <= $end_time_stamp2 ) ) {
-					Debug::text(' Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
-					return TRUE;
+			//If the premium policy start/end time spans midnight, there could be multiple windows to check
+			//where the premium policy applies, make sure we check all windows.
+			for( $i=($start_time_stamp-86400); $i <= ($end_time_stamp+86400); $i+=86400 ) {
+				$tmp_start_time_stamp = $i;
+				$tmp_end_time_stamp = $tmp_start_time_stamp + ($end_time_stamp - $start_time_stamp);
+
+				if ( $this->isActive( $tmp_start_time_stamp, $tmp_end_time_stamp ) == TRUE ) {
+					//Debug::text(' Checking against Start TimeStamp: '. TTDate::getDate('DATE+TIME', $tmp_start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $tmp_end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
+					if ( $this->getIncludePartialPunch() == TRUE AND TTDate::isTimeOverLap( $in_epoch, $out_epoch, $tmp_start_time_stamp, $tmp_end_time_stamp) == TRUE ) {
+						//When dealing with partial punches, any overlap whatsoever activates the policy.
+						Debug::text(' Partial Punch Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
+						return TRUE;
+					} elseif ( $in_epoch >= $tmp_start_time_stamp AND $in_epoch <= $tmp_end_time_stamp ) {
+						//Non partial punches, they must punch in within the time window.
+						Debug::text(' Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
+						return TRUE;
+					}
+				} else {
+					Debug::text(' Not Active on this day: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__, 10);
 				}
 			}
 		}
@@ -1442,7 +1615,7 @@ class PremiumPolicyFactory extends Factory {
 
 	//Check if this date is within the effective date range
 	function isActiveDate( $epoch ) {
-		Debug::text(' Checking for Active Date.', __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text(' Checking for Active Date: '. TTDate::getDate('DATE+TIME', $epoch), __FILE__, __LINE__, __METHOD__, 10);
 		$epoch = TTDate::getBeginDayEpoch( $epoch );
 
 		if ( $this->getStartDate() == '' AND $this->getEndDate() == '') {
@@ -1459,7 +1632,7 @@ class PremiumPolicyFactory extends Factory {
 
 	//Check if this day of the week is active
 	function isActiveDayOfWeek($epoch) {
-		Debug::text(' Checking for Active Day of Week.', __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text(' Checking for Active Day of Week.', __FILE__, __LINE__, __METHOD__, 10);
 		$day_of_week = strtolower(date('D', $epoch));
 
 		switch ($day_of_week) {
@@ -1538,6 +1711,10 @@ class PremiumPolicyFactory extends Factory {
 			$this->setJobItemSelectionType(10); //All
 		}
 
+		if ( $this->getWageGroup() === FALSE ) {
+			$this->setWageGroup( 0 );
+		}
+
 		return TRUE;
 	}
 
@@ -1547,6 +1724,87 @@ class PremiumPolicyFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'start_date':
+						case 'end_date':
+						case 'start_time':
+						case 'end_time':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'type':
+						case 'pay_type':
+						case 'branch_selection_type':
+						case 'department_selection_type':
+						case 'job_group_selection_type':
+						case 'job_selection_type':
+						case 'job_item_group_selection_type':
+						case 'job_item_selection_type':
+							$function = 'get'. str_replace('_','', $variable);
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'start_date':
+						case 'end_date':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						case 'start_time':
+						case 'end_time':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'TIME', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Premium Policy'), NULL, $this->getTable() );
 	}
