@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: PunchControlFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3562 $
+ * $Id: PunchControlFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -60,6 +60,30 @@ class PunchControlFactory extends Factory {
 	protected $plf = NULL;
 	protected $is_total_time_calculated = FALSE;
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'user_date_id' => 'UserDateID',
+											'branch_id' => 'Branch',
+											'department_id' => 'Department',
+											'job_id' => 'Job',
+											'job_item_id' => 'JobItem',
+											'quantity' => 'Quantity',
+											'bad_quantity' => 'BadQuantity',
+											'total_time' => 'TotalTime',
+											'actual_total_time' => 'ActualTotalTime',
+											'meal_policy_id' => 'MealPolicyID',
+											'note' => 'Note',
+											'other_id1' => 'OtherID1',
+											'other_id2' => 'OtherID2',
+											'other_id3' => 'OtherID3',
+											'other_id4' => 'OtherID4',
+											'other_id5' => 'OtherID5',
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
+
 	function getUserDateObject( $id = NULL ) {
 		if ( $id == '' AND is_object( $this->user_date_obj ) ) {
 			return $this->user_date_obj;
@@ -271,212 +295,6 @@ class PunchControlFactory extends Factory {
 		return TRUE;
 	}
 
-/*
-	function findUserDate($user_id = NULL, $epoch = NULL, $status_id = 10, $punch_id = 0 ) {
-		//
-			Issues to consider:
-				1. Employee punches out at 11:00PM, then is called in early at 4AM to start a new shift.
-				Don't want to pair these punches.
-
-				2. Employee starts 11:00PM shift late at 1:00AM the next day. Works until 7AM, then comes in again
-				at 11:00PM the same day and works until 4AM, then 4:30AM to 7:00AM. The 4AM-7AM punches need to be paired on the same day.
-
-				3. Ambulance EMT works 36hours straight in a single punch.
-
-				*Perhaps we should handle lunch punches and normal punches differently? Lunch punches have
-				a different "continuous time setting then normal punches.
-
-				*Change daily continuous time to:
-				* Group (Normal) Punches: X hours before midnight to punches X hours after midnight
-				* Group (Lunch/Break) Punches: X hours before midnight to punches X hours after midnight
-				*	Normal punches X hours after midnight group to punches X hours before midnight.
-				*	Lunch/Break punches X hours after midnight group to punches X hours before midnight.
-
-				OR, what if we change continuous time to be just the gap between punches that cause
-					a new day to start? Combine this with daily cont. time so we know what the window
-					is for punches to begin the gap search. Or we can always just search for a previous
-					punch Xhrs before the current punch.
-					- Do we look back to a In punch, or look back to an Out punch though? I think an Out Punch.
-						What happens if they forgot to punch out though?
-					Logic:
-						If this is an Out punch:
-							Find previous punch back to maximum shift time to find an In punch to pair it with.
-						Else, if this is an In punch:
-							Find previous punch back to maximum shift time to find an Out punch to combine it with.
-							If out punch is found inside of new_shift trigger time, we place this punch on the previous day.
-							Else: we place this punch on todays date.
-
-
-				* Minimum time between punches to cause a new shift to start: Xhrs (default: 4hrs)
-					new_day_trigger_time
-					Call it: Minimum time-off that triggers new shift:
-						Minimum Time-Off Between Shifts:
-				* Maximum shift time: Xhrs (for ambulance service) default to 16 or 24hrs?
-					This is essentially how far back we look for In punch to pair out punches with.
-					maximum_shift_length
-					- Add checks to ensure that no punch pair exceeds the maximum_shift_length
-
-		//
-		if ( is_object( $this->getPunchObject() ) ) {
-			if ( $this->getPunchObject()->getUser() != FALSE ) {
-				$user_id = $this->getPunchObject()->getUser();
-			} elseif ( is_object( $this->getUserDateObject() ) ) {
-				$user_id = $this->getUserDateObject()->getUser();
-			}
-
-			$epoch = $this->getPunchObject()->getTimeStamp();
-			//Get pay period new_day_trigger/maximum_shift time
-			$ppslf = new PayPeriodScheduleListFactory();
-			$ppslf->getByUserId( $user_id );
-			if ( $ppslf->getRecordCount() == 1 ) {
-				$pps_obj = $ppslf->getCurrent();
-				Debug::Text(' Pay Period Schedule Maximum Shift Time: '. $pps_obj->getMaximumShiftTime() .' Shift Assigned Day: '. $pps_obj->getShiftAssignedDay(), __FILE__, __LINE__, __METHOD__,10);
-
-				$this->shift_data = $pps_obj->getShiftData( NULL, $user_id, $epoch, 'nearest_shift', $this);
-
-				if ( is_array($this->shift_data) ) {
-					switch ( $pps_obj->getShiftAssignedDay() ) {
-						case 10: //Day they start on
-							//Can't use the First In user_date_id because it may need to be changed when editing a punch.
-							Debug::Text('Assign Shifts to the day they START on... Date: '. TTDate::getDate('DATE', $this->shift_data['first_in']['time_stamp']) , __FILE__, __LINE__, __METHOD__,10);
-							$user_date_id = UserDateFactory::findOrInsertUserDate( $user_id, $this->shift_data['first_in']['time_stamp'] );
-							break;
-						case 20: //Day they end on
-							Debug::Text('Assign Shifts to the day they END on... Date: '. TTDate::getDate('DATE', $this->shift_data['last_out']['time_stamp']) , __FILE__, __LINE__, __METHOD__,10);
-							$user_date_id = UserDateFactory::findOrInsertUserDate( $user_id, $this->shift_data['last_out']['time_stamp'] );
-							break;
-						case 30: //Day with most time worked
-							Debug::Text('Assign Shifts to the day they WORK MOST on... Date: '. TTDate::getDate('DATE', $this->shift_data['day_with_most_time']) , __FILE__, __LINE__, __METHOD__,10);
-							$user_date_id = UserDateFactory::findOrInsertUserDate( $user_id, $this->shift_data['day_with_most_time'] );
-							break;
-						case 40: //Split at midnight
-							Debug::Text('Assign Shifts to each day (split at midnight)...', __FILE__, __LINE__, __METHOD__,10);
-							break;
-					}
-					Debug::Text('Assigning to User Date ID: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
-
-					if ( isset($user_date_id) AND $user_date_id > 0 ) {
-						if ( $this->getUserDateID() != FALSE AND $this->getUserDateID() != $user_date_id ) {
-							$this->setOldUserDateID( $this->getUserDateID() );
-						}
-						$this->setUserDateID( $user_date_id );
-
-						return TRUE;
-					}
-				}
-			}
-
-			Debug::Text(' Pay Period Schedule Record Count: '. $ppslf->getRecordCount() .' Epoch: '. TTDate::getDate('DATE+TIME', $epoch)  , __FILE__, __LINE__, __METHOD__,10);
-			Debug::Text('bSkipping find...', __FILE__, __LINE__, __METHOD__,10);
-			return $this->setUserDate( $user_id, $epoch );
-		}
-
-		Debug::Text('Returning FALSE!', __FILE__, __LINE__, __METHOD__,10);
-		return FALSE;
-	}
-*/
-/*
-	function findUserDate($user_id, $epoch, $status_id = 10, $punch_id = 0 ) {
-		//
-			Issues to consider:
-				1. Employee punches out at 11:00PM, then is called in early at 4AM to start a new shift.
-				Don't want to pair these punches.
-
-				2. Employee starts 11:00PM shift late at 1:00AM the next day. Works until 7AM, then comes in again
-				at 11:00PM the same day and works until 4AM, then 4:30AM to 7:00AM. The 4AM-7AM punches need to be paired on the same day.
-
-				3. Ambulance EMT works 36hours straight in a single punch.
-
-				*Perhaps we should handle lunch punches and normal punches differently? Lunch punches have
-				a different "continuous time setting then normal punches.
-
-				*Change daily continuous time to:
-				* Group (Normal) Punches: X hours before midnight to punches X hours after midnight
-				* Group (Lunch/Break) Punches: X hours before midnight to punches X hours after midnight
-				*	Normal punches X hours after midnight group to punches X hours before midnight.
-				*	Lunch/Break punches X hours after midnight group to punches X hours before midnight.
-
-				OR, what if we change continuous time to be just the gap between punches that cause
-					a new day to start? Combine this with daily cont. time so we know what the window
-					is for punches to begin the gap search. Or we can always just search for a previous
-					punch Xhrs before the current punch.
-					- Do we look back to a In punch, or look back to an Out punch though? I think an Out Punch.
-						What happens if they forgot to punch out though?
-					Logic:
-						If this is an Out punch:
-							Find previous punch back to maximum shift time to find an In punch to pair it with.
-						Else, if this is an In punch:
-							Find previous punch back to maximum shift time to find an Out punch to combine it with.
-							If out punch is found inside of new_shift trigger time, we place this punch on the previous day.
-							Else: we place this punch on todays date.
-
-
-				* Minimum time between punches to cause a new shift to start: Xhrs (default: 4hrs)
-					new_day_trigger_time
-					Call it: Minimum time-off that triggers new shift:
-						Minimum Time-Off Between Shifts:
-				* Maximum shift time: Xhrs (for ambulance service) default to 16 or 24hrs?
-					This is essentially how far back we look for In punch to pair out punches with.
-					maximum_shift_length
-					- Add checks to ensure that no punch pair exceeds the maximum_shift_length
-
-		//
-		//Get pay period new_day_trigger/maximum_shift time
-		$ppslf = new PayPeriodScheduleListFactory();
-		$ppslf->getByUserId( $user_id );
-		if ( $ppslf->getRecordCount() == 1 ) {
-			$pps_obj = $ppslf->getCurrent();
-			Debug::Text(' Pay Period Schedule Maximum Shift Time: '. $pps_obj->getMaximumShiftTime(), __FILE__, __LINE__, __METHOD__,10);
-
-			//If this is an out punch, we need to find the timestamp of the In punch to base
-			//maximum shift time off of.
-			$plf = new PunchListFactory();
-			if ( $status_id == 20 ) {
-				//getPreviousPunchByUserIdAndEpoch uses <= $epoch, so we minus one second from it
-				//so it doesn't find the punch we may be editing.
-				$plf->getPreviousPunchByUserIdAndEpochAndNotPunchIDAndMaximumShiftTime( $user_id, $epoch-1, $punch_id, $pps_obj->getMaximumShiftTime() );
-				if ( $plf->getRecordCount() > 0 ) {
-					$p_obj = $plf->getCurrent();
-
-					//Make sure the previous punch is an In punch only. This fixes the bug where the employee forgot
-					//to punch In the next day after a regular shift, so the first punch of the day was an Out punch
-					//causing TimeTrex to place it on the previous day.
-					if ( $p_obj->getStatus() == 10 ) {
-						$epoch = $p_obj->getTimeStamp();
-						Debug::Text('Found In Punch Epoch: '. $epoch .' - '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__,10);
-					} else {
-						Debug::Text('Previous punch was an Out punch, not pairing with it.', __FILE__, __LINE__, __METHOD__,10);
-					}
-					unset($p_obj);
-				} else {
-					Debug::Text('DID NOT Find In Punch Epoch: '. $epoch, __FILE__, __LINE__, __METHOD__,10);
-				}
-			}
-
-			//Get previous punch, if its an Out punch, make sure this punch is within the new_day_trigger_time to be grouped
-			//on the same day as it.
-			$plf->getPreviousPunchByUserIdAndEpochAndNotPunchIDAndMaximumShiftTime( $user_id, $epoch-1, $punch_id, $pps_obj->getNewDayTriggerTime() );
-			if ( $plf->getRecordCount() > 0 ) {
-				$p_obj = $plf->getCurrent();
-				//Debug::Text('Current Punch Epoch: '. $epoch .' First Punch Epoch: '.$p_obj->getTimeStamp(), __FILE__, __LINE__, __METHOD__,10);
-
-				if ( ( $epoch - $p_obj->getTimeStamp() ) <= $pps_obj->getNewDayTriggerTime() ) {
-					$user_date_id = $p_obj->getPunchControlObject()->getUserDateID();
-					Debug::text(' User Date ID found: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
-
-					$this->setUserDateID( $user_date_id );
-					return TRUE;
-				}
-			}
-		}
-
-		Debug::Text('Skipping Find...', __FILE__, __LINE__, __METHOD__,10);
-		Debug::Text(' Pay Period Schedule Record Count: '. $ppslf->getRecordCount() .' Epoch: '. TTDate::getDate('DATE+TIME', $epoch)  , __FILE__, __LINE__, __METHOD__,10);
-
-		return $this->setUserDate( $user_id, $epoch );
-	}
-*/
-
 	function setUserDate($user_id, $date) {
 		$user_date_id = UserDateFactory::findOrInsertUserDate( $user_id, $date );
 		Debug::text(' User Date ID: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
@@ -1201,18 +1019,17 @@ class PunchControlFactory extends Factory {
 										TTi18n::gettext('Pay Period is Currently Locked') );
 		}
 
-		$plf = $this->getPLFByPunchControlID();
-		if ( $plf !== NULL AND ( ( $this->isNew() AND $plf->getRecordCount() == 2 )
-				OR $plf->getRecordCount() > 2 ) ) {
-			//TTi18n::gettext('Punch Control can not have more than two punches. Please use the Add Punch button instead')
-			//They might be trying to insert a punch inbetween two others?
-			$this->Validator->isTRUE(	'punch_control',
-										FALSE,
-										TTi18n::gettext('Time conflicts with another punch on this day (c)'));
-		}
-
 		//Skip these checks if they are deleting a punch.
 		if ( is_object( $this->getPunchObject() ) AND $this->getPunchObject()->getDeleted() == FALSE ) {
+			$plf = $this->getPLFByPunchControlID();
+			if ( $plf !== NULL AND ( ( $this->isNew() AND $plf->getRecordCount() == 2 ) OR $plf->getRecordCount() > 2 ) ) {
+				//TTi18n::gettext('Punch Control can not have more than two punches. Please use the Add Punch button instead')
+				//They might be trying to insert a punch inbetween two others?
+				$this->Validator->isTRUE(	'punch_control',
+											FALSE,
+											TTi18n::gettext('Time conflicts with another punch on this day (c)'));
+			}
+
 			$shift_data = $this->getShiftData();
 			if ( is_array($shift_data) ) {
 				foreach ( $shift_data['punches'] as $punch_data ) {
@@ -1476,6 +1293,272 @@ class PunchControlFactory extends Factory {
 		return FALSE;
 	}
 
+	//This function handles when th UI wants to drag and drop punches around the time sheet.
+	//$action = 0 (Copy), 1 (Move)
+	//$position = -1 (Before), 0 (Overwrite), 1 (After)
+	static function dragNdropPunch( $company_id, $src_punch_id, $dst_punch_id, $position, $action = 0, $dst_date = NULL ) {
+		/*
+			Operations to handle:
+				- Moving punch from Out to In, or In to Out in same punch pair, this is ALWAYS a move, and not a copy.
+				- Move punch from one pair to another in the same day, this can be a copy or move.
+				- Move punch from one day to another, inserting inbetween other punches if necessary.
+				- Move punch from one day to another without any other punches.
+
+
+				- Inserting BEFORE on a dst_punch_id that is an In punch doesn't do any splitting.
+				- Inserting AFTER on a dst_punch_id that is on a Out punch doesn't do any splitting.
+				- Overwriting should just take the punch time and overwrite the existing punch time.
+				- The first thing this function does it check if there are two punches assigned to the punch control of the destination punch, if there is, it splits the punches
+					across two punch_controls, it then attaches the src_punch_id to the same punch_control_id as the dst_punch_id.
+				- If no dst_punch_id is specified, assume copying to a blank cell, just copy the punch to that date along with the punch_control?
+		*/
+		$dst_date = TTDate::getMiddleDayEpoch( $dst_date );
+		Debug::text('Src Punch ID: '. $src_punch_id .' Dst Punch ID: '. $dst_punch_id .' Position: '. $position .' Action: '. $action .' Dst Date: '. $dst_date, __FILE__, __LINE__, __METHOD__,10);
+
+		$retval = FALSE;
+
+		//Get source and destination punch objects.
+		$plf = new PunchListFactory();
+		$plf->StartTransaction();
+
+		$plf->getByCompanyIDAndId( $company_id, $src_punch_id );
+		if ( $plf->getRecordCount() == 1 ) {
+			$src_punch_obj = $plf->getCurrent();
+			$src_punch_date = TTDate::getMiddleDayEpoch( $src_punch_obj->getPunchControlObject()->getUserDateObject()->getDateStamp() );
+			Debug::text('Found SRC punch ID: '. $src_punch_id .' Source Punch Date: '. $src_punch_date , __FILE__, __LINE__, __METHOD__,10);
+
+			//If we are moving the punch, we need to delete the source punch first so it doesn't conflict with the new punch.
+			//Especially if we are just moving a punch to fill a gap in the same day.
+			//If the punch being moved is in the same day, or within the same punch pair, we don't want to delete the source punch, instead we just modify
+			//the necessary bits later on. So we need to short circuit the move functionality when copying/moving punches within the same day.
+			if ( ( $action == 1 AND $src_punch_id != $dst_punch_id AND $src_punch_date != $dst_date )
+					OR ( $action == 0 AND $src_punch_id != $dst_punch_id AND $src_punch_date == $dst_date ) ) { //Move
+				Debug::text('Deleting original punch...: '. $src_punch_id, __FILE__, __LINE__, __METHOD__,10);
+				$src_punch_obj->setUser( $src_punch_obj->getPunchControlObject()->getUserDateObject()->getUser() );
+				$src_punch_obj->setDeleted(TRUE);
+
+				//These aren't doing anything because they aren't acting on the PunchControl object?
+				$src_punch_obj->setEnableCalcTotalTime( TRUE );
+				$src_punch_obj->setEnableCalcSystemTotalTime( TRUE );
+				$src_punch_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
+				$src_punch_obj->setEnableCalcUserDateTotal( TRUE );
+				$src_punch_obj->setEnableCalcException( TRUE );
+				$src_punch_obj->Save(FALSE); //Keep object around for later.
+			} else {
+				Debug::text('NOT Deleting original punch, either in copy mode or condition is not met...', __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			if ( $src_punch_id == $dst_punch_id OR $dst_punch_id == '' ) {
+				//Assume we are just moving a punch within the same punch pair, unless a new date is specfied.
+				if ( $src_punch_date != $dst_date ) {
+					Debug::text('aCopying punch to new day...', __FILE__, __LINE__, __METHOD__,10);
+					//Moving punch to a new date.
+					//Copy source punch to proper location by destination punch.
+					$src_punch_control_obj = $src_punch_obj->getPunchControlObject();
+
+					$src_punch_obj->setId( FALSE );
+					$src_punch_obj->setPunchControlId( (int)$src_punch_control_obj->getNextInsertId() );
+					$src_punch_obj->setDeleted(FALSE); //Just in case it was marked deleted by the MOVE action.
+
+					$new_time_stamp = TTDate::getTimeLockedDate($src_punch_obj->getTimeStamp(), $dst_date );
+					Debug::text('SRC TimeStamp: '. TTDate::getDate('DATE+TIME', $src_punch_obj->getTimeStamp() ).' DST TimeStamp: '. TTDate::getDate('DATE+TIME', $new_time_stamp ), __FILE__, __LINE__, __METHOD__,10);
+
+					$src_punch_obj->setTimeStamp( $new_time_stamp, FALSE );
+					$src_punch_obj->setActualTimeStamp( $new_time_stamp );
+					$src_punch_obj->setOriginalTimeStamp( $new_time_stamp );
+					if ( $src_punch_obj->isValid() == TRUE ) {
+						$src_punch_obj->Save( FALSE );
+
+						$src_punch_control_obj->shift_data = NULL; //Need to clear the shift data so its obtained from the DB again, otherwise shifts will appear on strange days.
+						$src_punch_control_obj->setId( $src_punch_obj->getPunchControlID() );
+						$src_punch_control_obj->setPunchObject( $src_punch_obj );
+
+						if ( $src_punch_control_obj->isValid() == TRUE ) {
+							Debug::Text(' Punch Control is valid, saving...: ', __FILE__, __LINE__, __METHOD__,10);
+
+							//We need to calculate new total time for the day and exceptions because we are never guaranteed that the gaps will be filled immediately after
+							//in the case of a drag & drop or something.
+							$src_punch_control_obj->setEnableStrictJobValidation( TRUE );
+							$src_punch_control_obj->setEnableCalcUserDateID( TRUE );
+							$src_punch_control_obj->setEnableCalcTotalTime( TRUE );
+							$src_punch_control_obj->setEnableCalcSystemTotalTime( TRUE );
+							$src_punch_control_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
+							$src_punch_control_obj->setEnableCalcUserDateTotal( TRUE );
+							$src_punch_control_obj->setEnableCalcException( TRUE );
+							if ( $src_punch_control_obj->isValid() == TRUE ) {
+								if ( $src_punch_control_obj->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
+									$retval = TRUE;
+								}
+							}
+						}
+					}
+				} else {
+					Debug::text('Copying punch within same pair/day...', __FILE__, __LINE__, __METHOD__,10);
+					//Moving punch within the same punch pair.
+					$src_punch_obj->setStatus( $src_punch_obj->getNextStatus() ); //Change just the punch status.
+					//$src_punch_obj->setDeleted(FALSE); //Just in case it was marked deleted by the MOVE action.
+					if ( $src_punch_obj->isValid() == TRUE ) {
+						$src_punch_obj->Save( FALSE );
+						$retval = TRUE;
+					}
+				}
+			} else {
+				Debug::text('bCopying punch to new day...', __FILE__, __LINE__, __METHOD__,10);
+				$plf->getByCompanyIDAndId($company_id, $dst_punch_id );
+				if ( $plf->getRecordCount() == 1 ) {
+					Debug::text('Found DST punch ID: '. $dst_punch_id, __FILE__, __LINE__, __METHOD__,10);
+					$dst_punch_obj = $plf->getCurrent();
+					$dst_punch_control_obj = $dst_punch_obj->getPunchControlObject();
+
+					if ( $position == 0 ) { //Overwrite
+						//All we need to do is update the time of the destination punch.
+						$punch_obj = $dst_punch_obj;
+					} else { //Before or After
+						//Determine if the destination punch needs to split from another punch
+						if ( ( $position == -1 AND $dst_punch_obj->getStatus() == 20 )
+								OR ( $position == 1 AND $dst_punch_obj->getStatus() == 10 ) ) { //Before on Out punch, After on In Punch,
+							Debug::text('Need to split destination punch out to its own Punch Control row...', __FILE__, __LINE__, __METHOD__,10);
+							PunchControlFactory::splitPunchControl( $dst_punch_obj->getPunchControlID() );
+
+							//Once a split occurs, we need to re-get the destination punch as the punch_control_id may have changed.
+							//We could probably optimize this to only occur when the destination punch is an In punch, as the
+							//Out punch is always the one to be moved to a new punch_control_id
+							if ( $src_punch_obj->getStatus() != $dst_punch_obj->getStatus() ) {
+								$plf->getByCompanyIDAndId($company_id, $dst_punch_id );
+								if ( $plf->getRecordCount() == 1 ) {
+									$dst_punch_obj = $plf->getCurrent();
+									Debug::text('Found DST punch ID: '. $dst_punch_id .' Punch Control ID: '. $dst_punch_obj->getPunchControlID(), __FILE__, __LINE__, __METHOD__,10);
+								}
+							}
+
+							$punch_control_id = $dst_punch_obj->getPunchControlID();
+						} else {
+							Debug::text('No Need to split destination punch, simply add a new punch/punch_control all on its own.', __FILE__, __LINE__, __METHOD__,10);
+							$punch_control_id = (int)$dst_punch_control_obj->getNextInsertId();
+						}
+
+						//Take the source punch and base our new punch on that.
+						$punch_obj = $src_punch_obj;
+
+						//Copy source punch to proper location by destination punch.
+						$punch_obj->setId( FALSE );
+						$punch_obj->setDeleted(FALSE); //Just in case it was marked deleted by the MOVE action.
+						$punch_obj->setPunchControlId( $punch_control_id );
+					}
+
+					$new_time_stamp = TTDate::getTimeLockedDate($src_punch_obj->getTimeStamp(), $dst_punch_obj->getTimeStamp() );
+					Debug::text('SRC TimeStamp: '. TTDate::getDate('DATE+TIME', $src_punch_obj->getTimeStamp() ).' DST TimeStamp: '. TTDate::getDate('DATE+TIME', $new_time_stamp ), __FILE__, __LINE__, __METHOD__,10);
+
+					$punch_obj->setTimeStamp( $new_time_stamp, FALSE );
+					$punch_obj->setActualTimeStamp( $new_time_stamp );
+					$punch_obj->setOriginalTimeStamp( $new_time_stamp );
+					if ( $punch_obj->isValid() == TRUE ) {
+						$punch_obj->Save( FALSE );
+
+						$dst_punch_control_obj->shift_data = NULL; //Need to clear the shift data so its obtained from the DB again, otherwise shifts will appear on strange days, or cause strange conflicts.
+						$dst_punch_control_obj->setID( $punch_obj->getPunchControlID() );
+						$dst_punch_control_obj->setPunchObject( $punch_obj );
+
+						if ( $dst_punch_control_obj->isValid() == TRUE ) {
+							Debug::Text(' Punch Control is valid, saving...: ', __FILE__, __LINE__, __METHOD__,10);
+
+							//We need to calculate new total time for the day and exceptions because we are never guaranteed that the gaps will be filled immediately after
+							//in the case of a drag & drop or something.
+							$dst_punch_control_obj->setEnableStrictJobValidation( TRUE );
+							$dst_punch_control_obj->setEnableCalcUserDateID( TRUE );
+							$dst_punch_control_obj->setEnableCalcTotalTime( TRUE );
+							$dst_punch_control_obj->setEnableCalcSystemTotalTime( TRUE );
+							$dst_punch_control_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
+							$dst_punch_control_obj->setEnableCalcUserDateTotal( TRUE );
+							$dst_punch_control_obj->setEnableCalcException( TRUE );
+							if ( $dst_punch_control_obj->isValid() == TRUE ) {
+								if ( $dst_punch_control_obj->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
+									$retval = TRUE;
+								}
+							}
+						}
+					}
+				}
+			}
+		}
+
+		if ( $retval == FALSE ) {
+			$plf->FailTransaction();
+		}
+		//$plf->FailTransaction();
+		$plf->CommitTransaction();
+
+		Debug::text('Returning: '. (int)$retval, __FILE__, __LINE__, __METHOD__,10);
+		return $retval;
+	}
+
+	//When passed a punch_control_id, if it has two punches assigned to it, a new punch_control_id row is created and the punches are split between the two.
+	static function splitPunchControl( $punch_control_id ) {
+		if ( $punch_control_id != '' ) {
+			$plf = new PunchListFactory();
+			$plf->StartTransaction();
+			$plf->getByPunchControlID( $punch_control_id, NULL, array( 'time_stamp' => 'desc' ) ); //Move out punch to new punch_control_id.
+			if ( $plf->getRecordCount() == 2 ) {
+				$pclf = new PunchControlListFactory();
+				$new_punch_control_id = (int)$pclf->getNextInsertId();
+				Debug::text(' Punch Control ID: '. $punch_control_id .' only has two punches assigned, splitting... New Punch Control ID: '. $new_punch_control_id, __FILE__, __LINE__, __METHOD__,10);
+				$i = 0;
+				foreach( $plf as $p_obj ) {
+					if ( $i == 0 ) {
+						//First punch (out)
+						//Get the PunchControl Object before we change to the new punch_control_id
+						$pc_obj = $p_obj->getPunchControlObject();
+
+						$p_obj->setPunchControlId( $new_punch_control_id );
+						if ( $p_obj->isValid() == TRUE ) {
+							$p_obj->Save( FALSE );
+
+							$pc_obj->setId( $new_punch_control_id );
+							$pc_obj->setPunchObject( $p_obj );
+
+							if ( $pc_obj->isValid() == TRUE ) {
+								Debug::Text(' Punch Control is valid, saving Punch ID: '. $p_obj->getID() .' To new Punch Control ID: '. $new_punch_control_id, __FILE__, __LINE__, __METHOD__,10);
+
+								//We need to calculate new total time for the day and exceptions because we are never guaranteed that the gaps will be filled immediately after
+								//in the case of a drag & drop or something.
+								$pc_obj->setEnableStrictJobValidation( TRUE );
+								$pc_obj->setEnableCalcUserDateID( TRUE );
+								$pc_obj->setEnableCalcTotalTime( TRUE );
+								$pc_obj->setEnableCalcSystemTotalTime( FALSE ); //Do this for In punch only.
+								$pc_obj->setEnableCalcWeeklySystemTotalTime( FALSE ); //Do this for In punch only.
+								$pc_obj->setEnableCalcUserDateTotal( TRUE );
+								$pc_obj->setEnableCalcException( TRUE );
+								$pc_obj->Save( TRUE, TRUE ); //Force isNew() lookup.
+							}
+						}
+					} else {
+						//Second punch (in), need to recalculate user_date_total for this one to clear the total time, as well as recalculate the entire week
+						//for system totals so those are updated as well.
+						Debug::text(' ReCalculating total time for In punch...', __FILE__, __LINE__, __METHOD__,10);
+						$pc_obj = $p_obj->getPunchControlObject();
+						$pc_obj->setEnableStrictJobValidation( TRUE );
+						$pc_obj->setEnableCalcUserDateID( TRUE );
+						$pc_obj->setEnableCalcTotalTime( TRUE );
+						$pc_obj->setEnableCalcSystemTotalTime( TRUE );
+						$pc_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
+						$pc_obj->setEnableCalcUserDateTotal( TRUE );
+						$pc_obj->setEnableCalcException( TRUE );
+						$pc_obj->Save();
+					}
+
+					$i++;
+				}
+			} else {
+				Debug::text(' Punch Control ID: '. $punch_control_id .' only has one punch assigned, doing nothing...', __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			//$plf->FailTransaction();
+			$plf->CommitTransaction();
+		}
+
+		return FALSE;
+	}
+
 	function postSave() {
 		$this->removeCache( $this->getId() );
 
@@ -1492,5 +1575,59 @@ class PunchControlFactory extends Factory {
 
 		return TRUE;
 	}
+
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'user_date_id': //Ignore any user_date_id, as we will figure it out on our own based on the time_stamp and pay period settings ($pcf->setEnableCalcUserDateID(TRUE))
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'total_time':  //Ignore total time, as its calculated later anyways, so if its set here it will cause a validation error.
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 }
 ?>
