@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3219 $
- * $Id: PunchFactory.class.php 3219 2009-12-24 18:01:51Z ipso $
- * $Date: 2009-12-24 10:01:51 -0800 (Thu, 24 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: PunchFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -50,7 +50,6 @@ class PunchFactory extends Factory {
 	protected $schedule_obj = NULL;
 	var $tmp_data = NULL;
 
-
 	function _getFactoryOptions( $name ) {
 
 		$retval = NULL;
@@ -74,12 +73,107 @@ class PunchFactory extends Factory {
 										1 => TTi18n::gettext('Yes'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1000-first_name' => TTi18n::gettext('First Name'),
+										'-1002-last_name' => TTi18n::gettext('Last Name'),
+										//'-1005-user_status' => TTi18n::gettext('Employee Status'),
+										'-1010-title' => TTi18n::gettext('Title'),
+										'-1039-group' => TTi18n::gettext('Group'),
+										'-1040-default_branch' => TTi18n::gettext('Default Branch'),
+										'-1050-default_department' => TTi18n::gettext('Default Department'),
+										'-1160-branch' => TTi18n::gettext('Branch'),
+										'-1170-department' => TTi18n::gettext('Department'),
 
+										'-1200-type' => TTi18n::gettext('Type'),
+										'-1202-status' => TTi18n::gettext('Status'),
+										'-1210-date_stamp' => TTi18n::gettext('Date'),
+										'-1220-time_stamp' => TTi18n::gettext('Time'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'type',
+								'status',
+								'date_stamp',
+								'time_stamp',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+
+											'user_id' => 'User',
+											'transfer' => 'Transfer',
+											'type_id' => 'Type',
+											'type' => FALSE,
+											'status_id' => 'Status',
+											'status' => FALSE,
+											'time_stamp' => 'TimeStamp',
+											'full_time_stamp' => FALSE,
+											'punch_control_id' => 'PunchControlID',
+											'actual_time_stamp' => 'ActualTimeStamp',
+											'original_time_stamp' => 'OriginalTimeStamp',
+											'schedule_id' => 'ScheduleID',
+											'station_id' => 'Station',
+											'longitude' => 'Longitude',
+											'latitude' => 'Latitude',
+
+											'first_name' => FALSE,
+											'last_name' => FALSE,
+											'user_status_id' => FALSE,
+											'user_status' => FALSE,
+											'group_id' => FALSE,
+											'group' => FALSE,
+											'title_id' => FALSE,
+											'title' => FALSE,
+											'default_branch_id' => FALSE,
+											'default_branch' => FALSE,
+											'default_department_id' => FALSE,
+											'default_department' => FALSE,
+
+											'date_stamp' => FALSE,
+											'user_date_id' => FALSE,
+											'pay_period_id' => FALSE,
+
+											'branch_id' => FALSE,
+											'branch' => FALSE,
+											'department_id' => FALSE,
+											'department' => FALSE,
+											'job_id' => FALSE,
+											'job' => FALSE,
+											'job_item_id' => FALSE,
+											'job_item' => FALSE,
+											'quantity_id' => FALSE,
+											'bad_quantity_id' => FALSE,
+											'meal_policy_id' => FALSE,
+											'note' => FALSE,
+
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
+
 	function getPunchControlObject() {
 		if ( is_object($this->punch_control_obj) ) {
 			return $this->punch_control_obj;
@@ -1366,8 +1460,238 @@ class PunchFactory extends Factory {
 		return TRUE;
 	}
 
+	//Takes Punch rows and calculates the total breaks/lunches and how long each is.
+	static function calcMealAndBreakTotalTime( $data ) {
+		if ( is_array($data) and count($data) > 0 ) {
+			//Sort data by date_stamp at the top, so it works for multiple days at a time.
+			foreach ( $data as $key => $row ) {
+				if ( $row['type_id'] != 10 ) {
+					if ( $row['status_id'] == 20 ) {
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev'] = TTDate::strtotime($row['full_time_stamp']);
+					} elseif ( isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) ) {
+						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time']) ) {
+							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = 0;
+						}
+
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = bcadd( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'], bcsub( TTDate::strtotime($row['full_time_stamp']), $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) );
+
+						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks']) ) {
+							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks'] = 0;
+						}
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks']++;
+
+						if ( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] > 0 ) {
+							if (  $row['type_id'] == 20 ) {
+								$break_name = TTi18n::gettext('Lunch Time');
+							} else {
+								$break_name = TTi18n::gettext('Break Time');
+							}
+
+							$date_break_totals[$row['date_stamp']][$row['type_id']] = array(
+																								'break_name' => $break_name,
+																								'total_time' => $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'],
+																								'total_breaks' => $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks'],
+																								);
+							unset($break_name);
+						}
+
+					}
+
+					$date_total_break_ids[] = (int)$row['type_id'];
+				}
+			}
+
+			if ( isset($date_break_totals) ) {
+				return $date_break_totals;
+			}
+		}
+
+		return FALSE;
+	}
+
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+
+			//We need to set the UserID as soon as possible.
+			if ( isset($data['user_id']) AND $data['user_id'] != '' ) {
+				Debug::text('Setting User ID: '. $data['user_id'], __FILE__, __LINE__, __METHOD__, 10);
+				$this->setUser( $data['user_id'] );
+			}
+
+
+/*
+			//We need to set the UserDate as soon as possible.
+			if ( isset($data['user_id']) AND $data['user_id'] != ''
+					AND isset($data['date_stamp']) AND $data['date_stamp'] != ''
+					AND isset($data['start_time']) AND $data['start_time'] != '' ) {
+				Debug::text('Setting User Date ID based on User ID:'. $data['user_id'] .' Date Stamp: '. $data['date_stamp'] .' Start Time: '. $data['start_time'] , __FILE__, __LINE__, __METHOD__, 10);
+				$this->setUserDate( $data['user_id'], TTDate::parseDateTime( $data['date_stamp'].' '.$data['start_time'] ) );
+			} elseif ( isset( $data['user_date_id'] ) AND $data['user_date_id'] > 0 ) {
+				Debug::text(' Setting UserDateID: '. $data['user_date_id'], __FILE__, __LINE__, __METHOD__,10);
+				$this->setUserDateID( $data['user_date_id'] );
+			} else {
+				Debug::text(' NOT CALLING setUserDate or setUserDateID!', __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			if ( isset($data['overwrite']) ) {
+				$this->setEnableOverwrite( TRUE );
+			}
+*/
+
+			/*
+				ORDER IS EXTREMELY IMPORTANT FOR THIS FUNCTION:
+				1. $pf->setUser();
+				2. $pf->setType();
+				3. $pf->setStatus();
+				4. $pf->setTimeStamp();
+				5. $pf->setPunchControlID();
+
+				All these related fields MUST be passed to this function as well, even if they are blank.
+			*/
+
+			$full_time_stamp = NULL;
+
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'time_stamp':
+							if ( method_exists( $this, $function ) ) {
+								if ( isset($data['disable_rounding']) AND $data['disable_rounding'] == TRUE ) {
+									$enable_rounding = FALSE;
+								} else {
+									$enable_rounding = TRUE;
+								}
+
+								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
+									$full_time_stamp = TTDate::parseDateTime( $data['date_stamp'].' '.$data['time_stamp'] );
+								} elseif ( isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
+									$full_time_stamp = TTDate::parseDateTime( $data['time_stamp'] );
+								}
+
+								$this->$function( $full_time_stamp, $enable_rounding ); //Assume time_stamp contains date as well.
+
+							}
+							break;
+						case 'actual_time_stamp': //Ignore actual/original timestamps.
+						case 'original_time_stamp':
+							break;
+						case 'punch_control_id':
+							//If this is a new punch or punch_contol_id is not being set, find a new one to use.
+							if ( $data['punch_control_id'] == '' OR $data['punch_control_id'] == 0 ) {
+								$this->setPunchControlID( $this->findPunchControlID() );
+								Debug::text('Setting Punch Control ID: '. $this->getPunchControlID() .' Was passed: '. $data['punch_control_id'] , __FILE__, __LINE__, __METHOD__, 10);
+							} else {
+								Debug::text('Valid Punch Control ID passed...', __FILE__, __LINE__, __METHOD__, 10);
+								$this->$function( $data[$key] );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			//Handle actual/original timestamp at the end, as we need to make sure we have the full_time_stamp set first.
+			if ( $this->isNew() == TRUE AND $full_time_stamp != NULL ) {
+				Debug::text('Setting actual/original timestamp: '. $full_time_stamp, __FILE__, __LINE__, __METHOD__, 10);
+				$this->setActualTimeStamp( $full_time_stamp );
+				$this->setOriginalTimeStamp( $this->getTimeStamp() );
+			} else {
+				Debug::text('NOT setting actual/original timestamp...', __FILE__, __LINE__, __METHOD__, 10);
+			}
+
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$uf = new UserFactory();
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'user_id':
+						case 'first_name':
+						case 'last_name':
+						case 'user_status_id':
+						case 'group_id':
+						case 'group':
+						case 'title_id':
+						case 'title':
+						case 'default_branch_id':
+						case 'default_branch':
+						case 'default_department_id':
+						case 'default_department':
+						case 'pay_period_id':
+						case 'branch_id':
+						case 'branch':
+						case 'department_id':
+						case 'department':
+						case 'job_id':
+						case 'job':
+						case 'job_item_id':
+						case 'job_item':
+						case 'quantity_id':
+						case 'bad_quantity_id':
+						case 'user_date_id':
+						case 'meal_policy_id':
+						case 'note':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'status':
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'date_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::strtotime( $this->getColumn( 'date_stamp' ) ) );
+							break;
+						case 'time_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
+							break;
+						case 'full_time_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
+							break;
+						case 'original_time_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'original_time_stamp' ) ) );
+							break;
+						case 'actual_time_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'actual_time_stamp' ) ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Punch - Employee').': '. $this->getUser() . TTi18n::getText(' Timestamp').': '. TTDate::getDate('DATE+TIME', $this->getTimeStamp() ) , NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Punch - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) . TTi18n::getText(' Timestamp').': '. TTDate::getDate('DATE+TIME', $this->getTimeStamp() ) , NULL, $this->getTable() );
 	}
 }
 ?>
