@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2857 $
- * $Id: PunchListFactory.class.php 2857 2009-09-27 09:11:28Z ipso $
- * $Date: 2009-09-27 02:11:28 -0700 (Sun, 27 Sep 2009) $
+ * $Revision: 3562 $
+ * $Id: PunchListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -130,6 +130,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$this->rs = $this->db->Execute($query, $ph);
 	}
 
+	function getByIdAndCompanyId( $id, $company_id ) {
+		return $this->getByCompanyIDAndId($company_id, $id);
+	}
 	function getByCompanyIDAndId($company_id, $id) {
 		if ( $company_id == '' ) {
 			return FALSE;
@@ -148,6 +151,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					);
 
 		//Status sorting MUST be desc first, otherwise transfer punches are completely out of order.
+		//We can't have extra columns displayed here as this is the function called before a delete, and if extra columns exist it will create a SQL error on getEmptyRecordSet()
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a,
@@ -168,6 +172,56 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getAPIByIdAndCompanyId($id, $company_id) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$uf = new UserFactory();
+		$pcf = new PunchControlFactory();
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		//Status sorting MUST be desc first, otherwise transfer punches are completely out of order.
+		//This function returns additional columns needed by the API to Mass Edit punches, however it CAN NOT be used to deleted
+		//data, as the additional records cause a syntax error.
+		$query = '
+					select 	a.*,
+							b.user_date_id as user_date_id,
+							b.branch_id as branch_id,
+							b.department_id as department_id,
+							b.job_id as job_id,
+							b.job_item_id as job_item_id,
+							b.note as note,
+
+							c.user_id as user_id,
+							c.date_stamp as date_stamp,
+							c.pay_period_id as pay_period_id
+					from	'. $this->getTable() .' as a,
+							'. $pcf->getTable() .' as b,
+							'. $udf->getTable() .' as c,
+							'. $uf->getTable() .' as d
+					where	a.punch_control_id = b.id
+						AND b.user_date_id = c.id
+						AND c.user_id = d.id
+						AND d.company_id = ?
+						AND a.id in ('. $this->getListSQL($id, $ph) .')
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 )
+					ORDER BY a.time_stamp asc, a.status_id desc, a.punch_control_id asc
+					';
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByPunchControlIdAndStatusId($punch_control_id, $status_id, $where = NULL, $order = NULL) {
 		if ( $punch_control_id == '') {
 			return FALSE;
@@ -434,34 +488,10 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					'start_time_stamp2' => $this->db->BindTimeStamp( $start_time_stamp ),
 					'end_time_stamp2' => $this->db->BindTimeStamp( $end_time_stamp ),
 					);
-/*
-	ORIGINAL SLOW query. Moving OR into the sub-query.
- 					select a.*
-					from '. $this->getTable() .' as a
-					where
-						(
-						a.punch_control_id = ?
-						OR
-						a.punch_control_id in (
-													select 	distinct(x.punch_control_id)
-													from 	'. $this->getTable() .' as x,
-															'. $pcf->getTable() .' as y,
-															'. $udf->getTable() .' as z
-													where	x.punch_control_id = y.id
-														AND y.user_date_id = z.id
-														AND z.user_id = ?
-														AND z.date_stamp >= ?
-														AND z.date_stamp <= ?
-														AND x.time_stamp >= ?
-														AND x.time_stamp <= ?
-														AND ( x.deleted = 0 AND y.deleted=0 AND z.deleted=0 )
 
-												)
-						)
-					AND a.deleted = 0
-					ORDER BY a.time_stamp asc, a.status_id asc
-
-*/
+		//Order by a.punch_control_id is extremely important here so two punches at the same time, one paired already, and one not paired don't come in the wrong order, and cause getShiftData() to handle them incorrectly.
+		//This query with sub-selects performs horribly with MySQL v5.0 once the punch table grows over 500,000 rows or so.
+		/*
 		$query = '
 					select a.*
 					from '. $this->getTable() .' as a
@@ -486,8 +516,35 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 												)
 						)
 					AND a.deleted = 0
-					ORDER BY a.time_stamp asc, a.status_id asc
+					ORDER BY a.time_stamp asc, a.punch_control_id, a.status_id asc
 					';
+		*/
+
+		//This query removes the sub-query and is optimized for MySQL.
+		$query = '
+					select distinct a.*
+					from '. $this->getTable() .' as a
+					INNER JOIN
+						(
+							select '. (int)$punch_control_id .' as punch_control_id
+							UNION ALL
+							select 	x.punch_control_id
+							from 	'. $this->getTable() .' as x
+							LEFT JOIN '. $pcf->getTable() .' as y ON x.punch_control_id = y.id
+							LEFT JOIN '. $udf->getTable() .' as z ON y.user_date_id = z.id
+							where z.user_id = ?
+								AND z.date_stamp >= ?
+								AND z.date_stamp <= ?
+								AND x.time_stamp >= ?
+								AND x.time_stamp <= ?
+								AND ( x.deleted = 0 AND y.deleted=0 AND z.deleted=0 )
+
+						) as z ON a.punch_control_id = z.punch_control_id
+					WHERE a.deleted = 0
+					ORDER BY a.time_stamp asc, a.punch_control_id, a.status_id asc
+					';
+
+
 		//$query .= $this->getSortSQL( $order );
 
 		$this->rs = $this->db->Execute($query, $ph);
@@ -560,6 +617,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 
 		$ph = array(
 					'user_id' => $user_id,
+					'start_date' => $this->db->BindDate($start_time),
+					'end_date' => $this->db->BindDate($epoch),
 					'start_time' => $this->db->BindTimeStamp($start_time),
 					'end_time' => $this->db->BindTimeStamp($epoch),
 					);
@@ -567,6 +626,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		//Status order matters, because if its a.status_id desc, OUT comes first, but if the last
 		//punch doesn't have OUT yet, it defaults to IN
 		// with a.status_id asc...
+
+		//Include date_stamp filter on user_date table as this greatly speeds up the query when its not already cached.
 		$query = '
 					select 	a.*
 					from 	'. $this->getTable() .' as a,
@@ -575,6 +636,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					where	a.punch_control_id = b.id
 						AND b.user_date_id = c.id
 						AND c.user_id = ?
+						AND c.date_stamp >= ?
+						AND c.date_stamp <= ?
 						AND a.time_stamp >= ?
 						AND a.time_stamp <= ?
 						AND ( a.deleted = 0 AND b.deleted=0 AND c.deleted=0)
@@ -582,7 +645,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					LIMIT 1
 					';
 		$query .= $this->getSortSQL( $order );
-		//Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+		Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 		//echo "Get Previous Punch Query: ". $query ."<br>\n";
 
 		$this->rs = $this->db->Execute($query, $ph);
@@ -610,6 +673,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 
 		$ph = array(
 					'user_id' => $user_id,
+					'start_date' => $this->db->BindDate($start_time),
+					'end_date' => $this->db->BindDate($epoch),
 					'start_time' => $this->db->BindTimeStamp($start_time),
 					'end_time' => $this->db->BindTimeStamp($epoch),
 					'punch_id' => (int)$punch_id,
@@ -626,6 +691,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					where	a.punch_control_id = b.id
 						AND b.user_date_id = c.id
 						AND c.user_id = ?
+						AND c.date_stamp >= ?
+						AND c.date_stamp <= ?
 						AND a.time_stamp >= ?
 						AND a.time_stamp <= ?
 						AND a.id != ?
@@ -1520,6 +1587,314 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
+		$additional_order_fields = array('first_name', 'last_name', 'date_stamp','time_stamp','type_id','status_id','branch','department','default_branch','default_department','group','title');
+
+		$sort_column_aliases = array(
+									 'status' => 'status_id',
+									 'type' => 'type_id',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.time_stamp' => 'asc', 'a.punch_control_id' => 'asc', 'a.status_id' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = FALSE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( isset($filter_data['exclude_user_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
+		}
+/*
+		if ( isset($filter_data['user_id']) ) {
+			$filter_data['id'] = $filter_data['user_id'];
+		}
+		if ( isset($filter_data['include_user_ids']) ) {
+			$filter_data['id'] = $filter_data['include_user_ids'];
+		}
+*/
+		if ( isset($filter_data['user_status_ids']) ) {
+			$filter_data['status_id'] = $filter_data['user_status_ids'];
+		}
+		if ( isset($filter_data['user_title_ids']) ) {
+			$filter_data['title_id'] = $filter_data['user_title_ids'];
+		}
+		if ( isset($filter_data['group_ids']) ) {
+			$filter_data['group_id'] = $filter_data['group_ids'];
+		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['default_branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['default_department_id'] = $filter_data['department_ids'];
+		}
+		if ( isset($filter_data['punch_branch_ids']) ) {
+			$filter_data['punch_branch_id'] = $filter_data['punch_branch_ids'];
+		}
+		if ( isset($filter_data['punch_department_ids']) ) {
+			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
+		}
+/*
+		if ( isset($filter_data['exclude_job_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_job_ids'];
+		}
+		if ( isset($filter_data['include_job_ids']) ) {
+			$filter_data['include_job_id'] = $filter_data['include_job_ids'];
+		}
+		if ( isset($filter_data['job_group_ids']) ) {
+			$filter_data['job_group_id'] = $filter_data['job_group_ids'];
+		}
+		if ( isset($filter_data['job_item_ids']) ) {
+			$filter_data['job_item_id'] = $filter_data['job_item_ids'];
+		}
+*/
+		$uf = new UserFactory();
+		$udf = new UserDateFactory();
+		$pcf = new PunchControlFactory();
+		$uwf = new UserWageFactory();
+		$sf = new StationFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select
+							a.id as id,
+							a.punch_control_id as punch_control_id,
+							a.type_id as type_id,
+							a.status_id as status_id,
+							a.time_stamp as time_stamp,
+							a.actual_time_stamp as actual_time_stamp,
+							a.original_time_stamp as original_time_stamp,
+
+							a.created_by as created_by,
+							a.created_date as created_date,
+							a.updated_by as updated_by,
+							a.updated_date as updated_date,
+
+							b.user_date_id as user_date_id,
+							b.branch_id as branch_id,
+							j.name as branch,
+							b.department_id as department_id,
+							k.name as department,
+							b.job_id as job_id,
+							r.name as job,
+							b.job_item_id as job_item_id,
+							s.name as job_item,
+							b.quantity as quantity_id,
+							b.bad_quantity as bad_quantity_id,
+							b.total_time as total_time,
+							b.actual_total_time as actual_total_time,
+							b.meal_policy_id as meal_policy_id,
+							b.other_id1 as other_id1,
+							b.other_id2 as other_id2,
+							b.other_id3 as other_id3,
+							b.other_id4 as other_id4,
+							b.other_id5 as other_id5,
+							b.note as note,
+
+							c.user_id as user_id,
+							c.date_stamp as date_stamp,
+							c.pay_period_id as pay_period_id,
+
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.status_id as user_status_id,
+							d.group_id as group_id,
+							g.name as group,
+							d.title_id as title_id,
+							h.name as title,
+							d.default_branch_id as default_branch_id,
+							e.name as default_branch,
+							d.default_department_id as default_department_id,
+							f.name as default_department,
+							d.created_by as user_created_by,
+
+							l.type_id as station_type_id,
+							l.station_id as station_station_id,
+							l.source as station_source,
+							l.description as station_description,
+
+							w.id as user_wage_id,
+							w.effective_date as user_wage_effective_date,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+							';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						r.name as job_name,
+						r.status_id as job_status_id,
+						r.manual_id as job_manual_id,
+						r.branch_id as job_branch_id,
+						r.department_id as job_department_id,
+						r.group_id as job_group_id';
+		}
+
+		$query .= '
+					from 	'. $this->getTable() .' as a
+							LEFT JOIN '. $pcf->getTable() .' as b ON a.punch_control_id = b.id
+							LEFT JOIN '. $udf->getTable() .' as c ON b.user_date_id = c.id
+							LEFT JOIN '. $uf->getTable() .' as d ON c.user_id = d.id
+
+							LEFT JOIN '. $bf->getTable() .' as e ON ( d.default_branch_id = e.id AND e.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as f ON ( d.default_department_id = f.id AND f.deleted = 0)
+							LEFT JOIN '. $ugf->getTable() .' as g ON ( d.group_id = g.id AND g.deleted = 0 )
+							LEFT JOIN '. $utf->getTable() .' as h ON ( d.title_id = h.id AND h.deleted = 0 )
+
+							LEFT JOIN '. $bf->getTable() .' as j ON ( b.branch_id = j.id AND j.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as k ON ( b.department_id = k.id AND k.deleted = 0)
+
+							LEFT JOIN '. $sf->getTable() .' as l ON a.station_id = l.id
+
+							LEFT JOIN '. $uwf->getTable() .' as w ON w.id = (select w.id
+																		from '. $uwf->getTable() .' as w
+																		where w.user_id = c.user_id
+																			and w.effective_date <= c.date_stamp
+																			and w.deleted = 0
+																			order by w.effective_date desc LiMiT 1)
+
+							LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+							LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					';
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as r ON b.job_id = r.id';
+			$query .= '	LEFT JOIN '. $jif->getTable() .' as s ON b.job_item_id = s.id';
+		}
+
+		$query .= '	WHERE d.company_id = ?';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND d.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND c.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['punch_branch_id'][0]) AND !in_array(-1, (array)$filter_data['punch_branch_id']) ) {
+			$query  .=	' AND b.branch_id in ('. $this->getListSQL($filter_data['punch_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
+			$query  .=	' AND b.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
+			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
+		}
+
+
+		//Use the job_id in the punch_control table so we can filter by '0' or No Job
+		if ( isset($filter_data['include_job_id']) AND isset($filter_data['include_job_id'][0]) AND !in_array(-1, (array)$filter_data['include_job_id']) ) {
+			$query  .=	' AND b.job_id in ('. $this->getListSQL($filter_data['include_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_job_id']) AND isset($filter_data['exclude_job_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_job_id']) ) {
+			$query  .=	' AND b.job_id not in ('. $this->getListSQL($filter_data['exclude_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
+			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['job_group_id'] = $uglf->getByCompanyIdAndGroupIdAndjob_subgroupsArray( $company_id, $filter_data['job_group_id'], TRUE);
+			}
+			$query  .=	' AND r.group_id in ('. $this->getListSQL($filter_data['job_group_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+			$query  .=	' AND b.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+		}
+
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['start_date']);
+			$query  .=	' AND c.date_stamp >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['end_date']);
+			$query  .=	' AND c.date_stamp <= ?';
+		}
+
+		$query .= 	'
+						AND (a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND d.deleted = 0)
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getLastPunchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -1540,8 +1915,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		} else {
 			$strict = TRUE;
 		}
-		Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
-		Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( isset($filter_data['exclude_user_ids']) ) {
 			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
@@ -1608,6 +1983,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 							a.actual_time_stamp as actual_time_stamp,
 
 							b.user_date_id as user_date_id,
+							c.date_stamp as date_stamp,
 							b.branch_id as branch_id,
 							b.department_id as department_id,
 							b.job_id as job_id,
