@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: RequestFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: RequestFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -127,7 +127,7 @@ class RequestFactory extends Factory {
 
 		if (  $this->Validator->isResultSetWithRows(	'user_date',
 														$udlf->getByID($id),
-														TTi18n::gettext('Invalid User Date ID')
+														TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already')
 														) ) {
 			$this->data['user_date_id'] = $id;
 
@@ -268,7 +268,7 @@ class RequestFactory extends Factory {
 		if ( $this->getUserDateID() == FALSE ) {
 			$this->Validator->isTRUE(		'user_date',
 											FALSE,
-											TTi18n::gettext('Invalid User Date ID') );
+											TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already') );
 		}
 
 		return TRUE;
@@ -301,18 +301,43 @@ class RequestFactory extends Factory {
 
 	function postSave() {
 		//Save message here after we have the request_id.
-		//if ( $this->isNew() == TRUE ) {
 		if ( $this->getMessage() !== FALSE ) {
+			$mcf = new MessageControlFactory();
+			$mcf->StartTransaction();
+
+			$hlf = new HierarchyListFactory();
+			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), 50, TRUE, FALSE ); //Request - Immediate parents only.
+			Debug::Arr($request_parent_level_user_ids, 'Sending message to current direct Superiors: ', __FILE__, __LINE__, __METHOD__,10);
+
+			$mcf = new MessageControlFactory();
+			$mcf->setFromUserId( $this->getUser() );
+			$mcf->setToUserId( $request_parent_level_user_ids );
+			$mcf->setObjectType( 50 );
+			$mcf->setObject( $this->getID() );
+			$mcf->setParent( 0 );
+			$mcf->setSubject( Option::getByKey( $this->getType(), $this->getOptions('type') ) .' '. TTi18n::gettext('request from') .': '. $this->getUserObject()->getFullName(TRUE) );
+			$mcf->setBody( $this->getMessage() );
+
+			if ( $mcf->isValid() ) {
+				$mcf->Save();
+
+				$mcf->CommitTransaction();
+			} else {
+				$mcf->FailTransaction();
+			}
+
+/*
 			$mf = new MessageFactory();
 			$mf->setObjectType( 50 ); //Request
 			$mf->setObject( $this->getID() );
 			$mf->setParent( 0 );
 			$mf->setPriority();
-			$mf->setStatus('UNREAD');
+			$mf->setStatus(10); //UnRead
 			$mf->setBody( $this->getMessage() );
 			if ( $mf->isValid() ) {
 				return $mf->Save();
 			}
+*/
 		}
 
 		return TRUE;
