@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: RequestListFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3415 $
+ * $Id: RequestListFactory.class.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 
 /**
@@ -380,6 +380,55 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByHierarchyLevelMapAndStatusAndNotAuthorized($hierarchy_level_map, $status,  $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $hierarchy_level_map == '') {
+			return FALSE;
+		}
+
+		if ( $status == '') {
+			return FALSE;
+		}
+
+		$additional_sort_fields = array( 'date_stamp', 'user_id' );
+
+		$strict_order = TRUE;
+		if ( $order == NULL ) {
+			$order = array('b.user_id' => 'asc', 'b.date_stamp' => 'asc');
+			$strict_order = FALSE;
+		}
+
+		$af = new AuthorizationFactory();
+		$udf = new UserDateFactory();
+		$huf = new HierarchyUserFactory();
+
+		$ph = array(
+					'status' => $status,
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $udf->getTable() .' as b,
+							'. $huf->getTable() .' as z
+					where	a.user_date_id = b.id
+						AND b.user_id = z.user_id
+						AND	a.status_id = ?
+						AND a.authorized = 0
+						AND ( '. HierarchyLevelFactory::convertHierarchyLevelMapToSQL( $hierarchy_level_map ) .' )
+						AND ( a.deleted = 0 AND b.deleted = 0 )
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict_order, $additional_sort_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 /*
 	function getByUserIdListAndStatusAndNotAuthorized($id, $status, $parent_level_user_ids, $current_level_user_ids, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
 		$key = Option::getByValue($status, $this->getOptions('status') );
