@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: RecurringScheduleControlFactory.class.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: RecurringScheduleControlFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -47,6 +47,80 @@ class RecurringScheduleControlFactory extends Factory {
 	protected $pk_sequence_name = 'recurring_schedule_control_id_seq'; //PK Sequence name
 
 	protected $recurring_schedule_template_obj = NULL;
+
+	function _getFactoryOptions( $name ) {
+
+		$retval = NULL;
+		switch( $name ) {
+			case 'columns':
+				$retval = array(
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+
+										'-1030-recurring_schedule_template_control' => TTi18n::gettext('Template'),
+										'-1040-recurring_schedule_template_control_description' => TTi18n::gettext('Description'),
+										'-1050-start_date' => TTi18n::gettext('Start Date'),
+										'-1060-end_date' => TTi18n::gettext('End Date'),
+										'-1070-auto_fill' => TTi18n::gettext('Auto Pilot'),
+
+										'-1090-title' => TTi18n::gettext('Title'),
+										'-1099-group' => TTi18n::gettext('Group'),
+										'-1100-default_branch' => TTi18n::gettext('Branch'),
+										'-1110-default_department' => TTi18n::gettext('Department'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'recurring_schedule_template_control',
+								'recurring_schedule_template_control_description',
+								'start_date',
+								'end_date',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'user_id' => FALSE,
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'default_branch' => FALSE,
+										'default_department' => FALSE,
+										'group' => FALSE,
+										'title' => FALSE,
+										'recurring_schedule_template_control_id' => 'RecurringScheduleTemplateControl',
+										'recurring_schedule_template_control' => FALSE,
+										'recurring_schedule_template_control_description' => FALSE,
+										'start_week' => 'StartWeek',
+										'start_date' => 'StartDate',
+										'end_date' => 'EndDate',
+										'auto_fill' => 'AutoFill',
+										'user' => 'User',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getCompany() {
 		if ( isset($this->data['company_id']) ) {
 			return $this->data['company_id'];
@@ -84,7 +158,7 @@ class RecurringScheduleControlFactory extends Factory {
 
 		$rstclf = new RecurringScheduleTemplateControlListFactory();
 
-		if ( $this->Validator->isResultSetWithRows(	'recurring_schedule_template_control',
+		if ( $this->Validator->isResultSetWithRows(	'recurring_schedule_template_control_id',
 													$rstclf->getByID($id),
 													TTi18n::gettext('Recurring Schedule Template Control is invalid')
 													) ) {
@@ -208,7 +282,7 @@ class RecurringScheduleControlFactory extends Factory {
 	}
 	function setUser($ids) {
 		Debug::text('Setting User IDs : ', __FILE__, __LINE__, __METHOD__, 10);
-		if (is_array($ids) and count($ids) > 0) {
+		if ( is_array($ids) and count($ids) > 0 ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$rsulf = new RecurringScheduleUserListFactory();
@@ -329,7 +403,7 @@ class RecurringScheduleControlFactory extends Factory {
 		if ( $this->getEndDate(TRUE) != NULL AND $end_date > $this->getEndDate() ) {
 			$end_date = $this->getEndDate();
 		}
-		Debug::text('Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date), __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .'('.$start_date.') End Date: '. TTDate::getDate('DATE+TIME', $end_date) .'('.$end_date.')', __FILE__, __LINE__, __METHOD__, 10);
 
 		//Get week data
 		$rstlf = new RecurringScheduleTemplateListFactory();
@@ -338,7 +412,7 @@ class RecurringScheduleControlFactory extends Factory {
 		$weeks = array();
 		if ( $rstlf->getRecordCount() > 0 ) {
 			foreach($rstlf as $rst_obj) {
-				Debug::text('Week: '. $rst_obj->getWeek(), __FILE__, __LINE__, __METHOD__, 10);
+				//Debug::text('Week: '. $rst_obj->getWeek(), __FILE__, __LINE__, __METHOD__, 10);
 				$template_week_rows[$rst_obj->getWeek()][] = $rst_obj->getObjectAsArray();
 
 				$weeks[$rst_obj->getWeek()] = $rst_obj->getWeek();
@@ -352,17 +426,24 @@ class RecurringScheduleControlFactory extends Factory {
 		$weeks = $this->ReMapWeeks( $weeks );
 
 		//Get week of start_date
-		$start_date_week = TTDate::getWeek( $this->getStartDate(), 0 ); //Start week on Sunday to match Recurring Schedule.
-		Debug::text('Week of Start Date: '. $start_date_week ,__FILE__, __LINE__, __METHOD__, 10);
+		$start_date_week = TTDate::getBeginWeekEpoch( $this->getStartDate(), 0 ); //Start week on Sunday to match Recurring Schedule.
+		//Debug::text('Week of Start Date: '. $start_date_week .' Date: '. TTDate::getDate('DATE+TIME', $this->getStartDate() ) ,__FILE__, __LINE__, __METHOD__, 10);
 
-		for ( $i=$start_date; $i <= $end_date; $i+=86400) {
-			$current_week = TTDate::getWeek( $i, 0 ); //Start week on Sunday to match Recurring Schedule.
-			//Debug::text('Current Date: '. TTDate::getDate('DATE+TIME', $i) .' Current Week: '. $current_week,__FILE__, __LINE__, __METHOD__, 10);
+		//Since we add 43200 to each iteration (even though its removed right after), we need to add 43200 to the end_date as well so we loop the
+		//proper amount of times, otherwise schedules may be added too late.
+		for ( $i=$start_date; $i <= ($end_date+43200); $i+=(86400+43200)) {
+			//Handle DST by adding 12hrs to the date to get the mid-day epoch, then forcing it back to the beginning of the day.
+			$i = TTDate::getBeginDayEpoch( $i );
 
-			$template_week = ( ( ( abs($current_week-$start_date_week) ) % $max_week ) ) + 1;
+			//This needs to take into account weeks spanning January 1st of each year. Where the week goes from 53 to 1.
+			//Rather then use the week of the year, calculate the weeks between the recurring schedule start date and now.
+			$current_week = round( ( TTDate::getBeginWeekEpoch( $i, 0 ) - $start_date_week ) / ( 604800 ) ); //Find out which week we are on based on the recurring schedule start date. Use round due to DST the week might be 6.9 or 7.1, so we need to round to the nearest full week.
+			//Debug::text('I: '. $i .' User ID: '. $this->getColumn('user_id') .' Current Date: '. TTDate::getDate('DATE+TIME', $i) .' Current Week: '. $current_week .' Start Week: '. $start_date_week,__FILE__, __LINE__, __METHOD__, 10);
+
+			$template_week = ( $current_week % $max_week ) + 1;
 			//Debug::text('Template Week: '. $template_week .' Max Week: '. $max_week,__FILE__, __LINE__, __METHOD__, 10);
 
-			$day_of_week = strtolower(date('D', $i));
+			$day_of_week = strtolower( date('D', $i) );
 			//Debug::text('Day Of Week: '. $day_of_week,__FILE__, __LINE__, __METHOD__, 10);
 
 			if ( isset($weeks[$template_week] ) ) {
@@ -376,8 +457,8 @@ class RecurringScheduleControlFactory extends Factory {
 						if ( $template_week_arr['days'][$day_of_week] == TRUE ) {
 							//Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Found Scheduled Time: Start Time: '. TTDate::getDate('DATE+TIME', TTDate::getTimeLockedDate( $template_week_arr['start_time'], $i ) ),__FILE__, __LINE__, __METHOD__, 10);
 
-							$start_time = TTDate::getTimeLockedDate( $template_week_arr['start_time'], $i );
-							$end_time = TTDate::getTimeLockedDate( $template_week_arr['end_time'], $i );
+							$start_time = TTDate::getTimeLockedDate( $template_week_arr['raw_start_time'], $i );
+							$end_time = TTDate::getTimeLockedDate( $template_week_arr['raw_end_time'], $i );
 							if ( $end_time < $start_time ) {
 								//Spans the day boundary, add 86400 to end_time
 								$end_time = $end_time + 86400;
@@ -411,7 +492,6 @@ class RecurringScheduleControlFactory extends Factory {
 			} else {
 				//Debug::text('&nbsp;&nbsp;cSkipping!',__FILE__, __LINE__, __METHOD__, 10);
 			}
-
 		}
 
 		//var_dump($shifts);
@@ -422,6 +502,73 @@ class RecurringScheduleControlFactory extends Factory {
 		return FALSE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'start_date':
+						case 'end_date':
+							$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+						case 'title':
+						case 'group':
+						case 'default_branch':
+						case 'default_department':
+						case 'recurring_schedule_template_control':
+						case 'recurring_schedule_template_control_description':
+						case 'user_id':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'start_date':
+						case 'end_date':
+							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::strtotime( $this->$function() ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Schedule'), NULL, $this->getTable() );
 	}
