@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: RecurringScheduleTemplateFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: RecurringScheduleTemplateFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -47,6 +47,97 @@ class RecurringScheduleTemplateFactory extends Factory {
 	protected $pk_sequence_name = 'recurring_schedule_template_id_seq'; //PK Sequence name
 
 	protected $schedule_policy_obj = NULL;
+
+	function _getFactoryOptions( $name ) {
+
+		$retval = NULL;
+		switch( $name ) {
+			case 'columns':
+				$retval = array(
+										'-1010-week' => TTi18n::gettext('Week'),
+
+										'-1101-sun' => TTi18n::gettext('S'),
+										'-1102-mon' => TTi18n::gettext('M'),
+										'-1103-tue' => TTi18n::gettext('T'),
+										'-1104-wed' => TTi18n::gettext('W'),
+										'-1105-thu' => TTi18n::gettext('T'),
+										'-1106-fri' => TTi18n::gettext('F'),
+										'-1107-sat' => TTi18n::gettext('S'),
+
+										'-1200-start_time' => TTi18n::gettext('In'),
+										'-1210-end_time' => TTi18n::gettext('Out'),
+
+										'-1220-schedule_policy' => TTi18n::gettext('Schedule Policy'),
+
+										'-1230-branch' => TTi18n::gettext('Branch'),
+										'-1240-department' => TTi18n::gettext('Department'),
+										'-1250-job' => TTi18n::gettext('Job'),
+										'-1260-job_item' => TTi18n::gettext('Task'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'week',
+								'sun',
+								'mon',
+								'tue',
+								'wed',
+								'thu',
+								'fri',
+								'sat',
+								'start_time',
+								'end_time',
+								'schedule_policy',
+								'branch',
+								'department',
+								'job',
+								'job_item',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'status_id' => FALSE,
+										'recurring_schedule_template_control_id' => 'RecurringScheduleTemplateControl',
+										'week' => 'Week',
+										'sun' => 'Sun',
+										'mon' => 'Mon',
+										'tue' => 'Tue',
+										'wed' => 'Wed',
+										'thu' => 'Thu',
+										'fri' => 'Fri',
+										'sat' => 'Sat',
+										'start_time' => 'StartTime',
+										'end_time' => 'EndTime',
+										'total_time' => 'TotalTime',
+										'schedule_policy_id' => 'SchedulePolicyID',
+										'branch_id' => 'Branch',
+										'department_id' => 'Department',
+										'job_id' => 'Job',
+										'job_item_id' => 'JobItem',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getSchedulePolicyObject() {
 		if ( is_object($this->schedule_policy_obj) ) {
 			return $this->schedule_policy_obj;
@@ -311,6 +402,8 @@ class RecurringScheduleTemplateFactory extends Factory {
 
 		$blf = new BranchListFactory();
 
+		Debug::text('Branch ID: '. $id ,__FILE__, __LINE__, __METHOD__, 10);
+
 		//-1 is for user default branch.
 		if (  $id == 0 OR $id == -1
 				OR
@@ -418,7 +511,6 @@ class RecurringScheduleTemplateFactory extends Factory {
 	}
 
 	function isActiveShiftDay( $epoch ) {
-
 		$day_of_week = strtolower( date('D', $epoch) );
 		if ( isset( $this->data[$day_of_week] ) ) {
 			return $this->fromBool( $this->data[$day_of_week] );
@@ -442,9 +534,12 @@ class RecurringScheduleTemplateFactory extends Factory {
 		}
 
 		//Get week of start_date
-		$start_date_week = TTDate::getWeek( $recurring_schedule_control_start_date, 0 ); //Start week on Sunday to match Recurring Schedule.
+		$start_date_week = TTDate::getBeginWeekEpoch( $recurring_schedule_control_start_date, 0 ); //Start week on Sunday to match Recurring Schedule.
 		//Debug::text('Week of Start Date: '. $start_date_week ,__FILE__, __LINE__, __METHOD__, 10);
 
+		$apf = new AbsencePolicyFactory();
+		$absence_policy_paid_type_options = $apf->getOptions('paid_type');
+
 		for ( $i=$start_date; $i <= $end_date; $i+=(86400+43200)) {
 			//Handle DST by adding 12hrs to the date to get the mid-day epoch, then forcing it back to the beginning of the day.
 			$i = TTDate::getBeginDayEpoch( $i );
@@ -456,10 +551,12 @@ class RecurringScheduleTemplateFactory extends Factory {
 				continue;
 			}
 
-			$current_week = TTDate::getWeek( $i, 0 ); //Start week on Sunday to match Recurring Schedule.
-			//Debug::text('I: '. $i .' User ID: '. $this->getColumn('user_id') .' Current Date: '. TTDate::getDate('DATE+TIME', $i) .' Current Week: '. $current_week,__FILE__, __LINE__, __METHOD__, 10);
+			//This needs to take into account weeks spanning January 1st of each year. Where the week goes from 53 to 1.
+			//Rather then use the week of the year, calculate the weeks between the recurring schedule start date and now.
+			$current_week = round( ( TTDate::getBeginWeekEpoch( $i, 0 ) - $start_date_week ) / ( 604800 ) ); //Find out which week we are on based on the recurring schedule start date. Use round due to DST the week might be 6.9 or 7.1, so we need to round to the nearest full week.
+			//Debug::text('I: '. $i .' User ID: '. $this->getColumn('user_id') .' Current Date: '. TTDate::getDate('DATE+TIME', $i) .' Current Week: '. $current_week .' Start Week: '. $start_date_week,__FILE__, __LINE__, __METHOD__, 10);
 
-			$template_week = ( ( ( abs($current_week-$start_date_week) ) % $max_week ) ) + 1;
+			$template_week = ( $current_week % $max_week ) + 1;
 			//Debug::text('Template Week: '. $template_week .' Max Week: '. $max_week,__FILE__, __LINE__, __METHOD__, 10);
 
 			if ( $template_week == $current_template_week ) {
@@ -503,6 +600,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 
 					$status_id = 10; //Working
 					$absence_policy_id = FALSE;
+					$absence_policy_type_id = FALSE;
 					$absence_policy = NULL;
 
 					if ( isset($holiday_data[$iso_date_stamp]) ) {
@@ -513,15 +611,46 @@ class RecurringScheduleTemplateFactory extends Factory {
 						$status_id = $holiday_data[$iso_date_stamp]['status_id'];
 						if ( isset($holiday_data[$iso_date_stamp]['absence_policy_id']) ) {
 							$absence_policy_id = $holiday_data[$iso_date_stamp]['absence_policy_id'];
+							$absence_policy_type_id = $holiday_data[$iso_date_stamp]['type_id'];
 							$absence_policy = $holiday_data[$iso_date_stamp]['absence_policy'];
 						}
 					}
 
+					$hourly_rate = Misc::MoneyFormat( $this->getColumn('user_wage_hourly_rate'), FALSE );
+
+					if ( $absence_policy_id > 0
+							AND in_array( $absence_policy_type_id, $absence_policy_paid_type_options ) == FALSE ) {
+						//UnPaid Absence.
+						$total_time_wage = Misc::MoneyFormat(0);
+					} else {
+						$total_time_wage = Misc::MoneyFormat( bcmul( TTDate::getHours( $this->getTotalTime() ), $hourly_rate ), FALSE );
+					}
+
 					//Debug::text('I: '. $i .' User ID: '. $this->getColumn('user_id') .' Current Date: '. TTDate::getDate('DATE+TIME', $i) .' Current Week: '. $current_week .' Start Time: '. TTDate::getDate('DATE+TIME', $start_time ),__FILE__, __LINE__, __METHOD__, 10);
 					$shifts[$iso_date_stamp][$this->getColumn('user_id').$start_time] = array(
+														'pay_period_id' => FALSE,
 														'user_id' => $this->getColumn('user_id'),
-														'user_full_name' => Misc::getFullName( $this->getColumn('first_name'), NULL, $this->getColumn('last_name'), FALSE, FALSE ),
 														'user_created_by' => $this->getColumn('user_created_by'),
+														'user_full_name' => Misc::getFullName( $this->getColumn('first_name'), NULL, $this->getColumn('last_name'), FALSE, FALSE ),
+
+														'title_id' => $this->getColumn('title_id'),
+														'group_id' => $this->getColumn('group_id'),
+														'default_branch_id' => $this->getColumn('default_branch_id'),
+														'default_branch' => Option::getByKey($this->getColumn('default_branch_id'), $branch_options, NULL ),
+														'default_department_id' => $this->getColumn('default_department_id'),
+														'default_department' =>  Option::getByKey($this->getColumn('default_department_id'), $department_options, NULL ),
+
+														'job_id' => $this->getJob(),
+														'job_name' => $this->getColumn('job_name'),
+														'job_status_id' => $this->getColumn('job_status_id'),
+														'job_manual_id' => $this->getColumn('job_manual_id'),
+														'job_branch_id' => $this->getColumn('job_branch_id'),
+														'job_department_id' => $this->getColumn('job_department_id'),
+														'job_group_id' => $this->getColumn('job_group_id'),
+														'job_item_id' => $this->getJobItem(),
+														'job_item_name' => $this->getColumn('job_item_name'),
+
+														'type_id' => 20, //Recurring
 														'status_id' => $status_id,
 
 														'date_stamp' => TTDate::getAPIDate('DATE', $start_time ),
@@ -535,6 +664,10 @@ class RecurringScheduleTemplateFactory extends Factory {
 														//'raw_end_time' => TTDate::getDate('DATE+TIME', $end_time ),
 
 														'total_time' => $this->getTotalTime(),
+
+														'hourly_rate' => $hourly_rate,
+														'total_time_wage' => $total_time_wage,
+
 														'schedule_policy_id' => $this->getSchedulePolicyID(),
 														'absence_policy_id' => $absence_policy_id,
 														'absence_policy' => $absence_policy,
@@ -542,8 +675,6 @@ class RecurringScheduleTemplateFactory extends Factory {
 														'branch' => Option::getByKey($this->getColumn('schedule_branch_id'), $branch_options, NULL ),
 														'department_id' => $this->getColumn('schedule_department_id'),
 														'department' =>  Option::getByKey($this->getColumn('schedule_department_id'), $department_options, NULL ),
-														'job_id' => $this->getJob(),
-														'job_item_id' => $this->getJobItem(),
 														);
 					$shifts_index[$iso_date_stamp][$this->getColumn('user_id')][] = $this->getColumn('user_id').$start_time;
 
@@ -561,11 +692,9 @@ class RecurringScheduleTemplateFactory extends Factory {
 
 		return FALSE;
 	}
-
+/*
 	function getObjectAsArray( $raw_dates = FALSE ) {
-		/*
-			array( 'date_stamp' => array( 0 => ALLDATA 1=> ALLDATA ) );
-		*/
+		//array( 'date_stamp' => array( 0 => ALLDATA 1=> ALLDATA ) );
 
 		//Calculate offset for day of the week
 		$data = array(
@@ -592,6 +721,81 @@ class RecurringScheduleTemplateFactory extends Factory {
 
 		return $data;
 	}
+*/
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'start_time':
+						case 'end_time':
+							$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							break;
+						case 'total_time': //Ignore this field when setting data.
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status_id':
+							$data[$variable] = 10; //Working: Always working when its a recurring schedule.
+							break;
+						case 'start_time':
+						case 'end_time':
+							//$data[$variable] = ( defined('TIMETREX_API') ) ? TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->$function() ) ) : $this->$function();
+							$data[$variable] = ( defined('TIMETREX_API') ) ? TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->$function() ) ) : $this->$function();
+							//Need to include the raw_start_time,raw_end_time columns that are in EPOCH format so getShiftsByStartDateAndEndDate() can convert them as needed.
+							$data['raw_'.$variable] = $this->$function();
+							break;
+						case 'sun':
+						case 'mon':
+						case 'tue':
+						case 'wed':
+						case 'thu':
+						case 'fri':
+						case 'sat':
+							//For backwards compatibility, put all days inside the "days" array, AS WELL as in their own column for the API to use.
+							if ( method_exists( $this, $function ) ) {
+								$data['days'][$variable] = $this->$function();
+							}
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
 
 	function preSave() {
 		if ( $this->getEndTime() < $this->getStartTime() ) {
