@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2681 $
- * $Id: RecurringScheduleTemplateListFactory.class.php 2681 2009-07-23 22:30:39Z ipso $
- * $Date: 2009-07-23 15:30:39 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 3562 $
+ * $Id: RecurringScheduleTemplateListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -84,6 +84,37 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		return $this;
 	}
 
+	function getByIdAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		$rstcf = new RecurringScheduleTemplateControlFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'id' => $id,
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $rstcf->getTable() .' as b ON a.recurring_schedule_template_control_id = b.id
+					where	b.company_id = ?
+						AND a.id = ?
+						AND a.deleted = 0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByRecurringScheduleTemplateControlId($id, $where = NULL, $order = NULL) {
 		if ( $id == '') {
 			return FALSE;
@@ -123,7 +154,7 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 
 		$additional_order_fields = array('name', 'description', 'last_name');
 		if ( $order == NULL ) {
-			$order = array( 'c.start_date' => 'asc', 'd.user_id' => 'asc', 'a.week' => 'asc' );
+			$order = array( 'c.start_date' => 'asc', 'cb.user_id' => 'asc', 'a.week' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
@@ -174,70 +205,120 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		$uf = new UserFactory();
+		$uwf = new UserWageFactory();
 		$rscf = new RecurringScheduleControlFactory();
 		$rsuf = new RecurringScheduleUserFactory();
 		$rstcf = new RecurringScheduleTemplateControlFactory();
 
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
 		$ph = array(
+					'filter_end_date' => $this->db->BindDate( $filter_data['end_date'] ),
 					'company_id' => $company_id,
 					);
 
 		$query = '
 					select 	a.*,
-							d.user_id as user_id,
-							e.first_name as first_name,
-							e.last_name as last_name,
-							e.created_by as user_created_by,
-							CASE WHEN a.branch_id = -1 THEN e.default_branch_id ELSE a.branch_id END as schedule_branch_id,
-							CASE WHEN a.department_id = -1 THEN e.default_department_id ELSE a.department_id END as schedule_department_id,
+							cb.user_id as user_id,
+
+							CASE WHEN a.branch_id = -1 THEN d.default_branch_id ELSE a.branch_id END as schedule_branch_id,
+							CASE WHEN a.department_id = -1 THEN d.default_department_id ELSE a.department_id END as schedule_department_id,
 							c.start_date as recurring_schedule_control_start_date,
 							c.end_date as recurring_schedule_control_end_date,
 							c.start_week as recurring_schedule_control_start_week,
-							y.max_week as max_week,
-							( (((a.week-1)+y.max_week-(c.start_week-1))%y.max_week) + 1) as remapped_week,
-							e.hire_date as hire_date,
-							e.termination_date as termination_date
+							zz.max_week as max_week,
+							( (((a.week-1)+zz.max_week-(c.start_week-1))%zz.max_week) + 1) as remapped_week,
+
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.default_branch_id as default_branch_id,
+							d.default_department_id as default_department_id,
+							d.title_id as title_id,
+							d.group_id as group_id,
+							d.created_by as user_created_by,
+							d.hire_date as hire_date,
+							d.termination_date as termination_date,
+
+							uw.id as user_wage_id,
+							uw.hourly_rate as user_wage_hourly_rate,
+							uw.effective_date as user_wage_effective_date';
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						x.name as job_name,
+						x.status_id as job_status_id,
+						x.manual_id as job_manual_id,
+						x.branch_id as job_branch_id,
+						x.department_id as job_department_id,
+						x.group_id as job_group_id,
+
+						y.name as job_item_name,
+						y.manual_id as job_item_manual_id,
+						y.group_id as job_item_group_id';
+		}
+
+		//Since when dealing with recurring schedules, we don't have a row for each specific date, so when determining wages
+		//we can only use the last wage entered that is earlier than the filter end date.
+		//Since in theory committed schedules will occur before todays date anyways, the accuracy won't be off too much unless
+		//the end date they specify is really far in the future, and post dated wage entry is also made.
+		$query .= '
 					from 	'. $this->getTable() .' as a
-						LEFT JOIN ( select z.recurring_schedule_template_control_id, max(z.week) as max_week from recurring_schedule_template as z where deleted = 0 group by z.recurring_schedule_template_control_id ) as y ON a.recurring_schedule_template_control_id = y.recurring_schedule_template_control_id
+						LEFT JOIN ( select z.recurring_schedule_template_control_id, max(z.week) as max_week from recurring_schedule_template as z where deleted = 0 group by z.recurring_schedule_template_control_id ) as zz ON a.recurring_schedule_template_control_id = zz.recurring_schedule_template_control_id
 						LEFT JOIN '. $rstcf->getTable() .' as b ON a.recurring_schedule_template_control_id = b.id
 						LEFT JOIN '. $rscf->getTable() .' as c ON a.recurring_schedule_template_control_id = c.recurring_schedule_template_control_id
-						LEFT JOIN '. $rsuf->getTable() .' as d ON c.id = d.recurring_schedule_control_id
-						LEFT JOIN '. $uf->getTable() .' as e ON d.user_id = e.id
-					where	b.company_id = ?
+						LEFT JOIN '. $rsuf->getTable() .' as cb ON c.id = cb.recurring_schedule_control_id
+						LEFT JOIN '. $uf->getTable() .' as d ON cb.user_id = d.id
+						LEFT JOIN '. $uwf->getTable() .' as uw ON uw.id = (select uwb.id
+																	from '. $uwf->getTable() .' as uwb
+																	where uwb.user_id = cb.user_id
+																		and uwb.effective_date <= ?
+																		and uwb.deleted = 0
+																		order by uwb.effective_date desc limit 1)
+
+						';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as x ON a.job_id = x.id';
+			$query .= '	LEFT JOIN '. $jif->getTable() .' as y ON a.job_item_id = y.id';
+		}
+
+		$query .=' where 	b.company_id = ?
 					';
 
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
-			$query  .=	' AND e.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
-			$query  .=	' AND e.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
 		}
 		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
-			$query  .=	' AND e.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
 			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
 				$uglf = new UserGroupListFactory();
 				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
 			}
-			$query  .=	' AND e.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
-			$query  .=	' AND e.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
-			$query  .=	' AND e.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
 		}
 
 		if ( isset($filter_data['schedule_branch_id']) AND isset($filter_data['schedule_branch_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_branch_id']) ) {
-			$query  .=	' AND ( a.branch_id in ('. $this->getListSQL($filter_data['schedule_branch_id'], $ph) .') OR ( a.branch_id = -1 AND e.default_branch_id in ('. $this->getListSQL($filter_data['schedule_branch_id'], $ph) .') ) )';
+			$query  .=	' AND ( a.branch_id in ('. $this->getListSQL($filter_data['schedule_branch_id'], $ph) .') OR ( a.branch_id = -1 AND d.default_branch_id in ('. $this->getListSQL($filter_data['schedule_branch_id'], $ph) .') ) )';
 		}
 		if ( isset($filter_data['schedule_department_id']) AND isset($filter_data['schedule_department_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_department_id']) ) {
-			$query  .=	' AND ( a.department_id in ('. $this->getListSQL($filter_data['schedule_department_id'], $ph) .') OR ( a.department_id = -1 AND e.default_department_id in ('. $this->getListSQL($filter_data['schedule_department_id'], $ph) .') ) )';
+			$query  .=	' AND ( a.department_id in ('. $this->getListSQL($filter_data['schedule_department_id'], $ph) .') OR ( a.department_id = -1 AND d.default_department_id in ('. $this->getListSQL($filter_data['schedule_department_id'], $ph) .') ) )';
 		}
 
 		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
-			$query  .=	' AND e.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != ''
@@ -279,15 +360,15 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 							)
 							AND
 							(
-								( e.hire_date is NULL OR e.hire_date <= ? )
+								( d.hire_date is NULL OR d.hire_date <= ? )
 								AND
-								( e.termination_date is NULL OR e.termination_date >= ? )
+								( d.termination_date is NULL OR d.termination_date >= ? )
 							)
 						';
 		}
 
 		$query .= 	'
-						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND e.deleted = 0 )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND d.deleted = 0 )
 					';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
@@ -303,5 +384,96 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		return $this;
 	}
 
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+
+		$additional_order_fields = array();
+		$sort_column_aliases = array(
+
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'week' => 'asc', 'start_time' => 'asc', 'end_time' => 'asc');
+			$strict = FALSE;
+		} else {
+			//Always sort by last name,first name after other columns
+			if ( !isset($order['week']) ) {
+				$order['week'] = 'asc';
+			}
+			if ( !isset($order['start_time']) ) {
+				$order['start_time'] = 'asc';
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$rstcf = new RecurringScheduleTemplateControlFactory();
+		$uf = new UserFactory();
+
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $rstcf->getTable() .' as b ON a.recurring_schedule_template_control_id = b.id
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	b.company_id = ?
+					';
+
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['recurring_schedule_template_control_id']) AND isset($filter_data['recurring_schedule_template_control_id'][0]) AND !in_array(-1, (array)$filter_data['recurring_schedule_template_control_id']) ) {
+			$query  .=	' AND a.recurring_schedule_template_control_id in ('. $this->getListSQL($filter_data['recurring_schedule_template_control_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 }
 ?>
