@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: ScheduleFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: ScheduleFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -54,6 +54,12 @@ class ScheduleFactory extends Factory {
 
 		$retval = NULL;
 		switch( $name ) {
+			case 'type':
+				$retval = array(
+										10 => TTi18n::gettext('Committed'),
+										20 => TTi18n::gettext('Recurring')
+									);
+				break;
 			case 'status':
 				$retval = array(
 										10 => TTi18n::gettext('Working'),
@@ -289,7 +295,7 @@ class ScheduleFactory extends Factory {
 					AND
 					$this->Validator->isResultSetWithRows(	'user_date',
 															$udlf->getByID($id),
-															TTi18n::gettext('Invalid User/Date. Pay Period may be locked')
+															TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already')
 															)
 				)
 				) {
@@ -746,26 +752,62 @@ class ScheduleFactory extends Factory {
 		$dlf = new DepartmentListFactory();
 		$department_options = $dlf->getByCompanyIdArray( $current_user->getCompany(), FALSE );
 
+		$apf = new AbsencePolicyFactory();
+		$absence_policy_paid_type_options = $apf->getOptions('paid_type');
+
 		$slf = new ScheduleListFactory();
 		$slf->getSearchByCompanyIdAndArrayCriteria( $current_user->getCompany(), $filter_data );
 		Debug::text('Found Scheduled Rows: '. $slf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
+		Debug::Arr($absence_policy_paid_type_options, 'Paid Absences: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( $slf->getRecordCount() > 0 ) {
 			foreach( $slf as $s_obj ) {
-				Debug::text('Schedule ID: '. $s_obj->getId() .' User ID: '. $s_obj->getColumn('user_id') .' Start Time: '. $s_obj->getStartTime(), __FILE__, __LINE__, __METHOD__, 10);
-				if ( is_object($s_obj->getAbsencePolicyObject()) ) {
+				//Debug::text('Schedule ID: '. $s_obj->getId() .' User ID: '. $s_obj->getColumn('user_id') .' Start Time: '. $s_obj->getStartTime(), __FILE__, __LINE__, __METHOD__, 10);
+				if ( $s_obj->getAbsencePolicyID() > 0 AND is_object($s_obj->getAbsencePolicyObject()) ) {
 					$absence_policy_name = (string)$s_obj->getAbsencePolicyObject()->getName();
-				} else {
+				} elseif ( $s_obj->getAbsencePolicyID() > 0 ) {
 					$absence_policy_name = 'N/A';
+				} else {
+					$absence_policy_name = FALSE;
+				}
+
+				$hourly_rate = Misc::MoneyFormat( $s_obj->getColumn('user_wage_hourly_rate'), FALSE );
+
+				if ( $s_obj->getAbsencePolicyID() > 0
+						AND  is_object($s_obj->getAbsencePolicyObject())
+						AND in_array( $s_obj->getAbsencePolicyObject()->getType(), $absence_policy_paid_type_options ) == FALSE ) {
+					//UnPaid Absence.
+					$total_time_wage = Misc::MoneyFormat(0);
+				} else {
+					$total_time_wage = Misc::MoneyFormat( bcmul( TTDate::getHours( $s_obj->getColumn('total_time') ), $hourly_rate ), FALSE );
 				}
 
 				$iso_date_stamp = TTDate::getISODateStamp($s_obj->getStartTime());
 				$schedule_shifts[$iso_date_stamp][$s_obj->getColumn('user_id').$s_obj->getStartTime()] = array(
 													'id' => (int)$s_obj->getID(),
+													'pay_period_id' => (int)$s_obj->getColumn('pay_period_id'),
 													'user_id' => (int)$s_obj->getColumn('user_id'),
 													'user_created_by' => (int)$s_obj->getColumn('user_created_by'),
 													'user_full_name' => Misc::getFullName( $s_obj->getColumn('first_name'), NULL, $s_obj->getColumn('last_name'), FALSE, FALSE ),
-													'first_name' => $s_obj->getColumn('first_name'),
-													'last_name' => $s_obj->getColumn('last_name'),
+													//'first_name' => $s_obj->getColumn('first_name'),
+													//'last_name' => $s_obj->getColumn('last_name'),
+													'title_id' => $s_obj->getColumn('title_id'),
+													'group_id' => $s_obj->getColumn('group_id'),
+													'default_branch_id' => $s_obj->getColumn('default_branch_id'),
+													'default_branch' => Option::getByKey($s_obj->getColumn('default_branch_id'), $branch_options, NULL ),
+													'default_department_id' => $s_obj->getColumn('default_department_id'),
+													'default_department' =>  Option::getByKey($s_obj->getColumn('default_department_id'), $department_options, NULL ),
+
+													'job_id' => $s_obj->getColumn('job_id'),
+													'job_name' => $s_obj->getColumn('job_name'),
+													'job_status_id' => $s_obj->getColumn('job_status_id'),
+													'job_manual_id' => $s_obj->getColumn('job_manual_id'),
+													'job_branch_id' => $s_obj->getColumn('job_branch_id'),
+													'job_department_id' => $s_obj->getColumn('job_department_id'),
+													'job_group_id' => $s_obj->getColumn('job_group_id'),
+													'job_item_id' => $s_obj->getColumn('job_item_id'),
+													'job_item_name' => $s_obj->getColumn('job_item_name'),
+
+													'type_id' => 10, //Committed
 													'status_id' => (int)$s_obj->getStatus(),
 
 													'date_stamp' => TTDate::getAPIDate( 'DATE', TTDate::parseDateTime( $s_obj->getColumn('date_stamp') ) ),
@@ -775,6 +817,10 @@ class ScheduleFactory extends Factory {
 													'end_time' => ( defined('TIMETREX_API') ) ? TTDate::getAPIDate('TIME', $s_obj->getEndTime() ) : $s_obj->getEndTime(),
 
 													'total_time' => $s_obj->getTotalTime(),
+
+													'hourly_rate' => $hourly_rate,
+													'total_time_wage' => $total_time_wage,
+
 													'schedule_policy_id' => (int)$s_obj->getSchedulePolicyID(),
 													'absence_policy_id' => (int)$s_obj->getAbsencePolicyID(),
 													'absence_policy' => $absence_policy_name,
@@ -803,7 +849,7 @@ class ScheduleFactory extends Factory {
 		Debug::text('Found Holiday Rows: '. $hlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		foreach( $hlf as $h_obj ) {
 			if ( is_object( $h_obj->getHolidayPolicyObject() ) AND is_object( $h_obj->getHolidayPolicyObject()->getAbsencePolicyObject() ) ) {
-				$holiday_data[TTDate::getISODateStamp($h_obj->getDateStamp())] = array('status_id' => (int)$h_obj->getHolidayPolicyObject()->getDefaultScheduleStatus(), 'absence_policy_id' => $h_obj->getHolidayPolicyObject()->getAbsencePolicyID(), 'absence_policy' => $h_obj->getHolidayPolicyObject()->getAbsencePolicyObject()->getName() );
+				$holiday_data[TTDate::getISODateStamp($h_obj->getDateStamp())] = array('status_id' => (int)$h_obj->getHolidayPolicyObject()->getDefaultScheduleStatus(), 'absence_policy_id' => $h_obj->getHolidayPolicyObject()->getAbsencePolicyID(), 'type_id' => $h_obj->getHolidayPolicyObject()->getAbsencePolicyObject()->getType(), 'absence_policy' => $h_obj->getHolidayPolicyObject()->getAbsencePolicyObject()->getName() );
 			} else {
 				$holiday_data[TTDate::getISODateStamp($h_obj->getDateStamp())] = array('status_id' => 10 ); //Working
 			}
@@ -846,6 +892,19 @@ class ScheduleFactory extends Factory {
 		return TRUE;
 	}
 
+	function getEnableOverwrite() {
+		if ( isset($this->overwrite) ) {
+			return $this->overwrite;
+		}
+
+		return FALSE;
+	}
+	function setEnableOverwrite($bool) {
+		$this->overwrite = $bool;
+
+		return TRUE;
+	}
+
 	function handleDayBoundary() {
 		Debug::Arr($this->getStartTime(), 'Start Time: '. TTDate::getDate('DATE+TIME', $this->getStartTime()), __FILE__, __LINE__, __METHOD__, 10);
 		Debug::Arr($this->getEndTime(), 'End Time: '. TTDate::getDate('DATE+TIME', $this->getEndTime()), __FILE__, __LINE__, __METHOD__, 10);
@@ -1281,7 +1340,7 @@ class ScheduleFactory extends Factory {
 						foreach ( $department_schedule_shifts as $department => $department_schedule_shift ) {
 							$sort = new arr_multisort();
 							$sort->setArray($department_schedule_shift);
-							$sort->addColumn('start_time', 1);
+							$sort->addColumn('last_name', 1); //Sort by last name so its easier for employees to find their shifts.
 							$department_schedule_shift = $sort->Sort();
 							unset($sort);
 
@@ -1373,11 +1432,17 @@ class ScheduleFactory extends Factory {
 
 		$this->handleDayBoundary();
 
+		//Check to make sure EnableOverwrite isn't enabled when editing an existing record.
+		if ( $this->isNew() == FALSE AND $this->getEnableOverwrite() == TRUE ) {
+			Debug::Text('Overwrite enabled when editing existing record, disabling overwrite.', __FILE__, __LINE__, __METHOD__,10);
+			$this->setEnableOverwrite( FALSE );
+		}
+
 		if ( $this->getUserDateObject() == FALSE OR !is_object( $this->getUserDateObject() ) ) {
 			Debug::Text('UserDateID is INVALID! ID: '. $this->getUserDateID(), __FILE__, __LINE__, __METHOD__,10);
 			$this->Validator->isTrue(		'user_date',
 											FALSE,
-											TTi18n::gettext('Invalid User/Date. Pay Period may be locked'));
+											TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already'));
 		}
 
 		if ( is_object( $this->getUserDateObject() ) AND $this->getUserDateObject()->getPayPeriodObject()->getIsLocked() == TRUE ) {
@@ -1386,7 +1451,8 @@ class ScheduleFactory extends Factory {
 											TTi18n::gettext('Pay Period is Currently Locked'));
 		}
 
-		if ( $this->getDeleted() == FALSE AND is_object( $this->getUserDateObject() ) ) {
+		//Ignore conflicting time check when EnableOverwrite is set, as we will just be deleting any conflicting shift anyways.
+		if ( $this->getEnableOverwrite() == FALSE AND $this->getDeleted() == FALSE AND is_object( $this->getUserDateObject() ) ) {
 			Debug::Text('User Date ID: '. $this->getUserDateID() .' User ID: '. $this->getUserDateObject()->getUser(), __FILE__, __LINE__, __METHOD__,10);
 			//Make sure we're not conflicting with any other schedule shifts.
 			$slf = new ScheduleListFactory();
@@ -1403,6 +1469,8 @@ class ScheduleFactory extends Factory {
 													TTi18n::gettext('Conflicting start time'));
 				}
 			}
+		} else {
+			Debug::text('Not checking for conflicts... UserDateObject: '. (int)is_object( $this->getUserDateObject() ) , __FILE__, __LINE__, __METHOD__, 10);
 		}
 
 		return TRUE;
@@ -1418,6 +1486,26 @@ class ScheduleFactory extends Factory {
 		if ( $this->getStatus() == 10 ) {
 			$this->setAbsencePolicyID( NULL );
 		}
+
+		if ( $this->getEnableOverwrite() == TRUE AND $this->isNew() == TRUE ) {
+			//Delete any conflicting schedule shift before saving.
+			$slf = new ScheduleListFactory();
+			$slf->getConflictingByUserIdAndStartDateAndEndDate( $this->getUserDateObject()->getUser(), $this->getStartTime(), $this->getEndTime() );
+			if ( $slf->getRecordCount() > 0 ) {
+				Debug::Text('Found Conflicting Shift!!', __FILE__, __LINE__, __METHOD__,10);
+				//Delete shifts.
+				foreach( $slf as $s_obj ) {
+					Debug::Text('Deleting Schedule Shift ID: '. $s_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
+					$s_obj->setDeleted(TRUE);
+					if ( $s_obj->isValid() ) {
+						$s_obj->Save();
+					}
+				}
+			} else {
+				Debug::Text('NO Conflicting Shift found...', __FILE__, __LINE__, __METHOD__,10);
+			}
+		}
+
 		return TRUE;
 	}
 
@@ -1450,6 +1538,10 @@ class ScheduleFactory extends Factory {
 				Debug::text(' NOT CALLING setUserDate or setUserDateID!', __FILE__, __LINE__, __METHOD__,10);
 			}
 
+			if ( isset($data['overwrite']) ) {
+				$this->setEnableOverwrite( TRUE );
+			}
+
 			$variable_function_map = $this->getVariableToFunctionMap();
 			foreach( $variable_function_map as $key => $function ) {
 				if ( isset($data[$key]) ) {
@@ -1461,7 +1553,7 @@ class ScheduleFactory extends Factory {
 						case 'start_time':
 							if ( method_exists( $this, $function ) ) {
 								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['start_date']) AND strlen($data['start_date']) > strlen($data[$key]) ) {
-									Debug::text(' aSetting start time... ', __FILE__, __LINE__, __METHOD__,10);
+									Debug::text(' aSetting start time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto start_time
 								} elseif ( is_object( $this->getUserDateObject() ) ) {
 									Debug::text(' bSetting start time...: '. $this->getUserDateObject()->getDateStamp(), __FILE__, __LINE__, __METHOD__,10);
@@ -1474,8 +1566,10 @@ class ScheduleFactory extends Factory {
 						case 'end_time':
 							if ( method_exists( $this, $function ) ) {
 								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['end_date']) AND strlen($data['end_date']) > strlen($data[$key]) ) {
+									Debug::text(' aaSetting start time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto end_time
 								} elseif ( is_object( $this->getUserDateObject() ) ) {
+									Debug::text(' bbSetting start time... "'. TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key] ) );
 								}
 							}
