@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: ScheduleListFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3628 $
+ * $Id: ScheduleListFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 
 /**
@@ -384,8 +384,12 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
-		$start_date = $this->db->BindTimeStamp( $start_date );
-		$end_date = $this->db->BindTimeStamp( $end_date );
+		//MySQL is picky when it comes to timestamp filters on datestamp columns.
+		$start_datestamp = $this->db->BindDate( $start_date );
+		$end_datestamp = $this->db->BindDate( $end_date );
+
+		$start_timestamp = $this->db->BindTimeStamp( $start_date );
+		$end_timestamp = $this->db->BindTimeStamp( $end_date );
 
 		$udf = new UserDateFactory();
 /*
@@ -401,37 +405,43 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							(start_time <= '. $start_date .' AND end_time >= '. $end_date .')
 						)
 
+
 */
 
 		$ph = array(
 					'user_id' => $user_id,
-					'start_date1' => $start_date,
-					'end_date1' => $end_date,
-					'start_date2' => $start_date,
-					'end_date2' => $end_date,
-					'start_date3' => $start_date,
-					'end_date3' => $end_date,
-					'start_date4' => $start_date,
-					'end_date4' => $end_date,
-					'start_date5' => $start_date,
-					'end_date5' => $end_date,
+					'start_date_a' => $start_datestamp,
+					'end_date_b' => $end_datestamp,
+					'start_date1' => $start_timestamp,
+					'end_date1' => $end_timestamp,
+					'start_date2' => $start_timestamp,
+					'end_date2' => $end_timestamp,
+					'start_date3' => $start_timestamp,
+					'end_date3' => $end_timestamp,
+					'start_date4' => $start_timestamp,
+					'end_date4' => $end_timestamp,
+					'start_date5' => $start_timestamp,
+					'end_date5' => $end_timestamp,
 					);
 
+		//Add filter on date_stamp for optimization
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a,
 							'. $udf->getTable() .' as b
 					where a.user_date_id = b.id
 						AND b.user_id = ?
+						AND b.date_stamp >= ?
+						AND b.date_stamp <= ?
 						AND
 						(
-							(start_time > ? AND end_time < ? )
+							(start_time >= ? AND end_time <= ? )
 							OR
-							(start_time > ? AND start_time < ? )
+							(start_time >= ? AND start_time < ? )
 							OR
-							(end_time > ? AND end_time < ? )
+							(end_time > ? AND end_time <= ? )
 							OR
-							(start_time < ? AND end_time > ? )
+							(start_time <= ? AND end_time >= ? )
 							OR
 							(start_time = ? AND end_time = ? )
 						)
@@ -460,8 +470,12 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
-		$start_date = $this->db->BindTimeStamp( $start_date );
-		$end_date = $this->db->BindTimeStamp( $end_date );
+		//MySQL is picky when it comes to timestamp filters on datestamp columns.
+		$start_datestamp = $this->db->BindDate( $start_date );
+		$end_datestamp = $this->db->BindDate( $end_date );
+
+		$start_timestamp = $this->db->BindTimeStamp( $start_date );
+		$end_timestamp = $this->db->BindTimeStamp( $end_date );
 
 		$udf = new UserDateFactory();
 /*
@@ -477,28 +491,34 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							(start_time <= '. $start_date .' AND end_time >= '. $end_date .')
 						)
 
+
 */
 
 		$ph = array(
 					'user_date_id' => $user_date_id,
-					'start_date1' => $start_date,
-					'end_date1' => $end_date,
-					'start_date2' => $start_date,
-					'end_date2' => $end_date,
-					'start_date3' => $start_date,
-					'end_date3' => $end_date,
-					'start_date4' => $start_date,
-					'end_date4' => $end_date,
-					'start_date5' => $start_date,
-					'end_date5' => $end_date,
+					'start_date_a' => $start_datestamp,
+					'end_date_b' => $end_datestamp,
+					'start_date1' => $start_timestamp,
+					'end_date1' => $end_timestamp,
+					'start_date2' => $start_timestamp,
+					'end_date2' => $end_timestamp,
+					'start_date3' => $start_timestamp,
+					'end_date3' => $end_timestamp,
+					'start_date4' => $start_timestamp,
+					'end_date4' => $end_timestamp,
+					'start_date5' => $start_timestamp,
+					'end_date5' => $end_timestamp,
 					);
 
+		//Add filter on date_stamp for optimization
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a,
 							'. $udf->getTable() .' as b
 					where a.user_date_id = b.id
 						AND a.user_date_id = ?
+						AND b.date_stamp >= ?
+						AND b.date_stamp <= ?
 						AND
 						(
 							(start_time > ? AND end_time < ? )
@@ -570,7 +590,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
 		$additional_order_fields = array();
 		if ( $order == NULL ) {
-			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.start_time' => 'asc' );
+			$order = array( 'udf.pay_period_id' => 'asc','udf.user_id' => 'asc', 'a.start_time' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
@@ -599,6 +619,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		if ( isset($filter_data['default_department_ids']) ) {
 			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
 		}
+		if ( isset($filter_data['schedule_status_ids']) ) {
+			$filter_data['schedule_status_id'] = $filter_data['schedule_status_ids'];
+		}
 		if ( isset($filter_data['schedule_branch_ids']) ) {
 			$filter_data['schedule_branch_id'] = $filter_data['schedule_branch_ids'];
 		}
@@ -622,6 +645,11 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$uf = new UserFactory();
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$apf = new AbsencePolicyFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$jf = new JobFactory();
@@ -648,17 +676,28 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							a.total_time as total_time,
 							a.schedule_policy_id as schedule_policy_id,
 							a.absence_policy_id as absence_policy_id,
+							apf.type_id as absence_policy_type_id,
 
-							c.user_id as user_id,
-							c.date_stamp as date_stamp,
-							c.pay_period_id as pay_period_id,
+							bf.name as default_branch,
+							df.name as default_department,
+							ugf.name as "group",
+							utf.name as title,
 
-							d.first_name as first_name,
-							d.last_name as last_name,
-							d.created_by as user_created_by,
+							udf.user_id as user_id,
+							udf.date_stamp as date_stamp,
+							udf.pay_period_id as pay_period_id,
 
-							z.id as user_wage_id,
-							z.effective_date as user_wage_effective_date ';
+							uf.first_name as first_name,
+							uf.last_name as last_name,
+							uf.default_branch_id as default_branch_id,
+							uf.default_department_id as default_department_id,
+							uf.title_id as title_id,
+							uf.group_id as group_id,
+							uf.created_by as user_created_by,
+
+							uwf.id as user_wage_id,
+							uwf.hourly_rate as user_wage_hourly_rate,
+							uwf.effective_date as user_wage_effective_date ';
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
@@ -667,54 +706,63 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 						x.manual_id as job_manual_id,
 						x.branch_id as job_branch_id,
 						x.department_id as job_department_id,
-						x.group_id as job_group_id';
+						x.group_id as job_group_id,
+
+						y.name as job_item_name,
+						y.manual_id as job_item_manual_id,
+						y.group_id as job_item_group_id';
 		}
 
 		$query .= '
 					from 	'. $this->getTable() .' as a
-							LEFT JOIN '. $udf->getTable() .' as c ON a.user_date_id = c.id
-							LEFT JOIN '. $uf->getTable() .' as d ON c.user_id = d.id
-							LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
+							LEFT JOIN '. $udf->getTable() .' as udf ON a.user_date_id = udf.id
+							LEFT JOIN '. $uf->getTable() .' as uf ON udf.user_id = uf.id
+							LEFT JOIN '. $bf->getTable() .' as bf ON ( uf.default_branch_id = bf.id AND bf.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as df ON ( uf.default_department_id = df.id AND df.deleted = 0)
+							LEFT JOIN '. $ugf->getTable() .' as ugf ON ( uf.group_id = ugf.id AND ugf.deleted = 0 )
+							LEFT JOIN '. $utf->getTable() .' as utf ON ( uf.title_id = utf.id AND utf.deleted = 0 )
+							LEFT JOIN '. $apf->getTable() .' as apf ON a.absence_policy_id = apf.id
+							LEFT JOIN '. $uwf->getTable() .' as uwf ON uwf.id = (select uwf.id
 																		from '. $uwf->getTable() .' as z
-																		where z.user_id = c.user_id
-																			and z.effective_date <= c.date_stamp
-																			and z.deleted = 0
-																			order by z.effective_date desc limit 1)
+																		where uwf.user_id = udf.user_id
+																			and uwf.effective_date <= udf.date_stamp
+																			and uwf.deleted = 0
+																			order by uwf.effective_date desc limit 1)
 					';
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= '	LEFT JOIN '. $jf->getTable() .' as x ON a.job_id = x.id';
 			$query .= '	LEFT JOIN '. $jif->getTable() .' as y ON a.job_item_id = y.id';
 		}
 
-		$query .= '	WHERE d.company_id = ?';
+		$query .= '	WHERE uf.company_id = ?';
 
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
-			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+			$query  .=	' AND uf.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
 		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
-			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+			$query  .=	' AND uf.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
 		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
-			$query  .=	' AND d.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+			$query  .=	' AND uf.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
-			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+			$query  .=	' AND uf.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
 			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
 				$uglf = new UserGroupListFactory();
 				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
 			}
-			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+			$query  .=	' AND uf.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
-			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+			$query  .=	' AND uf.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
-			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+			$query  .=	' AND uf.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
-			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+			$query  .=	' AND uf.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['schedule_branch_id']) AND isset($filter_data['schedule_branch_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_branch_id']) ) {
 			$query  .=	' AND a.branch_id in ('. $this->getListSQL($filter_data['schedule_branch_id'], $ph) .') ';
@@ -729,7 +777,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$query  .=	' AND a.schedule_policy_id in ('. $this->getListSQL($filter_data['schedule_policy_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
-			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
+			$query .= 	' AND udf.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 		}
 
 
@@ -763,7 +811,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		}
 
 		$query .= 	'
-						AND (a.deleted = 0 AND c.deleted = 0 AND d.deleted = 0)
+						AND (a.deleted = 0 AND udf.deleted = 0 AND uf.deleted = 0)
 					';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
@@ -818,6 +866,20 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['department_id'] = $filter_data['department_ids'];
+		}
+
+		if ( isset($filter_data['punch_branch_ids']) ) {
+			$filter_data['punch_branch_id'] = $filter_data['punch_branch_ids'];
+		}
+		if ( isset($filter_data['punch_department_ids']) ) {
+			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
+		}
+
 		$udf = new UserDateFactory();
 		$uf = new UserFactory();
 
@@ -842,6 +904,14 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$query .= 	' AND b.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 		}
 
+		//Schedule/Punch branches/departments
+ 		if ( isset($filter_data['punch_branch_id']) AND isset($filter_data['punch_branch_id'][0]) AND !in_array(-1, (array)$filter_data['punch_branch_id']) ) {
+			$query .= 	' AND a.branch_id in ('. $this->getListSQL($filter_data['punch_branch_id'], $ph) .') ';
+		}
+ 		if ( isset($filter_data['punch_department_id']) AND isset($filter_data['punch_department_id'][0]) AND !in_array(-1, (array)$filter_data['punch_department_id']) ) {
+			$query .= 	' AND a.department_id in ('. $this->getListSQL($filter_data['punch_department_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
 			$ph[] = $this->db->BindDate($filter_data['start_date']);
 			$query  .=	' AND b.date_stamp >= ?';
@@ -908,6 +978,20 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['department_id'] = $filter_data['department_ids'];
+		}
+
+		if ( isset($filter_data['punch_branch_ids']) ) {
+			$filter_data['punch_branch_id'] = $filter_data['punch_branch_ids'];
+		}
+		if ( isset($filter_data['punch_department_ids']) ) {
+			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
+		}
+
 		$udf = new UserDateFactory();
 		$uf = new UserFactory();
 
@@ -935,6 +1019,14 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$query .= 	' AND b.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 		}
 
+		//Schedule/Punch branches/departments
+ 		if ( isset($filter_data['punch_branch_id']) AND isset($filter_data['punch_branch_id'][0]) AND !in_array(-1, (array)$filter_data['punch_branch_id']) ) {
+			$query .= 	' AND a.branch_id in ('. $this->getListSQL($filter_data['punch_branch_id'], $ph) .') ';
+		}
+ 		if ( isset($filter_data['punch_department_id']) AND isset($filter_data['punch_department_id'][0]) AND !in_array(-1, (array)$filter_data['punch_department_id']) ) {
+			$query .= 	' AND a.department_id in ('. $this->getListSQL($filter_data['punch_department_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
 			$ph[] = $this->db->BindDate($filter_data['start_date']);
 			$query  .=	' AND b.date_stamp >= ?';
@@ -969,13 +1061,21 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		}
 
 		$additional_order_fields = array('schedule_policy_id', 'schedule_policy', 'first_name', 'last_name', 'user_status_id', 'group_id', 'group', 'title_id', 'title', 'default_branch_id', 'default_branch', 'default_department_id', 'default_department', 'total_time', 'date_stamp', 'pay_period_id', );
+
+		$sort_column_aliases = array(
+									 'updated_date' => 'a.updated_date',
+									 'created_date' => 'a.created_date',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
 		if ( $order == NULL ) {
 			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.start_time' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
 		}
-		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( isset($filter_data['exclude_user_ids']) ) {
@@ -1047,6 +1147,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 					'company_id' => $company_id,
 					);
 
+		//"group" is a reserved word in MySQL.
 		$query = '
 					select
 							a.id as id,
@@ -1076,7 +1177,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							d.last_name as last_name,
 							d.status_id as user_status_id,
 							d.group_id as group_id,
-							g.name as group,
+							g.name as "group",
 							d.title_id as title_id,
 							h.name as title,
 							d.default_branch_id as default_branch_id,
