@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: TimeTrexSoapServer.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 3021 $
+ * $Id: TimeTrexSoapServer.class.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 
 /**
@@ -61,6 +74,10 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		return $this->user_obj;
 	}
 
+	function getUserPreferenceObject() {
+		return $this->getUserObject()->getUserPreferenceObject();
+	}
+
 	function getStationObject() {
 		$station_id = trim($_GET['StationID']);
 
@@ -109,6 +126,16 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		return "Hello World22: $text - ". $this->getUserFullName() ."";
 	}
 
+	function getUserPreferenceData() {
+		$retarr = array(
+						'date_format' => $this->getUserPreferenceObject()->getDateFormat(),
+						'time_format' => $this->getUserPreferenceObject()->getTimeFormat(),
+						'time_unit_format' => $this->getUserPreferenceObject()->getTimeUnitFormat(),
+						);
+
+		return $retarr;
+	}
+
 	function StationCheckAllowed() {
 		if ( is_object( $this->getStationObject() ) ) {
 			return $this->getStationObject()->checkAllowed( $this->getUserObject()->getId(), $this->getStationObject()->getStation(), $this->getStationObject()->getType() );
@@ -162,7 +189,13 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			$sf->setCompany( $this->getCompanyObject()->getId() );
 			$sf->setStatus( 'ENABLED' );
 			$sf->setType( $type );
-			$sf->setSource( $source );
+
+			//If this is a new iButton,Fingerprint, or Barcode station, default to 'ANY' for the source, so we aren't restricted by IP.
+			if ( in_array( $sf->getType(), array(30,40,50) ) ) {
+				$sf->setSource( 'ANY' );
+			} else {
+				$sf->setSource( $source );
+			}
 			$sf->setStation( $station );
 			$sf->setDescription( $description );
 
@@ -193,7 +226,9 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 	function getEnrollUsers() {
 		//Check to make sure the logged in user has edit_advance permissions
-		if ( $this->getPermissionObject()->Check('user','enroll') ) {
+		//Take into account the station allowed employees, as well as child employees.
+		//This is important for companies with many thousands of employees.
+		if ( $this->getPermissionObject()->Check('user','enroll') OR $this->getPermissionObject()->Check('user','enroll_child') ) {
 			$ulf = new UserListFactory();
 			$user_list = $ulf->getByCompanyIdArray( $this->getUserObject()->getCompany(), FALSE, FALSE);
 
@@ -216,7 +251,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 		$ulf = new UserListFactory();
 
-		if ( version_compare( $this->getClientVersion(), '3.0.0', '<' ) ) {
+		if ( version_compare( $this->getClientVersion(), '2.7.0', '<' ) ) {
 			Debug::text('aVersion: '. $this->getClientVersion(), __FILE__, __LINE__, __METHOD__, 10);
 
 			//Fingerprints can send $id=NULL to clear an enrollment.
@@ -226,7 +261,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			}
 
 			//Check to make sure the logged in user has edit_advance permissions
-			if ( $this->getPermissionObject()->Check('user','enroll') ) {
+			if ( $this->getPermissionObject()->Check('user','enroll') OR $this->getPermissionObject()->Check('user','enroll_child') ) {
 				Debug::text('User : '. $this->getUserObject()->getFullName() .' has Enroll permission', __FILE__, __LINE__, __METHOD__, 10);
 
 				switch( $type ) {
@@ -378,12 +413,29 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 				Debug::text('User : '. $this->getUserObject()->getFullName() .' DOES NOT HAVE edit advance permission', __FILE__, __LINE__, __METHOD__, 10);
 			}
 		} else {
+			//This code path needs to handle re-enrolling iButtons, proximity cards, etc... for a different employees.
 			Debug::text('bVersion: '. $this->getClientVersion(), __FILE__, __LINE__, __METHOD__, 10);
 
 			$ulf->getByIdAndCompanyId( $user_id, $this->getUserObject()->getCompany() );
 			if ( $ulf->getRecordCount() == 1 ) {
 				Debug::text('Enroller User ID : '. $user_id .' FOUND', __FILE__, __LINE__, __METHOD__, 10);
 
+				//Checking to see if value is enrolled for a different user first.
+				$uilf = new UserIdentificationListFactory();
+				$uilf->getByCompanyIdAndTypeIdAndValue( $this->getUserObject()->getCompany(), $type, $id );
+				if ( $uilf->getRecordCount() > 0 ) {
+					foreach( $uilf as $ui_obj ) {
+						Debug::text('Removing enolled value from User: '. $ui_obj->getUserObject()->getUserName(), __FILE__, __LINE__, __METHOD__, 10);
+						$ui_obj->setDeleted(TRUE);
+						if ( $ui_obj->isValid() ) {
+							$ui_obj->Save();
+						}
+					}
+					unset($ui_obj);
+				} else {
+					Debug::text('Didnt find current user with enrolled value assigned...', __FILE__, __LINE__, __METHOD__, 10);
+				}
+
 				$enroll_user_obj = $ulf->getCurrent();
 
 				$uilf = new UserIdentificationListFactory();
@@ -423,7 +475,6 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 					}
 				}
 
-
 				Debug::text('Enroll User Object not valid : '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 			} else {
 				Debug::text('User ID : '. $user_id .' NOT FOUND', __FILE__, __LINE__, __METHOD__, 10);
@@ -455,6 +506,15 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			$job_id = $prev_punch_obj->getPunchControlObject()->getJob();
 			$job_item_id = $prev_punch_obj->getPunchControlObject()->getJobItem();
 
+			//Don't enable transfer by default if the previous punch was any OUT punch.
+			//Transfer does the OUT punch for them, so if the previous punch is an OUT punch
+			//we don't gain anything anyways.
+			if ( $this->getPermissionObject()->Check('punch','default_transfer') AND $prev_punch_obj->getStatus() == 10 ) {
+				$transfer = TRUE;
+			} else {
+				$transfer = FALSE;
+			}
+
 			if ( $branch_id == '' OR empty($branch_id)
 					OR $department_id == '' OR empty($department_id)
 					OR $job_id == '' OR empty($job_id)
@@ -488,40 +548,28 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 			$next_type = $prev_punch_obj->getNextType();
 
-			//CHeck for meal policy window.
-			$prev_punch_obj->setScheduleID( $epoch );
-			if ( is_object( $prev_punch_obj->getScheduleObject() )
-					AND is_object($prev_punch_obj->getScheduleObject()->getSchedulePolicyObject() )
-					AND is_object($prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject() )
-					AND $prev_punch_obj->getType() != 20 ) {
-				Debug::Text(' Found Schedule Meal Policy Object: Start Window: '. $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow(), __FILE__, __LINE__, __METHOD__,10);
+			//Check for break policy window.
+			if ( $next_type != 30 AND ( $prev_punch_obj->getStatus() != 30 AND $prev_punch_obj->getType() != 30 ) ) {
+				$prev_punch_obj->setUser( $this->getUserObject()->getId() );
+				$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $epoch ) );
+				if ( $prev_punch_obj->inBreakPolicyWindow( $epoch, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
+					Debug::Text(' Setting Type to Break: ', __FILE__, __LINE__, __METHOD__,10);
+					$next_type = 30;
+				}
+			}
 
-				if ( $epoch >= ($prev_punch_obj->getScheduleObject()->getStartTime() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() )
-						AND $epoch <= ($prev_punch_obj->getScheduleObject()->getStartTime() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getWindowLength() ) ) {
+			//Check for meal policy window.
+			if ( $next_type != 20 AND ( $prev_punch_obj->getStatus() != 20 AND $prev_punch_obj->getType() != 20 ) ) {
+				$prev_punch_obj->setUser( $this->getUserObject()->getId() );
+				$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $epoch ) );
+				if ( $prev_punch_obj->inMealPolicyWindow( $epoch, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
 					Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
 					$next_type = 20;
 				}
-			} elseif ( is_object($prev_punch_obj) AND $prev_punch_obj->getType() != 20 ) {
-				//Check NON-scheduled meal policies
-				$mplf = new MealPolicyListFactory();
-				$mplf->getByPolicyGroupUserId( $this->getUserObject()->getId() );
-				if ( $mplf->getRecordCount() > 0 ) {
-					$mp_obj = $mplf->getCurrent();
-					Debug::Text(' Found NON Schedule Meal Policy start Window: '. $mp_obj->getStartWindow(), __FILE__, __LINE__, __METHOD__,10);
-
-					if ( $epoch >= ($prev_punch_obj->getTimeStamp() + $mp_obj->getStartWindow())
-							AND $epoch <= ($prev_punch_obj->getTimeStamp() + $mp_obj->getStartWindow() + $mp_obj->getWindowLength() ) ) {
-						Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-						$next_type = 20;
-					}
-				} else {
-					Debug::Text(' DID NOT Find NON Schedule Meal Policy start Window: ', __FILE__, __LINE__, __METHOD__,10);
-				}
-				unset($mplf, $mp_obj);
 			}
 
 			Debug::Text(' cJob Item ID: '. $job_item_id, __FILE__, __LINE__, __METHOD__,10);
-			$note = NULL;
+			$note = '';
 			if ( (int)$prev_punch_obj->getNextStatus() == 20 ) {
 				$note = $prev_punch_obj->getPunchControlObject()->getNote();
 			}
@@ -532,13 +580,15 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 							'time_stamp' => TTDate::getDate('TIME', $epoch),
 							'date_stamp' => TTDate::getDate('DATE', $epoch),
 							'full_time_stamp' => $epoch,
+							'iso_time_stamp' => TTDate::getDBTimeStamp( $epoch, FALSE ),
+							'transfer' => $transfer,
 							'branch_id' => (int)$branch_id,
 							'department_id' => (int)$department_id,
 							'job_id' => $job_id,
 							'job_item_id' => $job_item_id,
 							'quantity' => $prev_punch_obj->getPunchControlObject()->getQuantity(),
 							'bad_quantity' => $prev_punch_obj->getPunchControlObject()->getBadQuantity(),
-							'note' => $note,
+							'note' => (string)$note, //Must not be NULL
 							'other_id1' => $prev_punch_obj->getPunchControlObject()->getOtherID1(),
 							'other_id2' => $prev_punch_obj->getPunchControlObject()->getOtherID2(),
 							'other_id3' => $prev_punch_obj->getPunchControlObject()->getOtherID3(),
@@ -553,10 +603,11 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 		} else {
 			Debug::Text(' DID NOT Find Previous Punch within Continuous Time from now: ', __FILE__, __LINE__, __METHOD__,10);
-			$branch_id = NULL;
-			$department_id = NULL;
-			$job_id = NULL;
-			$job_item_id = NULL;
+			//These used to be NULLs, but as of TT v3.0 they cause deserilizer errors with a Java client.
+			$branch_id = '';
+			$department_id = '';
+			$job_id = '';
+			$job_item_id = '';
 
 			$s_obj = $slf->getScheduleObjectByUserIdAndEpoch( $this->getUserObject()->getId(), $epoch );
 			if ( is_object($s_obj) ) {
@@ -569,6 +620,22 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 				//Check for defaults
 				$branch_id = $this->getUserObject()->getDefaultBranch();
 				$department_id = $this->getUserObject()->getDefaultDepartment();
+
+				//Check station for default/forced settings.
+				if ( is_object( $this->getStationObject() ) ) {
+					if ( $this->getStationObject()->getDefaultBranch() !== FALSE AND $this->getStationObject()->getDefaultBranch() != 0 ) {
+						$branch_id = $this->getStationObject()->getDefaultBranch();
+					}
+					if ( $this->getStationObject()->getDefaultDepartment() !== FALSE AND $this->getStationObject()->getDefaultDepartment() != 0 ) {
+						$department_id = $this->getStationObject()->getDefaultDepartment();
+					}
+					if ( $this->getStationObject()->getDefaultJob() !== FALSE AND $this->getStationObject()->getDefaultJob() != 0 ) {
+						$job_id = $this->getStationObject()->getDefaultJob();
+					}
+					if ( $this->getStationObject()->getDefaultJobItem() !== FALSE AND $this->getStationObject()->getDefaultJobItem() != 0 ) {
+						$job_item_id = $this->getStationObject()->getDefaultJobItem();
+					}
+				}
 			}
 
 			$data = array(
@@ -577,6 +644,8 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 							'time_stamp' => TTDate::getDate('TIME', $epoch),
 							'date_stamp' => TTDate::getDate('DATE', $epoch),
 							'full_time_stamp' => $epoch,
+							'iso_time_stamp' => TTDate::getDBTimeStamp( $epoch, FALSE ),
+							'transfer' => FALSE,
 							'branch_id' => (int)$branch_id,
 							'department_id' => (int)$department_id,
 							'job_id' => $job_id,
@@ -590,20 +659,10 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		$blf = new BranchListFactory();
 		$blf->getByCompanyId( $this->getCompanyObject()->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, TRUE, FALSE );
-		//$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
 		$dlf = new DepartmentListFactory();
 		$dlf->getByCompanyId( $this->getCompanyObject()->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, TRUE, FALSE);
-		//$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
-
-/*
-		$blf = new BranchListFactory();
-		$branch_options = $blf->getByCompanyIdArray( $this->getCompanyObject()->getId() );
-
-		$dlf = new DepartmentListFactory();
-		$department_options = $dlf->getByCompanyIdArray( $this->getCompanyObject()->getId() );
-*/
 
 		$job_options = array();
 		$job_item_options = array();
@@ -627,12 +686,15 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 		//Hack for PHP v5.0.4 shotty SOAP.
 		//If it can cast the first array key to a INT, it rekeys the entire array.
-		$data['status_options'] = Misc::prependArray( array('_' => NULL ), $data['status_options'] );
-		$data['type_options'] = Misc::prependArray( array('_' => NULL ), $data['type_options'] );
-		$data['branch_options'] = Misc::prependArray( array('_' => NULL ), $data['branch_options'] );
-		$data['department_options'] = Misc::prependArray( array('_' => NULL ), $data['department_options'] );
-		$data['job_options'] = Misc::prependArray( array('_' => NULL ), $data['job_options'] );
-		$data['job_item_options'] = Misc::prependArray( array('_' => NULL ), $data['job_item_options'] );
+		//02-Nov-09: Using NULL values causes the Java client to throw a deserlizer error. Using '' causes blank entries.
+		/*
+		$data['status_options'] = Misc::prependArray( array('_' => FALSE ), $data['status_options'] );
+		$data['type_options'] = Misc::prependArray( array('_' => FALSE ), $data['type_options'] );
+		$data['branch_options'] = Misc::prependArray( array('_' => FALSE ), $data['branch_options'] );
+		$data['department_options'] = Misc::prependArray( array('_' => FALSE ), $data['department_options'] );
+		$data['job_options'] = Misc::prependArray( array('_' => FALSE ), $data['job_options'] );
+		$data['job_item_options'] = Misc::prependArray( array('_' => FALSE ), $data['job_item_options'] );
+		*/
 
 		$data['timeout'] = 5;
 		$data['date_format_example'] = (string)$this->getUserObject()->getUserPreferenceObject()->getDateFormatExample();
@@ -647,11 +709,6 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		//Debug::Arr($data, 'Return Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		return $data;
-		//return array(  10 => 'Test1', 20 => 'Test2');
-		//return array(  '10' => 'Test1', '20' => 'Test2');
-		//return array(  '_' => '', 10 => 'Test1', 20 => 'Test2');
-		//return array(  '_' => NULL, 10 => 'Test1', 20 => 'Test2');
-		//return $data['status_options'];
 	}
 
 	function setPunchData($data) {
@@ -675,164 +732,167 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		$punch_full_time_stamp = TTDate::parseDateTime($data['date_stamp'].' '.$data['time_stamp']);
 		Debug::Text(' Punch Full TimeStamp: '. date('r'. $punch_full_time_stamp) .' ('.$punch_full_time_stamp.') TimeZone: '. $this->getUserObject()->getUserPreferenceObject()->getTimeZone(), __FILE__, __LINE__, __METHOD__,10);
 
-		$pcf = new PunchControlFactory();
 		$pf = new PunchFactory();
-
 		$pf->StartTransaction();
 
-		if ( isset($data['status_id']) AND $data['status_id'] == 20 ) { //Out
-			if ( isset($data['punch_control_id']) ) {
-				$pcf->setId( $data['punch_control_id'] );
-			}
-		} else {
-			$data['status_id'] = 10; // In
-		}
+		//Set User before setTimeStamp so rounding can be done properly.
+		$pf->setUser( $this->getUserObject()->getId() );
 
 		if ( isset($data['transfer']) AND $data['transfer'] == 1 ) {
 			Debug::Text(' Enabling Transfer!: ', __FILE__, __LINE__, __METHOD__,10);
 			$data['type_id'] = 10;
 			$data['status_id'] = 10;
+			$pf->setTransfer( TRUE );
 		}
 
-		if ( !isset($data['user_date_id']) OR $data['user_date_id'] == '' ) {
-			$pcf->findUserDate( $this->getUserObject()->getId(), $punch_full_time_stamp, $data['status_id'] );
+		$pf->setType( $data['type_id'] );
+		$pf->setStatus( $data['status_id'] );
+		$pf->setTimeStamp( $punch_full_time_stamp );
+
+		if ( isset($data['status_id']) AND $data['status_id'] == 20 AND isset( $data['punch_control_id'] ) AND $data['punch_control_id']  != '' ) {
+			$pf->setPunchControlID( $data['punch_control_id'] );
 		} else {
-			$pcf->setUserDateID( $data['user_date_id'] );
+			$pf->setPunchControlID( $pf->findPunchControlID() );
 		}
 
-		//Debug::Text(' Branch ID: '. $data['branch_id'], __FILE__, __LINE__, __METHOD__,10);
-		if ( isset($data['branch_id']) AND $data['branch_id'] != '') {
-			$pcf->setBranch( $data['branch_id'] );
-		}
-		if ( isset($data['department_id']) AND $data['department_id'] != '' ) {
-			$pcf->setDepartment( $data['department_id'] );
+		$pf->setStation( $this->getStationObject()->getId() );
+
+		if ( $pf->isNew() ) {
+			$pf->setActualTimeStamp( $punch_full_time_stamp );
+			$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
 		}
 
-		if ( isset($data['job_id']) AND $data['job_id'] != '' ) {
-			$pcf->setJob( $data['job_id'] );
-		}
-		if ( isset($data['job_item_id']) AND $data['job_item_id'] != '') {
-			$pcf->setJobItem( $data['job_item_id'] );
-		}
-		if ( isset($data['quantity']) AND $data['quantity'] != '' ) {
-			$pcf->setQuantity( $data['quantity'] );
-		}
-		if ( isset($data['bad_quantity']) AND $data['bad_quantity'] != '' ) {
-			$pcf->setBadQuantity( $data['bad_quantity'] );
-		}
-
-		//Don't overwrite note if a new one isn't set. This makes it more difficult to delete a note if they want to,
-		//But thats better then accidently deleting it.
-		if ( isset($data['note']) AND $data['note'] != '' ) {
-			$pcf->setNote( $data['note'] );
-		}
-
-		if ( isset($data['other_id1']) AND $data['other_id1'] != '' ) {
-			$pcf->setOtherID1( $data['other_id1'] );
-		}
-		if ( isset($data['other_id2']) AND $data['other_id2'] != '' ) {
-			$pcf->setOtherID2( $data['other_id2'] );
-		}
-		if ( isset($data['other_id3']) AND $data['other_id3'] != '' ) {
-			$pcf->setOtherID3( $data['other_id3'] );
-		}
-		if ( isset($data['other_id4']) AND $data['other_id4'] != '' ) {
-			$pcf->setOtherID4( $data['other_id4'] );
-		}
-		if ( isset($data['other_id5']) AND $data['other_id5'] != '' ) {
-			$pcf->setOtherID5( $data['other_id5'] );
-		}
-
-		if ( $pcf->isValid() ) {
-			$punch_control_id = $pcf->Save();
-
-			//If its an update, not a new insert
-			if ( $punch_control_id === TRUE ) {
-				Debug::Text(' Updating Punch Control Object', __FILE__, __LINE__, __METHOD__,10);
-				$punch_control_id = $data['punch_control_id'];
-			}
-			Debug::Text(' Punch Control ID: '. $punch_control_id, __FILE__, __LINE__, __METHOD__,10);
-
-			if ( isset($data['transfer']) AND $data['transfer'] == 1 ) {
-				Debug::Text(' Enabling Transfer!: ', __FILE__, __LINE__, __METHOD__,10);
-				$pf->setTransfer( TRUE );
-			}
-
-			$pf->setPunchControlID( $punch_control_id );
-			$pf->setType( $data['type_id'] );
-			$pf->setStatus( $data['status_id'] );
-			$pf->setTimeStamp( $punch_full_time_stamp );
-
-			if ( $pf->isNew() ) {
-				$pf->setActualTimeStamp( $punch_full_time_stamp );
-				$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
-			}
-
-			$pf->setStation( $this->getStationObject()->getId() );
-
-			if ( $pf->isValid() ) {
-				$return_date = $pf->getTimeStamp();
-				if ( $pf->getStatus() == 10 ) {
-					$label = 'In';
-				} else {
-					$label = 'Out';
-				}
-
-				$pf->setEnableCalcTotalTime( TRUE );
-				$pf->setEnableCalcSystemTotalTime( TRUE );
-				$pf->setEnableCalcUserDateTotal( TRUE );
-				$pf->setEnableCalcException( TRUE );
-				$pf->setEnablePreMatureException( TRUE );
-
-				$pf->Save();
-
-				Debug::text('Return Date: '. $return_date, __FILE__, __LINE__, __METHOD__, 10);
-				$retval = '<div style="font-size:28px; font-weight: bold">
-				<table>
-				<tr>
-					<td>'.$this->getUserObject()->getFullName() .'</td>
-				</tr>
-				<tr>
-					<td>
-					Punch '.$label.': '. TTDate::getDate('TIME', $return_date) .'
-					</td>
-				</tr>
-				</table>
-				</div>';
-
-				//Mike Benoit - Start Lunch: <time>
-				//$retval = '<div style="font-size:28px" nowrap>'.$this->getUserObject()->getFullName() ."\n".$label.': <div style="color: '.$color.'" nowrap>'. TTDate::getDate('TIME', $return_date) .'</div></div>';
-
-				Debug::text('RetVal: '. $retval, __FILE__, __LINE__, __METHOD__, 10);
-
-				//Set stations last punch time stamp so we can filter out duplicates later on.
-				/*
-				$this->getStationObject()->setLastPunchTimeStamp( $punch_full_time_stamp );
-				if ( $this->getStationObject()->isValid() ) {
-					$this->getStationObject()->Save(FALSE);
-				}
-				*/
-
-				$pf->CommitTransaction();
-
-				return $retval;
-
+		if ( $pf->isValid() == TRUE ) {
+			$return_date = $pf->getTimeStamp();
+			if ( $pf->getStatus() == 10 ) {
+				$label = 'In';
 			} else {
-				Debug::text('Punch is NOT VALID: ', __FILE__, __LINE__, __METHOD__, 10);
+				$label = 'Out';
 			}
+
+			if ( $pf->Save( FALSE ) == TRUE ) {
+				$pcf = new PunchControlFactory();
+				$pcf->setId( $pf->getPunchControlID() );
+				$pcf->setPunchObject( $pf );
+
+				if ( isset($data['branch_id']) AND $data['branch_id'] != '') {
+					$pcf->setBranch( $data['branch_id'] );
+				}
+				if ( isset($data['department_id']) AND $data['department_id'] != '' ) {
+					$pcf->setDepartment( $data['department_id'] );
+				}
+
+				if ( isset($data['job_id']) AND $data['job_id'] != '' ) {
+					$pcf->setJob( $data['job_id'] );
+				}
+				if ( isset($data['job_item_id']) AND $data['job_item_id'] != '') {
+					$pcf->setJobItem( $data['job_item_id'] );
+				}
+				if ( isset($data['quantity']) AND $data['quantity'] != '' ) {
+					$pcf->setQuantity( $data['quantity'] );
+				}
+				if ( isset($data['bad_quantity']) AND $data['bad_quantity'] != '' ) {
+					$pcf->setBadQuantity( $data['bad_quantity'] );
+				}
+
+				//Don't overwrite note if a new one isn't set. This makes it more difficult to delete a note if they want to,
+				//But thats better then accidently deleting it.
+				if ( isset($data['note']) AND $data['note'] != '' ) {
+					$pcf->setNote( $data['note'] );
+				}
+
+				if ( isset($data['other_id1']) AND $data['other_id1'] != '' ) {
+					$pcf->setOtherID1( $data['other_id1'] );
+				}
+				if ( isset($data['other_id2']) AND $data['other_id2'] != '' ) {
+					$pcf->setOtherID2( $data['other_id2'] );
+				}
+				if ( isset($data['other_id3']) AND $data['other_id3'] != '' ) {
+					$pcf->setOtherID3( $data['other_id3'] );
+				}
+				if ( isset($data['other_id4']) AND $data['other_id4'] != '' ) {
+					$pcf->setOtherID4( $data['other_id4'] );
+				}
+				if ( isset($data['other_id5']) AND $data['other_id5'] != '' ) {
+					$pcf->setOtherID5( $data['other_id5'] );
+				}
+
+				//$pcf->setEnableStrictJobValidation( TRUE );
+				$pcf->setEnableCalcUserDateID( TRUE );
+				$pcf->setEnableCalcTotalTime( TRUE );
+				$pcf->setEnableCalcSystemTotalTime( TRUE );
+				$pcf->setEnableCalcUserDateTotal( TRUE );
+				$pcf->setEnableCalcException( TRUE );
+				$pcf->setEnablePreMatureException( TRUE ); //Enable pre-mature exceptions at this point.
+
+				if ( $pcf->isValid() == TRUE ) {
+					Debug::Text(' Punch Control is valid, saving...: ', __FILE__, __LINE__, __METHOD__,10);
+
+					if ( $pcf->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
+
+						Debug::text('Return Date: '. $return_date, __FILE__, __LINE__, __METHOD__, 10);
+						$retval = '<div style="font-size:28px; font-weight: bold">
+						<table>
+						<tr>
+							<td>'.$this->getUserObject()->getFullName() .'</td>
+						</tr>
+						<tr>
+							<td>
+							Punch '.$label.': '. TTDate::getDate('TIME', $return_date) .'
+							</td>
+						</tr>
+						</table>
+						</div>';
+
+						Debug::text('RetVal: '. $retval, __FILE__, __LINE__, __METHOD__, 10);
+
+						//Set stations last punch time stamp so we can filter out duplicates later on.
+						//$pf->FailTransaction();
+						$pf->CommitTransaction();
+
+						return $retval;
+					} else {
+						Debug::text('Punch Control save failed!', __FILE__, __LINE__, __METHOD__, 10);
+					}
+				} else {
+					Debug::text('Punch Control is NOT VALID!', __FILE__, __LINE__, __METHOD__, 10);
+				}
+			} else {
+				Debug::text('Punch save failed!', __FILE__, __LINE__, __METHOD__, 10);
+			}
+		} else {
+			Debug::text('Punch is NOT VALID: ', __FILE__, __LINE__, __METHOD__, 10);
 		}
 
 		$pf->FailTransaction();
 
 		Debug::text('Returning FALSE: Action Failed! ', __FILE__, __LINE__, __METHOD__, 10);
-		return FALSE;
 
+		//Get text errors to display to the user.
+		$errors = NULL;
+		if ( isset($pf) AND is_object($pf) ) {
+			$errors .= $pf->Validator->getErrors();
+		}
+		if ( isset($pcf) AND is_object($pcf) ) {
+			$errors .= $pcf->Validator->getErrors();
+		}
+		$errors = wordwrap( $errors, 40, "<br>\n");
 
-		//return "FAILED...John Doe Signed in at 8:00AM";
-//		return "John Doe Signed in at 8:00AM";
+		$retval = '<table bgcolor="red">
+		<tr>
+			<td style="font-size:28px; font-weight: bold">Action Failed!</td>
+		</tr>
+		<tr>
+			<td style="font-size:14px; font-weight: bold">
+				'. $errors .'
+			</td>
+		</tr>
+		</table>';
+
+		return $retval;
+		//return FALSE;
 	}
 
-
 	function Logout() {
 		return $this->authentication->Logout();
 	}
@@ -840,5 +900,11 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 	function addLogEntry( $object_id, $action_id, $description, $user_id, $table ) {
 		TTLog::addEntry( $object_id, $action_id, $description, $user_id, $table );
 	}
+
+	function __call( $name, $arguments ) {
+		Debug::text('ERROR: Attempting to call function that does not exist in this class! Class: '. __CLASS__ .' Function: '. $name, __FILE__, __LINE__, __METHOD__, 10);
+
+		return FALSE;
+	}
 }
 ?>
