@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: TimeTrexSoapServerUnAuthenticated.class.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: TimeTrexSoapServerUnAuthenticated.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -45,7 +45,38 @@
 class TimeTrexSoapServerUnAuthenticated {
 
 	function helloworld($text) {
-		return "Hello World: $text - ". $_COOKIE['SessionID'] ."";
+		return "Hello World: $text";
+	}
+
+	function testArray( $input_arr = NULL ) {
+		if ( is_array($input_arr) ) {
+			return $input_arr;
+		} else {
+			$retarr[] = array(
+							'this' => 'first',
+							10 => 'complex array',
+							'with' => TRUE,
+							20 => 'Complex types',
+							30 => array('and' => 'sub-arrays'),
+							);
+
+			$retarr[] = array(
+							'this' => 'second',
+							10 => 'complex array',
+							'with' => TRUE,
+							20 => 'Complex types',
+							30 => array('and' => 'sub-arrays'),
+							);
+			$retarr[] = array(
+							'this' => 'third',
+							10 => 'complex array',
+							'with' => TRUE,
+							20 => 'Complex types',
+							30 => array('and' => 'sub-arrays'),
+							);
+
+			return $retarr;
+		}
 	}
 
 	function getClientVersion() {
@@ -111,7 +142,7 @@ class TimeTrexSoapServerUnAuthenticated {
 
 	//Check for updates each day... And on startup, and allow a menu option to force a check.
 	function getLatestVersion() {
-		return '2.5.4';
+		return '2.7.0';
 	}
 
 	function isLatestVersion($current_version) {
@@ -1079,8 +1110,8 @@ class TimeTrexSoapServerUnAuthenticated {
 						$prev_punch_obj->setUser( $current_user->getId() );
 						$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $punch_full_time_stamp ) );
 						if ( $prev_punch_obj->inBreakPolicyWindow( $punch_full_time_stamp, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
-							Debug::Text(' Setting Type to Break: ', __FILE__, __LINE__, __METHOD__,10);
-							$next_type = 30;
+							Debug::Text(' Setting Type to Break...', __FILE__, __LINE__, __METHOD__,10);
+							$type_id = 30;
 						}
 					}
 
@@ -1089,12 +1120,12 @@ class TimeTrexSoapServerUnAuthenticated {
 						$prev_punch_obj->setUser( $current_user->getId() );
 						$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $punch_full_time_stamp ) );
 						if ( $prev_punch_obj->inMealPolicyWindow( $punch_full_time_stamp, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
-							Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-							$next_type = 20;
+							Debug::Text(' Setting Type to Lunch...', __FILE__, __LINE__, __METHOD__,10);
+							$type_id = 20;
 						}
 					}
 				} else {
-					Debug::Text(' DID NOT Find Previous Punch within Continuous Time from now: ', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' DID NOT Find Previous Punch within Continuous Time from now...', __FILE__, __LINE__, __METHOD__,10);
 					$branch_id = NULL;
 					$department_id = NULL;
 					$job_id = NULL;
@@ -1191,6 +1222,8 @@ class TimeTrexSoapServerUnAuthenticated {
 				$pf->setTransfer( TRUE );
 			}
 
+			Debug::Text(' Final Type ID: '. $type_id .' Status ID: '. $status_id, __FILE__, __LINE__, __METHOD__,10);
+
 			$pf->setType( $type_id );
 			$pf->setStatus( $status_id );
 			$pf->setTimeStamp( $punch_full_time_stamp, TRUE ); //Make sure we round here.
@@ -1289,6 +1322,7 @@ class TimeTrexSoapServerUnAuthenticated {
 				$pf->CommitTransaction();
 			} else {
 				$pf->FailTransaction();
+				$pf->CommitTransaction(); //When a transaction fails in a loop, we need to commit the failed transaction, otherwise all other iterations will fail as well.
 			}
 
 			unset($punch_full_time_stamp, $current_station, $current_user);
