@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: UserFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: UserFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -267,7 +267,7 @@ class UserFactory extends Factory {
 			$clf = new CurrencyListFactory();
 
 			$clf->getById( $this->getCurrency() );
-			if ( $clf->getRecordCount() > 0 ) {
+			if ( $clf->getRecordCount() == 1 ) {
 				$this->currency_obj = $clf->getCurrent();
 				return $this->currency_obj;
 			}
@@ -547,9 +547,37 @@ class UserFactory extends Factory {
 	function checkPassword($password) {
 		global $config_vars;
 
-		$password = $this->encryptPassword( trim(strtolower($password)) );
+		//Check if LDAP is enabled
+		$ldap_authentication_type_id = 0;
+		if ( DEMO_MODE != TRUE AND function_exists('ldap_connect') AND !isset($config_vars['other']['enable_ldap']) OR ( isset($config_vars['other']['enable_ldap']) AND $config_vars['other']['enable_ldap'] == TRUE ) ) {
+			//Check company object to make sure LDAP is enabled.
+			$c_obj = $this->getCompanyObject();
+			if ( is_object($this->getCompanyObject()) ) {
+				$ldap_authentication_type_id = $this->getCompanyObject()->getLDAPAuthenticationType();
+				if ( $ldap_authentication_type_id > 0 ) {
+					$ldap = new TTLDAP();
+					$ldap->setHost( $this->getCompanyObject()->getLDAPHost() );
+					$ldap->setPort( $this->getCompanyObject()->getLDAPPort() );
+					$ldap->setBindUserName( $this->getCompanyObject()->getLDAPBindUserName() );
+					$ldap->setBindPassword( $this->getCompanyObject()->getLDAPBindPassword() );
+					$ldap->setBaseDN( $this->getCompanyObject()->getLDAPBaseDN() );
+					$ldap->setBindAttribute( $this->getCompanyObject()->getLDAPBindAttribute() );
+					$ldap->setUserFilter( $this->getCompanyObject()->getLDAPUserFilter() );
+					$ldap->setLoginAttribute( $this->getCompanyObject()->getLDAPLoginAttribute() );
+					if (  $ldap->authenticate( $this->getUserName(), $password ) === TRUE ) {
+						return TRUE;
+					} elseif ( $ldap_authentication_type_id == 1 ) {
+						Debug::Text('LDAP authentication failed, falling back to local password...', __FILE__, __LINE__, __METHOD__,10);
+						TTLog::addEntry( $this->getId(), 510, TTi18n::getText('LDAP Authentication failed, falling back to local password for username').': '. $this->getUserName() . TTi18n::getText('IP Address') .': '.$_SERVER['REMOTE_ADDR'], $this->getId(), $this->getTable() );
+					}
+					unset($ldap);
+				}
+			}
+		}
 
-		if ( $password == $this->getPassword() ) {
+		$password = $this->encryptPassword( trim(strtolower($password)) );
+		//Don't check local TT passwords if LDAP Only authentication is enabled. Still accept override passwords though.
+		if ( $ldap_authentication_type_id != 2 AND $password == $this->getPassword() ) {
 			return TRUE;
 		} elseif ( isset($config_vars['other']['override_password_prefix'])
 						AND $config_vars['other']['override_password_prefix'] != '' ) {
@@ -560,7 +588,6 @@ class UserFactory extends Factory {
 			}
 		}
 
-
 		return FALSE;
 	}
 	function getPassword() {
@@ -1902,7 +1929,7 @@ class UserFactory extends Factory {
 	}
 	function setSIN($sin) {
 		//If *'s are in the SIN number, skip setting it
-		//This allows them to change other data without seeing the CC number.
+		//This allows them to change other data without seeing the SIN number.
 		if ( stripos( $sin, 'X') !== FALSE  ) {
 			return FALSE;
 		}
@@ -2641,6 +2668,9 @@ class UserFactory extends Factory {
 							$data[$variable] = $this->getColumn( $variable );
 						case 'password': //Don't return password
 							break;
+						case 'sin':
+							$data[$variable] = $this->getSecureSIN();
+							break;
 						case 'hire_date':
 						case 'birth_date':
 						case 'termination_date':
