@@ -276,7 +276,7 @@ class UserIdentificationFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Identification - Employee: '. $this->getUser() .' Type: '. $this->getType() ), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Identification - Employee'). ': '. UserListFactory::getFullNameById( $this->getUser() ) .' '. TTi18n::getText('Type') . ': '. $this->getType(), NULL, $this->getTable() );
 	}
 }
 ?>
