@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2862 $
- * $Id: UserPreferenceFactory.class.php 2862 2009-09-30 19:35:20Z ipso $
- * $Date: 2009-09-30 12:35:20 -0700 (Wed, 30 Sep 2009) $
+ * $Revision: 3562 $
+ * $Id: UserPreferenceFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -800,15 +800,23 @@ class UserPreferenceFactory extends Factory {
 			case 'columns':
 				$retval = array(
 										'-1000-first_name' => TTi18n::gettext('First Name'),
-										'-1010-last_name' => TTi18n::gettext('Last Name'),
-										'-1020-language_display' => TTi18n::gettext('Language'),
-										'-1030-date_format' => TTi18n::gettext('Date Format'),
-										'-1040-time_format' => TTi18n::gettext('Time Format'),
-										'-1050-time_zone' => TTi18n::gettext('TimeZone'),
-										'-1060-time_unit_format' => TTi18n::gettext('Time Unit Format'),
-										'-1070-items_per_page' => TTi18n::gettext('Items Per Page'),
-										'-1080-timesheet_view' => TTi18n::gettext('TimeSheet View'),
-										'-1090-start_week_day' => TTi18n::gettext('Start Weekday'),
+										'-1002-last_name' => TTi18n::gettext('Last Name'),
+										'-1005-user_status' => TTi18n::gettext('Employee Status'),
+										'-1010-title' => TTi18n::gettext('Title'),
+										'-1020-group' => TTi18n::gettext('Group'),
+										'-1030-default_branch' => TTi18n::gettext('Default Branch'),
+										'-1040-default_department' => TTi18n::gettext('Default Department'),
+										'-1050-branch' => TTi18n::gettext('Branch'),
+										'-1060-department' => TTi18n::gettext('Department'),
+
+										'-1120-language_display' => TTi18n::gettext('Language'),
+										'-1130-date_format' => TTi18n::gettext('Date Format'),
+										'-1140-time_format' => TTi18n::gettext('Time Format'),
+										'-1150-time_zone' => TTi18n::gettext('TimeZone'),
+										'-1160-time_unit_format' => TTi18n::gettext('Time Unit Format'),
+										'-1170-items_per_page' => TTi18n::gettext('Items Per Page'),
+										'-1180-timesheet_view' => TTi18n::gettext('TimeSheet View'),
+										'-1190-start_week_day' => TTi18n::gettext('Start Weekday'),
 										//'-1100-enable_email_notification_exception' => TTi18n::gettext('Email Notification Exception'),
 										//'-1110-enable_email_notification_message' => TTi18n::gettext('Email Notification Message'),
 										//'-1120-enable_email_notification_home' => TTi18n::gettext('Email Notification Home'),
@@ -827,10 +835,6 @@ class UserPreferenceFactory extends Factory {
 								'time_format',
 								'time_unit_format',
 								'time_zone',
-								'created_by',
-								'created_date',
-								'updated_by',
-								'updated_date',
 								);
 				break;
 		}
@@ -842,13 +846,27 @@ class UserPreferenceFactory extends Factory {
 		$variable_function_map = array(
 										'id' => 'ID',
 										'user_id' => 'User',
+
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'user_status_id' => FALSE,
+										'user_status' => FALSE,
+										'group_id' => FALSE,
+										'group' => FALSE,
+										'title_id' => FALSE,
+										'title' => FALSE,
+										'default_branch_id' => FALSE,
+										'default_branch' => FALSE,
+										'default_department_id' => FALSE,
+										'default_department' => FALSE,
+
 										'language' => 'Language',
 										'date_format' => 'DateFormat',
 										'time_format' => 'TimeFormat',
 										'time_zone' => 'TimeZone',
 										'time_unit_format' => 'TimeUnitFormat',
 										'items_per_page' => 'ItemsPerPage',
-										'timesheet_view' => 'TimeSheetView',
+										//'timesheet_view' => 'TimeSheetView',
 										'start_week_day' => 'StartWeekDay',
 										'enable_email_notification_exception' => 'EnableEmailNotificationException',
 										'enable_email_notification_message' => 'EnableEmailNotificationMessage',
@@ -1292,6 +1310,8 @@ class UserPreferenceFactory extends Factory {
 
 
 	function getObjectAsArray( $include_columns = NULL ) {
+		$uf = new UserFactory();
+
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -1299,6 +1319,22 @@ class UserPreferenceFactory extends Factory {
 
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+						case 'user_status_id':
+						case 'group_id':
+						case 'group':
+						case 'title_id':
+						case 'title':
+						case 'default_branch_id':
+						case 'default_branch':
+						case 'default_department_id':
+						case 'default_department':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'user_status':
+							$data[$variable] = Option::getByKey( (int)$this->getColumn( 'user_status_id' ), $uf->getOptions( 'status' ) );
+							break;
 						case 'language':
 						case 'date_format':
 						case 'time_format':
