@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: UserWageListFactory.class.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 3562 $
+ * $Id: UserWageListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 
 /**
@@ -146,6 +146,35 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByIdAndUserId($id, $user_id, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		$this->rs = $this->getCache($id.$user_id);
+		if ( $this->rs === FALSE ) {
+			$ph = array(
+						'id' => $id,
+						'user_id' => $user_id,
+						);
+
+			$query = '
+						select 	*
+						from	'. $this->getTable() .'
+						where	id = ?
+							AND user_id = ?
+							AND deleted = 0';
+			$query .= $this->getWhereSQL( $where );
+			$query .= $this->getSortSQL( $order );
+
+			$this->rs = $this->db->Execute($query, $ph);
+
+			$this->saveCache($this->rs,$id.$user_id);
+		}
+
+		return $this;
+	}
+
 	function getByUserId($user_id, $order = NULL) {
 		if ( $user_id == '') {
 			return FALSE;
@@ -461,6 +490,8 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 		$ph['company_id2'] = $company_id;
 		$ph['start_date2'] = $this->db->BindTimeStamp( $start_date );
 
+		//This query is broken, as the after the UNION it has LIMIT 1, which only shows wages for the first employee, not the last wage for EACH employee.
+/*
 		$query = '
 					(
 					select b.*
@@ -490,8 +521,8 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 					)
 					ORDER BY effective_date desc
 					';
+*/
 
-/*
 		$query = '
 					(
 					select b.*
@@ -524,7 +555,7 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 					)
 					ORDER BY effective_date desc
 					';
-*/
+
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -672,6 +703,9 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 					where	b.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
