@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: PayrollDeduction.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3349 $
+ * $Id: PayrollDeduction.class.php 3349 2010-02-10 17:38:41Z ipso $
+ * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
  */
 
 /**
@@ -66,7 +66,6 @@ class PayrollDeduction {
 		}
 
 		//Debug::text('Country: '. $country_file_name .' Province: '. $province_file_name .' District: '. $district_file_name .' Class: '. $class_name, __FILE__, __LINE__, __METHOD__, 10);
-
 		if ( ( file_exists($country_file_name) OR ( $this->getProvince() != '' AND file_exists($province_file_name) ) OR ( $this->getDistrict() != '' AND file_exists($district_file_name) ) ) AND file_exists($data_file_name) ) {
 			//Debug::text('Country File Exists: '. $country_file_name .' Province File Name: '. $province_file_name .' Data File: '. $data_file_name, __FILE__, __LINE__, __METHOD__, 10);
 
@@ -83,12 +82,16 @@ class PayrollDeduction {
 				include_once( $district_file_name );
 			}
 
-			$this->obj = new $class_name;
-			$this->obj->setCountry( $this->getCountry() );
-			$this->obj->setProvince( $this->getProvince() );
-			$this->obj->setDistrict( $this->getDistrict() );
+			if ( class_exists( $class_name ) ) {
+				$this->obj = new $class_name;
+				$this->obj->setCountry( $this->getCountry() );
+				$this->obj->setProvince( $this->getProvince() );
+				$this->obj->setDistrict( $this->getDistrict() );
 
-			return TRUE;
+				return TRUE;
+			} else {
+				return FALSE;
+			}
 		} else {
 			Debug::text('File DOES NOT Exists Country File Name: '. $country_file_name .' Province File: '. $province_file_name, __FILE__, __LINE__, __METHOD__, 10);
 		}
