@@ -34,18 +34,29 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2299 $
- * $Id: DC.class.php 2299 2008-12-21 21:26:53Z ipso $
- * $Date: 2008-12-21 13:26:53 -0800 (Sun, 21 Dec 2008) $
+ * $Revision: 3298 $
+ * $Id: DC.class.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 
 /**
  * @package PayrollDeduction
  */
+
+/*
+														10 => TTi18n::gettext('Single'),
+														20 => TTi18n::gettext('Married (Filing Jointly)'),
+														30 => TTi18n::gettext('Married (Filing Separately)'),
+														40 => TTi18n::gettext('Head of Household'),
+
+*/
 class PayrollDeduction_US_DC extends PayrollDeduction_US {
 
 	var $state_options = array(
-								1230796800 => array(
+								1262332800 => array( //01-Jan-2010
+													'allowance' => 1675
+													),
+								1230796800 => array( //01-Jan-09
 													'allowance' => 1750
 													),
 								1136102400 => array(
