@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: OR.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3665 $
+ * $Id: OR.class.php 3665 2010-06-18 18:01:03Z ipso $
+ * $Date: 2010-06-18 11:01:03 -0700 (Fri, 18 Jun 2010) $
  */
 
 /**
@@ -45,6 +45,14 @@
 class PayrollDeduction_US_OR extends PayrollDeduction_US {
 	var $original_filing_status = NULL;
 	var $state_options = array(
+								1262332800 => array( //01-Jan-10
+												'standard_deduction' => array(
+																			'10' => 1950,
+																			'20' => 3900,
+																			),
+												'allowance' => 177,
+												'federal_tax_maximum' => 5850
+												),
 								1230796800 => array( //01-Jan-09
 												'standard_deduction' => array(
 																			'10' => 1945,
