@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2299 $
- * $Id: UT.class.php 2299 2008-12-21 21:26:53Z ipso $
- * $Date: 2008-12-21 13:26:53 -0800 (Sun, 21 Dec 2008) $
+ * $Revision: 3298 $
+ * $Id: UT.class.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 
 /**
@@ -45,30 +45,27 @@
 class PayrollDeduction_US_UT extends PayrollDeduction_US {
 
 	var $state_options = array(
-								1199174400 => array(
-													'allowance' => 125 //Completely new formula after this date.
+								1199174400 => array( //Completely new formula after this date.
+													'rate' => 5.0, //Percent
+													'allowance' => 125,
+													'base_allowance' => array(
+																					10 => 250,
+																					20 => 375
+																					),
+													'allowance_reduction' => array(
+																					10 => 12000,
+																					20 => 18000
+																					),
+													'allowance_reduction_rate' => 1.3, //Percent
 													),
-								1167638400 => array(
-													'allowance' => 2040
-													),
-								1136102400 => array(
-													'allowance' => 1800
-													)
 								);
 
 	function getStatePayPeriodDeductions() {
-		return bcdiv($this->getStateTaxPayable(), $this->getAnnualPayPeriods() );
+		return bcdiv( $this->getStateTaxPayable(), $this->getAnnualPayPeriods() );
 	}
 
 	function getStateAnnualTaxableIncome() {
-		if ( $this->getDate() >= strtotime('01-Jan-2008') ) {
-			$income = $this->getAnnualTaxableIncome();
-		} else {
-			$annual_income = $this->getAnnualTaxableIncome();
-			$state_allowance = $this->getStateAllowanceAmount();
-
-			$income = bcsub( $annual_income, $state_allowance );
-		}
+		$income = $this->getAnnualTaxableIncome();
 
 		Debug::text('State Annual Taxable Income: '. $income, __FILE__, __LINE__, __METHOD__,10);
 
@@ -81,46 +78,67 @@ class PayrollDeduction_US_UT extends PayrollDeduction_US {
 			return FALSE;
 		}
 
-		if ( $this->getDate() >= strtotime('01-Jan-2008') ) {
-			$rate_arr = $this->getRateArray( $this->getAnnualTaxableIncome(), 'state' );
-			if ( is_array($rate_arr) AND isset($rate_arr['first']) AND isset($rate_arr['last']) ) {
-				if ( $rate_arr['first'] == TRUE OR $rate_arr['last'] == TRUE ) {
-					Debug::text('State First or Last bracket, ignoring allowance!', __FILE__, __LINE__, __METHOD__,10);
-					$retval = 0;
-				} else {
-					Debug::text('State NOT First or Last bracket, using allowance!', __FILE__, __LINE__, __METHOD__,10);
-					$allowance_arr = $retarr['allowance'];
-					$retval = bcmul( $this->getStateAllowance(), $allowance_arr );
-				}
-			}
-		} else {
-			$allowance_arr = $retarr['allowance'];
-			$retval = bcmul( $this->getStateAllowance(), $allowance_arr );
-		}
+		$allowance_amount = $retarr['allowance'];
+		$retval = bcadd( bcmul( $this->getStateAllowance(), $allowance_amount ), $this->getStateBaseAllowanceAmount() );
 
 		Debug::text('State Allowance Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
 
 		return $retval;
 	}
 
+	function getStateBaseAllowanceAmount() {
+		$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
+		if ( $retarr == FALSE ) {
+			return FALSE;
+		}
+
+		$retval = $retarr['base_allowance'][$this->getStateFilingStatus()];
+
+		Debug::text('State Base Allowance Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+
+		return $retval;
+	}
+
+	function getStateAllowanceReductionAmount() {
+		$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
+		if ( $retarr == FALSE ) {
+			return FALSE;
+		}
+
+		$allowance_reduction_amount = $retarr['allowance_reduction'][$this->getStateFilingStatus()];
+
+		$adjusted_taxable_income = bcsub( $this->getStateAnnualTaxableIncome(), $allowance_reduction_amount );
+		if ( $adjusted_taxable_income > 0 )  {
+			$allowance_reduction_rate = $retarr['allowance_reduction_rate'];
+			$retval = bcmul( $adjusted_taxable_income, bcdiv( $allowance_reduction_rate, 100 ) );
+		} else {
+			$retval = 0;
+		}
+
+		Debug::text('State Allowance Reduction Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+
+		return $retval;
+	}
+
+
 	function getStateTaxPayable() {
 		$annual_income = $this->getStateAnnualTaxableIncome();
 
 		$retval = 0;
-		
+
 		if ( $annual_income > 0 ) {
-			if ( $this->getDate() >= strtotime('01-Jan-2008') ) {
-				$rate = $this->getData()->getStateRate($annual_income);
-				$state_allowance = $this->getStateAllowanceAmount();
-
-				$retval = bcsub( bcmul( $annual_income, $rate ), $state_allowance );
-			} else {
-				$rate = $this->getData()->getStateRate($annual_income);
-				$state_constant = $this->getData()->getStateConstant($annual_income);
-				$state_rate_income = $this->getData()->getStateRatePreviousIncome($annual_income);
-
-				$retval = bcadd( bcmul( bcsub( $annual_income, $state_rate_income ), $rate ), $state_constant );
+			$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
+			if ( $retarr == FALSE ) {
+				return FALSE;
 			}
+
+			$gross_tax = bcmul( $annual_income, bcdiv( $retarr['rate'], 100 ) );
+			$allowance_amount = bcsub( $this->getStateAllowanceAmount(), $this->getStateAllowanceReductionAmount() );
+			if ( $allowance_amount < 0 ) {
+				$allowance_amount = 0;
+			}
+
+			$retval = bcsub( $gross_tax, $allowance_amount );
 		}
 
 		if ( $retval < 0 ) {
