@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3219 $
- * $Id: global.inc.php 3219 2009-12-24 18:01:51Z ipso $
- * $Date: 2009-12-24 10:01:51 -0800 (Thu, 24 Dec 2009) $
+ * $Revision: 3665 $
+ * $Id: global.inc.php 3665 2010-06-18 18:01:03Z ipso $
+ * $Date: 2010-06-18 11:01:03 -0700 (Fri, 18 Jun 2010) $
  */
 $global_script_start_time = microtime(true);
 
@@ -56,7 +56,7 @@ ini_set( 'max_execution_time', 1800 );
 //Check: http://ca3.php.net/manual/en/security.magicquotes.php#61188 for disabling magic_quotes_gpc
 ini_set( 'magic_quotes_runtime', 0 );
 
-define('APPLICATION_VERSION', '3.0.4' );
+define('APPLICATION_VERSION', '3.1.2' );
 
 /*
 	Config file inside webroot.
@@ -89,7 +89,7 @@ if ( isset($config_vars['debug']['production']) AND $config_vars['debug']['produ
 
 //
 //
-// **REMOVING OR CHANGING THIS APPLICATION NAME IS IN STRICT VIOLATION OF THE LICENSE AGREEMENT**
+// **REMOVING OR CHANGING THIS APPLICATION NAME AND ORGANIZATION URL IS IN STRICT VIOLATION OF THE LICENSE AGREEMENT**
 //
 //
 if ( PRODUCTION == TRUE ) {
@@ -97,6 +97,8 @@ if ( PRODUCTION == TRUE ) {
 } else {
 	define('APPLICATION_NAME', 'TimeTrex-Debug');
 }
+define('ORGANIZATION_NAME', 'TimeTrex');
+define('ORGANIZATION_URL', 'www.TimeTrex.com');
 
 if ( isset($config_vars['other']['demo_mode']) AND $config_vars['other']['demo_mode'] == 1 ) {
 	define('DEMO_MODE', TRUE);
@@ -118,7 +120,8 @@ if ( isset($config_vars['other']['primary_company_id']) AND $config_vars['other'
 
 //Try to dynamically load required PHP extensions if they aren't already.
 //This saves people from having to modify php.ini if possible.
-if( (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
+//v5.3 of PHP deprecates DL().
+if ( version_compare(PHP_VERSION, '5.3.0', '<') AND (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FALSE ) {
 	$prefix = (PHP_SHLIB_SUFFIX === 'dll') ? 'php_' : '';
 
 	//This quite possibly breaks PEAR's Cache_Lite <= v1.7.2 because
@@ -152,6 +155,9 @@ if( (bool)ini_get( 'enable_dl' ) == TRUE AND (bool)ini_get( 'safe_mode' ) == FAL
 	if ( extension_loaded('gd') == FALSE AND extension_loaded('gd2') == FALSE ) {
 		@dl($prefix . 'gd2.' . PHP_SHLIB_SUFFIX);
 	}
+	if ( extension_loaded('ldap') == FALSE ) {
+		@dl($prefix . 'ldap.' . PHP_SHLIB_SUFFIX);
+	}
 
 	//Load database extension based on config file.
 	if ( isset($config_vars['database']['type']) ) {
@@ -185,19 +191,28 @@ if ( !isset($_SERVER['REQUEST_URI']) ) {
 	}
 }
 
-/*
-function __shutdown() {
-	//Include content length header so we can show a downloading progress bar.
-	header('Content-Length: '. ob_get_length() );
-}
-register_shutdown_function('__shutdown');
-*/
+require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'ClassMap.inc.php');
 function __autoload( $name ) {
-	$file_name = $name .'.class.php';
+	global $global_class_map, $profiler;
+
+	if ( isset($profiler) ) {
+		$profiler->startTimer( '__autoload' );
+	}
+
+	if ( isset($global_class_map[$name]) ) {
+		$file_name = Environment::getBasePath() . DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR . $global_class_map[$name];
+	} else {
+		$file_name = $name .'.class.php';
+	}
 
 	//Use include_once() instead of require_once so the installer
 	//doesn't Fatal Error without displaying anything.
-	@include_once( $file_name );
+	//include_once() is redundant in __autoload.
+	@include( $file_name );
+
+	if ( isset($profiler) ) {
+		$profiler->stopTimer( '__autoload' );
+	}
 
 	return TRUE;
 }
@@ -275,46 +290,15 @@ function getTTProductEditionName( ) {
 //This has to be first, always.
 require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'core'. DIRECTORY_SEPARATOR .'Environment.class.php');
 
+require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'core'. DIRECTORY_SEPARATOR .'Profiler.class.php');
+$profiler = new Profiler( true );
+
 //clearstatcache();
 set_include_path(
 					Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'core' .
 					PATH_SEPARATOR . Environment::getBasePath() .'classes' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'pear' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'api' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'company' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'users' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'punch' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'schedule' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'department' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'help' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'client' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'document' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'hierarchy' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'holiday' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'invoice' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'invoice_policy' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'job' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'job_item' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'message' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'other' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'payperiod'.
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'pay_stub' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'pay_stub_amendment' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'policy' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'product' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'request' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'accrual' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'soap' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'install' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'cron' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'time_clock' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'tax_forms' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'tax_forms' . DIRECTORY_SEPARATOR . 'ca' .
-					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'tax_forms' . DIRECTORY_SEPARATOR . 'us' .
-
-					PATH_SEPARATOR . get_include_path() );
-
-//define('FPDF_FONTPATH', Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'fpdf'. DIRECTORY_SEPARATOR .'font'. DIRECTORY_SEPARATOR);
+					PATH_SEPARATOR . get_include_path() .
+					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'pear' ); //Put PEAR path at the end so system installed PEAR is used first, this prevents require_once() from including PEAR from two directories, which causes a fatal error.
 
 require_once(Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'core'. DIRECTORY_SEPARATOR .'Exception.class.php');
 require_once(Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'core'. DIRECTORY_SEPARATOR .'Debug.class.php');
@@ -324,8 +308,6 @@ if ( isset($_SERVER['REQUEST_URI']) ) {
 }
 Debug::Text('Version: '. APPLICATION_VERSION .' Edition: '. getTTProductEdition() .' Production: '. (int)PRODUCTION .' Demo Mode: '. (int)DEMO_MODE, __FILE__, __LINE__, __METHOD__, 10);
 
-$profiler = new Profiler( true );
-
 if ( function_exists('bcscale') ) {
 	bcscale(10);
 }
