@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3091 $
- * $Id: AuthorizationList.php 3091 2009-11-18 18:00:31Z ipso $
- * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
+ * $Revision: 3415 $
+ * $Id: AuthorizationList.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -89,30 +89,24 @@ switch ($action) {
 
 		if ( $permission->Check('request','authorize') ) {
 			//Debug::Text('Request: Selected Level: '. $selected_levels['request'], __FILE__, __LINE__, __METHOD__,10);
-			$request_levels = $hllf->getLevelsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
-			Debug::Arr( $request_levels, 'Request Levels', __FILE__, __LINE__, __METHOD__,10);
+			$request_levels = $hllf->getLevelsAndHierarchyControlIDsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
+			//Debug::Arr( $request_levels, 'Request Levels', __FILE__, __LINE__, __METHOD__,10);
 
 			if ( isset($selected_levels['request']) AND isset($request_levels[$selected_levels['request']]) ) {
 				$request_selected_level = $request_levels[$selected_levels['request']];
-				Debug::Text(' Switching Levels to Level: '. $request_selected_level, __FILE__, __LINE__, __METHOD__,10);
+				Debug::Text(' Switching Levels to Level: '. key($request_selected_level), __FILE__, __LINE__, __METHOD__,10);
 			} elseif ( isset($request_levels[1]) ) {
 				$request_selected_level = $request_levels[1];
 			} else {
 				Debug::Text( 'No Request Levels... Not in hierarchy?', __FILE__, __LINE__, __METHOD__,10);
 				$request_selected_level = 0;
 			}
-			Debug::Text( 'Request Selected Level: '. $request_selected_level, __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Arr( $request_selected_level, 'Request Selected Level Arr: ', __FILE__, __LINE__, __METHOD__,10);
 
-			//Get all relevant hierarchy ids
-			$request_hierarchy_user_ids = $hlf->getByUserIdAndObjectTypeIDAndLevel( $current_user->getId(), 50, (int)$request_selected_level );
-
-			if ( is_array($request_hierarchy_user_ids)
-					AND isset($request_hierarchy_user_ids['child_level'])
-					AND isset($request_hierarchy_user_ids['parent_level'])
-					AND isset($request_hierarchy_user_ids['current_level']) ) {
+			if ( is_array($request_selected_level) ) {
 				Debug::Text( 'Hierarchy information found...', __FILE__, __LINE__, __METHOD__,10);
 				$rlf = new RequestListFactory();
-				$rlf->getByUserIdListAndStatusAndLevelAndMaxLevelAndNotAuthorized( $request_hierarchy_user_ids['child_level'], 30, (int)$request_selected_level, (int)end($request_levels), NULL, NULL, NULL, $sort_array );
+				$rlf->getByHierarchyLevelMapAndStatusAndNotAuthorized($request_selected_level, 30, NULL, NULL, NULL, $sort_array );
 
 				$status_options = $rlf->getOptions('status');
 				$type_options = $rlf->getOptions('type');
@@ -145,31 +139,23 @@ switch ($action) {
 		if ( $permission->Check('punch','authorize') ) {
 			//Debug::Text('TimeSheet: Selected Level: '. $selected_levels['timesheet'], __FILE__, __LINE__, __METHOD__,10);
 
-			$timesheet_levels = $hllf->getLevelsByUserIdAndObjectTypeID( $current_user->getId(), 90 );
-			Debug::Arr( $timesheet_levels , 'TimeSheet Levels', __FILE__, __LINE__, __METHOD__,10);
+			$timesheet_levels = $hllf->getLevelsAndHierarchyControlIDsByUserIdAndObjectTypeID( $current_user->getId(), 90 );
+			//Debug::Arr( $timesheet_levels , 'TimeSheet Levels', __FILE__, __LINE__, __METHOD__,10);
 
 			if ( isset($selected_levels['timesheet']) AND isset($timesheet_levels[$selected_levels['timesheet']]) ) {
 				$timesheet_selected_level = $timesheet_levels[$selected_levels['timesheet']];
-				Debug::Text(' Switching Levels to Level: '. $timesheet_selected_level, __FILE__, __LINE__, __METHOD__,10);
+				Debug::Text(' Switching Levels to Level: '. key($timesheet_selected_level), __FILE__, __LINE__, __METHOD__,10);
 			} elseif ( isset($timesheet_levels[1]) ) {
-				$timesheet_selected_level = $request_levels[1];
+				$timesheet_selected_level = $timesheet_levels[1];
 			} else {
 				Debug::Text( 'No TimeSheet Levels... Not in hierarchy?', __FILE__, __LINE__, __METHOD__,10);
 				$timesheet_selected_level = 0;
 			}
-			Debug::Text( 'TimeSheet Selected Level: '. $timesheet_selected_level, __FILE__, __LINE__, __METHOD__,10);
-
-			//Get all relevant hierarchy ids
-			$timesheet_hierarchy_user_ids = $hlf->getByUserIdAndObjectTypeIDAndLevel( $current_user->getId(), 90, (int)$timesheet_selected_level );
-			//Debug::Arr( $request_hierarchy_user_ids, 'Request Hierarchy Ids', __FILE__, __LINE__, __METHOD__,10);
-
-			if ( is_array($timesheet_hierarchy_user_ids)
-					AND isset($timesheet_hierarchy_user_ids['child_level'])
-					AND isset($timesheet_hierarchy_user_ids['parent_level'])
-					AND isset($timesheet_hierarchy_user_ids['current_level']) ) {
+			//Debug::Arr( $timesheet_selected_level, 'TimeSheet Selected Level Arr: ', __FILE__, __LINE__, __METHOD__,10);
 
+			if ( is_array($timesheet_selected_level) ) {
 				$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
-				$pptsvlf->getByUserIdListAndStatusAndLevelAndMaxLevelAndNotAuthorized( $timesheet_hierarchy_user_ids['child_level'], 30, (int)$timesheet_selected_level, (int)end($timesheet_levels), NULL, NULL, NULL, $sort_array  );
+				$pptsvlf->getByHierarchyLevelMapAndStatusAndNotAuthorized($timesheet_selected_level, 30, NULL, NULL, NULL, $sort_array );
 
 				$status_options = $pptsvlf->getOptions('status');
 
