@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: global.js.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3415 $
+ * $Id: global.js.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 $disable_cache_control = TRUE;
 require_once('..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR.'global.inc.php');
@@ -149,7 +149,7 @@ function isArray(obj) {
 }
 
 function MoneyFormat( val ) {
-	if ( val != '' ) {
+	if ( isNaN(val) == false ) {
 		//Floats are PITA, need to round to 4 decimal places, then to two to keep things consistent with PHP.
 		retval = Math.round( (Math.round( parseFloat( val )*10000)/10000)*100 )/100;
 		return retval.toFixed(2);
@@ -1103,6 +1103,12 @@ function uniqueSelect(obj, obj2) {
     }
 }
 
+function filterCountSelect( element_id ) {
+	layer_id = element_id+'_count';
+	total = countSelect( document.getElementById( element_id ) );
+	writeLayer( layer_id, total);
+}
+
 function countSelect(obj) {
 	if ( obj != null ) {
 		total = obj.options.length;
