@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1764 $
- * $Id: HierarchyList.php 1764 2008-03-24 18:42:46Z ipso $
- * $Date: 2008-03-24 11:42:46 -0700 (Mon, 24 Mar 2008) $
+ * $Revision: 3415 $
+ * $Id: HierarchyList.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 //$_COOKIE['SessionID'] = '07bc520b3e90835ab586f0c585c4dd8f';
 //$_SERVER['REMOTE_ADDR'] = '192.168.1.100';
@@ -69,7 +69,8 @@ switch ($action) {
 		Redirect::Page( URLBuilder::getURL( array('hierarchy_id' => $hierarchy_id) , 'EditHierarchy.php') );
 
 		break;
-	case 'delete' OR 'undelete':
+	case 'delete':
+	case 'undelete':
 		if ( strtolower($action) == 'delete' ) {
 			$delete = TRUE;
 		} else {
