@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: index.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: index.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -49,6 +49,7 @@ require_once(Environment::getBasePath() .'includes/Interface.inc.php');
 $smarty->assign('title', TTi18n::gettext($title = 'Home'));
 BreadCrumb::setCrumb($title);
 
+//Debug::setVerbosity( 11 );
 
 /*
  * Get FORM variables
@@ -67,11 +68,7 @@ $elf = new ExceptionListFactory();
 $elf->getFlaggedExceptionsByUserIdAndPayPeriodStatus( $current_user->getId(), 10 );
 if ( $elf->getRecordCount() > 0 ) {
 	foreach($elf as $e_obj) {
-		if ( isset($exceptions[$e_obj->getColumn('severity_id')]) ) {
-			$exceptions[$e_obj->getColumn('severity_id')]++;
-		} else {
-			$exceptions[$e_obj->getColumn('severity_id')] = 1;
-		}
+		$exceptions[$e_obj->getColumn('severity_id')] = $e_obj->getColumn('total');
 	}
 }
 unset($elf, $e_obj);
@@ -101,79 +98,61 @@ if ($rlf->getRecordCount() > 0 ) {
 }
 $smarty->assign_by_ref('requests', $requests);
 
-
 //Grab list of unread messages
-$mlf = new MessageListFactory();
-$mlf->getByUserIdAndFolder( $current_user->getId(), 10, 5, 1);
-if ( $mlf->getRecordCount() > 0 ) {
-	$object_name_options = $mlf->getOptions('object_name');
-
-	$require_ack = FALSE;
-	foreach ($mlf as $message) {
+$mclf = new MessageControlListFactory();
+$mclf->getByCompanyIdAndUserIdAndFolder( $current_user->getCompany(), $current_user->getId(), 10, 5, 1 );
+if ( $mclf->getRecordCount() > 0 ) {
+	$object_name_options = $mclf->getOptions('object_name');
+	foreach ($mclf as $message) {
 		//Get user info
-		$ulf = new UserListFactory();
-
-		if ( $message->isAck() == FALSE ) {
-			$require_ack = TRUE;
-		}
-
-		if ( $message->getRequireAck() == TRUE ) {
-			$show_ack_column = TRUE;
-		}
+		$user_id = $message->getColumn('from_user_id');
+		$user_full_name = Misc::getFullName( $message->getColumn('from_first_name'), $message->getColumn('from_middle_name'), $message->getColumn('from_last_name') );
 
 		$messages[] = array(
 							'id' => $message->getId(),
 							'parent_id' => $message->getParent(),
 							'object_type_id' => $message->getObjectType(),
-							'object_type' => $object_name_options[$message->getObjectType()],
+							'object_type' => Option::getByKey($message->getObjectType(), $object_name_options ),
 							'object_id' => $message->getObject(),
-							'priority' => $message->getPriority(),
 							'status_id' => $message->getStatus(),
-							'require_ack' => $message->getRequireAck(),
-							'ack_date' => $message->getAckDate(),
-							'subject' => Misc::TruncateString( $message->getSubject(), 20 ),
+							'subject' => $message->getSubject(),
 							'body' => $message->getBody(),
+
+							'user_id' => $user_id,
+							'user_full_name' =>  $user_full_name,
 							'created_date' => $message->getCreatedDate(),
 							'created_by' => $message->getCreatedBy(),
-							'created_by_full_name' => $ulf->getById( $message->getCreatedBy() )->getIterator()->current()->getFullName(),
 							'updated_date' => $message->getUpdatedDate(),
 							'updated_by' => $message->getUpdatedBy(),
 							'deleted_date' => $message->getDeletedDate(),
 							'deleted_by' => $message->getDeletedBy()
 						);
-
 	}
+	$smarty->assign_by_ref('messages', $messages);
 }
-$smarty->assign_by_ref('messages', $messages);
 
 //Grab requests pending authorization if they are a supervisor.
 if ( $permission->Check('authorization','enabled')
 		AND $permission->Check('authorization','view')
 		AND $permission->Check('request','authorize') ) {
-	
-	$ulf = new UserListFactory();
-	$hlf = new HierarchyListFactory();
+
 	$hllf = new HierarchyLevelListFactory();
+	$request_levels = $hllf->getLevelsAndHierarchyControlIDsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
 
-	$request_levels = $hllf->getLevelsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
-
-	//Use highest hierarchy level to show on the home page.
-	$request_selected_level = 1;
-	if ( isset($request_levels[1]) ) {
+	$selected_levels['request'] = 1;
+	if ( isset($selected_levels['request']) AND isset($request_levels[$selected_levels['request']]) ) {
+		$request_selected_level = $request_levels[$selected_levels['request']];
+		Debug::Text(' Switching Levels to Level: '. key($request_selected_level), __FILE__, __LINE__, __METHOD__,10);
+	} elseif ( isset($request_levels[1]) ) {
 		$request_selected_level = $request_levels[1];
+	} else {
+		Debug::Text( 'No Request Levels... Not in hierarchy?', __FILE__, __LINE__, __METHOD__,10);
+		$request_selected_level = 0;
 	}
 
-	$request_hierarchy_user_ids = $hlf->getByUserIdAndObjectTypeIDAndLevel( $current_user->getId(), 50, 1 );
-
-	if ( is_array($request_hierarchy_user_ids)
-			AND isset($request_hierarchy_user_ids['child_level'])
-			AND isset($request_hierarchy_user_ids['parent_level'])
-			AND isset($request_hierarchy_user_ids['current_level']) ) {
-
+	if ( is_array($request_selected_level) ) {
 		$rlf = new RequestListFactory();
-		//$rlf->getByUserIdListAndStatusAndNotAuthorized($request_hierarchy_user_ids['child_level'], 30, $request_hierarchy_user_ids['parent_level'], $request_hierarchy_user_ids['current_level'] );
-		$rlf->getByUserIdListAndStatusAndLevelAndMaxLevelAndNotAuthorized( $request_hierarchy_user_ids['child_level'], 30, $request_selected_level, (int)end($request_levels)  );
-
+		$rlf->getByHierarchyLevelMapAndStatusAndNotAuthorized($request_selected_level, 30);
 
 		$status_options = $rlf->getOptions('status');
 		$type_options = $rlf->getOptions('type');
@@ -190,8 +169,10 @@ if ( $permission->Check('authorization','enabled')
 									'type' => $type_options[$r_obj->getType()],
 									'status_id' => $r_obj->getStatus(),
 									'status' => $status_options[$r_obj->getStatus()]
-												);
+								);
 		}
+	} else {
+		Debug::Text( 'No hierarchy information found...', __FILE__, __LINE__, __METHOD__,10);
 	}
 	$smarty->assign_by_ref('pending_requests', $pending_requests);
 	unset($pending_requests, $request_hierarchy_id, $request_user_id, $request_node_data, $request_current_level_user_ids, $request_parent_level_user_ids, $request_child_level_user_ids );
