@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: EditMessage.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 3562 $
+ * $Id: EditMessage.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -62,7 +62,9 @@ extract	(FormVariables::GetVariables(
 												'data',
 												) ) );
 
-$mf = new MessageFactory();
+$mcf = new MessageControlFactory();
+$mrf = new MessageRecipientFactory();
+$msf = new MessageSenderFactory();
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -73,85 +75,31 @@ switch ($action) {
 		$redirect = TRUE;
 		//Make sure the only array entry isn't 0 => 0;
 		if ( is_array($filter_user_id) AND count($filter_user_id) > 0 AND ( isset($filter_user_id[0]) AND $filter_user_id[0] != 0 ) ) {
-			$mf->StartTransaction();
-			foreach( $filter_user_id as $object_id ) {
-				Debug::Text('Adding Message for: '. $object_id, __FILE__, __LINE__, __METHOD__,10);
+			$mcf->StartTransaction();
 
-				$mf = new MessageFactory();
-				$mf->setObjectType( 5 );
-				$mf->setObject( $object_id );
-				$mf->setParent( 0 );
-				$mf->setPriority();
-				$mf->setStatus('UNREAD');
-				$mf->setSubject( $data['subject'] );
-				$mf->setBody( $data['body'] );
+			$mcf = new MessageControlFactory();
+			$mcf->setFromUserId( $current_user->getId() );
+			$mcf->setToUserId( $filter_user_id );
+			$mcf->setObjectType( 5 );
+			$mcf->setObject( $current_user->getId() );
+			$mcf->setParent( 0 );
+			$mcf->setSubject( $data['subject'] );
+			$mcf->setBody( $data['body'] );
 
-				if ( isset($data['require_ack']) ) {
-					Debug::Text('Requires Ack!!', __FILE__, __LINE__, __METHOD__,10);
-					$mf->setRequireAck( TRUE );
-				} else {
-					Debug::Text('DOES NOT Requires Ack!!', __FILE__, __LINE__, __METHOD__,10);
-					$mf->setRequireAck( FALSE );
-				}
+			if ( $mcf->isValid() ) {
+				$mcf->Save();
 
-				if ( $mf->isValid() ) {
-					$mf->Save();
-				} else {
-					$redirect = FALSE;
-				}
-			}
-
-			if ( $redirect == TRUE ) {
-				$mf->CommitTransaction();
+				$mcf->CommitTransaction();
 				Redirect::Page( URLBuilder::getURL( NULL, 'UserMessageList.php') );
-
 				break;
 			}
-			$mf->FailTransaction();
+			$mcf->FailTransaction();
 		} else {
-			$mf->Validator->isTrue(	'to',
+			$mcf->Validator->isTrue(	'to',
 									FALSE,
 									TTi18n::gettext('Please select at least one recipient') );
 		}
 	default:
-		if ( isset($id) AND $action != 'submit_message') {
-			unset($data);
-
-			Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-			$mlf = new MessageListFactory();
-			$mlf->getById($id);
-			if ( $mlf->getRecordCount() > 0 ) {
-				foreach ($mlf as $m_obj) {
-					$data = array(
-										'id' => $m_obj->getId(),
-										'status_id' => $m_obj->getStatus(),
-										'status_date' => $c_obj->getStatusDate(),
-										'object_type_id' => $m_obj->getObjectType(),
-										'object_id' => $m_obj->getObject(),
-										'priority' => $m_obj->getPriority(),
-
-										'subject' => $m_obj->getSubject(),
-										'body' => $m_obj->getBody(),
-
-										'require_ack' => $m_obj->getRequireAck(),
-										'ack_date' => $m_obj->getAckDate(),
-										'ack_by' => $m_obj->getAckBy(),
-
-										'created_date' => $c_obj->getCreatedDate(),
-										'created_by' => $c_obj->getCreatedBy(),
-										'created_by_full_name' => $ulf->getById( $message->getCreatedBy() )->getCurrent()->getFullName(),
-										'updated_date' => $c_obj->getUpdatedDate(),
-										'updated_by' => $c_obj->getUpdatedBy(),
-										'deleted_date' => $c_obj->getDeletedDate(),
-										'deleted_by' => $c_obj->getDeletedBy()
-									);
-				}
-			}
-		}
-
-		$data['status_options'] = $mf->getOptions('status');
-		$data['priority_options'] = $mf->getOptions('priority');
-
 		if ( $permission->Check('message','send_to_any') ) {
 			$user_options = UserListFactory::getByCompanyIdArray( $current_company->getId(), FALSE, TRUE);
 			$data['user_options'] = Misc::arrayDiffByKey( (array)$filter_user_id, $user_options );
@@ -167,7 +115,7 @@ switch ($action) {
 			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID($current_company->getId(), $current_user->getId(), 50, FALSE, FALSE );
 			//Debug::Arr( $request_parent_level_user_ids, 'Request Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);
 
-			//Get Children
+			//Get Children, in case the current user is a superior.
 			$request_child_level_user_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId(), 50);
 			//Debug::Arr( $request_child_level_user_ids, 'Request Child Level Ids', __FILE__, __LINE__, __METHOD__,10);
 
@@ -191,7 +139,7 @@ switch ($action) {
 		break;
 }
 
-$smarty->assign_by_ref('mf', $mf);
+$smarty->assign_by_ref('mcf', $mcf);
 
 $smarty->display('message/EditMessage.tpl');
 ?>
\ No newline at end of file
