@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1458 $
- * $Id: EmbeddedMessageList.php 1458 2007-11-20 22:46:59Z ipso $
- * $Date: 2007-11-20 14:46:59 -0800 (Tue, 20 Nov 2007) $
+ * $Revision: 3562 $
+ * $Id: EmbeddedMessageList.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -45,9 +45,7 @@ require_once(Environment::getBasePath() .'includes/Interface.inc.php');
 
 if ( !$permission->Check('message','enabled')
 		OR !( $permission->Check('message','view') OR $permission->Check('message','view_own') ) ) {
-
 	$permission->Redirect( FALSE ); //Redirect
-
 }
 
 $smarty->assign('title', TTi18n::gettext($title = 'Message List') ); // See index.php
@@ -69,7 +67,8 @@ extract	(FormVariables::GetVariables(
 												'template',
 												'close'
 												) ) );
-$mf = new MessageFactory();
+
+$mcf = new MessageControlFactory();
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -87,81 +86,96 @@ switch ($action) {
 				$parent_id = 0;
 			}
 
-			$mf->setObjectType( $object_type_id );
-			$mf->setObject( $object_id );
-			$mf->setParent( $parent_id );
-			$mf->setPriority();
-			$mf->setStatus('UNREAD');
-			$mf->setSubject( $message_data['subject'] );
-			$mf->setBody( $message_data['body'] );
+			$mcf->StartTransaction();
 
-			if ( $mf->isValid() ) {
-				$mf->Save();
+			$mcf = new MessageControlFactory();
 
-				Redirect::Page( URLBuilder::getURL( 	array(	'template' => $template,
-																'close' => 1,
-																'object_type_id' => $object_type_id,
-																'object_id' => $object_id), 'EmbeddedMessageList.php') );
+			$mcf->setObjectType( $object_type_id );
+			$mcf->setObject( $object_id );
+			$mcf->setParent( $parent_id );
 
-				break;
+			$mcf->setFromUserId( $current_user->getId() );
+
+			//This needs to reply to all those involved in the object thread. As when the object (request) creator
+			//responds, we don't know who exactly they are responding to? Or should it be the last message sender only?
+			$mclf = new MessageControlListFactory();
+			$to_user_ids = $mclf->getByCompanyIdAndObjectTypeAndObjectAndNotUser( $current_user->getCompany(), $object_type_id, $object_id, $current_user->getId() );
+			$mcf->setToUserId( $to_user_ids );
+
+			$mcf->setSubject( $message_data['subject'] );
+			$mcf->setBody( $message_data['body'] );
+			$mcf->setRequireAck( FALSE );
+
+			if ( $mcf->isValid() ) {
+				if ( $mcf->Save() == TRUE ) {
+					//$mcf->FailTransaction();
+					$mcf->CommitTransaction();
+					Redirect::Page( URLBuilder::getURL( 	array(	'template' => $template,
+																	'close' => 1,
+																	'object_type_id' => $object_type_id,
+																	'object_id' => $object_id), 'EmbeddedMessageList.php') );
+					break;
+				}
 			}
 
+			$mcf->FailTransaction();
 		}
 	default:
 		if ( isset($object_type_id) AND isset($object_id) ) {
-			$mlf = new MessageListFactory();
+			$mclf = new MessageControlListFactory();
+			$mclf->getByCompanyIDAndUserIdAndObjectTypeAndObject( $current_user->getCompany(), $current_user->getId(), $object_type_id, $object_id );
 
-			$mlf->getByObjectTypeAndObject($object_type_id, $object_id);
+			if ( $mclf->getRecordCount() > 0 ) {
+				$mark_read_message_ids = array();
+				$i=0;
+				foreach( $mclf as $message ) {
+					$ulf = new UserListFactory();
 
-			$i=0;
-			foreach ($mlf as $message) {
-				//Get user info
-				$ulf = new UserListFactory();
+					$from_user_id = $message->getColumn('from_user_id');
+					$from_user_full_name = Misc::getFullName( $message->getColumn('from_first_name'), $message->getColumn('from_middle_name'), $message->getColumn('from_last_name') );
 
-				$messages[] = array(
-									'id' => $message->getId(),
-									'parent_id' => $message->getParent(),
-									'object_type' => $message->getObjectType(),
-									'object_id' => $message->getObject(),
-									'priority' => $message->getPriority(),
-									'status' => $message->getStatus(),
-									'subject' => $message->getSubject(),
-									'body' => $message->getBody(),
-									'created_date' => $message->getCreatedDate(),
-									'created_by' => $message->getCreatedBy(),
-									'created_by_full_name' => $ulf->getById( $message->getCreatedBy() )->getCurrent()->getFullName(),
-									'updated_date' => $message->getUpdatedDate(),
-									'updated_by' => $message->getUpdatedBy(),
-									'deleted_date' => $message->getDeletedDate(),
-									'deleted_by' => $message->getDeletedBy()
-								);
+					$messages[] = array(
+										'id' => $message->getId(),
+										'parent_id' => $message->getParent(),
+										'object_type_id' => $message->getObjectType(),
+										'object_id' => $message->getObject(),
+										'status_id' => $message->getStatus(),
+										'subject' => $message->getSubject(),
+										'body' => $message->getBody(),
 
-				//Mark own messages as read.
-				if ( $message->getCreatedBy() != $current_user->getId() ) {
-					$mlf_b = new MessageListFactory();
-					$message_obj = $mlf_b->getById( $message->getId() )->getCurrent();
-					$message_obj->setStatus(20);
-					$message_obj->Save();
+										'from_user_id' => $from_user_id,
+										'from_user_full_name' => $from_user_full_name,
+
+										'created_date' => $message->getCreatedDate(),
+										'created_by' => $message->getCreatedBy(),
+										'updated_date' => $message->getUpdatedDate(),
+										'updated_by' => $message->getUpdatedBy(),
+										'deleted_date' => $message->getDeletedDate(),
+										'deleted_by' => $message->getDeletedBy()
+									);
+
+					//Mark own messages as read.
+					if ( $message->getStatus() == 10 AND $message->getCreatedBy() != $current_user->getId() ) {
+						$mark_read_message_ids[] = $message->getId();
+					}
+
+					if ( $i == 0 ) {
+						$parent_id = $message->getId();
+						$default_subject = TTi18n::gettext('Re:').' '.$message->getSubject();
+					}
+
+					$i++;
 				}
 
-				if ( $i == 0 ) {
-					$parent_id = $message->getId();
-					$default_subject = TTi18n::gettext('Re:').' '.$message->getSubject();
-				}
-
-				$i++;
+				MessageControlFactory::markRecipientMessageAsRead( $current_user->getCompany(), $current_user->getID(), $mark_read_message_ids );
 			}
 
 			//Get object data
-			$object_name_options = $mlf->getOptions('object_name');
+			$object_name_options = $mclf->getOptions('object_name');
 			$smarty->assign_by_ref('object_name', $object_name_options[$object_type_id]);
-
 			$smarty->assign_by_ref('messages', $messages);
-
 			$smarty->assign_by_ref('message_data', $message_data);
-
 			$smarty->assign_by_ref('default_subject', $default_subject);
-
 			$smarty->assign_by_ref('total_messages', $i);
 
 			$smarty->assign_by_ref('parent_id', $parent_id);
@@ -175,7 +189,7 @@ switch ($action) {
 		break;
 }
 
-$smarty->assign_by_ref('mf', $mf);
+$smarty->assign_by_ref('mcf', $mcf);
 
 if ( $template == 1 ) {
 	$smarty->display('message/LayerMessageList.tpl');
