@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2058 $
- * $Id: ViewMessage.php 2058 2008-08-21 19:16:38Z ipso $
- * $Date: 2008-08-21 12:16:38 -0700 (Thu, 21 Aug 2008) $
+ * $Revision: 3562 $
+ * $Id: ViewMessage.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -60,6 +60,7 @@ extract	(FormVariables::GetVariables(
 												'page',
 												'sort_column',
 												'sort_order',
+												'filter_folder_id',
 												'object_type_id',
 												'object_id',
 												'parent_id',
@@ -67,7 +68,7 @@ extract	(FormVariables::GetVariables(
 												'message_data',
 												'ack_message_id',
 												) ) );
-$mf = new MessageFactory();
+$mcf = new MessageControlFactory();
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -82,12 +83,9 @@ switch ($action) {
 		}
 		break;
 	case 'submit_message':
-		//Debug::setVerbosity(11);
 		if ( !$permission->Check('message','enabled')
 			OR !( $permission->Check('message','add') ) ) {
-
 			$permission->Redirect( FALSE ); //Redirect
-
 		}
 
 		if ( isset($object_type_id) AND isset($object_id) ) {
@@ -95,108 +93,110 @@ switch ($action) {
 				$parent_id = 0;
 			}
 
-			$mf->setObjectType( $object_type_id );
-			$mf->setObject( $object_id );
-			$mf->setParent( $parent_id );
-			$mf->setPriority();
-			$mf->setStatus('UNREAD');
-			$mf->setSubject( $message_data['subject'] );
-			$mf->setBody( $message_data['body'] );
+			$mcf->StartTransaction();
 
-			if ( $mf->isValid() ) {
-				$mf->Save();
+			$mcf = new MessageControlFactory();
+			$mcf->setFromUserId( $current_user->getId() );
 
-				Redirect::Page( URLBuilder::getURL( 	array('object_type_id' => $object_type_id,'object_id' => $object_id, 'id' => $parent_id), 'ViewMessage.php') );
+			//Get sender of the original message, as we only reply directly to them.
+			$mcf->setToUserId( $object_id );
 
-				break;
+			$mcf->setObjectType( 5 );
+			$mcf->setObject( $current_user->getId() );
+			$mcf->setParent( $parent_id );
+			$mcf->setSubject( $message_data['subject'] );
+			$mcf->setBody( $message_data['body'] );
+			$mcf->setRequireAck( FALSE );
+
+			if ( $mcf->isValid() ) {
+				if ( $mcf->Save() == TRUE ) {
+					//$mcf->FailTransaction();
+					$mcf->CommitTransaction();
+					Redirect::Page( URLBuilder::getURL( 	array('object_type_id' => $object_type_id,'object_id' => $object_id, 'id' => $parent_id), 'ViewMessage.php') );
+					break;
+				}
 			}
+
+			$mcf->FailTransaction();
 		}
 	default:
 		if ( isset($object_type_id) AND isset($object_id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$mlf = new MessageListFactory();
+			//If a supervisors sends a message to multiple recipients, we always treat it as individual messages,
+			//So we only display a message thread for a single from/to pair.
+			$mclf = new MessageControlListFactory();
+			$mclf->getByCompanyIDAndUserIdAndIdAndFolder( $current_user->getCompany(), $current_user->getID(), $id, $filter_folder_id, NULL, NULL, NULL, array( 'a.created_date' => 'asc' ) );
+			if ( $mclf->getRecordCount() > 0 ) {
+				$mark_read_message_ids = array();
+				$i=0;
+				foreach ($mclf as $message) {
+					//Get user info
+					$ulf = new UserListFactory();
 
-			$mlf->getByObjectTypeAndObjectAndId($object_type_id, $object_id, $id);
+					$from_user_id = $message->getColumn('from_user_id');
+					$from_user_full_name = Misc::getFullName( $message->getColumn('from_first_name'), $message->getColumn('from_middle_name'), $message->getColumn('from_last_name') );
 
-			$ack_message_id = NULL;
-			$require_ack = FALSE;
-			$i=0;
-			foreach ($mlf as $message) {
-				//Get user info
-				$ulf = new UserListFactory();
+					$to_user_id = $message->getColumn('to_user_id');
+					$to_user_full_name = Misc::getFullName( $message->getColumn('to_first_name'), $message->getColumn('to_middle_name'), $message->getColumn('to_last_name') );
 
-				if ( $message->getRequireAck() == TRUE
-						AND $message->isAck() == FALSE
-						AND $ack_message_id == NULL
-						AND $message->getCreatedBy() != $current_user->getId() ) {
-					$require_ack = TRUE;
-					$ack_message_id = $message->getId();
-				}
+					$messages[] = array(
+										'id' => $message->getId(),
+										'parent_id' => $message->getParent(),
+										'object_type_id' => $message->getObjectType(),
+										//'object_type' => Option::getByKey($message->getObjectType(), $object_name_options ),
+										'object_id' => $message->getObject(),
+										//'priority' => $message->getPriority(),
+										'status_id' => $message->getStatus(),
+										//'require_ack' => $message->getRequireAck(),
+										//'ack_date' => $message->getAckDate(),
+										'subject' => $message->getSubject(),
+										'body' => $message->getBody(),
 
-				if ( $message->getAckBy() != '' ) {
-					$ack_by_full_name = $ulf->getById( $message->getAckBy() )->getCurrent()->getFullName();
-				} else {
-					$ack_by_full_name = NULL;
-				}
+										'from_user_id' => $from_user_id,
+										'from_user_full_name' => $from_user_full_name,
+										'to_user_id' => $to_user_id,
+										'to_user_full_name' => $to_user_full_name,
 
-				$messages[] = array(
-									'id' => $message->getId(),
-									'parent_id' => $message->getParent(),
-									'object_type' => $message->getObjectType(),
-									'object_id' => $message->getObject(),
-									'priority' => $message->getPriority(),
-									'status' => $message->getStatus(),
-									'require_ack' => $message->getRequireAck(),
-									'ack_date' => $message->getAckDate(),
-									'ack_by' => $message->getAckBy(),
-									'ack_by_full_name' => $ack_by_full_name,
-									'is_ack' => $message->isAck(),
-									'subject' => $message->getSubject(),
-									'body' => $message->getBody(),
-									'created_date' => $message->getCreatedDate(),
-									'created_by' => $message->getCreatedBy(),
-									'created_by_full_name' => $ulf->getById( $message->getCreatedBy() )->getCurrent()->getFullName(),
-									'updated_date' => $message->getUpdatedDate(),
-									'updated_by' => $message->getUpdatedBy(),
-									'deleted_date' => $message->getDeletedDate(),
-									'deleted_by' => $message->getDeletedBy()
-								);
+										'created_date' => $message->getCreatedDate(),
+										'created_by' => $message->getCreatedBy(),
+										'updated_date' => $message->getUpdatedDate(),
+										'updated_by' => $message->getUpdatedBy(),
+										'deleted_date' => $message->getDeletedDate(),
+										'deleted_by' => $message->getDeletedBy()
+									);
 
-				//Mark own messages as read.
-				if ( $message->getCreatedBy() != $current_user->getId() ) {
-					$mlf_b = new MessageListFactory();
-					$message_obj = $mlf_b->getById( $message->getId() )->getCurrent();
-					if ( $message_obj->getStatus() == 10 ) {
-						$message_obj->setStatus(20);
-						$message_obj->Save();
+					//Mark own messages as read.
+					if ( $message->getStatus() == 10 AND $message->getCreatedBy() != $current_user->getId() ) {
+						$mark_read_message_ids[] = $message->getId();
 					}
-				}
 
-				if ( $i == 0 ) {
-					$parent_id = $message->getId();
-					$default_subject = 'Re: '.$message->getSubject();
-				}
+					//Parent ID should be the ID of ONLY the first message in the thread. Single level threading...
+					if ( $i == 0 ) {
+						$parent_id = $message->getId();
+						$default_subject = 'Re: '.$message->getSubject();
+					}
 
-				$i++;
+					$i++;
+				}
+				MessageControlFactory::markRecipientMessageAsRead( $current_user->getCompany(), $current_user->getID(), $mark_read_message_ids );
 			}
 
 			//Get object data
-			$object_name_options = $mlf->getOptions('object_name');
+			/*
+			$object_name_options = $mclf->getOptions('object_name');
 			$smarty->assign_by_ref('object_name', $object_name_options[$object_type_id]);
+			*/
 
 			$smarty->assign_by_ref('messages', $messages);
 			$smarty->assign_by_ref('message_data', $message_data);
 
 			$smarty->assign_by_ref('default_subject', $default_subject);
-
 			$smarty->assign_by_ref('total_messages', $i);
 
-			$smarty->assign_by_ref('require_ack', $require_ack);
-			$smarty->assign_by_ref('ack_message_id', $ack_message_id);
-			$smarty->assign_by_ref('current_date', TTDate::getTime() );
-
 			$smarty->assign_by_ref('id', $id);
+			$smarty->assign_by_ref('parent_id', $parent_id);
+			$smarty->assign_by_ref('filter_folder_id', $filter_folder_id);
 			$smarty->assign_by_ref('object_type_id', $object_type_id);
 			$smarty->assign_by_ref('object_id', $object_id);
 		}
@@ -204,7 +204,7 @@ switch ($action) {
 		break;
 }
 
-$smarty->assign_by_ref('mf', $mf);
+$smarty->assign_by_ref('mcf', $mcf);
 
 $smarty->display('message/ViewMessage.tpl');
 ?>
\ No newline at end of file
