@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PayStubList.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 3021 $
+ * $Id: PayStubList.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -178,6 +191,7 @@ switch ($action) {
 					$filter_data['permission_children_ids'] = $permission_children_ids;
 				}
 				if ( $permission->Check('pay_stub','view_own') == TRUE ) {
+					$hide_employer_rows = TRUE;
 					$filter_data['permission_children_ids'][] = $current_user->getId();
 				}
 			}
@@ -402,26 +416,9 @@ switch ($action) {
 			unset($end_date);
 			unset($transaction_date);
 		}
-		//var_dump($pay_stubs);
-
+		
 		$export_type_options = $pslf->getOptions('export_type');
-/*
-		$export_type_options = array(
-										'1464' => TTi18n::gettext('EFT (CPA 005/1464-Byte)'),
-										'105' => TTi18n::gettext('EFT (105-Byte)'),
-										'HSBC' => TTi18n::gettext('HSBC EFT-PC (CSV)'),
-										'cheque_9085' => TTi18n::gettext('Cheques (Simply - NEBS #9085)'),
-										'cheque_9209p' => TTi18n::gettext('Cheques (Quickbooks - NEBS #9209P)'),
-										'ACH' => TTi18n::gettext('US ACH (94-Byte)'),
-										//'simply' => 'Simply Accounting GL',
-										//'csv' => 'CSV (Excel)'
-									);
 
-		if ($current_company->getCountry() == 'CR'){
-			$export_type_options['cheque_cr_standard_form_1'] = TTi18n::gettext('Cheques (Costa Rica Standard Form 1)');
-			$export_type_options['cheque_cr_standard_form_2'] = TTi18n::gettext('Cheques (Costa Rica Standard Form 2)');
-		}
-*/
 		$all_array_option = array('-1' => TTi18n::gettext('-- Any --'));
 
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
