@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: ClosePayPeriod.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 3562 $
+ * $Id: ClosePayPeriod.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -181,7 +181,7 @@ switch ($action) {
 						foreach( $pptsvlf as $pptsv_obj ) {
 							if ( $pptsv_obj->getAuthorized() == TRUE ) {
 								$verified_time_sheets++;
-							} elseif (  $pptsv_obj->getStatus() == 30 ) {
+							} elseif (  $pptsv_obj->getStatus() == 30 OR $pptsv_obj->getStatus() == 45 ) {
 								$pending_time_sheets++;
 							}
 						}
