@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2644 $
- * $Id: EditPayPeriodSchedule.php 2644 2009-07-10 19:27:12Z ipso $
- * $Date: 2009-07-10 12:27:12 -0700 (Fri, 10 Jul 2009) $
+ * $Revision: 3562 $
+ * $Id: EditPayPeriodSchedule.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -130,6 +130,7 @@ switch ($action) {
 		$ppsf->setMaximumShiftTime( $pay_period_schedule_data['maximum_shift_time'] );
 		$ppsf->setShiftAssignedDay( $pay_period_schedule_data['shift_assigned_day_id'] );
 
+		$ppsf->setTimeSheetVerifyType( $pay_period_schedule_data['timesheet_verify_type_id'] );
 		$ppsf->setTimeSheetVerifyBeforeEndDate( $pay_period_schedule_data['timesheet_verify_before_end_date'] );
 		$ppsf->setTimeSheetVerifyBeforeTransactionDate( $pay_period_schedule_data['timesheet_verify_before_transaction_date'] );
 
@@ -202,6 +203,7 @@ switch ($action) {
 													'maximum_shift_time' => $pay_period_schedule->getMaximumShiftTime(),
 													'shift_assigned_day_id' => $pay_period_schedule->getShiftAssignedDay(),
 
+													'timesheet_verify_type_id' => (int)$pay_period_schedule->getTimeSheetVerifyType(),
 													'timesheet_verify_before_end_date' => (int)$pay_period_schedule->getTimeSheetVerifyBeforeEndDate(),
 													'timesheet_verify_before_transaction_date' => (int)$pay_period_schedule->getTimeSheetVerifyBeforeTransactionDate(),
 													'timesheet_verify_notice_before_transaction_date' => $pay_period_schedule->getTimeSheetVerifyNoticeBeforeTransactionDate(),
@@ -227,6 +229,7 @@ switch ($action) {
 											'maximum_shift_time' => (3600*16),
 											'time_zone' => $current_user_prefs->getTimeZone(),
 											'type' => 20,
+											'timesheet_verify_type_id' => 10, //Disabled
 											'timesheet_verify_before_end_date' => 0,
 											'timesheet_verify_before_transaction_date' => 0,
 											'annual_pay_periods' => 0
@@ -236,6 +239,7 @@ switch ($action) {
 		$pay_period_schedule_data['type_options'] = $ppsf->getOptions('type');
 		$pay_period_schedule_data['startweekday_options'] = $ppsf->getOptions('startweekday');
 		$pay_period_schedule_data['shift_assigned_day_options'] = $ppsf->getOptions('shift_assigned_day');
+		$pay_period_schedule_data['timesheet_verify_type_options'] = $ppsf->getOptions('timesheet_verify_type');
 		$pay_period_schedule_data['time_zone_options'] = $ppsf->getTimeZoneOptions();
 		$pay_period_schedule_data['transaction_date_bd_options'] = $ppsf->getOptions('transaction_date_business_day');
 		$pay_period_schedule_data['day_of_week_options'] = TTDate::getDayOfWeekArray();
