@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: ProgressBar.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 3199 $
+ * $Id: ProgressBar.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -346,6 +359,8 @@ switch ($action) {
 		break;
 	case 'add_mass_punch':
 		if ( isset($filter_user_id) AND is_array($filter_user_id) AND count($filter_user_id) > 0 ) {
+			//Debug::setVerbosity(11);
+
 			$init_progress_bar = TRUE;
 
 			if ( $init_progress_bar == TRUE ) {
@@ -389,112 +404,104 @@ switch ($action) {
 
 						Debug::Text('Punch Full Time Stamp: '. TTDate::getDate('DATE+TIME', $time_stamp), __FILE__, __LINE__, __METHOD__,10);
 
-						$pcf->findUserDate( $user_id, $time_stamp, $data['status_id'] );
+						//Set User before setTimeStamp so rounding can be done properly.
+						$pf->setUser( $user_id );
 
-						//Try to find a punch_control_id we can attach to safely.
-						$pclf = new PunchControlListFactory();
-						$tmp_punch_control_id = $pclf->getInCompletePunchControlIdByUserDateIdAndEpoch( $pcf->getUserDateId(), $time_stamp, $data['status_id'] );
-						if ( $tmp_punch_control_id !== FALSE ) {
-							$pcf->setId( $tmp_punch_control_id );
+						$pf->setType( $data['type_id'] );
+						$pf->setStatus( $data['status_id'] );
+						if ( isset($data['disable_rounding']) ) {
+							$enable_rounding = FALSE;
+						} else {
+							$enable_rounding = TRUE;
+						}
+						$pf->setTimeStamp( $time_stamp, $enable_rounding );
+
+						$pf->setPunchControlID( $pf->findPunchControlID() );
+
+						$pf->setStation( $current_station->getID() );
+
+						if ( $pf->isNew() ) {
+							$pf->setActualTimeStamp( $time_stamp );
+							$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
 						}
 
-						if ( isset($data['branch_id']) AND $data['branch_id'] == -1 ) {
-							$pcf->setBranch( $user_obj->getDefaultBranch() );
-						} elseif ( isset($data['branch_id']) ) {
-							$pcf->setBranch( $data['branch_id'] );
-						}
-						if ( isset($data['department_id']) AND $data['department_id'] == -1 ) {
-							$pcf->setDepartment( $user_obj->getDefaultDepartment() );
-						} elseif ( isset($data['department_id']) ) {
-							$pcf->setDepartment( $data['department_id'] );
-						}
+						if ( $pf->isValid() == TRUE ) {
+							if ( $pf->Save( FALSE ) == TRUE ) {
+								$pcf = new PunchControlFactory();
+								$pcf->setId( $pf->getPunchControlID() );
+								$pcf->setPunchObject( $pf );
 
-						if ( isset($data['job_id']) ) {
-							$pcf->setJob( $data['job_id'] );
-						}
-						if ( isset($data['job_item_id']) ) {
-							$pcf->setJobItem( $data['job_item_id'] );
-						}
-						if ( isset($data['quantity']) ) {
-							$pcf->setQuantity( $data['quantity'] );
-						}
-						if ( isset($data['bad_quantity']) ) {
-							$pcf->setBadQuantity( $data['bad_quantity'] );
-						}
-						if ( isset($data['note']) ) {
-							$pcf->setNote( $data['note'] );
-						}
+								if ( isset($data['branch_id']) ) {
+									$pcf->setBranch( $data['branch_id'] );
+								}
+								if ( isset($data['department_id']) ) {
+									$pcf->setDepartment( $data['department_id'] );
+								}
 
-						if ( isset($data['other_id1']) ) {
-							$pcf->setOtherID1( $data['other_id1'] );
-						}
-						if ( isset($data['other_id2']) ) {
-							$pcf->setOtherID2( $data['other_id2'] );
-						}
-						if ( isset($data['other_id3']) ) {
-							$pcf->setOtherID3( $data['other_id3'] );
-						}
-						if ( isset($data['other_id4']) ) {
-							$pcf->setOtherID4( $data['other_id4'] );
-						}
-						if ( isset($data['other_id5']) ) {
-							$pcf->setOtherID5( $data['other_id5'] );
-						}
+								if ( isset($data['job_id']) ) {
+									$pcf->setJob( $data['job_id'] );
+								}
+								if ( isset($data['job_item_id']) ) {
+									$pcf->setJobItem( $data['job_item_id'] );
+								}
+								if ( isset($data['quantity']) ) {
+									$pcf->setQuantity( $data['quantity'] );
+								}
+								if ( isset($data['bad_quantity']) ) {
+									$pcf->setBadQuantity( $data['bad_quantity'] );
+								}
+								if ( isset($data['note']) ) {
+									$pcf->setNote( $data['note'] );
+								}
 
+								if ( isset($data['other_id1']) ) {
+									$pcf->setOtherID1( $data['other_id1'] );
+								}
+								if ( isset($data['other_id2']) ) {
+									$pcf->setOtherID2( $data['other_id2'] );
+								}
+								if ( isset($data['other_id3']) ) {
+									$pcf->setOtherID3( $data['other_id3'] );
+								}
+								if ( isset($data['other_id4']) ) {
+									$pcf->setOtherID4( $data['other_id4'] );
+								}
+								if ( isset($data['other_id5']) ) {
+									$pcf->setOtherID5( $data['other_id5'] );
+								}
 
-						if ( $pcf->isValid() == TRUE ) {
-							$punch_control_id = $pcf->Save();
+								$pcf->setEnableStrictJobValidation( TRUE );
+								$pcf->setEnableCalcUserDateID( TRUE );
+								$pcf->setEnableCalcTotalTime( TRUE );
+								$pcf->setEnableCalcSystemTotalTime( TRUE );
+								$pcf->setEnableCalcUserDateTotal( TRUE );
+								$pcf->setEnableCalcException( TRUE );
 
-							//If its an update, not a new insert
-							if ( $punch_control_id === TRUE ) {
-								$punch_control_id = $tmp_punch_control_id;
-							}
-							Debug::Text(' Punch Control ID: '. $punch_control_id, __FILE__, __LINE__, __METHOD__,10);
+								if ( $pcf->isValid() == TRUE ) {
+									Debug::Text(' Punch Control is valid, saving...: ', __FILE__, __LINE__, __METHOD__,10);
 
-							if ( isset($data['transfer']) ) {
-								$pf->setTransfer( TRUE );
-							}
-							$pf->setPunchControlID( $punch_control_id );
-							$pf->setType( $data['type_id'] );
-							$pf->setStatus( $data['status_id'] );
-							if ( isset($data['disable_rounding']) ) {
-								$enable_rounding = FALSE;
-							} else {
-								$enable_rounding = TRUE;
-							}
-							$pf->setTimeStamp( $time_stamp, $enable_rounding );
+									if ( $pcf->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
+										UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 30, NULL, NULL );
+									} else {
+										Debug::Text(' aFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
+										$fail_transaction = TRUE;
+										break;
+									}
+								} else {
+									Debug::Text(' bFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
+									UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 10, $pcf->Validator->getTextErrors(), NULL );
 
-							if ( $pf->isNew() ) {
-								$pf->setActualTimeStamp( $time_stamp );
-								$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
-							}
-
-							if ( $pf->isValid() ) {
-								$pf->setEnableCalcTotalTime( TRUE );
-								$pf->setEnableCalcSystemTotalTime( TRUE );
-								$pf->setEnableCalcWeeklySystemTotalTime( TRUE );
-								$pf->setEnableCalcUserDateTotal( TRUE );
-								$pf->setEnableCalcException( TRUE );
-
-								if ( $pf->Save() != TRUE ) {
-									Debug::Text(' aFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
 									$fail_transaction = TRUE;
 									break;
-								} else {
-									UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 30, NULL, NULL );
 								}
 							} else {
-								Debug::Text(' bFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
-
-								UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 10, $pf->Validator->getTextErrors(), NULL );
-
+								Debug::Text(' cFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
 								$fail_transaction = TRUE;
 								break;
 							}
 						} else {
-							Debug::Text(' cFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
-
-							UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 10, $pcf->Validator->getTextErrors(), NULL );
+							Debug::Text(' dFail Transaction: ', __FILE__, __LINE__, __METHOD__,10);
+							UserGenericStatusFactory::queueGenericStatus( $user_generic_status_label, 10, $pf->Validator->getTextErrors(), NULL );
 
 							$fail_transaction = TRUE;
 							break;
@@ -719,9 +726,9 @@ switch ($action) {
 						TTLog::addEntry( $current_user->getId(), 500, 'Recalculate Accrual Policy: '. $ap_obj->getName() .' Start Date: '. TTDate::getDate('TIME', $data['start_date']) .' End Date: '. TTDate::getDate('TIME', $data['end_date']) .' Total Days: '. round( $total_days ), $current_user->getId(), $ap_obj->getTable() );
 
 						$x=0;
-						for( $i=$start_date; $i < $end_date; $i+=86400 ) {
-							Debug::Text('Recalculating Accruals for Date: '. TTDate::getDate('DATE+TIME', $i), __FILE__, __LINE__, __METHOD__,10);
-							$ap_obj->addAccrualPolicyTime( $i, $offset );
+						for( $i=$start_date; $i < $end_date; $i+=(86400+3601) ) {
+							Debug::Text('Recalculating Accruals for Date: '. TTDate::getDate('DATE+TIME', TTDate::getBeginDayEpoch( $i ) ), __FILE__, __LINE__, __METHOD__,10);
+							$ap_obj->addAccrualPolicyTime( TTDate::getBeginDayEpoch( $i ), $offset );
 
 							$progress_bar->setValue( Misc::calculatePercent( $x, $total_days ) );
 							$progress_bar->display();
