@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2868 $
- * $Id: Form940.php 2868 2009-10-02 22:48:14Z ipso $
- * $Date: 2009-10-02 15:48:14 -0700 (Fri, 02 Oct 2009) $
+ * $Revision: 3298 $
+ * $Id: Form940.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -88,6 +88,9 @@ $quarter_dates = array(
 						);
 
 //Get a unique list of states each employee belongs to
+$cf = new CompanyFactory();
+$state_options = Misc::prependArray( array( 0 => TTi18n::getText('- Multi-state Employer -') ), $cf->getOptions('province', 'US' ) );
+/*
 $ulf = new UserListFactory();
 $ulf->getByCompanyId( $current_company->getId() );
 if ( $ulf->getRecordCount() > 0 ) {
@@ -95,6 +98,7 @@ if ( $ulf->getRecordCount() > 0 ) {
 		$state_options[$u_obj->getProvince()] = $u_obj->getProvince();
 	}
 }
+*/
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
@@ -266,12 +270,6 @@ switch ($action) {
 					unset($pay_period_ids, $ps_entries);
 				}
 
-				//Calc Annual Total.
-				if ( isset($lines_arr) ) {
-					$lines_arr['total'] = Misc::ArrayAssocSum($lines_arr, NULL, 6);
-					Debug::Arr($lines_arr, 'Lines Array: ', __FILE__, __LINE__, __METHOD__,10);
-				}
-
 				$f940->year = $filter_data['year'];
 				$f940->ein = $current_company->getBusinessNumber();
 				$f940->name = $setup_data['name'];
@@ -301,17 +299,18 @@ switch ($action) {
 
 					$f940->return_type = $return_type_arr;
 				}
-/*
-				if ( count($state_options) > 1 ) {
-					//2006 form doesn't support this yet.
-					$f940->l1b = TRUE;
-				} else {
-					$state = trim( array_shift($state_options) );
-					if ( strlen($state) == 2 ) {
-						$f940->l1a = $state;
+
+				if ( isset($setup_data['state_id']) ) {
+					if ( $setup_data['state_id'] === 0 OR $setup_data['state_id'] == '00' OR $setup_data['state_id'] == '' ) {
+						$f940->l1b = TRUE; //Let them set this manually.
+					} else {
+						if ( strlen($setup_data['state_id']) == 2 ) {
+							$f940->l1a = $setup_data['state_id'];
+						}
 					}
+
 				}
-*/
+
 				//Exempt payment check boxes
 				if ( isset($setup_data['exempt_payment']) AND is_array($setup_data['exempt_payment']) ) {
 					foreach( $setup_data['exempt_payment'] as $return_type ) {
@@ -335,25 +334,36 @@ switch ($action) {
 					}
 				}
 
-				$f940->l3 = $lines_arr['total']['p2_3'];
-				$f940->l4 = $lines_arr['total']['p2_4'];
-				$f940->l5 = $lines_arr['total']['p2_5'];
+				if ( isset($lines_arr) ) {
+					//Calc Annual Total.
+					if ( isset($lines_arr) ) {
+						$lines_arr['total'] = Misc::ArrayAssocSum($lines_arr, NULL, 6);
+						Debug::Arr($lines_arr, 'Lines Array: ', __FILE__, __LINE__, __METHOD__,10);
+					}
 
-				$f940->l13 = $setup_data['tax_deposited'];
 
-				$f940->l15b = TRUE;
+					$f940->l3 = $lines_arr['total']['p2_3'];
+					$f940->l4 = $lines_arr['total']['p2_4'];
+					$f940->l5 = $lines_arr['total']['p2_5'];
 
-				if ( isset($lines_arr[1]['p4_12']) ) {
-					$f940->l16a = $lines_arr[1]['p4_12'];
-				}
-				if ( isset($lines_arr[2]['p4_12']) ) {
-					$f940->l16b = $lines_arr[2]['p4_12'];
-				}
-				if ( isset($lines_arr[3]['p4_12']) ) {
-					$f940->l16c = $lines_arr[3]['p4_12'];
-				}
-				if ( isset($lines_arr[4]['p4_12']) ) {
-					$f940->l16d = $lines_arr[4]['p4_12'];
+					$f940->l10 = $setup_data['line_10'];
+
+					$f940->l13 = $setup_data['tax_deposited'];
+
+					$f940->l15b = TRUE;
+
+					if ( isset($lines_arr[1]['p4_12']) ) {
+						$f940->l16a = $lines_arr[1]['p4_12'];
+					}
+					if ( isset($lines_arr[2]['p4_12']) ) {
+						$f940->l16b = $lines_arr[2]['p4_12'];
+					}
+					if ( isset($lines_arr[3]['p4_12']) ) {
+						$f940->l16c = $lines_arr[3]['p4_12'];
+					}
+					if ( isset($lines_arr[4]['p4_12']) ) {
+						$f940->l16d = $lines_arr[4]['p4_12'];
+					}
 				}
 
 				$gf->addForm( $f940 );
