@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2882 $
- * $Id: FormW2.php 2882 2009-10-07 23:10:54Z ipso $
- * $Date: 2009-10-07 16:10:54 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 3474 $
+ * $Id: FormW2.php 3474 2010-03-31 21:07:06Z ipso $
+ * $Date: 2010-03-31 14:07:06 -0700 (Wed, 31 Mar 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -257,16 +257,16 @@ switch ($action) {
 						if ( isset($tax_deductions) ) {
 							foreach( $tax_deductions as $tax_deduction_arr ) {
 								if ( isset($tax_deduction_arr['user_ids']) AND is_array($tax_deduction_arr['user_ids']) AND in_array( $user_id, $tax_deduction_arr['user_ids'] ) ) {
-									Debug::Text('Found user in Tax Deduction ID: '. $tax_deduction_arr['id'] .' Pay Stub Entry Account ID: '. $tax_deduction_arr['pay_stub_entry_account_id'], __FILE__, __LINE__, __METHOD__,10);
+									Debug::Text('Found User ID: '. $user_id .' in Tax Deduction ID: '. $tax_deduction_arr['id'] .' Pay Stub Entry Account ID: '. $tax_deduction_arr['pay_stub_entry_account_id'], __FILE__, __LINE__, __METHOD__,10);
 
-									if ( $tax_deduction_arr['district'] == '' ) {
+									if ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] == '' ) {
 										//State Wages/Taxes
 										//Handle two states here, just check if $tmp_rows[$x]['state_1'] isset,
 										//if it is, move on to state 2.
 										$tmp_rows[$x]['state_1'] = $tax_deduction_arr['province'];
 										$tmp_rows[$x]['state_wage_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $tax_deduction_arr['include'] ), FALSE );
 										$tmp_rows[$x]['state_tax_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], array($tax_deduction_arr['pay_stub_entry_account_id']) ), FALSE );
-									} else {
+									} elseif ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] != '' )  {
 										//District Wages/Taxes
 										$tmp_rows[$x]['district_1'] = $tax_deduction_arr['district'];
 										$tmp_rows[$x]['district_wage_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $tax_deduction_arr['include'] ), FALSE );
