@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: GeneralLedgerSummary.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3349 $
+ * $Id: GeneralLedgerSummary.php 3349 2010-02-10 17:38:41Z ipso $
+ * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -242,8 +242,8 @@ switch ($action) {
 											$debit_account = replaceGLAccountVariables( $debit_account, $replace_arr);
 											Debug::Text('Debit Entry: Account: '. $debit_account .' Amount: '. $pse_obj->getAmount() , __FILE__, __LINE__, __METHOD__,10);
 
-											//Skip negative amounts completely and Don't include entries that are $0.
-											if ( $pse_obj->getAmount() > 0 ) {
+											//Allow negative amounts, but skip any $0 entries
+											if ( $pse_obj->getAmount() != 0 ) {
 												$raw_je_records[] = array(
 																	'type' => 'debit',
 																	'account' => $debit_account,
@@ -261,10 +261,9 @@ switch ($action) {
 										Debug::Text('Combined Credit Accounts: '. count($credit_accounts) , __FILE__, __LINE__, __METHOD__,10);
 										foreach( $credit_accounts as $credit_account) {
 											$credit_account = replaceGLAccountVariables( $credit_account, $replace_arr);
-											Debug::Text('Credit Entry: Account: '. $credit_account .' Amount: '. $pse_obj->getAmount() , __FILE__, __LINE__, __METHOD__,10);
 
-											//Don't include entries that are $0.
-											if ( $pse_obj->getAmount() > 0 ) {
+											//Allow negative amounts, but skip any $0 entries
+											if ( $pse_obj->getAmount() != 0 ) {
 												$raw_je_records[] = array(
 																	'type' => 'credit',
 																	'account' => $credit_account,
