@@ -316,6 +316,7 @@ switch ($action) {
 					foreach($data_a as $pay_period_id => $data_b ) {
 						$rows[$x]['user_id'] = $user_obj->getId();
 						$rows[$x]['first_name'] = $user_obj->getFirstName();
+						$rows[$x]['middle_name'] = $user_obj->getMiddleName();
 						$rows[$x]['last_name'] = $user_obj->getLastName();
 						$rows[$x]['full_name'] = $user_obj->getFullName(TRUE);
 						$rows[$x]['employee_number'] = $user_obj->getEmployeeNumber();
@@ -440,6 +441,7 @@ switch ($action) {
 
 						break;
 					case 'paychex_preview': //Paychex Preview export format.
+						//Add an advanced PayChex Previous format that supports rates perhaps?
 						$file_name = $setup_data['paychex_preview']['client_number'] .'_TA.txt';
 
 						ksort($setup_data['paychex_preview']['columns']);
@@ -457,7 +459,7 @@ switch ($action) {
 						}
 
 						break;
-					case 'ceridian_insync': //Paychex Preview export format.
+					case 'ceridian_insync': //Ceridian InSync export format.
 						$data = NULL;
 
 						ksort($setup_data['ceridian_insync']['columns']);
@@ -517,6 +519,65 @@ switch ($action) {
 						unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 
 						break;
+					case 'csv': //Generic CSV
+						$data = NULL;
+
+						ksort($setup_data['csv']['columns']);
+						$setup_data['csv']['columns'] = Misc::trimSortPrefix( $setup_data['csv']['columns'] );
+
+						$export_column_map = array('employee' => '', 'employee_number' => '', 'default_branch' => '', 'default_department' => '', 'pay_period' => '', 'hour_code' => '', 'hours' => '');
+
+						$i=0;
+						foreach($rows as $row) {
+							if ( $i == 0 ) {
+								//Include header.
+								$tmp_rows[] = array(
+													'employee' => 'Employee',
+													'employee_number' => 'Employee Number',
+													'default_branch' => 'Default Branch',
+													'default_department' => 'Default Department',
+													'pay_period' => 'Pay Period',
+													'hour_code' => 'Hours Code',
+													'hours' => 'Hours',
+													);
+							}
+
+							//Combine all hours from the same code together.
+							foreach( $setup_data['csv']['columns'] as $column_id => $column_data ) {
+								$hour_code = trim($column_data['hour_code']);
+								if ( isset( $row[$column_id] ) AND $hour_code != '' ) {
+									if ( !isset($tmp_hour_codes[$hour_code]) ) {
+										$tmp_hour_codes[$hour_code] = 0;
+									}
+									$tmp_hour_codes[$hour_code] = bcadd( $tmp_hour_codes[$column_data['hour_code']], $row[$column_id] ); //Use seconds for math here.
+								}
+							}
+
+							if ( isset($tmp_hour_codes) ) {
+								foreach($tmp_hour_codes as $hour_code => $hours ) {
+									$tmp_rows[] = array(
+														'employee' => $row['full_name'],
+														'employee_number' => $row['employee_number'],
+														'default_branch' => $row['default_branch'],
+														'default_department' => $row['default_department'],
+														'pay_period' => $row['pay_period'],
+														'hour_code' => $hour_code,
+														'hours' => TTDate::getTimeUnit($hours, 20 ),
+														);
+								}
+								unset($tmp_hour_codes, $hour_code, $hours);
+							}
+
+							$i++;
+						}
+
+						if ( isset( $tmp_rows) ) {
+							$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE, FALSE );
+						}
+						unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
+
+						break;
+
 					case 'quickbooks': //Quickbooks Pro export format.
 						$file_name = 'payroll_export.iif';
 
@@ -526,14 +587,32 @@ switch ($action) {
 						//
 						// Quickbooks header
 						//
-						$data = '!TIMERHDR	VER	REL	COMPANYNAME	IMPORTEDBEFORE	FROMTIMER	COMPANYCREATETIME'."\n";
-						$data .= 'TIMERHDR	 8	 0	'. trim($setup_data['quickbooks']['company_name']) .'	N	Y	'. trim($setup_data['quickbooks']['company_created_date']) ."\n";
-						$data .= '!TIMEACT	DATE	JOB	EMP	ITEM	PITEM	DURATION	PROJ	NOTE	XFERTOPAYROLL	BILLINGSTATUS'."\n";
+						/*
+							Company Create Time can be found by first running an Timer Activity export in QuickBooks and viewing the output.
+
+							PITEM field needs to be populated, as that is the PAYROLL ITEM in quickbooks. It can be the same as the ITEM field.
+							PROJ could be mapped to the default department/branch?
+						*/
+						$data =  "!TIMERHDR\tVER\tREL\tCOMPANYNAME\tIMPORTEDBEFORE\tFROMTIMER\tCOMPANYCREATETIME\n";
+						$data .= "TIMERHDR\t8\t0\t". trim($setup_data['quickbooks']['company_name']) ."\tN\tY\t". trim($setup_data['quickbooks']['company_created_date']) ."\n";
+						$data .= "!TIMEACT\tDATE\tJOB\tEMP\tITEM\tPITEM\tDURATION\tPROJ\tNOTE\tXFERTOPAYROLL\tBILLINGSTATUS\n";
 
 						foreach($rows as $row) {
 							foreach( $setup_data['quickbooks']['columns'] as $column_id => $column_data ) {
 								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
-									$data .= 'TIMEACT	'. date('n/j/y', $row['pay_period_end_date']).'		'. $row['first_name'].'  '. $row['last_name'].'		'. trim($column_data['hour_code']) .'	'.  TTDate::getTimeUnit( $row[$column_id], 10 ) .'			Y	0'."\n";
+									//Make sure employee name is in format: LastName, FirstName MiddleInitial
+									$tmp_employee_name = $row['last_name'].', '. $row['first_name'];
+									if ( isset($row['middle_name']) AND strlen($row['middle_name']) > 0 ) {
+										$tmp_employee_name .= ' '.substr(trim($row['middle_name']),0,1);
+									}
+
+									$proj = NULL;
+									if ( isset($row[$setup_data['quickbooks']['proj']]) ) {
+										$proj = $row[$setup_data['quickbooks']['proj']];
+									}
+
+									$data .= "TIMEACT\t". date('n/j/y', $row['pay_period_end_date'])."\t\t". $tmp_employee_name ."\t". trim($column_data['hour_code']) ."\t". trim($column_data['hour_code']) ."\t".  TTDate::getTimeUnit( $row[$column_id], 10 ) ."\t". $proj ."\t\tY\t0\n";
+									unset($tmp_employee_name);
 								}
 							}
 						}
@@ -711,6 +790,7 @@ switch ($action) {
 													'millenium' => TTi18n::gettext('Millenium'),
 													'quickbooks' => TTi18n::gettext('QuickBooks Pro'),
 													'surepayroll' => TTi18n::gettext('SurePayroll'),
+													'csv' => TTi18n::gettext('Generic Excel/CSV'),
 													'other' => TTi18n::gettext('-- Other --'),
 													);
 
@@ -726,6 +806,15 @@ switch ($action) {
 			$setup_data['adp_hour_column_options'][$i] = TTi18n::gettext('Hours') .' '. $i;
 		}
 
+		//Quickbooks additional column mapping
+		$setup_data['quickbooks_proj_options'] = array(
+													0 => TTi18n::gettext('-- NONE --'),
+													'default_branch' => TTi18n::gettext('Default Branch'),
+													'default_department' => TTi18n::gettext('Default Department'),
+													'group' => TTi18n::gettext('Group'),
+													'title' => TTi18n::gettext('Title'),
+													);
+
 		$saved_report_options = $ugdlf->getByUserIdAndScriptArray( $current_user->getId(), $_SERVER['SCRIPT_NAME']);
 		$generic_data['saved_report_options'] = $saved_report_options;
 		$smarty->assign_by_ref('generic_data', $generic_data);
