@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: PunchSummary.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: PunchSummary.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -49,7 +49,7 @@ if ( !$permission->Check('report','enabled')
 $smarty->assign('title', TTi18n::gettext($title = 'Punch Summary Report')); // See index.php
 
 //User Wage cache array.
-function getUserWageObject( $user_wage_id ) {
+function getUserWageObject( $user_wage_id, $user_id ) {
 	global $user_wage_obj;
 
 	if ( isset($user_wage_obj[$user_wage_id])
@@ -59,7 +59,7 @@ function getUserWageObject( $user_wage_id ) {
 		$uwlf = new UserWageListFactory();
 
 		//This handles future wage changes properly.
-		$uwlf->getByID( $user_wage_id );
+		$uwlf->getByIDAndUserId( $user_wage_id, $user_id );
 		if ( $uwlf->getRecordCount() > 0 ) {
 			$user_wage_obj[$user_wage_id] = $uwlf->getCurrent();
 
@@ -193,9 +193,10 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
+$wage_permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
 	if ( $permission->Check('punch','view_child') == FALSE ) {
@@ -208,6 +209,18 @@ if ( $permission->Check('punch','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -282,9 +295,11 @@ switch ($action) {
 				if ( !isset($tmp_rows[$p_obj->getColumn('pay_period_id')][$p_obj->getColumn('user_id')][$p_obj->getColumn('punch_control_id')]) ) {
 
 					$hourly_rate = 0;
-					$uw_obj = getUserWageObject( $p_obj->getColumn('user_wage_id') );
-					if ( is_object($uw_obj) ) {
-						$hourly_rate = $uw_obj->getHourlyRate();
+					if ( $permission->Check('wage','view') == TRUE OR in_array( $p_obj->getColumn('user_id'), $wage_filter_data['permission_children_ids']) == TRUE ) {
+						$uw_obj = getUserWageObject( $p_obj->getColumn('user_wage_id'), $p_obj->getColumn('user_id') );
+						if ( is_object($uw_obj) ) {
+							$hourly_rate = $uw_obj->getHourlyRate();
+						}
 					}
 
 					$actual_time_diff = (int)$p_obj->getColumn('actual_total_time') - (int)$p_obj->getColumn('total_time');
