@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2906 $
- * $Id: TimesheetDetail.php 2906 2009-10-16 21:41:04Z ipso $
- * $Date: 2009-10-16 14:41:04 -0700 (Fri, 16 Oct 2009) $
+ * $Revision: 3628 $
+ * $Id: TimesheetDetail.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -173,9 +173,10 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
+$wage_permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
 	if ( $permission->Check('punch','view_child') == FALSE ) {
@@ -188,6 +189,18 @@ if ( $permission->Check('punch','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -273,12 +286,12 @@ switch ($action) {
 					$i=0;
 					foreach ( $filter_data['pay_period_ids'] as $tmp_pay_period_id ) {
 						$tmp_pay_period_id = Misc::trimSortPrefix($tmp_pay_period_id);
-						if ( $i == 0 ) {
+						if ( $i == 0 AND isset($pay_period_end_dates[$tmp_pay_period_id]) ) {
+							$end_date = $pay_period_end_dates[$tmp_pay_period_id];
+						} elseif ( isset($pay_period_end_dates[$tmp_pay_period_id]) AND $pay_period_end_dates[$tmp_pay_period_id] > $end_date ) {
 							$end_date = $pay_period_end_dates[$tmp_pay_period_id];
 						} else {
-							if ( $pay_period_end_dates[$tmp_pay_period_id] > $end_date ) {
-								$end_date = $pay_period_end_dates[$tmp_pay_period_id];
-							}
+							$end_date = time();
 						}
 
 						$i++;
@@ -288,8 +301,13 @@ switch ($action) {
 			} else {
 				$end_date = $filter_data['end_date'];
 			}
+
+            //Make sure we account for wage permissions.
+            if ( $permission->Check('wage','view') == TRUE ) {
+                $wage_filter_data['permission_children_ids'] = $filter_data['user_id'];
+            }
 			$uwlf = new UserWageListFactory();
-			$uwlf->getLastWageByUserIdAndDate( $filter_data['user_id'], $end_date );
+			$uwlf->getLastWageByUserIdAndDate( $wage_filter_data['permission_children_ids'], $end_date );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
 					$user_wage[$uw_obj->getUser()] = $uw_obj->getBaseCurrencyHourlyRate( $uw_obj->getHourlyRate() );
@@ -511,7 +529,7 @@ switch ($action) {
 							if ( $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 50 ) {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Yes');
 								$rows[$i]['verified_time_sheet_date'] = $verified_time_sheets[$user_id][$pay_period_id]['created_date'];
-							} elseif ( $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 30 ) {
+							} elseif ( $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 30 OR $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 45 ) {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Pending');
 							} else {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Declined');
@@ -1343,7 +1361,7 @@ switch ($action) {
 
 			}
 		}
-		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
+		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'punch_branch_ids', 'punch_department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
 
 		$ulf = new UserListFactory();
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
@@ -1377,6 +1395,9 @@ switch ($action) {
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
+		$filter_data['src_punch_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['punch_branch_ids'], $branch_options );
+		$filter_data['selected_punch_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_branch_ids'], $branch_options );
+
 		//Get departments
 		$dlf = new DepartmentListFactory();
 		$dlf->getByCompanyId( $current_company->getId() );
@@ -1384,6 +1405,9 @@ switch ($action) {
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
+		$filter_data['src_punch_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['punch_department_ids'], $department_options );
+		$filter_data['selected_punch_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_department_ids'], $department_options );
+
 		//Get employee titles
 		$utlf = new UserTitleListFactory();
 		$utlf->getByCompanyId( $current_company->getId() );
