@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: TimesheetSummary.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 3628 $
+ * $Id: TimesheetSummary.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -86,8 +86,8 @@ $columns = array(					'-1070-schedule_working' => TTi18n::gettext('Scheduled Tim
 									'-1085-worked_days' => TTi18n::gettext('Worked Days'),
 									'-1090-worked_time' => TTi18n::gettext('Worked Time'),
 									'-1100-actual_time' => TTi18n::gettext('Actual Time'),
-									'-1110-actual_time_diff' => TTi18n::gettext('Actual Time Diff.'),
-									'-1120-actual_time_diff_wage' => TTi18n::gettext('Actual Time Diff. Wage'),
+									'-1110-actual_time_diff' => TTi18n::gettext('Actual Time Difference'),
+									'-1120-actual_time_diff_wage' => TTi18n::gettext('Actual Time Difference Wage'),
 									'-1130-paid_time' => TTi18n::gettext('Paid Time'),
 									'-1140-regular_time' => TTi18n::gettext('Regular Time'),
 									);
@@ -166,9 +166,10 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
+$wage_permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
 	if ( $permission->Check('punch','view_child') == FALSE ) {
@@ -181,6 +182,18 @@ if ( $permission->Check('punch','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -254,8 +267,12 @@ switch ($action) {
 				$end_date = $filter_data['end_date'];
 			}
 
+            //Make sure we account for wage permissions.
+            if ( $permission->Check('wage','view') == TRUE ) {
+                $wage_filter_data['permission_children_ids'] = $filter_data['user_id'];
+            }
 			$uwlf = new UserWageListFactory();
-			$uwlf->getLastWageByUserIdAndDate( $filter_data['user_id'], $end_date );
+			$uwlf->getLastWageByUserIdAndDate( $wage_filter_data['permission_children_ids'], $end_date );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
 					$user_wage[$uw_obj->getUser()] = $uw_obj->getBaseCurrencyHourlyRate( $uw_obj->getHourlyRate() );
@@ -434,7 +451,7 @@ switch ($action) {
 						if ( $verified_time_sheets !== NULL AND isset($verified_time_sheets[$user_id][$pay_period_id]) ) {
 							if ( $verified_time_sheets[$user_id][$pay_period_id] == 50 ) {
 								$rows[$x]['verified_time_sheet'] = TTi18n::gettext('Yes');
-							} elseif ( $verified_time_sheets[$user_id][$pay_period_id] == 30 ) {
+							} elseif ( $verified_time_sheets[$user_id][$pay_period_id] == 30 OR $verified_time_sheets[$user_id][$pay_period_id] == 45 ) {
 								$rows[$x]['verified_time_sheet'] = TTi18n::gettext('Pending');
 							} else {
 								$rows[$x]['verified_time_sheet'] = TTi18n::gettext('Declined');
@@ -601,7 +618,7 @@ switch ($action) {
 				$filter_data['secondary_sort_dir'] = '-1';
 			}
 		}
-		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
+		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'punch_branch_ids', 'punch_department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
 
 		$ulf = new UserListFactory();
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
@@ -635,6 +652,9 @@ switch ($action) {
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
+		$filter_data['src_punch_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['punch_branch_ids'], $branch_options );
+		$filter_data['selected_punch_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_branch_ids'], $branch_options );
+
 		//Get departments
 		$dlf = new DepartmentListFactory();
 		$dlf->getByCompanyId( $current_company->getId() );
@@ -642,6 +662,9 @@ switch ($action) {
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
+		$filter_data['src_punch_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['punch_department_ids'], $department_options );
+		$filter_data['selected_punch_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_department_ids'], $department_options );
+
 		//Get employee titles
 		$utlf = new UserTitleListFactory();
 		$utlf->getByCompanyId( $current_company->getId() );
