@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2682 $
- * $Id: UserDetail.php 2682 2009-07-23 22:31:20Z ipso $
- * $Date: 2009-07-23 15:31:20 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 3562 $
+ * $Id: UserDetail.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -89,7 +89,7 @@ $static_columns = array(
 											'-1030-country' => TTi18n::gettext('Country'),
 											'-1040-default_branch' => TTi18n::gettext('Default Branch'),
 											'-1050-default_department' => TTi18n::gettext('Default Department'),
-											'-1060-verified_time_sheet' => TTi18n::gettext('Verified TimeSheet'),
+											//'-1060-verified_time_sheet' => TTi18n::gettext('Verified TimeSheet'),
 											);
 
 //$columns = Misc::prependArray( $columns, $deduction_columns);
@@ -129,9 +129,10 @@ if ( !isset($filter_data['column_ids']) ) {
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
+$wage_permission_children_ids = array();
 if ( $permission->Check('user','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
 	if ( $permission->Check('user','view_child') == FALSE ) {
@@ -144,6 +145,18 @@ if ( $permission->Check('user','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -157,17 +170,6 @@ switch ($action) {
 
 		$ulf = new UserListFactory();
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
-		/*
-		$ulf->getSearchByCompanyIdAndStatusIdAndBranchIdAndDepartmentIdAndUserTitleIdAndIncludeIdAndExcludeId(
-			$current_company->getId(),
-			$filter_data['user_status_ids'],
-			$filter_data['branch_ids'],
-			$filter_data['department_ids'],
-			$filter_data['user_title_ids'],
-			$filter_data['include_user_ids'],
-			$filter_data['exclude_user_ids'] );
-		*/
-
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
 				$filter_data['user_ids'][] = $u_obj->getId();
@@ -190,8 +192,11 @@ switch ($action) {
 
 			*/
 			if ( isset($columns['wage']) ) {
+				if ( $permission->Check('wage','view') == TRUE ) {
+					$wage_filter_data['permission_children_ids'] = $filter_data['user_ids'];
+				}
 				$uwlf = new UserWageListFactory();
-				$uwlf->getByUserIdAndCompanyIdAndStartDateAndEndDate( $filter_data['user_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
+				$uwlf->getByUserIdAndCompanyIdAndStartDateAndEndDate( $wage_filter_data['permission_children_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
 				if ( $uwlf->getRecordCount() > 0 ) {
 					foreach( $uwlf as $uw_obj ) {
 						$user_wage_rows[$uw_obj->getUser()][] = array(
@@ -206,7 +211,6 @@ switch ($action) {
 				}
 			}
 
-
 			/*
 
 				Get Attendance History
