@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: UserInformation.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3562 $
+ * $Id: UserInformation.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -179,9 +179,11 @@ $columns = Misc::prependArray( $columns, $deduction_columns);
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
+$wage_permission_children_ids = array();
 if ( $permission->Check('user','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
 	if ( $permission->Check('user','view_child') == FALSE ) {
 		$permission_children_ids = array();
@@ -193,6 +195,18 @@ if ( $permission->Check('user','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -262,8 +276,12 @@ switch ($action) {
 			$start_week_day_options = $upf->getOptions('start_week_day');
 			$time_zone_options = $upf->getOptions('time_zone');
 
+            //Make sure we account for wage permissions.
+            if ( $permission->Check('wage','view') == TRUE ) {
+                $wage_filter_data['permission_children_ids'] = $filter_data['user_ids'];
+            }
 			$uwlf = new UserWageListFactory();
-			$uwlf->getLastWageByUserIdAndDate( $filter_data['user_ids'], TTDate::getTime() );
+			$uwlf->getLastWageByUserIdAndDate( $wage_filter_data['permission_children_ids'], TTDate::getTime() );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
 					$user_wage[$uw_obj->getUser()] = array(
@@ -271,10 +289,8 @@ switch ($action) {
 															'type' => Option::getByKey($uw_obj->getType(), $uw_obj->getOptions('type') ),
 															'wage' => $uw_obj->getWage(),
 															'effective_date' => $uw_obj->getEffectiveDate(),
-															//'effective_date' => TTDate::getDate('DATE', $uw_obj->getEffectiveDate() )
 															);
 				}
-				//var_dump($user_wage);
 			}
 
 			$udlf = new UserDeductionListFactory();
