@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2882 $
- * $Id: EditROE.php 2882 2009-10-07 23:10:54Z ipso $
- * $Date: 2009-10-07 16:10:54 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 3415 $
+ * $Id: EditROE.php 3415 2010-03-12 22:31:26Z ipso $
+ * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -135,6 +135,12 @@ switch ($action) {
 			} else {
 				$roef->setEnableGeneratePayStub( FALSE );
 			}
+			if ( isset($roe_data['release_accruals']) AND $roe_data['release_accruals'] == 1 ) {
+				$roef->setEnableReleaseAccruals(TRUE );
+			} else {
+				$roef->setEnableReleaseAccruals( FALSE );
+			}
+
 			$roef->Save();
 
 			$ugsf = new UserGenericStatusFactory();
