@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2753 $
- * $Id: RecurringScheduleTemplateControlList.php 2753 2009-08-27 00:18:14Z ipso $
- * $Date: 2009-08-26 17:18:14 -0700 (Wed, 26 Aug 2009) $
+ * $Revision: 3628 $
+ * $Id: RecurringScheduleTemplateControlList.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -119,6 +119,8 @@ switch ($action) {
 
 				$rstc_obj->setId(FALSE);
 				$rstc_obj->setName( Misc::generateCopyName( $rstc_obj->getName() ) );
+				$rstc_obj->setCreatedBy( $current_user->getId() ); //Make sure the created by are changed to the current user.
+				$rstc_obj->setCreatedDate( time() );
 				if ( $rstc_obj->isValid() ) {
 					$rstc_id = $rstc_obj->Save();
 
