@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2681 $
- * $Id: ViewScheduleLinear.php 2681 2009-07-23 22:30:39Z ipso $
- * $Date: 2009-07-23 15:30:39 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 3298 $
+ * $Id: ViewScheduleLinear.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -164,7 +164,7 @@ switch ($do) {
 						Debug::text(' aSchedule Spans the Day boundary!', __FILE__, __LINE__, __METHOD__,10);
 						$day_schedule_shift['span_day'] = TRUE;
 						$min_hour = 0;
-						$max_hour = 24;
+						$max_hour = 23;
 					}
 
 					if ( $day_schedule_shift['span_day'] == TRUE ) {
@@ -177,7 +177,7 @@ switch ($do) {
 						$tmp_schedule_shift_day2['span_day_split'] = FALSE;
 
 						$tmp_schedule_shifts[$day_epoch][$day_schedule_shift['branch']][$day_schedule_shift['department']][$day_schedule_shift['user_id']][] = $tmp_schedule_shift_day1;
-						$tmp_schedule_shifts[$tmp_schedule_shift_day2['start_time']][$day_schedule_shift['branch']][$day_schedule_shift['department']][$day_schedule_shift['user_id']][] = $tmp_schedule_shift_day2;
+						$tmp_schedule_shifts[TTDate::getISODateStamp($tmp_schedule_shift_day2['start_time'])][$day_schedule_shift['branch']][$day_schedule_shift['department']][$day_schedule_shift['user_id']][] = $tmp_schedule_shift_day2;
 
 						Debug::text(' Shift SPans the Day Boundary: First End Date: '. TTDate::getDate('DATE+TIME', $tmp_schedule_shift_day1['end_time'] ) .' Second Start Date: '. TTDate::getDate('DATE+TIME', $tmp_schedule_shift_day2['start_time'] ) , __FILE__, __LINE__, __METHOD__,10);
 					} else {
@@ -210,7 +210,7 @@ switch ($do) {
 		$total_span_hours = 1;
 		if ( isset($schedule_shift_totals) ) {
 			//Find out how many hours to span
-			$total_span_hours = abs($max_hour - $min_hour);
+			$total_span_hours = abs($max_hour - $min_hour)+1;
 			Debug::text(' Total Hours Span: '. $total_span_hours, __FILE__, __LINE__, __METHOD__,10);
 
 			if ( $min_hour > $max_hour) {
@@ -223,7 +223,7 @@ switch ($do) {
 
 
 			//Generate smarty array for table header
-			for($i=$tmp_min_hour; $i < $tmp_max_hour; $i++) {
+			for($i=$tmp_min_hour; $i <= $tmp_max_hour; $i++) {
 				$header_hours[] = array('hour' => TTDate::getTimeStamp( "","","", $i ) );
 			}
 			unset($tmp_min_hour, $tmp_max_hour);
