@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: ViewUserTimeSheet.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3562 $
+ * $Id: ViewUserTimeSheet.php 3562 2010-05-07 00:03:34Z ipso $
+ * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -330,26 +330,25 @@ switch ($action) {
 		Debug::text('Verifying Pay Period TimeSheet ', __FILE__, __LINE__, __METHOD__,10);
 
 		$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+		$pptsvlf->StartTransaction();
 		$pptsvlf->getByPayPeriodIdAndUserId( $pay_period_obj->getId(), $user_id );
 		if ( $pptsvlf->getRecordCount() == 0 ) {
 			Debug::text('Timesheet NOT verified by employee yet.', __FILE__, __LINE__, __METHOD__,10);
 			$pptsvf = new PayPeriodTimeSheetVerifyFactory();
 		} else {
-			Debug::text('Timesheet re-verified by employee...', __FILE__, __LINE__, __METHOD__,10);
+			Debug::text('Timesheet re-verified by employee, or superior...', __FILE__, __LINE__, __METHOD__,10);
 			$pptsvf = $pptsvlf->getCurrent();
 		}
 
+		$pptsvf->setCurrentUser( $current_user->getId() );
 		$pptsvf->setUser( $user_id );
 		$pptsvf->setPayPeriod( $pay_period_id );
 
-		//With the new hierarchy system there will never be a case where the timesheet verification can be immiedately authorized
-		//as we can only determine hierarchies based on subordinates now.
-		$pptsvf->setStatus(30); //Pending Auth
-		$pptsvf->setAuthorized( FALSE );
-
 		if ( $pptsvf->isValid() ) {
 			$pptsvf->Save();
 		}
+		//$pptsvlf->FailTransaction();
+		$pptsvlf->CommitTransaction();
 
 		Redirect::Page( URLBuilder::getURL( NULL, '../timesheet/ViewUserTimeSheet.php') );
 
@@ -413,7 +412,7 @@ switch ($action) {
 		Debug::Text('Done Calculating Pay Stub', __FILE__, __LINE__, __METHOD__,10);
 
 		//Redirect::Page( URLBuilder::getURL( array('filter_user_id' => $filter_data['user_id'], 'filter_date' => $filter_date ), '../timesheet/ViewUserTimeSheet.php') );
-		Redirect::Page( URLBuilder::getURL( array('user_id' => $filter_data['user_id'] ), '../pay_stub_amendment/PayStubAmendmentList.php') );
+		Redirect::Page( URLBuilder::getURL( array('filter_user_id' => $filter_data['user_id'] ), '../pay_stub_amendment/PayStubAmendmentList.php') );
 
 		break;
 	case 'recalculate_company':
@@ -486,7 +485,7 @@ switch ($action) {
 							if (  $punch_obj->getType() == 20 ) {
 								$break_name = TTi18n::gettext('Lunch Time');
 							} else {
-								$break_name = TTi18n::gettext('Break Time');;
+								$break_name = TTi18n::gettext('Break Time');
 							}
 
 							$date_break_totals[$user_date_stamp][$punch_obj->getType()] = array(
@@ -1292,51 +1291,43 @@ switch ($action) {
 
 		*/
 		if ( isset($pay_period_obj) AND is_object($pay_period_obj) ) {
+			$is_timesheet_superior = FALSE;
 			$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
 			$pptsvlf->getByPayPeriodIdAndUserId( $pay_period_obj->getId(), $user_id );
+
 			if ( $pptsvlf->getRecordCount() > 0 ) {
 				$pptsv_obj = $pptsvlf->getCurrent();
-
-				$time_sheet_verify = array(
-										'id' => $pptsv_obj->getId(),
-										'status_id' => $pptsv_obj->getStatus(),
-										'status' => Option::getByKey( $pptsv_obj->getStatus(), $pptsv_obj->getOptions('status') ),
-										'pay_period_id' => $pptsv_obj->getPayPeriod(),
-										'user_id' => $pptsv_obj->getUser(),
-										'created_date' => $pptsv_obj->getCreatedDate(),
-										'created_by' => $pptsv_obj->getCreatedBy(),
-										'updated_date' => $pptsv_obj->getUpdatedDate(),
-										'updated_by' => $pptsv_obj->getUpdatedBy(),
-										'deleted_date' => $pptsv_obj->getDeletedDate(),
-										'deleted_by' => $pptsv_obj->getDeletedBy()
-										);
-			}
-
-			//Check if previous pay period was verified or not
-			$is_previous_time_sheet_verified = FALSE;
-
-			$pplf = new PayPeriodListFactory();
-			$pplf->getPreviousPayPeriodById( $pay_period_obj->getId() );
-			if ( $pplf->getRecordCount() > 0 ) {
-				$previous_pay_period_obj = $pplf->getCurrent();
-
-				if ( $previous_pay_period_obj->getStatus() == 20 ) {
-					$is_previous_time_sheet_verified = TRUE;
-				} else {
-					$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
-					$pptsvlf->getByPayPeriodIdAndUserId( $previous_pay_period_obj->getId(), $user_id );
-					if ( $pptsvlf->getRecordCount() > 0 ) {
-						$pptsv_obj = $pptsvlf->getCurrent();
-						if ( $pptsv_obj->getAuthorized() == TRUE ) {
-							$is_previous_time_sheet_verified = TRUE;
-						}
-					}
-				}
+				$pptsv_obj->setCurrentUser( $current_user->getId() );
 			} else {
-				$is_previous_time_sheet_verified = TRUE; //There is no previous pay period
+				$pptsv_obj = $pptsvlf;
+				$pptsv_obj->setCurrentUser( $current_user->getId() );
+				$pptsv_obj->setUser( $user_id );
+				$pptsv_obj->setPayPeriod( $pay_period_obj->getId() );
+				//$pptsv_obj->setStatus( 45 ); //Pending Verification
 			}
 
-			unset($previous_pay_period_obj, $pptsvlf, $pptsv_obj, $pplf);
+			$time_sheet_verify = array(
+									'id' => $pptsv_obj->getId(),
+									'user_verified' => $pptsv_obj->getUserVerified(),
+									'user_verified_date' => $pptsv_obj->getUserVerifiedDate(),
+									'status_id' => $pptsv_obj->getStatus(),
+									'status' => Option::getByKey( $pptsv_obj->getStatus(), $pptsv_obj->getOptions('status') ),
+									'pay_period_id' => $pptsv_obj->getPayPeriod(),
+									'user_id' => $pptsv_obj->getUser(),
+									'authorized' => $pptsv_obj->getAuthorized(),
+									'authorized_users' => $pptsv_obj->getAuthorizedUsers(),
+									'is_hierarchy_superior' => $pptsv_obj->isHierarchySuperior(),
+									'display_verify_button' => $pptsv_obj->displayVerifyButton(),
+									'verification_box_color' => $pptsv_obj->getVerificationBoxColor(),
+									'verification_status_display' => $pptsv_obj->getVerificationStatusDisplay(),
+									'previous_pay_period_verification_display' => $pptsv_obj->displayPreviousPayPeriodVerificationNotice(),
+									'created_date' => $pptsv_obj->getCreatedDate(),
+									'created_by' => $pptsv_obj->getCreatedBy(),
+									'updated_date' => $pptsv_obj->getUpdatedDate(),
+									'updated_by' => $pptsv_obj->getUpdatedBy(),
+									'deleted_date' => $pptsv_obj->getDeletedDate(),
+									'deleted_by' => $pptsv_obj->getDeletedBy()
+									);
 		}
 
 		//Get pay period totals
@@ -1408,7 +1399,6 @@ switch ($action) {
 		$smarty->assign_by_ref('pay_period_paid_absence_total_time', $paid_absence_total_time);
 		$smarty->assign_by_ref('pay_period_dock_absence_total_time', $dock_absence_total_time);
 		$smarty->assign_by_ref('time_sheet_verify', $time_sheet_verify);
-		$smarty->assign_by_ref('is_previous_time_sheet_verified', $is_previous_time_sheet_verified);
 
 		$is_assigned_pay_period_schedule = FALSE;
 		if ( isset($pay_period_obj) AND is_object($pay_period_obj) ) {
@@ -1420,6 +1410,7 @@ switch ($action) {
 			$smarty->assign('pay_period_id', $pay_period_obj->getId() );
 			$smarty->assign('pay_period_start_date', $pay_period_obj->getStartDate() );
 			$smarty->assign('pay_period_end_date', $pay_period_obj->getEndDate() );
+			$smarty->assign('pay_period_verify_type_id', $pay_period_obj->getTimeSheetVerifyType() );
 			$smarty->assign('pay_period_verify_window_start_date', $pay_period_obj->getTimeSheetVerifyWindowStartDate() );
 			$smarty->assign('pay_period_verify_window_end_date', $pay_period_obj->getTimeSheetVerifyWindowEndDate() );
 			$smarty->assign('pay_period_transaction_date', $pay_period_obj->getTransactionDate() );
