@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3091 $
- * $Id: UserList.php 3091 2009-11-18 18:00:31Z ipso $
- * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
+ * $Revision: 3470 $
+ * $Id: UserList.php 3470 2010-03-30 19:21:29Z ipso $
+ * $Date: 2010-03-30 12:21:29 -0700 (Tue, 30 Mar 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -295,7 +295,7 @@ switch ($action) {
 									'home_email' => $u_obj->getHomeEmail(),
 									'work_email' => $u_obj->getWorkEmail(),
 									'birth_date' => TTDate::getDate('DATE', $u_obj->getBirthDate() ),
-									'sin' => $u_obj->getSIN(),
+									'sin' => $u_obj->getSecureSIN(),
 									'hire_date' => TTDate::getDate('DATE', $u_obj->getHireDate() ),
 									'termination_date' => TTDate::getDate('DATE', $u_obj->getTerminationDate() ),
 
