@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2894 $
- * $Id: AddRecurringScheduleShift.php 2894 2009-10-13 18:35:51Z ipso $
- * $Date: 2009-10-13 11:35:51 -0700 (Tue, 13 Oct 2009) $
+ * $Revision: 3310 $
+ * $Id: AddRecurringScheduleShift.php 3310 2010-01-21 16:35:23Z ipso $
+ * $Date: 2010-01-21 08:35:23 -0800 (Thu, 21 Jan 2010) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -109,7 +109,7 @@ if ( $clf->getRecordCount() > 0 ) {
 								Debug::text('Skipping User due to hire/termination date...'. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 								continue; //Skip user.
 							}
-							
+
 							//Set the timezone before getting the recurring schedule shifts
 							//so we prevent timezone issues and DST issues from arising.
 							$recurring_schedule_days = $rsc_obj->getShiftsByStartDateAndEndDate( $start_date, $end_date );
@@ -355,7 +355,7 @@ if ( $clf->getRecordCount() > 0 ) {
 									}
 								}
 							} else {
-								Debug::text('No Recurring Schedule Days To Add!'. $user_id, __FILE__, __LINE__, __METHOD__, 10);
+								Debug::text('No Recurring Schedule Days To Add! User ID: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 							}
 
 							//Set timezone back to default before we loop to the next user.
