@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3041 $
- * $Id: DateTimeTest.php 3041 2009-11-12 19:34:13Z ipso $
- * $Date: 2009-11-12 11:34:13 -0800 (Thu, 12 Nov 2009) $
+ * $Revision: 3298 $
+ * $Id: DateTimeTest.php 3298 2010-01-20 18:52:46Z ipso $
+ * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -273,10 +273,11 @@ class DateTimeTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( TTDate::parseDateTime('02-25-05 18:09'), 1109383740 );
 		$this->assertEquals( TTDate::parseDateTime('02-25-05 18:09 EST'), 1109372940 );
 
-		//Try test before 1970, like 1920
-		$this->assertEquals( TTDate::parseDateTime('02-25-20'), -1573142400 );
-		$this->assertEquals( TTDate::parseDateTime('02-25-20 8:09PM'), -1573069860);
-		$this->assertEquals( TTDate::parseDateTime('02-25-20 8:09 AM'), -1573113060 );
+		//Try test before 1970, like 1920 - *1920 fails after 2010 has passed, try a different value.
+
+		$this->assertEquals( TTDate::parseDateTime('02-25-55'), -468604800 );
+		$this->assertEquals( TTDate::parseDateTime('02-25-55 8:09PM'), -468532260 );
+		$this->assertEquals( TTDate::parseDateTime('02-25-55 8:09 AM'), -468575460 );
 
 	}
 
@@ -615,5 +616,62 @@ class DateTimeTest extends PHPUnit_Framework_TestCase {
 		$date1 = strtotime('09-Jan-10 12:00PM');
 		$this->assertEquals( TTDate::getWeek( $date1, 6), 1 );
 	}
+
+	function test_getNearestWeekDay() {
+/*
+				case 0: //No adjustment
+					break 2;
+				case 1: //Previous day
+					$epoch -= 86400;
+					break;
+				case 2: //Next day
+					$epoch += 86400;
+					break;
+				case 3: //Closest day
+
+*/
+
+		$date1 = strtotime('16-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 0 ), strtotime('16-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 1 ), strtotime('15-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 2 ), strtotime('18-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3 ), strtotime('15-Jan-2010 12:00PM') );
+
+		$date2 = strtotime('17-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date2, 3 ), strtotime('18-Jan-2010 12:00PM') );
+
+		$holidays = array(
+						TTDate::getBeginDayEpoch( strtotime('15-Jan-2010') )
+						);
+		$date1 = strtotime('16-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3, $holidays ), strtotime('14-Jan-2010 12:00PM') );
+
+		$holidays = array(
+						TTDate::getBeginDayEpoch( strtotime('15-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('14-Jan-2010') )
+						);
+		$date1 = strtotime('16-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 1, $holidays ), strtotime('13-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3, $holidays ), strtotime('18-Jan-2010 12:00PM') );
+
+		$holidays = array(
+						TTDate::getBeginDayEpoch( strtotime('15-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('14-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('18-Jan-2010') )
+						);
+		$date1 = strtotime('16-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 1, $holidays ), strtotime('13-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3, $holidays ), strtotime('13-Jan-2010 12:00PM') );
+
+		$holidays = array(
+						TTDate::getBeginDayEpoch( strtotime('15-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('14-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('13-Jan-2010') ),
+						TTDate::getBeginDayEpoch( strtotime('18-Jan-2010') )
+						);
+		$date1 = strtotime('16-Jan-2010 12:00PM');
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 1, $holidays ), strtotime('12-Jan-2010 12:00PM') );
+		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3, $holidays ), strtotime('19-Jan-2010 12:00PM') );
+	}
 }
 ?>
\ No newline at end of file
