@@ -189,8 +189,7 @@ class OverTimePolicyTest extends PHPUnit_Framework_TestCase {
 		$ppsf->setType( 20 );
 		$ppsf->setStartWeekDay( 0 );
 
-
-		$anchor_date = TTDate::getBeginWeekEpoch( TTDate::getBeginYearEpoch() ); //Start 6 weeks ago
+		$anchor_date = TTDate::getBeginWeekEpoch( ( TTDate::getBeginYearEpoch( time() )-(86400*(7*6) ) ) ); //Start 6 weeks ago
 
 		$ppsf->setAnchorDate( $anchor_date );
 
@@ -235,7 +234,7 @@ class OverTimePolicyTest extends PHPUnit_Framework_TestCase {
 			for ( $i = 0; $i < $max_pay_periods; $i++ ) {
 				if ( $i == 0 ) {
 					//$end_date = TTDate::getBeginYearEpoch( strtotime('01-Jan-07') );
-					$end_date = TTDate::getBeginYearEpoch( time() );
+					$end_date = TTDate::getBeginWeekEpoch( ( TTDate::getBeginYearEpoch( time() )-(86400*(7*6) ) ) );
 				} else {
 					$end_date = $end_date + ( (86400*14) );
 				}
