@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: PayStubCalculationTest.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 3628 $
+ * $Id: PayStubCalculationTest.php 3628 2010-05-28 00:36:37Z ipso $
+ * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -66,6 +66,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
     public function setUp() {
 		global $dd;
         Debug::text('Running setUp(): ', __FILE__, __LINE__, __METHOD__,10);
+		TTDate::setTimeZone('PST8PDT');
 
 		$dd = new DemoData();
 		$dd->setUserNamePostFix( rand(1000,99999) );
@@ -378,6 +379,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$ppsf->setTransactionDate( 7 );
 
 		$ppsf->setTransactionDateBusinessDay( TRUE );
+		$ppsf->setTimeZone('PST8PDT');
 
 /*
 		$ppsf->setPrimaryDate( ($anchor_date+(86400*14)) );
@@ -1004,7 +1006,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		return TRUE;
 	}
-
+/*
 	function testNoHoursPayStub() {
 		$pse_accounts = array(
 							'regular_time' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Regular Time'),
@@ -1075,5 +1077,6 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		return TRUE;
 	}
+*/
 }
 ?>
\ No newline at end of file
