@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: PayStubTest.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2490 $
+ * $Id: PayStubTest.php 2490 2009-04-24 22:13:40Z ipso $
+ * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -54,7 +67,7 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
         Debug::text('Running setUp(): ', __FILE__, __LINE__, __METHOD__,10);
 
 		$dd = new DemoData();
-		$dd->setUserNamePostFix( rand(1000,9999) );
+		$dd->setUserNamePostFix( rand(1000,99999) );
 		$this->company_id = $dd->createCompany();
 		Debug::text('Company ID: '. $this->company_id, __FILE__, __LINE__, __METHOD__,10);
 
@@ -62,6 +75,8 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 
 		$dd->createPermissionGroups( $this->company_id );
 
+		$dd->createUserWageGroups( $this->company_id );
+
 		$this->user_id = $dd->createUser( $this->company_id, 100 );
 
 		$dd->createPayStubAccount( $this->company_id );
@@ -73,7 +88,6 @@ class PayStubTest extends PHPUnit_Framework_TestCase {
 		$this->createPayPeriods();
 		$this->getAllPayPeriods();
 
-
         return TRUE;
     }
 
