@@ -186,7 +186,7 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		$ppsf->setStartWeekDay( 0 );
 
 
-		$anchor_date = TTDate::getBeginWeekEpoch( TTDate::getBeginYearEpoch() ); //Start 6 weeks ago
+		$anchor_date = TTDate::getBeginWeekEpoch( ( TTDate::getBeginYearEpoch( time() )-(86400*(7*6) ) ) ); //Start 6 weeks ago
 
 		$ppsf->setAnchorDate( $anchor_date );
 
@@ -231,7 +231,7 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 			for ( $i = 0; $i < $max_pay_periods; $i++ ) {
 				if ( $i == 0 ) {
 					//$end_date = TTDate::getBeginYearEpoch( strtotime('01-Jan-07') );
-					$end_date = TTDate::getBeginYearEpoch( time() );
+					$end_date = TTDate::getBeginWeekEpoch( ( TTDate::getBeginYearEpoch( time() )-(86400*(7*6) ) ) );
 				} else {
 					$end_date = $end_date + ( (86400*14) );
 				}
@@ -640,6 +640,78 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		return TRUE;
 	}
 
+	//Special test to fix a bug when there is a 2hr gap between punches, but a new shift is only triggered after 4hrs.
+	function testDayShiftStartsBasicF() {
+		global $dd;
+
+		$this->createPayPeriodSchedule( 10 );
+		$this->createPayPeriods();
+		$this->getAllPayPeriods();
+
+		$date_epoch = TTDate::getBeginWeekEpoch( time() );
+		$date_stamp = TTDate::getDate('DATE', $date_epoch );
+
+		$dd->createPunchPair( 	$this->user_id,
+								strtotime($date_stamp.' 10:00AM'),
+								strtotime($date_stamp.' 2:00PM'),
+								array(
+											'in_type_id' => 10,
+											'out_type_id' => 10,
+											'branch_id' => 0,
+											'department_id' => 0,
+											'job_id' => 0,
+											'job_item_id' => 0,
+										),
+								TRUE
+								);
+
+		$dd->createPunchPair( 	$this->user_id,
+								strtotime($date_stamp.' 4:00PM'),
+								strtotime($date_stamp.' 8:00PM'),
+								array(
+											'in_type_id' => 10,
+											'out_type_id' => 10,
+											'branch_id' => 0,
+											'department_id' => 0,
+											'job_id' => 0,
+											'job_item_id' => 0,
+										),
+								TRUE
+								);
+
+		$dd->createPunchPair( 	$this->user_id,
+								strtotime($date_stamp.' 8:00PM'),
+								strtotime($date_stamp.' 9:00PM'),
+								array(
+											'in_type_id' => 10,
+											'out_type_id' => 10,
+											'branch_id' => 0,
+											'department_id' => 0,
+											'job_id' => 0,
+											'job_item_id' => 0,
+										),
+								TRUE
+								);
+
+		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch) );
+		//print_r($punch_arr);
+		$this->assertEquals( 3, count($punch_arr[$date_epoch]) );
+		$this->assertEquals( $date_epoch, $punch_arr[$date_epoch][0]['date_stamp'] );
+		$this->assertEquals( $date_epoch, $punch_arr[$date_epoch][1]['date_stamp'] );
+		$this->assertEquals( $date_epoch, $punch_arr[$date_epoch][2]['date_stamp'] );
+
+		$this->assertEquals( $punch_arr[$date_epoch][0]['shift_data']['punches'][0]['punch_control_id'], $punch_arr[$date_epoch][1]['shift_data']['punches'][0]['punch_control_id'] ); //Make sure punch_control_id from both shifts DO match.
+		$this->assertEquals( $punch_arr[$date_epoch][1]['shift_data']['punches'][0]['punch_control_id'], $punch_arr[$date_epoch][2]['shift_data']['punches'][0]['punch_control_id'] ); //Make sure punch_control_id from both shifts DO match.
+
+
+		$udt_arr = $this->getUserDateTotalArray( $date_epoch, $date_epoch );
+		//Total Time
+		$this->assertEquals( 10, $udt_arr[$date_epoch][0]['status_id'] );
+		$this->assertEquals( 10, $udt_arr[$date_epoch][0]['type_id'] );
+		$this->assertEquals( (9*3600), $udt_arr[$date_epoch][0]['total_time'] );
+
+		return TRUE;
+	}
 
 	//
 	//  Test when shifts are assigned to the day they end on.
@@ -711,7 +783,8 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 								);
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
-		//print_r($punch_arr);
+
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
 		$this->assertEquals( 1, count($punch_arr[$date_epoch2]) );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][0]['date_stamp'] );
 
@@ -768,6 +841,8 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		$this->assertEquals( 2, count($punch_arr[$date_epoch2]) );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][0]['date_stamp'] );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][1]['date_stamp'] );
@@ -897,6 +972,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
+
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
 		$this->assertEquals( 1, count($punch_arr[$date_epoch2]) );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][0]['date_stamp'] );
 
@@ -966,6 +1044,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		$this->assertEquals( 2, count($punch_arr[$date_epoch2]) );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][0]['date_stamp'] );
 
@@ -1160,6 +1241,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch) );
 		//print_r($punch_arr);
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		$this->assertEquals( 2, count($punch_arr[$date_epoch][0]['shift_data']['punches']) );
 		$this->assertEquals( 1, count($punch_arr[$date_epoch][0]['shift_data']['punch_control_ids']) );
 		//$this->assertEquals( $date_epoch, $punch_arr[$date_epoch][0]['date_stamp'] );
@@ -1168,12 +1252,15 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		//Total Time
 		$this->assertEquals( 10, $udt_arr[$date_epoch][0]['status_id'] );
 		$this->assertEquals( 10, $udt_arr[$date_epoch][0]['type_id'] );
-		$this->assertEquals( (15.5*3600), $udt_arr[$date_epoch][0]['total_time'] );
+		if ( TTDate::doesRangeSpanDST( $date_epoch, $date_epoch2 ) ) {
+			$this->assertEquals( (14.5*3600), $udt_arr[$date_epoch][0]['total_time'] ); //If this is the week of the DST switchover, this can be off by one hour.
+		} else {
+			$this->assertEquals( (15.5*3600), $udt_arr[$date_epoch][0]['total_time'] ); //If this is the week of the DST switchover, this can be off by one hour.
+		}
 
 		return TRUE;
 	}
 
-
 	function testPunchControlMatchingD() {
 		global $dd;
 
@@ -1199,10 +1286,10 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 								TRUE
 								);
 
-		//Just create out punch, 16.5hrs later. Threshold is 16hrs.
+		//Just create out punch, 17.5hrs later. Threshold is 16hrs. //This needs to be more than 1 hour outside the limit due to DST issues.
 		$dd->createPunchPair( 	$this->user_id,
 								NULL,
-								strtotime($date_stamp.' 6:30PM'), //Normal Out
+								strtotime($date_stamp.' 7:30PM'), //Normal Out
 								array(
 											'in_type_id' => 10,
 											'out_type_id' => 10,
@@ -1215,7 +1302,8 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 								);
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch) );
-		//print_r($punch_arr);
+
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
 		$this->assertEquals( 1, count($punch_arr[$date_epoch][0]['shift_data']['punches']) );
 		$this->assertEquals( 1, count($punch_arr[$date_epoch][0]['shift_data']['punch_control_ids']) );
 
@@ -1433,6 +1521,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
 
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		//Make sure previous day has no totals, but new day has proper totals.
 		if ( !isset($punch_arr[$date_epoch]) ) {
 			$this->assertTrue( TRUE );
@@ -1503,6 +1594,8 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
 		$this->assertEquals( 2, count($punch_arr[$date_epoch2][0]['shift_data']['punches']) );
 		$this->assertEquals( 1, count($punch_arr[$date_epoch2][0]['shift_data']['punch_control_ids']) );
 		$this->assertEquals( $date_epoch2, $punch_arr[$date_epoch2][0]['date_stamp'] );
@@ -1611,6 +1704,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
 
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		//Make sure previous day has no totals, but new day has proper totals.
 		if ( !isset($punch_arr[$date_epoch]) ) {
 			$this->assertTrue( TRUE );
@@ -1802,6 +1898,9 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 		$punch_arr = $this->getPunchDataArray( TTDate::getBeginDayEpoch($date_epoch), TTDate::getEndDayEpoch($date_epoch2) );
 		//print_r($punch_arr);
 
+		$date_epoch = TTDate::getBeginDayEpoch($date_epoch); //This accounts for DST.
+		$date_epoch2 = TTDate::getBeginDayEpoch($date_epoch2); //This accounts for DST.
+
 		$this->assertEquals( 3, count($punch_arr[$date_epoch][0]['shift_data']['punches']) );
 		$this->assertEquals( 2, count($punch_arr[$date_epoch][0]['shift_data']['punch_control_ids']) );
 		$this->assertEquals( $date_epoch, $punch_arr[$date_epoch][0]['date_stamp'] );
@@ -2600,6 +2699,5 @@ class PunchTest extends PHPUnit_Framework_TestCase {
 
 		return TRUE;
 	}
-
 }
 ?>
\ No newline at end of file
