@@ -370,82 +370,6 @@ class USPayrollDeductionTest2007 extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( $this->mf( $pd_obj->getStatePayPeriodDeductions() ), '175.00' ); //175.00
 	}
 
-	//
-	// UT
-	//
-	function testUT_2007a_BiWeekly_Single_LowIncome() {
-		Debug::text('US - BiWeekly - Beginning of 2007 01-Jan-07: ', __FILE__, __LINE__, __METHOD__,10);
-
-		$pd_obj = new PayrollDeduction('US','UT');
-		$pd_obj->setDate(strtotime('01-Jan-07'));
-		$pd_obj->setAnnualPayPeriods( 26 ); //Bi-Weekly
-
-		$pd_obj->setFederalFilingStatus( 10 ); //Single
-		$pd_obj->setFederalAllowance( 1 );
-
-		$pd_obj->setStateFilingStatus( 10 ); //Single
-		$pd_obj->setStateAllowance( 0 );
-
-		$pd_obj->setFederalTaxExempt( FALSE );
-		$pd_obj->setProvincialTaxExempt( FALSE );
-
-		$pd_obj->setGrossPayPeriodIncome( 1000.00 );
-
-		//var_dump($pd_obj->getArray());
-
-		$this->assertEquals( $this->mf( $pd_obj->getGrossPayPeriodIncome() ), '1000.00' );
-		$this->assertEquals( $this->mf( $pd_obj->getFederalPayPeriodDeductions() ), '100.73' ); //100.73
-		$this->assertEquals( $this->mf( $pd_obj->getStatePayPeriodDeductions() ), '53.48' ); //53.46
-	}
-
-	function testUT_2007a_BiWeekly_Married_LowIncome() {
-		Debug::text('US - BiWeekly - Beginning of 2007 01-Jan-07: ', __FILE__, __LINE__, __METHOD__,10);
-
-		$pd_obj = new PayrollDeduction('US','UT');
-		$pd_obj->setDate(strtotime('01-Jan-07'));
-		$pd_obj->setAnnualPayPeriods( 26 ); //Bi-Weekly
-
-		$pd_obj->setFederalFilingStatus( 10 ); //Single
-		$pd_obj->setFederalAllowance( 1 );
-
-		$pd_obj->setStateFilingStatus( 20 ); //Married
-		$pd_obj->setStateAllowance( 1 );
-
-		$pd_obj->setFederalTaxExempt( FALSE );
-		$pd_obj->setProvincialTaxExempt( FALSE );
-
-		$pd_obj->setGrossPayPeriodIncome( 1000.00 );
-
-		$this->assertEquals( $this->mf( $pd_obj->getGrossPayPeriodIncome() ), '1000.00' );
-		$this->assertEquals( $this->mf( $pd_obj->getFederalPayPeriodDeductions() ), '100.73' ); //100.73
-		$this->assertEquals( $this->mf( $pd_obj->getStatePayPeriodDeductions() ), '43.40' ); //43.40
-	}
-
-	function testUT_2007a_SemiMonthly_Married_HighIncome_8Allowances() {
-		Debug::text('US - SemiMonthly - Beginning of 2007 01-Jan-07: ', __FILE__, __LINE__, __METHOD__,10);
-
-		$pd_obj = new PayrollDeduction('US','UT');
-		$pd_obj->setDate(strtotime('01-Jan-07'));
-		$pd_obj->setAnnualPayPeriods( 24 ); //Semi-Monthly
-
-		$pd_obj->setFederalFilingStatus( 10 ); //Single
-		$pd_obj->setFederalAllowance( 1 );
-
-		$pd_obj->setStateFilingStatus( 20 ); //Married
-		$pd_obj->setStateAllowance( 8 );
-
-		$pd_obj->setFederalTaxExempt( FALSE );
-		$pd_obj->setProvincialTaxExempt( FALSE );
-
-		$pd_obj->setGrossPayPeriodIncome( 4000.00 );
-
-		//var_dump($pd_obj->getArray());
-
-		$this->assertEquals( $this->mf( $pd_obj->getGrossPayPeriodIncome() ), '4000.00' );
-		$this->assertEquals( $this->mf( $pd_obj->getFederalPayPeriodDeductions() ), '812.20' ); //812.20
-		$this->assertEquals( $this->mf( $pd_obj->getStatePayPeriodDeductions() ), '197.93' ); //197.93
-	}
-
 	//
 	// NM
 	//
